within DCOL.Consumption.Fluid.HeatExchangers.Examples;
model WetCoil
  import DCOL;
  import Modelica_IK4_TEKNIKER;
  package Medium1 = Media.Water                  "Medium model for water";
  package Medium2 = Media.Air                  "Medium model for air";
  parameter Modelica.SIunits.Temperature T_a1_nominal=6 + 273.15
    "Nominal water inlet temperature";
  parameter Modelica.SIunits.Temperature T_b1_nominal=12 + 273.15
    "Nominal water outlet temperature";
  parameter Modelica.SIunits.Temperature T_a2_nominal=25 + 273.15
    "Nominal air inlet temperature";
  parameter Modelica.SIunits.Temperature T_b2_nominal=13.8 + 273.15
    "Nominal air outlet temperature";
  parameter Modelica.SIunits.HeatFlowRate Q_flow_nominal=m1_flow_nominal*4200*(
      T_a1_nominal - T_b1_nominal) "Nominal heat transfer";
  parameter Modelica.SIunits.MassFlowRate m1_flow_nominal=0.97
    "Nominal mass flow rate medium 1";
  parameter Modelica.SIunits.MassFlowRate m2_flow_nominal=1.647
    "Nominal mass flow rate medium 2";

  extends Modelica.Icons.Example;
  //   extends
  //     Buildings.Fluid.HeatExchangers.Examples.BaseClasses.EffectivenessNTUMassFlow
  //     (
  //     sou_1(nPorts=1),
  //     sin_2(nPorts=1),
  //     sou_2(nPorts=1),
  //     mAirGai(table=[0, 1; 3600*0.5, 1; 3600*0.6, 1; 3600*0.7, 1; 3600*1, 1]),
  //     mWatGai(table=[0, 1; 3600*0.5, 1; 3600*0.6, 1; 3600*0.7, 1; 3600*1, 1]),
  //     sin_1(nPorts=1),
  //     relHum(k=0.5));
  //   //mAirGai(table=[0, 1; 3600*0.5, 1; 3600*0.6, 0.1; 3600*0.7, 0.1; 3600*1, 0.1]),

  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.HeatExchangers.WetCoil wetCoil(
    redeclare package Medium1 = Medium2,
    redeclare package Medium2 = Medium1,
    m1_flow_nominal=m2_flow_nominal,
    m2_flow_nominal=m1_flow_nominal,
    dp1_nominal=200,
    dp2_nominal=3000,
    allowFlowReversal1=false,
    allowFlowReversal2=false,
    Ti0_a=T_a2_nominal + Modelica.Constants.T_zero,
    To0_a=T_b2_nominal + Modelica.Constants.T_zero,
    Ti0_w=T_a1_nominal + Modelica.Constants.T_zero,
    To0_w=T_b1_nominal + Modelica.Constants.T_zero,
    config=Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Types.HXConfiguration.CrossFlow,
    RHi0=0.7,
    RHo0=1.0) annotation (Placement(transformation(extent={{92,52},{72,32}})));

  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sensors.RelativeHumidityTwoPort
    senRelHum(
    m_flow_nominal=m2_flow_nominal,
    redeclare package Medium = Medium2,
    allowFlowReversal=false)
    annotation (Placement(transformation(extent={{48,10},{28,30}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sensors.TemperatureTwoPort
    senTem_air(m_flow_nominal=m2_flow_nominal, redeclare package Medium =
        Medium2)
    annotation (Placement(transformation(extent={{72,12},{52,32}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sensors.TemperatureTwoPort
    senTem_water(m_flow_nominal=m2_flow_nominal, redeclare package Medium =
        Medium1)
    annotation (Placement(transformation(extent={{90,54},{110,74}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sources.MassFlowSource_T sin_2(
    redeclare package Medium = Medium2,
    T=T_a2_nominal,
    use_m_flow_in=true,
    nPorts=1) "Sink for air"
    annotation (Placement(transformation(extent={{-18,10},{2,30}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sources.Boundary_pT sou_2(
    redeclare package Medium = Medium2,
    T=T_a2_nominal,
    X={0.02,1 - 0.02},
    use_T_in=true,
    use_X_in=true,
    nPorts=1) "Source for air"
    annotation (Placement(transformation(extent={{140,14},{120,34}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sources.MassFlowSource_T sin_1(
    redeclare package Medium = Medium1,
    T=T_a1_nominal,
    use_m_flow_in=true,
    nPorts=1) "Sink for water"
    annotation (Placement(transformation(extent={{142,50},{122,70}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sources.FixedBoundary sou_1(
    redeclare package Medium = Medium1,
    T=T_a1_nominal,
    nPorts=1) "Source for water"
    annotation (Placement(transformation(extent={{0,52},{20,72}})));
  Modelica.Blocks.Sources.Constant relHum(k=wetCoil.RHi0) "Relative humidity"
    annotation (Placement(transformation(extent={{102,-74},{122,-54}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Utilities.Psychrometrics.X_pTphi
    x_pTphi(use_p_in=false)
    annotation (Placement(transformation(extent={{152,-42},{172,-22}})));
  Modelica.Blocks.Sources.Constant temSou_2(k=1)
    "Temperature boundary condition"
    annotation (Placement(transformation(extent={{-90,60},{-70,80}})));
  Modelica.Blocks.Math.Gain mWat_flow(k=-m1_flow_nominal)
    "Water mass flow rate"
    annotation (Placement(transformation(extent={{-40,100},{-20,120}})));

  //mWatGai(table=[0, 1; 3600*0.1, 1; 3600*0.2,0.01; 3600*0.3, 0.01])
  Modelica.Blocks.Sources.Sine mAirGai(
    freqHz=1/3600,
    amplitude=0.5,
    offset=0.5) "Gain for air mass flow rate"
    annotation (Placement(transformation(extent={{-98,18},{-78,38}})));
  //mAirGai(table=[0, 1; 3600*0.5, 1; 3600*0.6,-1; 3600*0.7, 0; 3600*1, 0])

  Modelica.Blocks.Math.Gain mAir_flow(k=-m2_flow_nominal) "Air mass flow rate"
    annotation (Placement(transformation(extent={{-58,18},{-38,38}})));
  Modelica_IK4_TEKNIKER.DCOL.Consumption.Fluid.Sensors.MassFractionTwoPort
    senMassFraction_air(
    m_flow_nominal=m2_flow_nominal,
    redeclare package Medium = Medium2,
    allowFlowReversal=false)
    annotation (Placement(transformation(extent={{28,-4},{8,16}})));
  Modelica.Blocks.Sources.Step step(
    offset=T_a2_nominal,
    startTime=1000,
    height=0)
    annotation (Placement(transformation(extent={{86,-42},{106,-22}})));
  Modelica.Blocks.Sources.Sine mAirGai1(
    amplitude=0.5,
    offset=0.5,
    freqHz=1/(2*3600)) "Gain for air mass flow rate"
    annotation (Placement(transformation(extent={{-92,100},{-72,120}})));
equation
  connect(senRelHum.port_a, senTem_air.port_b)
    annotation (Line(points={{48,20},{52,20},{52,22}}, color={0,127,255}));
  connect(wetCoil.port_b2, senTem_water.port_a) annotation (Line(points={{92,48},
          {92,48},{92,64},{90,64}}, color={0,127,255}));
  connect(x_pTphi.X, sou_2.X_in) annotation (Line(
      points={{173,-32},{180,-32},{180,-34},{188,-34},{188,20},{142,20}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(mWat_flow.y, sin_1.m_flow_in) annotation (Line(
      points={{-19,110},{162,110},{162,68},{142,68}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(mAir_flow.y, sin_2.m_flow_in) annotation (Line(
      points={{-37,28},{-18,28}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sou_2.ports[1], wetCoil.port_a1) annotation (Line(points={{120,24},{
          110,24},{110,36},{92,36}}, color={0,127,255}));
  connect(sou_1.ports[1], wetCoil.port_a2) annotation (Line(points={{20,62},{48,
          62},{48,48},{72,48}}, color={0,127,255}));
  connect(senTem_air.port_a, wetCoil.port_b1)
    annotation (Line(points={{72,22},{72,22},{72,36}}, color={0,127,255}));
  connect(sin_1.ports[1], senTem_water.port_b) annotation (Line(points={{122,60},
          {118,60},{118,64},{110,64}}, color={0,127,255}));
  connect(x_pTphi.phi, relHum.y) annotation (Line(points={{150,-38},{136,-38},{
          136,-64},{123,-64}}, color={0,0,127}));
  connect(sin_2.ports[1], senMassFraction_air.port_b)
    annotation (Line(points={{2,20},{6,20},{6,6},{8,6}}, color={0,127,255}));
  connect(senRelHum.port_b, senMassFraction_air.port_a)
    annotation (Line(points={{28,20},{28,20},{28,6}}, color={0,127,255}));
  connect(step.y, x_pTphi.T)
    annotation (Line(points={{107,-32},{128,-32},{150,-32}}, color={0,0,127}));
  connect(step.y, sou_2.T_in) annotation (Line(points={{107,-32},{126,-32},{126,
          28},{142,28}}, color={0,0,127}));
  connect(temSou_2.y, mWat_flow.u) annotation (Line(points={{-69,70},{-69,90},{
          -42,90},{-42,110}}, color={0,0,127}));
  connect(temSou_2.y, mAir_flow.u) annotation (Line(points={{-69,70},{-69,50},{
          -60,50},{-60,28}}, color={0,0,127}));
  annotation (
    Diagram(coordinateSystem(extent={{-100,-80},{200,140}}, preserveAspectRatio=
           false)),
    Icon(coordinateSystem(extent={{-100,-80},{200,140}})),
    experiment(StopTime=3600),
    __Dymola_experimentSetupOutput);
end WetCoil;
