within DCOL.Consumption.Fluid.HeatExchangers.InProgress;
model Coil

  fullWetCoil wetCoil(
    redeclare package Medium1 = Medium1,
    redeclare package Medium2 = Medium2,
    m1_flow_nominal=m1_flow_nominal,
    m2_flow_nominal=m2_flow_nominal,
    allowFlowReversal1=false,
    allowFlowReversal2=false,
    config=Types.HXConfiguration.CrossFlow,
    Ti0_a=T_a2_nominal + Modelica.Constants.T_zero,
    To0_a=T_b2_nominal + Modelica.Constants.T_zero,
    Ti0_w=T_a1_nominal + Modelica.Constants.T_zero,
    To0_w=T_b1_nominal + Modelica.Constants.T_zero,
    dp1_nominal=1,
    dp2_nominal=1,
    RHo0=RHo0,
    RHi0=RHi0) annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=180,
        origin={108,22})));
  fullDryCoil dryCoil(
    redeclare package Medium1 = Medium2,
    redeclare package Medium2 = Medium1,
    m1_flow_nominal=m2_flow_nominal,
    m2_flow_nominal=m1_flow_nominal,
    dp1_nominal=200,
    dp2_nominal=3000,
    allowFlowReversal1=false,
    allowFlowReversal2=false,
    Ti0_a=T_a2_nominal + Modelica.Constants.T_zero,
    To0_a=T_b2_nominal + Modelica.Constants.T_zero,
    Ti0_w=T_a1_nominal + Modelica.Constants.T_zero,
    To0_w=T_b1_nominal + Modelica.Constants.T_zero,
    config=Types.HXConfiguration.CrossFlow,
    RHi0=RHi0,
    RHo0=RHo0)
    annotation (Placement(transformation(extent={{168,32},{148,12}})));
  Modelica.Blocks.Sources.RealExpression realExpression(y=(-Tdp.y +
        Modelica.SIunits.Conversions.to_degC(senTem_water_out.T))/max((
        senTem_water_out.T - senTem_water_in.T), 0.001))
    annotation (Placement(transformation(extent={{104,-22},{124,-2}})));
  Modelica.Blocks.Nonlinear.Limiter fraction(uMax=1, uMin=0)
    annotation (Placement(transformation(extent={{138,-16},{148,-6}})));
  Modelica.Blocks.Sources.RealExpression wetCoilFra(y=1 - fraction.y)
    annotation (Placement(transformation(extent={{122,34},{102,54}})));
  Sensors.TemperatureTwoPort senTem_water_mid(m_flow_nominal=m2_flow_nominal, redeclare package Medium = Medium1) annotation (Placement(transformation(extent={{144,58},{124,78}})));
  Sensors.TemperatureTwoPort senTem_air_mid(m_flow_nominal=m2_flow_nominal, redeclare package Medium = Medium2) annotation (Placement(transformation(extent={{144,26},{124,6}})));
  replaceable package Medium1 = Media.Water
    "Medium model for water";
  replaceable package Medium2 = Media.Air
    "Medium model for air";
  parameter Modelica.SIunits.Temperature T_a1_nominal=6 + 273.15
    "Nominal water inlet temperature";
  parameter Modelica.SIunits.Temperature T_b1_nominal=12 + 273.15
    "Nominal water outlet temperature";
  parameter Modelica.SIunits.Temperature T_a2_nominal=25 + 273.15
    "Nominal air inlet temperature";
  parameter Modelica.SIunits.Temperature T_b2_nominal=13.8 + 273.15
    "Nominal air outlet temperature";
  parameter Modelica.SIunits.MassFlowRate m1_flow_nominal=0.97
    "Nominal mass flow rate medium 1";
  parameter Modelica.SIunits.MassFlowRate m2_flow_nominal=1.647
    "Nominal mass flow rate medium 2";
  Modelica.Fluid.Interfaces.FluidPort_a port_a1(redeclare final package Medium =
        Medium2) annotation (Placement(transformation(rotation=0, extent={{240,
            -40},{260,-20}}), iconTransformation(extent={{240,-40},{260,-20}})));
  Modelica.Fluid.Interfaces.FluidPort_a port_a2(redeclare final package Medium =
        Medium1) annotation (Placement(transformation(rotation=0, extent={{20,
            100},{40,120}}), iconTransformation(extent={{20,100},{40,120}})));
  Modelica.Fluid.Interfaces.FluidPort_b port_b2(redeclare final package Medium =
        Medium1) annotation (Placement(transformation(rotation=0, extent={{240,
            100},{260,120}}), iconTransformation(extent={{240,100},{260,120}})));
  Modelica.Fluid.Interfaces.FluidPort_b port_b1(redeclare final package Medium =
        Medium2) annotation (Placement(transformation(rotation=0, extent={{22,-40},
            {42,-20}}), iconTransformation(extent={{22,-40},{42,-20}})));
  Modelica.Blocks.Sources.RealExpression Tdp(y=(senRelHum_in.phi)^(1/8)*(
        Modelica.SIunits.Conversions.to_degC(senTem_air_in.T) + 110) - 110)
    annotation (Placement(transformation(extent={{104,-40},{124,-20}})));
  Sensors.RelativeHumidityTwoPort senRelHum_in(
    m_flow_nominal=m2_flow_nominal,
    redeclare package Medium = Medium2,
    allowFlowReversal=false) annotation (Placement(transformation(extent={{214,-16},{194,4}})));
  parameter Real RHi0 "relative humidity input nominal, port a1 (air)";
  parameter Real RHo0 "relative humidity output nominal, port b1 (air)";
  Sensors.TemperatureTwoPort senTem_air_in(m_flow_nominal=m2_flow_nominal, redeclare package Medium = Medium2) annotation (Placement(transformation(extent={{240,-20},{220,0}})));
  Sensors.TemperatureTwoPort senTem_water_in(m_flow_nominal=m2_flow_nominal, redeclare package Medium = Medium1) annotation (Placement(transformation(extent={{58,100},{78,120}})));
  Sensors.TemperatureTwoPort senTem_water_out(m_flow_nominal=m2_flow_nominal, redeclare package Medium = Medium1) annotation (Placement(transformation(extent={{192,100},{212,120}})));
equation
  connect(realExpression.y, fraction.u) annotation (Line(points={{125,-12},{126,
          -12},{126,-11},{137,-11}},color={0,0,127}));
  connect(fraction.y, dryCoil.fractionUse) annotation (Line(points={{148.5,-11},
          {148.5,-2.5},{170,-2.5},{170,12}}, color={0,0,127}));
  connect(wetCoil.fractionUse, wetCoilFra.y) annotation (Line(points={{96,32},{
          96,32},{96,44},{101,44}}, color={0,0,127}));
  connect(dryCoil.port_b2, senTem_water_mid.port_a) annotation (Line(points={{
          168,28},{174,28},{174,68},{144,68}}, color={0,127,255}));
  connect(senTem_water_mid.port_b, wetCoil.port_a1) annotation (Line(points={{
          124,68},{90,68},{90,28},{98,28}}, color={0,127,255}));
  connect(wetCoil.port_a2, senTem_air_mid.port_b)
    annotation (Line(points={{118,16},{124,16}}, color={0,127,255}));
  connect(dryCoil.port_b1, senTem_air_mid.port_a)
    annotation (Line(points={{148,16},{144,16}}, color={0,127,255}));
  connect(port_b1, wetCoil.port_b2)
    annotation (Line(points={{32,-30},{98,-30},{98,16}}, color={0,127,255}));
  connect(senRelHum_in.port_b, dryCoil.port_a1) annotation (Line(points={{194,-6},
          {182,-6},{182,16},{168,16}}, color={0,127,255}));
  connect(senRelHum_in.port_a, senTem_air_in.port_b) annotation (Line(points={{
          214,-6},{218,-6},{218,-10},{220,-10}}, color={0,127,255}));
  connect(port_a1, senTem_air_in.port_a) annotation (Line(points={{250,-30},{
          246,-30},{246,-10},{240,-10}}, color={0,127,255}));
  connect(senTem_water_in.port_a, port_a2)
    annotation (Line(points={{58,110},{30,110},{30,110}}, color={0,127,255}));
  connect(senTem_water_in.port_b, dryCoil.port_a2)
    annotation (Line(points={{78,110},{148,110},{148,28}}, color={0,127,255}));
  connect(port_b2, senTem_water_out.port_b) annotation (Line(points={{250,110},
          {230,110},{212,110}}, color={0,127,255}));
  connect(senTem_water_out.port_a, wetCoil.port_b1) annotation (Line(points={{
          192,110},{124,110},{124,28},{118,28}}, color={0,127,255}));
  annotation (Diagram(coordinateSystem(extent={{40,-60},{240,140}})), Icon(
        coordinateSystem(extent={{40,-60},{240,140}}, initialScale=0.1),
        graphics={
        Rectangle(
          extent={{60,120},{220,-40}},
          lineColor={95,95,95},
          fillColor={95,95,95},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{36,114},{246,106}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{32,-26},{242,-34}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid)}));
end Coil;
