within DCOL.Consumption.Fluid.HeatExchangers.InProgress;
model WetCoil_new
  "Cooling and Dehumidifying coil, water in path a2-b2, air in path a1-b1"
  extends BaseClasses.PartialEffectiveness(
    redeclare replaceable package Medium1 =
        Modelica.Media.Interfaces.PartialCondensingGases,
    sensibleOnly1=false,
    sensibleOnly2=true,
    Q1_flow=-Q_flow,
    Q2_flow=Q_flow,
    mWat1_flow=mWat_flow,
    mWat2_flow=0,
    final prescribedHeatFlowRate1=true,
    final prescribedHeatFlowRate2=true);

  parameter Types.HXConfiguration config "heat exchanger configuration";
  //parameter Modelica.SIunits.Mass m_c "mass capacity of coil";
  parameter Modelica.SIunits.Temp_C Ti0_a
    "temperature input nominal, port a1 (air)"
    annotation (Dialog(tab="General", group="Nominal condition"));
  parameter Real RHi0 "relative humidity input nominal, port a1 (air)"
    annotation (Dialog(tab="General", group="Nominal condition"));
  parameter Modelica.SIunits.Temp_C To0_a
    "temperature output nominal, port b1 (air)"
    annotation (Dialog(tab="General", group="Nominal condition"));
  parameter Real RHo0 "relative humidity output nominal, port b1 (air)"
    annotation (Dialog(tab="General", group="Nominal condition"));
  parameter Modelica.SIunits.Temp_C Ti0_w
    "temperature input nominal, port a2 (water)"
    annotation (Dialog(tab="General", group="Nominal condition"));
  parameter Modelica.SIunits.Temp_C To0_w
    "temperature output nominal, port b2 (water)"
    annotation (Dialog(tab="General", group="Nominal condition"));
  parameter Real m=0.6
    "Constant defining system characteristics, normally set to 0.6";

protected
  final parameter Modelica.SIunits.MassFraction Wi0=
      Psychrometrics.Functions.RHtoW(
      p=Medium1.p_default,
      RH=RHi0,
      T=Ti0_a);
  final parameter Modelica.SIunits.MassFraction Wo0=
      Psychrometrics.Functions.RHtoW(
      p=Medium1.p_default,
      RH=RHo0,
      T=To0_a);

  final parameter Modelica.SIunits.Temp_C Ti0_wb(fixed=false);
  //wet buld temperature input nominal, air
  final parameter Modelica.SIunits.Temp_C To0_wb(fixed=false);
  //wet buld temperature output nominal, air
  final parameter Modelica.SIunits.SpecificEnthalpy hi_a0=
      Psychrometrics.Functions.h(                 Tdb=Ti0_a, W=Wi0);
  //enthalpy input nomina, air
  final parameter Modelica.SIunits.SpecificEnthalpy ho_a0=
      Psychrometrics.Functions.h(                 Tdb=To0_a, W=Wo0);

  final parameter Medium1.ThermodynamicState sta1_default=Medium1.setState_pTX(
      T=Ti0_a,
      p=Medium1.p_default,
      X={Wi0/(1 + Wi0),1 - Wi0/(1 + Wi0)})
    "Default state for medium 1 (only for wet air)";
  //
  final parameter Medium2.ThermodynamicState sta2_default=Medium2.setState_pTX(
      T=To0_a,
      p=Medium2.p_default,
      X=Medium2.X_default[1:Medium2.nXi]) "Default state for medium 2";
  parameter Integer i1_w(min=1, fixed=false) "Index for water substance";

  Medium1.MassFraction X_w_in1 "Inlet water mass fraction of medium 1";

  parameter Real r(start=0.75, fixed=true);
  //ratio of convection heat transfer
  parameter Modelica.SIunits.ThermalResistance Rerror(start=1e-4);
  //error due to calculate R and R_wet
  parameter Modelica.SIunits.ThermalResistance R0(start=1e-4, fixed=false);
  //overall coefficient of heat transfer nominal
  parameter Modelica.SIunits.ThermalResistance R0_a(fixed=false);
  //overall coefficient of heat transfer nominal, air
  parameter Modelica.SIunits.MassFlowRate mflow0_a=m1_flow_nominal
    "mass flow nominal, air";
  parameter Modelica.SIunits.MassFlowRate mflow0_w=m2_flow_nominal
    "mass flow nominal, water";

  //   parameter Real Le=1 "Lewis number (around 1 for water vapor in air)";
  //   parameter Real n=1/3 "Exponent in bondary layer ratio, delta/delta_t = Pr^n";

  final parameter Modelica.SIunits.ThermalConductance UA_nominal(fixed=false);

  final parameter Real NTU_nominal(fixed=false);

  Real b;

  Modelica.SIunits.HeatFlowRate Q_flow;
  Modelica.SIunits.MassFlowRate mWat_flow;

  Modelica.SIunits.MassFlowRate mflow_a;
  //mass flow, air
  Modelica.SIunits.Temp_C Ti_db;
  //temperature input, dry bulb air
  //Modelica.SIunits.Temp_C To_db;
  //temperature input, dry bulb air
  Modelica.SIunits.Temp_C Ti_wb(start=Ti0_a - 5);
  //temperature input, wet bulb air
  //   Modelica.SIunits.MassFraction Wo;
  //   //humidity ratio, output

  Modelica.SIunits.MassFlowRate mflow_w;
  //mass flow, water
  Modelica.SIunits.Temp_C Ti_w;
  //temperature input, water
  //Modelica.SIunits.Temp_C To_w;
  //temperature output, water
  Modelica.SIunits.ThermalConductance Cflow_w;
  //heat flow capacity, water

  //########################################################### DRY REGIME ###########################################################
  //=========================================================== Coil ===============================================================
  Modelica.SIunits.HeatFlowRate Qflow_dry;
  //heat flow rate, dry regime
  Modelica.SIunits.ThermalConductance Cflow_a;
  //heat flow capacity, air
  //Modelica.SIunits.Temp_C To_db_dry;
  //temperature output, air in the dry regime
  //Modelica.SIunits.Temp_C To_w_dry;
  //temperature output, water in the dry regime
  Real eff_dry;
  //effectiveness, dry regime
  Real NTU_dry(start=1.0);
  //number of exchanger heat transfer units in the dry regime
  Real Z_dry;
  //dimensionless capacity rate ratio, dry regime
  Modelica.SIunits.ThermalResistance R(start=1.0);
  //thermal resistance
  Modelica.SIunits.ThermalResistance R_a;
  //thermal resistance, air

  //########################################################### WET REGIME ###########################################################
  //=========================================================== Coil ===============================================================
  Modelica.SIunits.HeatFlowRate Qflow_wet;
  //heat flow rate, wet regime
  Modelica.SIunits.ThermalConductance Cflow_a_wet;
  //heat flow capacity, air in the wet regime
  Modelica.SIunits.Temp_C To_db_wet;
  //temperature output, dry bulb air in the wet regime
  Modelica.SIunits.Temp_C To_wb_wet(start=To0_a - 5);
  //temperature output, wet bulb air in the wet regime
  //Modelica.SIunits.Temp_C To_w_wet;
  //temperature output, water in the wet regime
  Real eff_wet;
  //effectiveness, wet regime
  Real NTU_wet(start=1.0);
  //number of exchanger heat transfer units in the wet regime
  Real Z_wet;
  //dimensionless capacity rate ratio, wet regime
  Modelica.SIunits.ThermalResistance R_wet;
  //thermal resistance, wet regime
  Modelica.SIunits.ThermalResistance R_a_wet;
  //thermal resistance, air in the wet regime
  Modelica.SIunits.SpecificHeatCapacity cf_a;
  //fictitious specific heat capacity, air;
  //========================================================= Contact ==============================================================
  Modelica.SIunits.Temp_C Tc_wet(start=To0_w - 2);
  //temperature, contact in the wet regime
  Real effc_wet(start=0.5);
  //effectiveness, contact in the wet regime
  Real NTUc_wet(start=1.0);
  //number of exchanger heat transfer units, contact

  //######################################################### PSYCHROMETRICS #########################################################
  Modelica.SIunits.SpecificHeatCapacity c_a "specific heat capacity, air";
  Modelica.SIunits.SpecificHeatCapacity c_w "specific heat capacity, water";
  //=========================================================== Input ==================ss============================================
  Modelica.SIunits.SpecificEnthalpy hi_a;
  //enthalpy input, air;
  Modelica.SIunits.MassFraction Wi;
  //humidity ratio, input
  //=========================================================== Output =============================================================
  Modelica.SIunits.SpecificEnthalpy ho_a;
  //enthalpy output, air;
  Modelica.SIunits.MassFraction Wo_wet;
  //humidity ratio in the wet regime, output
  Modelica.SIunits.MassFraction Xo_wet;
  //Species content output of Medium 1
  //=========================================================== Contact =============================================================
  Modelica.SIunits.MassFraction Wc_wet;
  Real RHo_wet;

initial equation
  R0 = 1/UA_nominal;

  R0_a = 0.51*R0;
  //Annex_43_Simulation_of_HVAC_components_with_the_help_of_an_Equations_solver

  UA_nominal =Medium1.specificHeatCapacityCp(sta1_default)*m1_flow_nominal*(
    Ti0_a - To0_a)/Consumption.Fluid.HeatAndMassExchangers.BaseClases.lmtd(
    Ti0_a,
    To0_a,
    Ti0_w,
    Ti0_w);

  NTU_nominal = UA_nominal/min(mflow0_a*Medium1.specificHeatCapacityCp(
    sta1_default), mflow0_w*Medium2.specificHeatCapacityCp(sta2_default));

  Ti0_wb = Psychrometrics.Functions.Twb(
    Tdb=Ti0_a,
    W=Wi0,
    WAs=Psychrometrics.Functions.Ws(p=Medium1.pressure(state_a1_inflow), T=Ti0_wb));
  To0_wb = Psychrometrics.Functions.Twb(
    Tdb=To0_a,
    W=Wo0,
    WAs=Psychrometrics.Functions.Ws(p=Medium1.pressure(state_a1_inflow), T=To0_wb));

  cf_a = (hi_a0 - ho_a0)/(Ti0_wb - To0_wb);
initial algorithm
  i1_w := -1;
  for i in 1:Medium1.nXi loop
    if Modelica.Utilities.Strings.isEqual(
        string1=Medium1.substanceNames[i],
        string2="Water",
        caseSensitive=false) then
      i1_w := i;
    end if;
  end for;
  assert(i1_w > 0, "Substance 'water' is not present in Medium1 '" + Medium1.mediumName
     + "'.\n" + "Check medium model.");
equation
  //########################################################## CONNECTORS ############################################################
  //=========================================================== Input ==============================================================
  //*********************************************************** Air ***************************************************************
  Ti_db = Modelica.SIunits.Conversions.to_degC(T_in1);
  //X_w_in1 = port_a1.Xi_outflow[i1_w];
  X_w_in1 = Modelica.Fluid.Utilities.regStep(
    mflow_a,
    state_a1_inflow.X[i1_w],
    state_b1_inflow.X[i1_w],
    m1_flow_small);
  Wi = X_w_in1/(1 - X_w_in1);
  mflow_a = max(abs(m1_flow), 1e-3);
  //********************************************************** Water **************************************************************
  Ti_w = Modelica.SIunits.Conversions.to_degC(T_in2);
  mflow_w = max(abs(m2_flow), 1e-3);

  //########################################################## DRY REGIME ############################################################

  //   Qflow_dry = Cflow_a*(Ti_db - To_db_dry);
  //   //*******************************************************************
  //   Qflow_dry = Cflow_w*(To_w_dry - Ti_w);
  //******************************************** eq. energy balance ***
  Qflow_dry = eff_dry*min(Cflow_a, Cflow_w)*(Ti_db - Ti_w);
  //*******************************************************************

  eff_dry = Psychrometrics.Functions.eff(
    config,
    Z_dry,
    NTU_dry);

  NTU_dry = 1/(R*min(Cflow_a, Cflow_w));

  Z_dry = min(Cflow_a, Cflow_w)/max(Cflow_a, Cflow_w);

  Cflow_a = C1_flow;
  Cflow_w = C2_flow;

  //########################################################## WET REGIME ############################################################
  //=========================================================== Coil ===============================================================
  c_a = Medium1.specificHeatCapacityCp(state_a1_inflow);
  c_w = Medium2.specificHeatCapacityCp(state_a2_inflow);
  Qflow_wet = mflow_a*(hi_a - ho_a);
  // //***************************************************************
  //Qflow_wet = Cflow_w*(To_w_wet - Ti_w);
  //**************************************** eq. energy balance ***
  Qflow_wet = eff_wet*min(Cflow_a_wet, Cflow_w)*(Ti_wb - Ti_w);
  //***************************************************************

  eff_wet = Psychrometrics.Functions.eff(
    config,
    Z_wet,
    NTU_wet);

  NTU_wet = 1/(R_wet*min(Cflow_a_wet, Cflow_w));

  Z_wet = min(Cflow_a_wet, Cflow_w)/max(Cflow_a_wet, Cflow_w);

  Cflow_a_wet = mflow_a*cf_a;
  //   cf_a = if noEvent((hi_a - ho_a) > 0.0) then (hi_a - ho_a)/(Ti_wb - To_wb_wet)
  //      else c_a;
  //========================================================= Contact ==============================================================
  Qflow_wet = effc_wet*Cflow_a_wet*(Ti_wb - Tc_wet);

  effc_wet = 1 - exp(-NTUc_wet);

  NTUc_wet = 1/(R_a_wet*Cflow_a_wet);

  //########################################################## RESISTANCE ############################################################
  b = (Wi0/Wi)*((Ti_w - Ti_db)/(Ti0_w - Ti0_a))*(((mflow0_w/mflow_w) + (
    mflow0_a/mflow_a))/2);
  //b = (Wi0/Wi)*(((Ti_w/Ti0_w)+(Ti_db/Ti0_a))/2)*(((mflow0_w/mflow_w)+(mflow0_w/mflow_w))/2);
  R/R0 = (1 + b) - b*((1/(1 + r))*(mflow_a/mflow0_a) + (r/(1 + r))*(mflow_w/
    mflow0_w));

  R_a/R0_a = (mflow0_a/mflow_a)^m;

  R_a_wet = R_a*c_a/cf_a;

  //R_wet - R_a_wet + Rerror = R - R_a;

  R_wet = R_a_wet/0.51;
  //Accorfing to annex_43

  //######################################################## PSYCHROMETRICS ##########################################################
  //=========================================================== Input ==============================================================
  hi_a = Psychrometrics.Functions.h(Tdb=Ti_db, W=Wi);
  Wi = Psychrometrics.Functions.W2(
    Tdb=Ti_db,
    Twb=Ti_wb,
    WAs=Psychrometrics.Functions.Ws(p=Medium1.pressure(state_a1_inflow), T=Ti_wb));
  //=========================================================== Output =============================================================
  //************************** ****************************** Wet Regime ***********************************************************
  ho_a = Psychrometrics.Functions.h(Tdb=To_db_wet, W=Wo_wet);

  To_db_wet = effc_wet*(Tc_wet - Ti_db) + Ti_db;

  Wo_wet = effc_wet*(Wc_wet - Wi) + Wi;
  //   Wo_wet = DCOL.Consumption.Psychrometrics.Functions.W2(
  //     Tdb=To_db_wet,
  //     Twb=To_wb_wet,
  //     WAs=DCOL.Consumption.Psychrometrics.Functions.Ws(p=Medium1.pressure(
  //       state_b1_inflow), T=To_wb_wet));
  Xo_wet = Wo_wet/(1 + Wo_wet);
  RHo_wet = Buildings.Utilities.Psychrometrics.Functions.phi_pTX(
    p=Medium1.pressure(state_b1_inflow),
    T=To_db_wet - Modelica.Constants.T_zero,
    X_w=Xo_wet);

  //========================================================== Contact =============================================================
  //******************************************************** Wet Regime ***********************************************************
  //hc_wet = Functions.h(Tdb=Tc_wet, W=Wc_wet);
  Wc_wet = Psychrometrics.Functions.Ws(T=Tc_wet, p=Medium1.pressure(state_a1_inflow));

  //######################################################## WORKING REGIME ##########################################################
  if not Qflow_wet > Qflow_dry then
    Q_flow = Qflow_dry;
    mWat_flow = 0;
  else
    Q_flow = Qflow_wet;
    //checked the base models, it requires total Qflow, odd?
    mWat_flow = min((Xo_wet - X_w_in1), -1e-5)*mflow_a;
  end if;
end WetCoil_new;
