within DCOL.Consumption.Psychrometrics.Functions;
function eff
  "Return the effectiveness (eff-NTU method) given Z and NTU for different coil configurations"

  input Fluid.Types.HXConfiguration config;
  input Fluid.Types.CapacityRateRatio Z "Dimensionless capacity rate ratio";
  input Fluid.Types.NTU NTU "Number of exchanger heat transfer units";
  output Fluid.Types.Effectiveness eff "Effectiveness";

algorithm
  if config == Fluid.Types.HXConfiguration.CrossFlow then
    //effectiveness in a cross-flow device
    eff := if noEvent(NTU >= 0) then eff_CrossFlow(Z, NTU) else eff_CrossFlow(Z,
      0.0);
  elseif config == Fluid.Types.HXConfiguration.CounterFlow then
    //effectiveness in a counter flow device
    eff := if noEvent(NTU >= 0) then eff_CounterFlow(Z, NTU) else
      eff_CounterFlow(Z, 0.0);
  else
    //effectiveness in a parallel flow device
    eff := if noEvent(NTU >= 0) then eff_ParallelFlow(Z, NTU) else
      eff_ParallelFlow(Z, 0.0);
  end if;
end eff;
