within DCOL.Consumption.Utilities;
model load_splitter

  Modelica.Blocks.Interfaces.RealInput T_sa annotation (Placement(
        transformation(extent={{-120,30},{-100,50}}), iconTransformation(extent=
           {{-120,30},{-100,50}})));
  Modelica.Blocks.Interfaces.RealInput W_sa annotation (Placement(
        transformation(extent={{-120,10},{-100,30}}), iconTransformation(extent=
           {{-120,10},{-100,30}})));
  Modelica.Blocks.Interfaces.RealInput T_z annotation (Placement(transformation(
          extent={{-120,-50},{-100,-30}}), iconTransformation(extent={{-120,-50},
            {-100,-30}})));
  Modelica.Blocks.Interfaces.RealInput W_z annotation (Placement(transformation(
          extent={{-120,-30},{-100,-10}}), iconTransformation(extent={{-120,-30},
            {-100,-10}})));
  Modelica.Blocks.Interfaces.RealInput mflow_sa annotation (Placement(
        transformation(extent={{-120,50},{-100,70}}), iconTransformation(extent=
           {{-120,50},{-100,70}})));
  Modelica.Blocks.Interfaces.RealOutput HSen_flow(unit="W")
    "Sensible enthalpy flow rate, positive if flow into the component"
    annotation (Placement(transformation(extent={{100,6},{120,26}})));
  Modelica.Blocks.Interfaces.RealOutput HLat_flow(unit="W")
    "Latent enthalpy flow rate, positive if flow into the component"
    annotation (Placement(transformation(extent={{100,-26},{120,-6}})));
  Modelica.Blocks.Sources.RealExpression supplyAir(y=1.006*T_sa + W_sa*(2501 +
        1.86*T_sa))
    annotation (Placement(transformation(extent={{-60,28},{-40,48}})));
  Modelica.Blocks.Sources.RealExpression extra_point_psych_chart(y=1.006*T_z +
        W_sa*(2501 + 1.86*T_sa))
    "this extra point has the sensible part of point 1 and the latent of point 2"
    annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));
  Modelica.Blocks.Sources.RealExpression zoneAir(y=1.006*T_z + W_z*(2501 + 1.86
        *T_z))
    annotation (Placement(transformation(extent={{-58,-48},{-38,-28}})));
  Modelica.Blocks.Math.MultiSum Hsen(nu=2, k={1,-1})
    annotation (Placement(transformation(extent={{2,32},{14,44}})));
  Modelica.Blocks.Math.MultiSum Hlat(nu=2, k={1,-1})
    annotation (Placement(transformation(extent={{0,-38},{12,-26}})));
  Modelica.Blocks.Math.MultiProduct Qsen(nu=3)
    annotation (Placement(transformation(extent={{56,32},{68,44}})));
  Modelica.Blocks.Math.MultiProduct Qlat(nu=3)
    annotation (Placement(transformation(extent={{56,-44},{68,-32}})));
  Modelica.Blocks.Sources.Constant kW_to_W(k=1000)
    annotation (Placement(transformation(extent={{4,-8},{14,2}})));
equation

  connect(Hsen.y, Qsen.u[1]) annotation (Line(points={{15.02,38},{36,38},{36,
          40.8},{56,40.8}}, color={0,0,127}));
  connect(Hlat.y, Qlat.u[1]) annotation (Line(points={{13.02,-32},{34,-32},{34,
          -35.2},{56,-35.2}}, color={0,0,127}));
  connect(mflow_sa, Qlat.u[2]) annotation (Line(points={{-110,60},{47,60},{47,-38},
          {56,-38}}, color={0,0,0}));
  connect(Qsen.y, HSen_flow) annotation (Line(points={{69.02,38},{86,38},{86,16},
          {110,16}}, color={0,0,127}));
  connect(Qlat.y, HLat_flow) annotation (Line(points={{69.02,-38},{84,-38},{84,
          -16},{110,-16}}, color={0,0,127}));
  connect(extra_point_psych_chart.y, Hlat.u[1]) annotation (Line(points={{-39,0},
          {-20,0},{-20,-29.9},{0,-29.9}}, color={0,0,127}));
  connect(zoneAir.y, Hlat.u[2]) annotation (Line(points={{-37,-38},{-18,-38},{-18,
          -34.1},{0,-34.1}}, color={0,0,127}));
  connect(supplyAir.y, Hsen.u[1]) annotation (Line(points={{-39,38},{-18,38},{-18,
          40.1},{2,40.1}}, color={0,0,127}));
  connect(extra_point_psych_chart.y, Hsen.u[2]) annotation (Line(points={{-39,0},
          {-18,0},{-18,35.9},{2,35.9}}, color={0,0,127}));
  connect(kW_to_W.y, Qsen.u[2]) annotation (Line(points={{14.5,-3},{40,-3},{40,
          38},{56,38}}, color={0,0,127}));
  connect(kW_to_W.y, Qlat.u[3]) annotation (Line(points={{14.5,-3},{40,-3},{40,
          -40.8},{56,-40.8}}, color={0,0,127}));
  connect(Qsen.u[3], mflow_sa) annotation (Line(points={{56,35.2},{46,35.2},{46,
          60},{-110,60}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(extent={{-100,-60},{100,60}},
          preserveAspectRatio=false)), Icon(coordinateSystem(extent={{-100,-60},
            {100,60}})));
end load_splitter;
