within DCOL.Distribution.HeatExchanger.BaseClasses;
partial model Partial_PlatesHeatExchanger_heatLosses_serie

  extends DCOL.Distribution.HeatExchanger.Icons.HeatExchangerPlates_serie;

  import Modelica.Constants;
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Hot fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Cold fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the plates" annotation (
      choicesAllMatching=true);

  parameter Boolean allowFlowReversal = system.allowFlowReversal
    "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)" annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Integer nPlates=10 "Number of total plates";
  parameter Integer nPipes=nPlates+1 "Number of total hot and cold passes";
  parameter Integer nPipes_C=integer(nPipes/2) "Number of cold passes";
  parameter Integer nPipes_H=nPipes-nPipes_C "Number of hot passes";
  parameter Integer nLength=10 "Number of segments dividing the length of the plate";
  parameter Integer nHeight=10 "Number of segments dividing the height of the plate";
  parameter Integer nWidth=10  "Number of segments dividing the width of the plate";

  parameter Modelica.SIunits.Length length_hot=10 "Length of the hot pipe";
  parameter Modelica.SIunits.Diameter diameter_hot=0.025 "Diameter of the circular hot pipe";
  parameter Modelica.SIunits.Length length_cold=10 "Length of the cold pipe";
  parameter Modelica.SIunits.Diameter diameter_cold=0.025 "Diameter of the circular cold pipe";

  parameter Real a_hot=1000 "Coefficient for quadratic term for the pressure drop of the hot water";
  parameter Real b_hot=1000 "Coefficient for linear term for the pressure drop of the hot water";
  parameter Real a_cold=1000 "Coefficient for quadratic term for the pressure drop of the cold water";
  parameter Real b_cold=1000 "Coefficient for linear term for the pressure drop of the cold water";

  parameter Modelica.SIunits.Area A=1.576*height*width/nHeight "Convection area (considelinr that the plate is completely plain)";
  parameter Modelica.SIunits.Length height=1.5 "Height of a plate";
  parameter Modelica.SIunits.Length width=1 "Width of a plate";
  parameter Modelica.SIunits.Length L=2*plate_s "Characteristic length, length of the plate";
  parameter Modelica.SIunits.Length plate_s=0.01 "Space between the plates";
  parameter Modelica.SIunits.Length e_plate=0.01 "Thickness of each plate";

  parameter Modelica.Media.Interfaces.Types.Temperature T_start_hot=system.T_start "Hot fluid start value of temperature" annotation(Evaluate=true, Dialog(tab = "Initialization", enable = use_T_start));
  parameter Modelica.Media.Interfaces.Types.Temperature T_start_cold=system.T_start "Cold fluid start value of temperature" annotation(Evaluate=true, Dialog(tab = "Initialization", enable = use_T_start));

protected
  parameter Real a=(nPlates/2)-integer(nPlates/2);

  //INITIALIZATION
public
  parameter Modelica.SIunits.Temperature T_start=20+273.15 "Start temperature of the plates" annotation(Dialog(tab="Initialization"));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Hot(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Inlet hot fluid" annotation (Placement(
        transformation(extent={{100,70},{120,90}}), iconTransformation(extent={{100,70},
            {120,90}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_Hot(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Outlet hot fluid" annotation (Placement(
        transformation(extent={{-120,-70},{-100,-50}}),
                                                      iconTransformation(extent={{-120,
            -70},{-100,-50}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Cold(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Inlet cold fluid" annotation (Placement(
        transformation(extent={{-120,50},{-100,70}}),   iconTransformation(
          extent={{-120,50},{-100,70}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_Cold(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Outlet cold fluid" annotation (
      Placement(transformation(extent={{100,-90},{120,-70}}),
        iconTransformation(extent={{100,-90},{120,-70}})));

  Modelica.Fluid.Pipes.DynamicPipe pipe_hot[nPipes_H](
    redeclare package Medium = Medium,
    each use_HeatTransfer=true,
    each length=length_hot,
    each diameter=diameter_hot,
    each nNodes=nHeight,
    each nParallel=1,
    each T_start=T_start_hot,
    each isCircular=false,
    each crossArea=width*plate_s,
    each perimeter=2*(width + plate_s)) annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=180,
        origin={30,-60})));

  Modelica.Fluid.Pipes.DynamicPipe pipe_cold[nPipes_C](
    redeclare package Medium = Medium1,
    each use_HeatTransfer=true,
    each diameter=diameter_cold,
    each nNodes=nHeight,
    each nParallel=1,
    each T_start=T_start_cold,
    each length=height,
    each isCircular=false,
    each crossArea=width*plate_s,
    each perimeter=2*(width + plate_s)) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=180,
        origin={-50,60})));

  Modelica.Fluid.Fittings.GenericResistances.VolumeFlowRate pressureDrop_cold(
    redeclare package Medium = Medium,
    a=a_cold,
    b=b_cold) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={50,60})));

  Modelica.Fluid.Fittings.GenericResistances.VolumeFlowRate pressureDrop_hot(
    redeclare package Medium = Medium1,
    a=a_hot,
    b=b_hot) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={-30,-60})));

  Interfaces.HeatTransferPlatesWithHeatLosses_segmented heatTransferPlates[nPlates](
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    redeclare package Material = Material,
    each A=A,
    each L=L,
    each plate_s=plate_s,
    each e_plate=e_plate,
    each height=height,
    each width=width) annotation (Placement(transformation(extent={{-20,-20},{
            20,20}},
        rotation=-90,
        origin={0,0})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_ambient
    "Heat exchanged wit the ambient" annotation (Placement(transformation(extent={{-10,90},
            {10,110}})));
equation
  //Number of plates is even or odd

  if a>0 then
  //Odd number of plates
    for j in 1:nHeight loop
      connect(pipe_hot[1].heatPorts[j], heatTransferPlates[1].port_a_fromHot[j]) annotation (Line(points={{29.9,
              -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                     color={127,0,0}));
      connect(pipe_cold[1].heatPorts[j], heatTransferPlates[nPlates].port_b_toCold[j]) annotation (Line(points={{-49.9,
              55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                           color={127,0,0}));
    end for;

    for i in 2:nPipes_H loop
      if (i/2)-integer(i/2)>0 then
        for j in 1:nHeight loop
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-2].port_a_fromHot[j]) annotation (Line(points={{29.9,
                  -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                         color={127,0,0}));
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-1].port_a_fromHot[j]) annotation (Line(points={{29.9,
                  -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                         color={127,0,0}));
        end for;
      else
        for j in 1:nHeight loop
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-2].port_a_fromHot[nHeight+1-j]) annotation (Line(points={{29.9,
                  -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                                   color={127,0,0}));
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-1].port_a_fromHot[nHeight+1-j]) annotation (Line(points={{29.9,
                  -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                                   color={127,0,0}));
        end for;
      end if;
    end for;

    for i in 2:nPipes_C loop
      if (i/2)-integer(i/2)>0 then
        for j in 1:nHeight loop
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+2-2*i].port_b_toCold[j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                    color={127,0,0}));
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+1-2*i].port_b_toCold[j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                    color={127,0,0}));
        end for;
      else
        for j in 1:nHeight loop
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+2-2*i].port_b_toCold[nHeight+1-j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                              color={127,0,0}));
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+1-2*i].port_b_toCold[nHeight+1-j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                              color={127,0,0}));
        end for;
      end if;
    end for;

  else
  //Even number of plates
    for j in 1:nHeight loop
      connect(pipe_hot[1].heatPorts[j], heatTransferPlates[1].port_a_fromHot[j]) annotation (Line(points={{29.9,
              -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                     color={127,0,0}));
      connect(pipe_hot[nPipes_H].heatPorts[j], heatTransferPlates[nPlates].port_a_fromHot[nHeight+1-j]) annotation (Line(points={{29.9,
              -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                                            color={127,0,0}));
    end for;

    for i in 2:nPipes_H-1 loop
      if (i/2)-integer(i/2)>0 then
        for j in 1:nHeight loop
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-2].port_a_fromHot[j]) annotation (Line(points={{29.9,
                  -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                         color={127,0,0}));
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-1].port_a_fromHot[j]) annotation (Line(points={{29.9,
                  -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                         color={127,0,0}));
        end for;
      else
        for j in 1:nHeight loop
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-1].port_a_fromHot[nHeight+1-j]) annotation (Line(points={{29.9,
                  -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                                   color={127,0,0}));
          connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*i-2].port_a_fromHot[nHeight+1-j]) annotation (Line(points={{29.9,
                -55.6},{30,-55.6},{30,0},{20,0},{20,-3.55271e-015}},                                                                                                     color={127,0,0}));
        end for;
      end if;
    end for;

    for i in 1:nPipes_C loop
      if (i/2)-integer(i/2)>0 then
        for j in 1:nHeight loop
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+2-2*i].port_b_toCold[j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                    color={127,0,0}));
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+1-2*i].port_b_toCold[j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                    color={127,0,0}));
        end for;
      else
        for j in 1:nHeight loop
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+2-2*i].port_b_toCold[nHeight+1-j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                              color={127,0,0}));
          connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*nPipes_C+1-2*i].port_b_toCold[nHeight+1-j]) annotation (Line(points={{-49.9,
                  55.6},{-49.9,0},{-20,0},{-20,3.55271e-015}},                                                                                                                              color={127,0,0}));
        end for;
      end if;
    end for;
  end if;

  for i in 2:nPipes_C loop
    connect(pipe_cold[i-1].port_b, pipe_cold[i].port_a);
  end for;

  for i in 2:nPipes_H loop
    connect(pipe_hot[i-1].port_b, pipe_hot[i].port_a);
  end for;

  for i in 1: nPlates loop
    connect(port_a_ambient, heatTransferPlates[i].port_b_left) annotation (Line(points={{0,100},
            {0,20},{3.77476e-015,20}},                                                                                           color={191,0,0}));
    connect(port_a_ambient, heatTransferPlates[i].port_b_bottom) annotation (Line(points={{0,100},
            {0,80},{-20,80},{-20,12}},                                                                                                 color={191,0,0}));
    connect(port_a_ambient, heatTransferPlates[i].port_a_top) annotation (Line(points={{0,100},
            {0,80},{24,80},{24,-12},{20,-12}},                                                                                       color={191,0,0}));
    connect(port_a_ambient, heatTransferPlates[i].port_a_right) annotation (Line(points={{0,100},
            {0,80},{24,80},{24,-20},{-3.55271e-015,-20}},                                                               color={191,0,0}));
  end for;

  connect(port_b_Cold, pressureDrop_cold.port_b) annotation (Line(points={{110,-80},
          {80,-80},{80,60},{60,60}},                                                                    color={0,127,255}));
  connect(pressureDrop_hot.port_b, port_b_Hot) annotation (Line(points={{-40,-60},
          {-110,-60}},                                                                                         color={0,127,255}));
  connect(port_a_Cold, pipe_cold[1].port_a) annotation (Line(points={{-110,60},
          {-60,60}},                                                                                  color={0,127,255}));
  connect(pipe_cold[nPipes_C].port_b, pressureDrop_cold.port_a) annotation (Line(points={{-40,60},
          {40,60}},                                                                                                     color={0,127,255}));
  connect(port_a_Hot, pipe_hot[1].port_a) annotation (Line(points={{110,80},{90,
          80},{90,-60},{40,-60}},                                                             color={0,127,255}));
  connect(pipe_hot[nPipes_H].port_b, pressureDrop_hot.port_a) annotation (Line(points={{20,-60},
          {-20,-60}},                                                                                    color={0,127,255}));

   annotation (Icon(coordinateSystem(preserveAspectRatio=false)),
   Diagram(coordinateSystem(preserveAspectRatio=false)),
   Documentation(info="<html>
<p>This model represents a plate heat exchanger. In this kind of heat exchangers, this heat is transfered from a hot fluid to a cold one through some plates. The hot fluid heats the plates and the plates transfer this heat to the cold fluid. The number of plates is selected with the &quot;nParallel&quot; parameter.</p>
<p>The difference with the <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.Distribution.HeatExchanger.BaseClasses.Partial_PlatesHeatExchanger_serie\">Partial_PlatesHeatExchanger_serie</a> model is that this model considers the heat losses form the plates to the ambient.</p>
<p>Assumptions:</p>
<ul>
<li>There is no mix of the cold and hot fluids (both water by default);</li>
<li>The name given to this type of plates heat echanger is &quot;Serie Plates heat exchanger&quot; due to the flow throught the heat exchanger of the hot and cold fluid. This flow is represented in the figure below.</li>
<li>Two models of &quot;VolumeFlowRate&quot; from modelica have been used to represent the pressure drop at both cold and hot size;</li>
<li>It is possible to select the material of the plates (by default AISI 321).</li>
</ul>
<p><br><img src=\"modelica://Modelica_IK4_TEKNIKER/Resources/Images/Serie.PNG\"/></p>
</html>", revisions="<html>
<p>2016-05-16 Eduardo Ubieta (IK4-TEKNIKER): First implementation</p>
<h4>Copyright &copy; IK4-TEKNIKER</h4>
</html>"));
end Partial_PlatesHeatExchanger_heatLosses_serie;
