within DCOL.Distribution.HeatExchanger.BaseClasses;
partial model Partial_PlatesHeatExchanger_parallel

  extends Icons.HeatExchangerPlates_parallel;

  import Modelica.Constants;
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Hot fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Cold fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the plates" annotation (
      choicesAllMatching=true);

  parameter Boolean allowFlowReversal = system.allowFlowReversal
    "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)" annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Integer nSeg=10 "Number of segments dividing vertically each plate";
  parameter Integer nPlates=10 "Number of total plates";
protected
  parameter Integer nPipes=nPlates+1 "Number of total hot and cold passes";
  parameter Integer nPipes_C=integer(nPipes/2) "Number of cold passes";
  parameter Integer nPipes_H=nPipes-nPipes_C "Number of hot passes";

public
  parameter Modelica.SIunits.Length length_hot=10 "Length of the hot pipe";
  parameter Modelica.SIunits.Diameter diameter_hot=0.025 "Diameter of the circular hot pipe";
  parameter Modelica.SIunits.Length length_cold=10 "Length of the cold pipe";
  parameter Modelica.SIunits.Diameter diameter_cold=0.025 "Diameter of the circular cold pipe";

  parameter Real a_hot=1000 "Coefficient for quadratic term for the pressure drop of the hot water";
  parameter Real b_hot=1000 "Coefficient for linear term for the pressure drop of the hot water";
  parameter Real a_cold=1000 "Coefficient for quadratic term for the pressure drop of the cold water";
  parameter Real b_cold=1000 "Coefficient for linear term for the pressure drop of the cold water";

  parameter Modelica.SIunits.Area A=1.576*height*width/nSeg "Convection area (considelinr that the plate is completely plain)";
  parameter Modelica.SIunits.Length height=1.5 "Height of a plate";
  parameter Modelica.SIunits.Length width=1 "Width of a plate";
  parameter Modelica.SIunits.Length L=2*plate_s "Characteristic length, length of the plate";
  parameter Modelica.SIunits.Length plate_s=0.01 "Space between the plates";
  parameter Modelica.SIunits.Length e_plate=0.01 "Thickness of each plate";

  parameter Modelica.Media.Interfaces.Types.Temperature T_start_hot=system.T_start "Hot fluid start value of temperature" annotation(Evaluate=true, Dialog(tab = "Initialization", enable = use_T_start));
  parameter Modelica.Media.Interfaces.Types.Temperature T_start_cold=system.T_start "Cold fluid start value of temperature" annotation(Evaluate=true, Dialog(tab = "Initialization", enable = use_T_start));

protected
  parameter Real a=(nPlates/2)-integer(nPlates/2);

  //INITIALIZATION
public
  parameter Modelica.SIunits.Temperature T_start=20+273.15 "Start temperature of the plates" annotation(Dialog(tab="Initialization"));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Hot(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Inlet hot fluid" annotation (Placement(
        transformation(extent={{100,70},{120,90}}), iconTransformation(extent={{100,70},
            {120,90}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_Hot(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Outlet hot fluid" annotation (Placement(
        transformation(extent={{100,-80},{120,-60}}), iconTransformation(extent=
           {{100,-80},{120,-60}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Cold(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Inlet cold fluid" annotation (Placement(
        transformation(extent={{-120,-90},{-100,-70}}), iconTransformation(
          extent={{-120,-90},{-100,-70}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_Cold(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Outlet cold fluid" annotation (
      Placement(transformation(extent={{-120,60},{-100,80}}),
        iconTransformation(extent={{-120,60},{-100,80}})));

  Modelica.Fluid.Pipes.DynamicPipe pipe_hot[nPipes_H](
    redeclare package Medium = Medium,
    each use_HeatTransfer=true,
    each length=length_hot,
    each diameter=diameter_hot,
    each T_start=T_start_hot,
    each nNodes=nSeg,
    each isCircular=false,
    each crossArea=width*plate_s,
    each perimeter=2*(width + plate_s)) annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=-90,
        origin={90,20})));

  Modelica.Fluid.Pipes.DynamicPipe pipe_cold[nPipes_C](
    redeclare package Medium = Medium1,
    each use_HeatTransfer=true,
    each length=length_cold,
    each diameter=diameter_cold,
    each T_start=T_start_cold,
    each nNodes=nSeg,
    each isCircular=false,
    each crossArea=width*plate_s,
    each perimeter=2*(width + plate_s)) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=-90,
        origin={-90,-20})));

  Modelica.Fluid.Fittings.GenericResistances.VolumeFlowRate pressureDrop_cold(
    redeclare package Medium = Medium,
    a=a_cold,
    b=b_cold) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-90,40})));

  Modelica.Fluid.Fittings.GenericResistances.VolumeFlowRate pressureDrop_hot(
    redeclare package Medium = Medium1,
    a=a_hot,
    b=b_hot) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={90,-40})));

  Interfaces.HeatTransferPlates_segmented heatTransferPlates[nPlates](
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    redeclare package Material = Material,
    each A=A,
    each L=L,
    each plate_s=plate_s,
    each e_plate=e_plate,
    each T_start=T_start,
    each height=height,
    each width=width,
    each nSeg=nSeg) annotation (Placement(transformation(extent={{-20,-20},{20,20}})));

  Modelica.Fluid.Fittings.MultiPort multiPort(
    redeclare package Medium = Medium,
    nPorts_b=nPipes_C) annotation (Placement(
        transformation(
        extent={{-4,-10},{4,10}},
        rotation=90,
        origin={-90,-44})));

  Modelica.Fluid.Fittings.MultiPort multiPort1(
    redeclare package Medium = Medium,
    nPorts_b=nPipes_C) annotation (Placement(
        transformation(
        extent={{4,-10},{-4,10}},
        rotation=90,
        origin={-90,4})));

  Modelica.Fluid.Fittings.MultiPort multiPort2(
    redeclare package Medium = Medium,
    nPorts_b=nPipes_H) annotation (Placement(
        transformation(
        extent={{4,-10},{-4,10}},
        rotation=90,
        origin={90,44})));

  Modelica.Fluid.Fittings.MultiPort multiPort3(
    redeclare package Medium = Medium,
    nPorts_b=nPipes_H) annotation (Placement(
        transformation(
        extent={{-4,-10},{4,10}},
        rotation=90,
        origin={90,-4})));
equation
  //Number of plates is even or odd

  if a>0 then
  //Odd number of plates
    for j in 1:nSeg loop
      connect(pipe_hot[nPipes_H].heatPorts[j], heatTransferPlates[1].port_a_fromHot[nSeg+1-j]) annotation (Line(points={{85.6,19.9},{60,19.9},{60,60},{0,60},{0,20}},color={127,0,0}));
      connect(pipe_cold[nPipes_C].heatPorts[j], heatTransferPlates[nPlates].port_b_toCold[j]) annotation (Line(points={{-85.6,-19.9},{-60,-19.9},{-60,-60},{0,-60},{0,-20}},color={127,0,0}));
    end for;

    for i in 1:nPipes_H-1 loop
      for j in 1:nSeg loop
        connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*nPipes_H+1-2*i].port_a_fromHot[nSeg+1-j]) annotation (Line(points={{85.6,19.9},{60,19.9},{60,60},{0,60},{0,20}},color={127,0,0}));
        connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*nPipes_H-2*i].port_a_fromHot[nSeg+1-j]) annotation (Line(points={{85.6,19.9},{60,19.9},{60,60},{0,60},{0,20}},color={127,0,0}));
      end for;
    end for;

    for i in 1:nPipes_C-1 loop
      for j in 1:nSeg loop
        connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*i-1].port_b_toCold[j]) annotation (Line(points={{-85.6,-19.9},{-60,-19.9},{-60,-60},{0,-60},{0,-20}},color={127,0,0}));
        connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*i].port_b_toCold[j]) annotation (Line(points={{-85.6,-19.9},{-60,-19.9},{-60,-60},{0,-60},{0,-20}},color={127,0,0}));
      end for;
    end for;

  else
  //Even number of plates
    for j in 1:nSeg loop
      connect(pipe_hot[1].heatPorts[j], heatTransferPlates[nPlates].port_a_fromHot[nSeg+1-j]) annotation (Line(points={{85.6,19.9},{60,19.9},{60,60},{0,60},{0,20}},color={127,0,0}));
      connect(pipe_hot[nPipes_H].heatPorts[j], heatTransferPlates[1].port_a_fromHot[nSeg+1-j]) annotation (Line(points={{85.6,19.9},{60,19.9},{60,60},{0,60},{0,20}},color={127,0,0}));
    end for;

    for i in 2:nPipes_H-1 loop
      for j in 1:nSeg loop
        connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*nPipes_H+1-2*i].port_a_fromHot[nSeg+1-j]) annotation (Line(points={{85.6,19.9},{60,19.9},{60,60},{0,60},{0,20}},color={127,0,0}));
        connect(pipe_hot[i].heatPorts[j], heatTransferPlates[2*nPipes_H-2*i].port_a_fromHot[nSeg+1-j]) annotation (Line(points={{85.6,19.9},{60,19.9},{60,60},{0,60},{0,20}},color={127,0,0}));
      end for;
    end for;

    for i in 1:nPipes_C loop
      for j in 1:nSeg loop
        connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*i-1].port_b_toCold[j]) annotation (Line(points={{-85.6,-19.9},{-60,-19.9},{-60,-60},{0,-60},{0,-20}},color={127,0,0}));
        connect(pipe_cold[i].heatPorts[j], heatTransferPlates[2*i].port_b_toCold[j]) annotation (Line(points={{-85.6,-19.9},{-60,-19.9},{-60,-60},{0,-60},{0,-20}},color={127,0,0}));
      end for;
    end for;
  end if;

  for i in 1:nPipes_H loop
    connect(multiPort2.ports_b[i], pipe_hot[i].port_a) annotation (Line(points={{90,40},{90,35},{90,30}}, color={0,127,255}));
    connect(pipe_hot[i].port_b, multiPort3.ports_b[i]) annotation (Line(points={{90,10},{90,0}}, color={0,127,255}));
  end for;

  for i in 1:nPipes_C loop
    connect(multiPort.ports_b[i], pipe_cold[i].port_a) annotation (Line(points={{-90,-40},{-90,-35},{-90,-30}}, color={0,127,255}));
    connect(pipe_cold[i].port_b, multiPort1.ports_b[i]) annotation (Line(points={{-90,-10},{-90,-5},{-90,0}}, color={0,127,255}));
  end for;

  connect(port_b_Cold, pressureDrop_cold.port_b) annotation (Line(points={{-110,70},{-90,70},{-90,50}}, color={0,127,255}));
  connect(pressureDrop_hot.port_b, port_b_Hot) annotation (Line(points={{90,-50},{90,-50},{90,-70},{110,-70}}, color={0,127,255}));
  connect(multiPort1.port_a, pressureDrop_cold.port_a) annotation (Line(points={{-90,8},{-90,19},{-90,30}}, color={0,127,255}));
  connect(port_a_Cold, multiPort.port_a) annotation (Line(points={{-110,-80},{
          -90,-80},{-90,-48}},                                                                                color={0,127,255}));
  connect(port_a_Hot, multiPort2.port_a) annotation (Line(points={{110,80},{110,
          80},{90,80},{90,48}},                                                                       color={0,127,255}));
  connect(multiPort3.port_a, pressureDrop_hot.port_a) annotation (Line(points={{90,-8},{90,-8},{90,-30}}, color={0,127,255}));

       annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents a plate heat exchanger. In this kind of heat exchangers, this heat is transfered from a hot fluid to a cold one through some plates. The hot fluid heats the plates and the plates transfer this heat to the cold fluid. The number of plates is selected with the &quot;nParallel&quot; parameter.</p>
<p>Assumptions:</p>
<ul>
<li>There is no mix of the cold and hot fluids (both water by default);</li>
<li>The name given to this type of plates heat echanger is &quot;Parallel Plates heat exchanger&quot; due to the flow throught the heat exchanger of the hot and cold fluid. This flow is represented in the figure below.</li>
<li>Two models of &quot;VolumeFlowRate&quot; from modelica have been used to represent the pressure drop at both cold and hot size;</li>
<li>It is possible to select the material of the plates (by default AISI 321).</li>
</ul>
<p><br><img src=\"modelica://Modelica_IK4_TEKNIKER/Resources/Images/Parallel.PNG\"/></p>
</html>", revisions="<html>
<p>2016-05-16 Eduardo Ubieta (IK4-TEKNIKER): First implementation</p>
<h4>Copyright &copy; IK4-TEKNIKER</h4>
</html>"));
end Partial_PlatesHeatExchanger_parallel;
