within DCOL.Distribution.HeatExchanger.Interfaces;
model HeatTransferPlatesWithHeatLosses_segmented

  extends HeatExchanger.Icons.Plates;

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Hot fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Cold fluid medium in the component" annotation (choicesAllMatching = true);

   replaceable package Material =
     Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
     constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the plates" annotation (
      choicesAllMatching=true);

  parameter Integer nLength=10 "Number of segments dividing the length of the plate";
  parameter Integer nHeight=10 "Number of segments dividing the height of the plate";
  parameter Integer nWidth=10  "Number of segments dividing the width of the plate";

  parameter Modelica.SIunits.Area A=1.576*height*width/nHeight "Convection area (considelinr that the plate is completely plain)";
  parameter Modelica.SIunits.Area A_trans=e_plate*width "Conduction area from midle to top/bottom";
  parameter Modelica.SIunits.Area A_long=e_plate*height "Conduction area from midle to left/right";
  parameter Modelica.SIunits.Length height=1.5 "Height of a plate";
  parameter Modelica.SIunits.Length width=1 "Width of a plate";
  parameter Modelica.SIunits.Length L=2*plate_s "Characteristic length, length of the plate";
  parameter Modelica.SIunits.Length plate_s=0.01 "Space between the plates";
  parameter Modelica.SIunits.Length e_plate=0.01 "Thickness of each plate";

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.ForcedConvection.Plate.ForcedConvectionPlateParalel
    forcedConvectionFromHot[nHeight](
    redeclare package Medium = Medium,
    each A=A,
    each L=L) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={0,60})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.ForcedConvection.Plate.ForcedConvectionPlateParalel
    forcedConvectionToCold[nHeight](
    redeclare package Medium = Medium1,
    each A=A,
    each L=L) annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=90,
        origin={0,-59})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_fromHot[nHeight]
    "Heat transfer the hot fluid" annotation (Placement(transformation(extent={{-10,90},{10,110}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_toCold[nHeight]
    "Heat transfer the cold fluid" annotation (Placement(transformation(extent={{-10,-110},{10,-90}})));

  Modelica.Blocks.Interfaces.RealInput v_Hot[nHeight]
    "Velocity of the hot fuid"                        annotation (Placement(transformation(extent={{-120,20},{-80,60}})));

  Modelica.Blocks.Interfaces.RealInput v_Cold[nHeight]
    "Velocity of the cold fuid"                        annotation (Placement(transformation(extent={{120,-60},{80,-20}})));

  Modelica.Blocks.Interfaces.RealInput p_Hot[nHeight]
    "Pressure of the hot fuid"                        annotation (Placement(transformation(extent={{-120,60},{-80,100}})));

  Modelica.Blocks.Interfaces.RealInput p_Cold[nHeight]
    "Pressure of the cold fuid"                        annotation (Placement(transformation(extent={{120,-100},{80,-60}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_left
    "Heat transfer to the left of the plate" annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_bottom
    "Heat transfer to the bottom of the plate" annotation (Placement(transformation(extent={{-70,-110},{-50,-90}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_right
    "Heat transfer to the right of the plate" annotation (Placement(transformation(extent={{90,-10},{110,10}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_top
    "Heat transfer to the top of the plate" annotation (Placement(transformation(extent={{50,90},{70,110}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.ThermalVolumes.Box box(
    redeclare package Material = Material,
    length=e_plate,
    height=height,
    width=width,
    nLength=1,
    nWidth=1,
    nHeight=nHeight) annotation (Placement(transformation(
        extent={{-30,30},{30,-30}},
        rotation=270,
        origin={0,0})));

equation

  for i in 1:nHeight loop
    connect(port_a_fromHot[i], forcedConvectionFromHot[i].fluid) annotation (Line(points={{0,100},{0,85},{0,70}}, color={191,0,0}));
    connect(v_Hot[i], forcedConvectionFromHot[i].v) annotation (Line(points={{-100,40},{-50,40},{-50,56},{-22,56},{-10,56},{-10,56.6}},color={0,0,127}));
    connect(p_Hot[i], forcedConvectionFromHot[i].P) annotation (Line(points={{-100,80},{-50,80},{-50,64},{-10,64}}, color={0,0,127}));
    connect(forcedConvectionFromHot[i].solid, box.port_a_1[1, i]) annotation (Line(points={{0,50},{0,40},{0,30}}, color={191,0,0}));
    connect(box.port_b_1[1, i], forcedConvectionToCold[i].solid) annotation (Line(points={{0,-30},
            {0,-49}},                                                                                               color={191,0,0}));
    connect(v_Cold[i],forcedConvectionToCold[i].v) annotation (Line(points={{100,-40},
            {50,-40},{50,-55.6},{10,-55.6}},                                                                          color={0,0,127}));
    connect(p_Cold[i], forcedConvectionToCold[i].P) annotation (Line(points={{100,-80},{50,-80},{50,-63},{10,-63}}, color={0,0,127}));
    connect(port_b_toCold[i], forcedConvectionToCold[i].fluid) annotation (Line(points={{0,-100},
            {0,-69}},                                                                                      color={191,0,0}));
    connect(box.port_a_3[i, 1], port_a_top) annotation (Line(points={{24,24},{42,24},{60,24},{60,100}}, color={191,0,0}));
    connect(box.port_b_3[i, 1], port_b_bottom) annotation (Line(points={{-24,-24},{
            -60,-24},{-60,-100}},                                                                        color={191,0,0}));
  end for;

  connect(port_a_right, box.port_a_2[1, 1]) annotation (Line(points={{100,0},{29.4,
          0}},                                                                                   color={191,0,0}));
  connect(box.port_b_2[1, 1], port_b_left) annotation (Line(points={{-30,0},{-65,0},{-100,0}}, color={191,0,0}));

     annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents one of the plates which compose a plate heat exchanger.</p>
<p>The difference with the <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.Distribution.HeatExchanger.Interfaces.HeatTransferPlates_segmented\">HeaTransferPlates_segmented</a> model is that this model considers the heat losses form the plates to the ambient.</p>
<p>Assumptions:</p>
<ul>
<li>Heat is transferred to and from the plate throught convection;</li>
<li>The heat is transferred throught the plate due to conduction;</li>
<li>It is considered a thermal inertia in the plate;</li>
<li>The plate is vertically divided in &quot;nSeg&quot; segments;</li>
<li>The thermal properties of the plate are defined in the &quot;Material&quot; package.</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16 Eduardo Ubieta (IK4-TEKNIKER): First implementation</p>
<h4>Copyright &copy; IK4-TEKNIKER</h4>
</html>"));
end HeatTransferPlatesWithHeatLosses_segmented;
