within DCOL.Distribution.HeatExchanger.Interfaces;
model HeatTransferPlates_segmented

  extends HeatExchanger.Icons.Plates;

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Hot fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Cold fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the plates" annotation (
      choicesAllMatching=true);

  parameter Integer nSeg=10 "Number of segments dividing vertically the plate";

  parameter Modelica.SIunits.Area A=1.576*height*width/nSeg "Convection area of each segment (consideling that the plate is not completely plain)";
//   parameter Modelica.SIunits.Area A_trans=e_plate*width "Conduction area from midle to top/bottom";
//   parameter Modelica.SIunits.Area A_long=e_plate*height "Conduction area from midle to left/right";
  parameter Modelica.SIunits.Length height=1.5 "Height of a plate";
  parameter Modelica.SIunits.Length width=1 "Width of a plate";
  parameter Modelica.SIunits.Length L=2*plate_s "Characteristic length, length of the plate";
  parameter Modelica.SIunits.Length plate_s=0.01 "Space between the plates";
  parameter Modelica.SIunits.Length e_plate=0.01 "Thickness of each plate";

  //INITIALIZATION
  parameter Modelica.SIunits.Temperature T_start=20+273.15 "Start temperature of the plates" annotation(Dialog(tab="Initialization"));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.ForcedConvection.Plate.ForcedConvectionPlateParalel
    forcedConvectionFromHot[nSeg](
    redeclare package Medium = Medium,
    each A=A,
    each L=L,
    each Tc(start=T_start)) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={0,60})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.ForcedConvection.Plate.ForcedConvectionPlateParalel
    forcedConvectionToCold[nSeg](
    redeclare package Medium = Medium1,
    each A=A,
    each L=L,
    each Tc(start=T_start)) annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=90,
        origin={0,-60})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D
    thermalConductorFromHot[nSeg](
    redeclare package Material = Material,
    each L=e_plate,
    each A=A,
    each T_start=T_start) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={0,30})), choicesAllMatching=true);

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D
    thermalConductorToCold[nSeg](
    redeclare package Material = Material,
    each L=e_plate,
    each A=A,
    each T_start=T_start) annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=-90,
        origin={0,-30})), choicesAllMatching=true);

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_fromHot[nSeg]
    "Heat transfer from the hot fluid" annotation (Placement(transformation(extent={{-10,90},{10,110}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_toCold[nSeg]
    "Heat transfer to the cold fluid" annotation (Placement(transformation(extent={{-10,-110},{10,-90}})));

  Modelica.Blocks.Interfaces.RealInput v_Hot[nSeg]
    "Velocity of the hot fuid"                     annotation (Placement(transformation(extent={{-120,20},{-80,60}})));

  Modelica.Blocks.Interfaces.RealInput v_Cold[nSeg]
    "Velocity of the cold fuid"                     annotation (Placement(transformation(extent={{120,-60},{80,-20}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor
    heatCapacitor[nSeg](
    redeclare package Material = Material,
    each V=A*e_plate,
    each T(start=T_start),
    each T_start=T_start) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={10,0})), choicesAllMatching=true);

  Modelica.Blocks.Interfaces.RealInput p_Hot[nSeg]
    "Pressure of the hot fuid"                     annotation (Placement(transformation(extent={{-120,60},{-80,100}})));

  Modelica.Blocks.Interfaces.RealInput p_Cold[nSeg]
    "Pressure of the cold fuid"                     annotation (Placement(transformation(extent={{120,-100},{80,-60}})));

equation

  for i in 1:nSeg loop
    connect(p_Hot[i], forcedConvectionFromHot[i].P) annotation (Line(points={{-100,80},{-50,80},{-50,64},{-10,64}},color={0,0,127}));
    connect(v_Hot[i], forcedConvectionFromHot[i].v) annotation (Line(points={{-100,40},{-50,40},{-50,56.6},{-10,56.6}},color={0,0,127}));
    connect(v_Cold[i], forcedConvectionToCold[i].v) annotation (Line(points={{100,-40},{50,-40},{50,-56.6},{10,-56.6}},color={0,0,127}));
    connect(p_Cold[i], forcedConvectionToCold[i].P) annotation (Line(points={{100,-80},{50,-80},{50,-64},{10,-64}},color={0,0,127}));
    connect(port_a_fromHot[i], forcedConvectionFromHot[i].fluid) annotation (Line(points={{0,100},{0,86},{0,70},{4.44089e-016,70}},color={191,0,0}));
    connect(thermalConductorFromHot[i].port_b, heatCapacitor[i].port) annotation(Line(points={{0,20},{0,1.77636e-015}},color={191,0,0}));
    connect(heatCapacitor[i].port, thermalConductorToCold[i].port_a) annotation (Line(points={{0,0},{0,-20}},color={191,0,0}));
    connect(forcedConvectionToCold[i].fluid, port_b_toCold[i]) annotation (Line(points={{
            -4.44089e-016,-70},{-4.44089e-016,-86},{0,-86},{0,-100}},                                                                             color={191,0,0}));
    connect(forcedConvectionFromHot.solid, thermalConductorFromHot.port_a) annotation (Line(points={{0,50},{0,45},{0,40}}, color={191,0,0}));
    connect(thermalConductorToCold.port_b, forcedConvectionToCold.solid) annotation (Line(points={{0,-40},
            {0,-50}},                                                                                                       color={191,0,0}));
  end for;

      annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents one of the plates which compose a plate heat exchanger.</p>
<p>Assumptions:</p>
<ul>
<li>Heat is transferred to and from the plate throught convection;</li>
<li>The heat is transferred throught the plate due to conduction;</li>
<li>It is considered a thermal inertia in the plate;</li>
<li>The plate is vertically divided in &quot;nSeg&quot; segments;</li>
<li>The thermal properties of the plate are defined in the &quot;Material&quot; package.</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16 Eduardo Ubieta (IK4-TEKNIKER): First implementation</p>
<h4>Copyright &copy; IK4-TEKNIKER</h4>
</html>"));
end HeatTransferPlates_segmented;
