within DCOL.Distribution.HeatExchanger;
model PlatesHeatExchanger_serie
  extends BaseClasses.Partial_PlatesHeatExchanger_serie;

  Modelica.SIunits.Temperature THotIn "Hot fluid inlet temperature in K";
  Modelica.SIunits.Temperature THotOut "Hot fluid outlet temperature in K";
  Modelica.SIunits.Temperature TColdIn "Cold fluid inlet temperature in K";
  Modelica.SIunits.Temperature TColdOut "Cold fluid outlet temperature in K";

  Modelica.SIunits.Area A_total "Total heat transfer area";
  Real efficiency "Efficiency of the Heat exchanger";

equation
  A_total=nSeg*A;
  efficiency=(THotIn-THotOut)/(THotIn-TColdIn);

//Calculation of the temperature at each port
  THotIn=Medium.temperature(Medium.setState_phX(
    p=port_a_Hot.p,
    h=inStream(port_a_Hot.h_outflow),
    X=inStream(port_a_Hot.Xi_outflow)))
    "Hot medium properties at the entrace";
  THotOut=Medium.temperature(Medium.setState_phX(
    p=port_b_Hot.p,
    h=port_b_Hot.h_outflow,
    X=port_b_Hot.Xi_outflow))
    "Hot medium properties at the exit";
  TColdIn=Medium1.temperature(Medium1.setState_phX(
    p=port_a_Cold.p,
    h=inStream(port_a_Cold.h_outflow),
    X=inStream(port_a_Cold.Xi_outflow)))
    "Cold medium properties at the entrace";
  TColdOut=Medium1.temperature(Medium1.setState_phX(
    p=port_b_Cold.p,
    h=port_b_Cold.h_outflow,
    X=port_b_Cold.Xi_outflow))
    "cold medium properties at the exit";

  for i in 1:nPlates loop
    for j in 1:nSeg loop
      heatTransferPlates[i].v_Hot[j]=pipe_hot[(i+1)-integer((i+1)/2)].vs[j];
      heatTransferPlates[i].p_Hot[j]=pipe_hot[(i+1)-integer((i+1)/2)].statesFM[j].p;
      heatTransferPlates[i].v_Cold[j]=pipe_cold[integer((i+1)/2)].vs[j];
      heatTransferPlates[i].p_Cold[j]=pipe_cold[integer((i+1)/2)].statesFM[j].p;
    end for;
  end for;

  annotation (Documentation(info="<html>
<p>This model extends from <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.Distribution.HeatExchanger.BaseClasses.Partial_PlatesHeatExchanger_serie\">Partial_PlatesHeatExchanger_serie</a> and is used to define the total efficiency of the heat exchanger, as well as the temperatures of the hot and cold fluid at the entrace and the exit.</p>
</html>"));
end PlatesHeatExchanger_serie;
