within DCOL.Distribution.HeatExchanger.Testing;
model PlatesHeatTransfer_heatLosses_parallel

  PlatesHeatExchanger_heatLosses_parallel
                               platesHeatExchanger(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    redeclare package Medium1 =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    length_hot=1.5,
    length_cold=1.5,
    redeclare package Material =
        Modelica_IK4_TEKNIKER.Thermal.Materials.Copper,
    diameter_hot=sqrt(0.01*4/Modelica.Constants.pi),
    diameter_cold=sqrt(0.01*4/Modelica.Constants.pi),
    nPlates=2,
    T_start_hot=313.15,
    T_start_cold=293.15,
    T_start=303.15)
    annotation (Placement(transformation(extent={{-40,-42},{40,38}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-90,20},
            {-70,40}})));

  Modelica.Fluid.Sources.FixedBoundary outlet_hot(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1) annotation (Placement(transformation(extent={{82,-70},{62,-50}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_hot(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    m_flow=50,
    T=323.15) annotation (Placement(transformation(extent={{80,50},{60,70}})));

  Modelica.Fluid.Sources.FixedBoundary outlet_cold(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1) annotation (Placement(transformation(extent={{-80,50},{-60,70}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_cold(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    m_flow=100,
    T=283.15) annotation (Placement(transformation(extent={{-80,-70},{-60,-50}})));

  Modelica.Blocks.Sources.Constant m_flowHot(k=50) annotation (Placement(transformation(extent={{120,80},{100,100}})));

  Modelica.Blocks.Sources.Constant THot(k=50 + 273.15) annotation (Placement(transformation(extent={{120,44},{100,64}})));

  Modelica.Blocks.Sources.Constant m_flowCold(k=60) annotation (Placement(transformation(extent={{-120,-40},{-100,-20}})));

  Modelica.Blocks.Sources.Constant TCold(k=10 + 273.15) annotation (Placement(transformation(extent={{-120,-80},{-100,-60}})));

  Modelica.Blocks.Sources.TimeTable timeTable(
    offset=273.15,
    table=[ 0,10; 20,10;
           20,30; 40,30]) annotation (Placement(transformation(extent={{-90,-10},{-70,10}})));

  Modelica.Blocks.Sources.TimeTable timeTable1(
    offset=273.15,
    table=[ 0,50; 20,50;
           20,30; 40,30]) annotation (Placement(transformation(extent={{70,10},{90,30}})));

  Modelica.Fluid.Sensors.Temperature outletCold_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{-40,60},{-20,80}})));

  Modelica.Fluid.Sensors.Temperature outletHot_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{20,-80},{40,-60}})));

  Modelica.Fluid.Sensors.Temperature inletHot_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{20,60},{40,80}})));

  Modelica.Fluid.Sensors.Temperature inletCold_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{-40,-80},{-20,-60}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature fixedTemperature(T=
        293.15) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={0,70})));
equation
  connect(inlet_hot.ports[1], platesHeatExchanger.port_a_Hot) annotation (Line(
        points={{60,60},{52,60},{52,30},{44,30}}, color={0,127,255}));
  connect(platesHeatExchanger.port_b_Hot, outlet_hot.ports[1]) annotation (Line(
        points={{44,-30},{52,-30},{52,-60},{62,-60}}, color={0,127,255}));
  connect(inlet_cold.ports[1], platesHeatExchanger.port_a_Cold) annotation (
      Line(points={{-60,-60},{-50,-60},{-50,-34},{-44,-34}}, color={0,127,255}));
  connect(outlet_cold.ports[1], platesHeatExchanger.port_b_Cold) annotation (
      Line(points={{-60,60},{-50,60},{-50,26},{-44,26}}, color={0,127,255}));
  connect(m_flowHot.y,inlet_hot. m_flow_in) annotation (Line(points={{99,90},{
          90,90},{90,68},{80,68}}, color={0,0,127}));
  connect(m_flowCold.y, inlet_cold.m_flow_in) annotation (Line(points={{-99,-30},
          {-90,-30},{-90,-52},{-80,-52}}, color={0,0,127}));
  connect(TCold.y, inlet_cold.T_in) annotation (Line(points={{-99,-70},{-90,-70},
          {-90,-56},{-82,-56}}, color={0,0,127}));
  connect(inlet_hot.T_in, THot.y) annotation (Line(points={{82,64},{90,64},{90,54},{99,54}},
                                                         color={0,0,127}));
  connect(platesHeatExchanger.port_a_Cold, inletCold_T.port) annotation (Line(
        points={{-44,-34},{-50,-34},{-50,-80},{-30,-80}},
        color={0,127,255}));
  connect(platesHeatExchanger.port_b_Hot, outletHot_T.port) annotation (Line(
        points={{44,-30},{52,-30},{52,-80},{30,-80}}, color={0,127,255}));
  connect(inletHot_T.port, platesHeatExchanger.port_a_Hot) annotation (Line(
        points={{30,60},{52,60},{52,30},{44,30}}, color={0,127,255}));
  connect(outletCold_T.port, platesHeatExchanger.port_b_Cold) annotation (Line(
        points={{-30,60},{-50,60},{-50,26},{-44,26}}, color={0,127,255}));
  connect(fixedTemperature.port, platesHeatExchanger.port_a_ambient)
    annotation (Line(points={{0,60},{0,38}}, color={191,0,0}));
  annotation (Documentation(revisions="<html>
<p>2016-05-16 Eduardo Ubieta (IK4-TEKNIKER): First implementation</p>
<h4>Copyright &copy; IK4-TEKNIKER</h4>
</html>"));
end PlatesHeatTransfer_heatLosses_parallel;
