within DCOL.Distribution.HeatExchanger.Testing;
model PlatesHeatTransfer_serie

  PlatesHeatExchanger_serie platesHeatExchanger(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    redeclare package Medium1 =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    length_hot=1.5,
    length_cold=1.5,
    redeclare package Material =
        Modelica_IK4_TEKNIKER.Thermal.Materials.Copper,
    diameter_hot=sqrt(0.01*4/Modelica.Constants.pi),
    diameter_cold=sqrt(0.01*4/Modelica.Constants.pi),
    nPlates=2,
    T_start_hot=313.15,
    T_start_cold=293.15,
    T_start=303.15)
    annotation (Placement(transformation(extent={{-40,-42},{40,38}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-90,20},
            {-70,40}})));

  Modelica.Fluid.Sources.FixedBoundary outlet_hot(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1) annotation (Placement(transformation(extent={{-100,-60},{-80,-40}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_hot(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    m_flow=50,
    T=323.15) annotation (Placement(transformation(extent={{80,50},{60,70}})));

  Modelica.Fluid.Sources.FixedBoundary outlet_cold(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1) annotation (Placement(transformation(extent={{100,-60},{80,-40}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_cold(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    m_flow=100,
    T=283.15) annotation (Placement(transformation(extent={{-80,50},{-60,70}})));

  Modelica.Blocks.Sources.Constant m_flowHot(k=50) annotation (Placement(transformation(extent={{120,70},
            {100,90}})));

  Modelica.Blocks.Sources.Constant THot(k=50 + 273.15) annotation (Placement(transformation(extent={{120,40},
            {100,60}})));

  Modelica.Blocks.Sources.Constant m_flowCold(k=60) annotation (Placement(transformation(extent={{-120,70},
            {-100,90}})));

  Modelica.Blocks.Sources.Constant TCold(k=10 + 273.15) annotation (Placement(transformation(extent={{-120,40},
            {-100,60}})));

  Modelica.Blocks.Sources.TimeTable timeTable(
    offset=273.15,
    table=[ 0,10; 20,10;
           20,30; 40,30]) annotation (Placement(transformation(extent={{-90,-10},
            {-70,10}})));

  Modelica.Blocks.Sources.TimeTable timeTable1(
    offset=273.15,
    table=[ 0,50; 20,50;
           20,30; 40,30]) annotation (Placement(transformation(extent={{90,10},
            {70,30}})));

  Modelica.Fluid.Sensors.Temperature outletCold_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{78,-28},
            {58,-8}})));

  Modelica.Fluid.Sensors.Temperature outletHot_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{-80,-40},
            {-60,-20}})));

  Modelica.Fluid.Sensors.Temperature inletHot_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{30,60},
            {50,80}})));

  Modelica.Fluid.Sensors.Temperature inletCold_T(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{-50,40},
            {-30,60}})));

equation
  connect(inlet_hot.ports[1], platesHeatExchanger.port_a_Hot) annotation (Line(
        points={{60,60},{52,60},{52,30},{44,30}}, color={0,127,255}));
  connect(platesHeatExchanger.port_b_Hot, outlet_hot.ports[1]) annotation (Line(
        points={{-44,-26},{-50,-26},{-50,-50},{-80,-50}},
                                                      color={0,127,255}));
  connect(inlet_cold.ports[1], platesHeatExchanger.port_a_Cold) annotation (
      Line(points={{-60,60},{-60,22},{-44,22}},              color={0,127,255}));
  connect(outlet_cold.ports[1], platesHeatExchanger.port_b_Cold) annotation (
      Line(points={{80,-50},{60,-50},{60,-34},{44,-34}}, color={0,127,255}));
  connect(m_flowHot.y,inlet_hot. m_flow_in) annotation (Line(points={{99,80},{
          90,80},{90,68},{80,68}}, color={0,0,127}));
  connect(m_flowCold.y, inlet_cold.m_flow_in) annotation (Line(points={{-99,80},
          {-92,80},{-92,68},{-80,68}},    color={0,0,127}));
  connect(TCold.y, inlet_cold.T_in) annotation (Line(points={{-99,50},{-92,50},
          {-92,64},{-82,64}},   color={0,0,127}));
  connect(inlet_hot.T_in, THot.y) annotation (Line(points={{82,64},{90,64},{90,
          50},{99,50}},                                  color={0,0,127}));
  connect(platesHeatExchanger.port_a_Cold, inletCold_T.port) annotation (Line(
        points={{-44,22},{-50,22},{-50,40},{-40,40}},
        color={0,127,255}));
  connect(platesHeatExchanger.port_b_Hot, outletHot_T.port) annotation (Line(
        points={{-44,-26},{-50,-26},{-50,-40},{-70,-40}},
                                                      color={0,127,255}));
  connect(inletHot_T.port, platesHeatExchanger.port_a_Hot) annotation (Line(
        points={{40,60},{52,60},{52,30},{44,30}}, color={0,127,255}));
  connect(outletCold_T.port, platesHeatExchanger.port_b_Cold) annotation (Line(
        points={{68,-28},{68,-28},{68,-34},{44,-34}}, color={0,127,255}));
  annotation (Documentation(revisions="<html>
<p>2016-05-16 Eduardo Ubieta (IK4-TEKNIKER): First implementation</p>
<h4>Copyright &copy; IK4-TEKNIKER</h4>
</html>"));
end PlatesHeatTransfer_serie;
