within DCOL.Distribution.Pipes.BaseClasses;
block Type31 "TRANSYS type31"
  import Modelica.Math.Vectors.interpolate;
  import Modelica.Constants.pi;
  import Modelica.Constants.inf;

  parameter Modelica.SIunits.Length length "Length";
  parameter Modelica.SIunits.Diameter diameter "Diameter of circular pipe";

  parameter Modelica.SIunits.Density rho "Density of fluid";
  parameter Modelica.SIunits.SpecificHeatCapacity cp "Cp of fluid";

  parameter Real U "Pipe loss coefficient"; //UNITS

  final parameter Modelica.SIunits.Length perimeter = pi*diameter "Perimeter";
  final parameter Modelica.SIunits.Area cross_area = pi*diameter*diameter/4 "Cross section area";
  final parameter Modelica.SIunits.Volume V = cross_area*length "Volume size";
  final parameter Modelica.SIunits.Mass mass = rho*V "Mass in pipe";

  parameter Integer n = 1000;
  parameter Real initialTs[n] = fill(0.0, n);

  final parameter Modelica.SIunits.Length length_x = length/n "Lenght of segment";
  final parameter Modelica.SIunits.Mass mass_x = mass/n "Mass of elements";
  final parameter Real UA_x = U*perimeter*length_x "Segment overall loss coefficient"; //UNITS

  input Modelica.SIunits.MassFlowRate mflow;
  input Modelica.SIunits.Temperature Tin_a;
  input Modelica.SIunits.Temperature Tin_b;
  input Modelica.SIunits.Temperature[n] Text;
  output Modelica.SIunits.Temperature Tout_a;
  output Modelica.SIunits.Temperature Tout_b;

  Modelica.SIunits.Velocity v "Fluid velocity";

protected
  Modelica.SIunits.Length x "Distant traveled by the new segment";
  Modelica.SIunits.Length x_a "Distant traveled by the new segment";
  Modelica.SIunits.Length x_b "Distant traveled by the new segment";

  Modelica.SIunits.Temperature Ts[n] "Temperature of fluid elements";

initial equation
  x = 0;
  x_a = 0;
  x_b = 0;
  Ts = initialTs;

equation
  v = mflow/(rho*cross_area);
  der(x) = v;
  der(x_a) = semiLinear(v, 1, 0);
  der(x_b) = semiLinear(v, 0, 1);

  Tout_b =  Ts[end];
  Tout_a =  Ts[1];

  mass_x*cp*der(Ts) = UA_x*(Ts - Text);

  when x_a>=length_x then
    reinit(Ts[end:-1:1], cat(1, Ts[end-1:-1:1], {Tin_a}));
    reinit(x_a, 0);
  elsewhen x_b<=-length_x then
    reinit(Ts, cat(1, Ts[2:end], {Tin_b}));
    reinit(x_b, 0);
  end when;
  // when {x_a>=length_x, x_b<=-length_x} then
  //   if x>0 then
  //     reinit(Ts, cat(1, {Tin_a}, Ts[1:end-1]));
  //     reinit(x, 0);
  //   else
  //     reinit(Ts, cat(1, Ts[2:end], {Tin_b}));
  //     reinit(x, 0);
  //   end if;
  // end when;

// algorithm
//   step = x - x0;
//   when abs(step)>=tol_step then
//     if step>0 then
//       Ts[2:end] = Ts[1:end-1];
//       Ts[1] = Tin_a;
//     elseif step<0 then
//       Ts[1:end-1] = Ts[2:end];
//       Ts[end] = Tin_b;
//     end if;
//     x0 = x;
//   end when;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(preserveAspectRatio=false)));
end Type31;
