within DCOL.Distribution.Pipes.BaseClasses;
block spatialDistributionUser "spatialDistribution operator implemented in Modelica"
  import Modelica.Math.Vectors.interpolate;
  import Modelica.Constants.inf;

  parameter Integer n_max = 1000;
  parameter Real tol_step;
  parameter Real initialPoints[:] = {0.0, 1.0};
  parameter Real initialValues[:] = {0.0, 0.0};
  input Real in0;
  input Real in1;
  input Real x;
  input Boolean positiveVelocity;
  output Real out0;
  output Real out1;
protected
  Real points[n_max] "Position points";
  Real values[n_max] "Values";
  Real x0 "Previuos position";
  // Real y0 "Previous value";
  Real step "Actual step";
  Real diff_min;
  Integer i_end "points[i_end] = 1";
  Integer i_start "points[i_start] = 0";
  Integer size "Actual size";
  Integer m "Counter";
  Integer i_diff_min "Counter";

initial algorithm
  x0 := x;
  points := linspace(0.0, 1.0, n_max);
  values := {
    interpolate(initialPoints, initialValues, points[i])
    for i in 1:n_max};
  i_end := n_max;
  i_start := 1;
  diff_min := inf;

algorithm
  step := x-x0;
  if positiveVelocity then
    (out1,) := interpolate(points[i_start:i_end], values[i_start:i_end], 1-step);
    out0 := values[i_start];
  else
    out1 := values[i_end]; //
    (out0,) := interpolate(points[i_start:i_end], values[i_start:i_end], 0-step);
  end if;

  when abs(step)>tol_step then
    size := i_end - (i_start-1);

    if size==n_max then
      i_diff_min := 1;
      diff_min := inf;
      for i in 1:(n_max-1) loop
        if abs(values[i]-values[i+1])<diff_min then
          diff_min := abs(values[i] - values[i+1]);
          i_diff_min := i;
        end if;
      end for;
      points[i_diff_min] := (points[i_diff_min]+points[i_diff_min+1])/2.0;
      values[i_diff_min] := (values[i_diff_min]+values[i_diff_min+1])/2.0;
      for i in i_diff_min+1:n_max-1 loop
        points[i] := points[i+1];
        values[i] := values[i+1];
      end for;
      i_end := i_end-1;
    end if;

    if step>0 then
      if i_end==n_max then
        i_end := i_end-1;
        for i in i_start:i_end loop
          points[i] := points[i+1];
          values[i] := values[i+1];
        end for;
      end if;
      m := i_end;
      while (m>i_start and points[m]+step>=1) loop
        m := m-1;
      end while;
      values[m+2] := interpolate(points[i_start:i_end], values[i_start:i_end], 1-step);
      values[i_start+1:m+1] := values[i_start:m];
      values[i_start] := in0;
      points[m+2] := 1;
      points[i_start+1:m+1] := points[i_start:m] .+ step;
      points[i_start] := 0;
      i_end := m+2;
    elseif step<0 then
      if i_start==1 then
        i_start := i_start+1;
        for i in i_end:-1:i_start loop
          points[i] := points[i-1];
          values[i] := values[i-1];
        end for;
      end if;
      m := i_start;
      while (m<i_end and points[m]+step<=0) loop
        m := m+1;
      end while;
      values[m-2] := interpolate(points[i_start:i_end], values[i_start:i_end], 0-step);
      values[m-1:i_end-1] := values[m:i_end];
      values[i_end] := in1;
      points[m-2] := 0;
      points[m-1:i_end-1] := points[m:i_end] .+ step;
      points[i_end] := 1;
      i_start := m-2;
    end if;
    x0 := x;
  end when;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(preserveAspectRatio=false)));
end spatialDistributionUser;
