within DCOL.Distribution.Pipes.FMI;
model Pipe
  import Modelica_IK4_TEKNIKER;
  model Monitoring
    parameter Integer n;
    input SI.Temperature[n] pipe_Ts;
    input SI.Temperature[n] tube_Ts;
    input SI.Temperature[n] isolation_Ts;
    //input SI.HeatFlowRate[n] pipeTube_Q_flows;
    //input SI.HeatFlowRate[n] tubeIsolation_Q_flows;
  end Monitoring;

  Monitoring monitoring(
    n = n,
    pipe_Ts = pipe.Ts,
    tube_Ts = tube.Ts[1,:,1],
    isolation_Ts = isolation.Ts[1,:,1]);
    //pipeTube_Q_flows = pipe.heatPorts.Q_flow,
    //tubeIsolation_Q_flows = tube.port_a_radial[1,:].Q_flow,

  import SI = Modelica.SIunits;

  parameter Integer n=100;
  parameter SI.Length length = 2000;
  parameter SI.Length diameter_int = 0.2;
  parameter SI.Length tube_thickness = 0.002;
  parameter SI.Length isolation_thickness = 0.002;
  parameter SI.Temperature T_start = 9 +273.15;
  parameter SI.Pressure p_start = 101325;
  parameter SI.MassFlowRate m_flow_start = 200;
  parameter SI.Pressure dp_nominal = 20;
  parameter SI.MassFlowRate m_flow_nominal = 200;

protected
  parameter SI.Length length_aux(fixed=false);
  parameter SI.Temperature T_start_aux(fixed=false);
  parameter SI.Pressure p_start_aux(fixed=false);
  parameter SI.MassFlowRate m_flow_start_aux(fixed=false);
  parameter SI.Pressure dp_nominal_aux(fixed=false);
  parameter SI.MassFlowRate m_flow_nominal_aux(fixed=false);

protected
  Pipes.DynamicPipePlugFlow pipe(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    nNodes=n,
    diameter=diameter_int,
    use_HeatTransfer=true,
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.LocalPipeFlowHeatTransfer,
    allowFlowReversal=false,
    nParallel=1,
    length=length_aux,
    isCircular=true,
    useLumpedPressure=false,
    useInnerPortProperties=false,
    T_start=T_start_aux,
    modelStructure=Modelica.Fluid.Types.ModelStructure.a_v_b,
    height_ab=0,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (                        dp_nominal=dp_nominal_aux, m_flow_nominal=m_flow_nominal_aux),
    p_a_start=p_start_aux,
    m_flow_start=m_flow_start_aux) annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica_IK4_TEKNIKER.DCOL.Distribution1.Thermal_temp.HollowCylinder tube(
    nRadial=1,
    nLongitudinal=n,
    nAngular=1,
    alpha=2*Modelica.Constants.pi,
    redeclare package Material =
        .Modelica_IK4_TEKNIKER.Thermal.Materials.Copper,
    use_radialDim=true,
    r_int=diameter_int/2,
    r_ext=tube_thickness + diameter_int/2,
    length=length_aux,
    modelStructure_longitudinal=Modelica.Fluid.Types.ModelStructure.av_vb,
    modelStructure_angular=Modelica.Fluid.Types.ModelStructure.a_v_b,
    use_longitudinalDim=false,
    use_angularDim=false,
    modelStructure_radial=Modelica.Fluid.Types.ModelStructure.a_vb,
    T_start=T_start_aux,
    der_T_start=0,
    nParallel=1) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={0,20})));
  Modelica_IK4_TEKNIKER.DCOL.Distribution1.Thermal_temp.HollowCylinder isolation(
    nLongitudinal=n,
    alpha=2*Modelica.Constants.pi,
    use_radialDim=true,
    r_int=tube_thickness + diameter_int/2,
    r_ext=isolation_thickness + tube_thickness + diameter_int/2,
    length=length_aux,
    nAngular=1,
    modelStructure_longitudinal=Modelica.Fluid.Types.ModelStructure.av_vb,
    modelStructure_angular=Modelica.Fluid.Types.ModelStructure.a_v_b,
    use_longitudinalDim=false,
    use_angularDim=false,
    nRadial=1,
    redeclare package Material =
        .Modelica_IK4_TEKNIKER.Thermal.Materials.Armaflex_ClassO,
    modelStructure_radial=Modelica.Fluid.Types.ModelStructure.a_vb,
    T_start=T_start_aux,
    der_T_start=0,
    nParallel=1) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={0,40})));

protected
  Modelica.Fluid.Sources.Boundary_pT IN_pT(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_T_in=true,
    nPorts=1,
    use_p_in=true)
    annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
  Modelica.Fluid.Sources.MassFlowSource_T IN_m_flow(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_T_in=false,
    use_m_flow_in=true,
    nPorts=1)
    annotation (Placement(transformation(extent={{-50,-50},{-30,-30}})));
  Modelica.Blocks.Math.Gain gain(k=-1)
    annotation (Placement(transformation(extent={{-68,-36},{-60,-28}})));
  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature fixedTemperature[n]
    annotation (Placement(transformation(extent={{-36,52},{-20,68}})));

  Modelica.Fluid.Sensors.TemperatureTwoPort temperature(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{20,-10},{40,10}})));
  Modelica.Fluid.Sensors.Pressure pressure(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{70,0},{90,20}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlowRate(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{50,-10},{70,10}})));

  inner Modelica.Fluid.System system(
    m_flow_start=m_flow_start_aux,
    T_start=T_start_aux,
    p_ambient(displayUnit="Pa"))
    annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));

public
  Modelica.Blocks.Interfaces.RealInput T_in
    annotation (Placement(transformation(extent={{-120,-6},{-100,14}})));
  Modelica.Blocks.Interfaces.RealInput p_in
    annotation (Placement(transformation(extent={{-120,10},{-100,30}})));
  Modelica.Blocks.Interfaces.RealInput m_flow_in
    annotation (Placement(transformation(extent={{-120,-42},{-100,-22}})));
  Modelica.Blocks.Interfaces.RealInput T_ambient
    annotation (Placement(transformation(extent={{-120,50},{-100,70}})));

  Modelica.Blocks.Interfaces.RealOutput T_out
    annotation (Placement(transformation(extent={{100,40},{120,60}})));
  Modelica.Blocks.Interfaces.RealOutput p_out
    annotation (Placement(transformation(extent={{100,0},{120,20}})));
  Modelica.Blocks.Interfaces.RealOutput m_flow_out
    annotation (Placement(transformation(extent={{100,20},{120,40}})));

  Modelica.Blocks.Discrete.TriggeredSampler sampler(trigger=pipe.whenTrigger) annotation (Placement(transformation(extent={{-92,-38},{-80,-26}})));
  Modelica.Blocks.Discrete.TriggeredSampler sampler1(trigger=pipe.whenTrigger) annotation (Placement(transformation(extent={{-92,14},{-80,26}})));
initial equation
  length_aux = length;
  T_start_aux = T_start;
  p_start_aux = p_start;
  m_flow_start_aux = m_flow_start;
  dp_nominal_aux = dp_nominal;
  m_flow_nominal_aux = m_flow_nominal;

equation
  connect(IN_pT.ports[1], pipe.port_a) annotation (Line(points={{-50,0},{-50,0},{-10,0}}, color={0,127,255}));
  connect(pipe.port_b, temperature.port_a) annotation (Line(points={{10,0},{20,0}}, color={0,127,255}));
  connect(temperature.T, T_out) annotation (Line(points={{30,11},{30,11},{30,50},{110,50}},color={0,0,127}));
  connect(p_out, pressure.p) annotation (Line(points={{110,10},{110,10},{91,10}}, color={0,0,127}));
  connect(temperature.port_b, massFlowRate.port_a) annotation (Line(points={{40,0},{45,0},{50,0}}, color={0,127,255}));
  connect(massFlowRate.port_b, pressure.port) annotation (Line(points={{70,0},{75,0},{80,0}}, color={0,127,255}));
  connect(pressure.port, IN_m_flow.ports[1]) annotation (Line(points={{80,0},{80,0},{80,-40},{-30,-40}}, color={0,127,255}));
  connect(massFlowRate.m_flow, m_flow_out) annotation (Line(points={{60,11},{60,30},{110,30}},color={0,0,127}));
  connect(gain.y, IN_m_flow.m_flow_in) annotation (Line(points={{-59.6,-32},{-50,-32}}, color={0,0,127}));
  connect(isolation.port_a_radial[1, :], fixedTemperature.port) annotation (Line(points={{0,48},{0,48},{0,60},{-20,60}},color={191,0,0}));
  connect(isolation.port_b_radial, tube.port_a_radial) annotation (Line(points={{0,32},{0,30},{0,28}}, color={191,0,0}));
  connect(tube.port_b_radial[1, :], pipe.heatPorts) annotation (Line(points={{0,12},{0,4.4},{0.1,4.4}}, color={191,0,0}));
  connect(T_in, IN_pT.T_in) annotation (Line(points={{-110,4},{-72,4}},         color={0,0,127}));
  for i in 1:n loop
    connect(T_ambient, fixedTemperature[i].T)
      annotation (Line(points={{-110,60},{-37.6,60}},            color={0,0,127}));
  end for;

  connect(m_flow_in, sampler.u) annotation (Line(points={{-110,-32},{-93.2,-32}}, color={0,0,127}));
  connect(sampler.y, gain.u) annotation (Line(points={{-79.4,-32},{-68.8,-32}}, color={0,0,127}));
  connect(p_in, sampler1.u) annotation (Line(points={{-110,20},{-93.2,20}}, color={0,0,127}));
  connect(sampler1.y, IN_pT.p_in) annotation (Line(points={{-79.4,20},{-72,20},{-72,8}}, color={0,0,127}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(preserveAspectRatio=false), graphics={Text(
          extent={{0,80},{-80,100}},
          lineColor={28,108,200},
          textString="Advanced.SparseActivate=true")}),
    experiment(
      StopTime=1200,
      Tolerance=1e-006,
      __Dymola_Algorithm="Cvode"),
    __Dymola_experimentSetupOutput);
end Pipe;
