within DCOL.Distribution.Pipes.Testing.Distribution;
model Annex60_pipe
  package Medium = Modelica.Media.Water.StandardWater;
  parameter Modelica.SIunits.Diameter diameter=0.2540 "Pipe diameter";
  parameter Modelica.SIunits.Length length=1000 "Pipe length";
  parameter Modelica.SIunits.Length thicknessIns=0.04 "Thickness of pipe insulation";
  parameter Modelica.SIunits.ThermalConductivity lambdaI=0.026 "Heat conductivity";
  parameter Modelica.SIunits.Temperature T_amb=313.15 "Amb. temp.";
  parameter Modelica.SIunits.Temperature T_in=280.15 "Inlet temp.";
  parameter Modelica.SIunits.MassFlowRate m_flow=5;

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature fixedTemperature(T=T_amb)
    annotation (Placement(transformation(extent={{-60,50},{-40,70}})));
  Annex60.Experimental.Pipe.PipeHeatLoss pipeHeatLoss(
    diameter=diameter,
    length=length,
    thicknessIns=thicknessIns,
    lambdaI=lambdaI,
    redeclare package Medium = Medium,
    m_flow_nominal=m_flow,
    allowFlowReversal=false)
    annotation (Placement(transformation(extent={{-24,-24},{24,24}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    nPorts=1,
    m_flow=m_flow,
    T=T_in,
    redeclare package Medium = Medium)
              annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));
  Modelica.Fluid.Sources.FixedBoundary boundary1(nPorts=1, redeclare package Medium = Medium)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={70,0})));
  Modelica.Blocks.Sources.RealExpression Losses(y=fixedTemperature.port.Q_flow)
    annotation (Placement(transformation(extent={{40,-70},{60,-50}})));
  Modelica.Fluid.Sensors.TemperatureTwoPort
                                     T_o(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{30,-10},{50,10}})));
  Modelica.Blocks.Interfaces.RealOutput T_out(unit="K") annotation (Placement(transformation(extent={{100,30},{120,50}})));
  Modelica.Blocks.Interfaces.RealOutput Q_losses annotation (Placement(transformation(extent={{100,-70},{120,-50}})));
equation
  connect(boundary.ports[1], pipeHeatLoss.port_a) annotation (Line(points={{-40,0},{-24,0}}, color={0,127,255}));

  connect(fixedTemperature.port, pipeHeatLoss.heatPort)
    annotation (Line(points={{-40,60},{0,60},{0,24}}, color={191,0,0}));
  connect(Losses.y, Q_losses) annotation (Line(points={{61,-60},{110,-60}},           color={0,0,127}));
  connect(T_o.T, T_out) annotation (Line(points={{40,11},{40,11},{40,40},{110,40}},
                                                                             color={0,0,127}));
  connect(pipeHeatLoss.port_b, T_o.port_a) annotation (Line(points={{24,0},{30,0}}, color={0,127,255}));
  connect(T_o.port_b, boundary1.ports[1]) annotation (Line(points={{50,0},{60,0}}, color={0,127,255}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)));
end Annex60_pipe;
