within DCOL.Distribution.Pipes.Testing.Distribution;
model Annex60pipeVsDynamicPipe
  parameter Integer nNodes=500;
  parameter Modelica.SIunits.Diameter diameter=0.2540 "Pipe diameter";
  parameter Modelica.SIunits.Length length=1000 "Pipe length";
  parameter Modelica.SIunits.Length thicknessIns=0.04 "Thickness of pipe insulation";
  parameter Modelica.SIunits.ThermalConductivity lambdaI=0.026 "Heat conductivity";

  Annex60.Experimental.Pipe.PipeHeatLoss pipeHeatLoss(
    m_flow_nominal=2,
    diameter=diameter,
    length=length,
    thicknessIns=thicknessIns,
    lambdaI=lambdaI,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    annotation (Placement(transformation(extent={{-24,16},{24,64}})));
  Modelica.Fluid.Pipes.DynamicPipe pipe(
    use_HeatTransfer=true,
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.LocalPipeFlowHeatTransfer,
    nNodes=nNodes,
    length=length,
    diameter=diameter,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    annotation (Placement(transformation(extent={{-18,-58},{18,-22}})));

  Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor[
    nNodes](G=(2*Modelica.Constants.pi*length/nNodes)*lambdaI/(((diameter/2) + thicknessIns)/(diameter/2)))
    annotation (Placement(transformation(extent={{-40,-20},{-20,0}})));

  Modelica.Fluid.Sources.FixedBoundary boundary(nPorts=1, redeclare package Medium =
               Modelica.Media.Water.StandardWater) annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={50,40})));
  Modelica.Fluid.Sources.MassFlowSource_T boundary1(
    nPorts=1,
    m_flow=2,
    T=280.15,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    annotation (Placement(transformation(extent={{-60,30},{-40,50}})));
  Modelica.Fluid.Sources.MassFlowSource_T boundary2(
    nPorts=1,
    m_flow=2,
    T=280.15,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    annotation (Placement(transformation(extent={{-60,-50},{-40,-30}})));
  Modelica.Fluid.Sources.FixedBoundary boundary3(nPorts=1, redeclare package Medium =
               Modelica.Media.Water.StandardWater) annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={50,-40})));
  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature fixedTemperature[nNodes](T=313.15)
    annotation (Placement(transformation(extent={{-118,70},{-98,90}})));
  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));
equation
  connect(pipeHeatLoss.port_b, boundary.ports[1]) annotation (Line(points={{24,40},{40,40}},
                                    color={0,127,255}));
  connect(boundary1.ports[1], pipeHeatLoss.port_a)
    annotation (Line(points={{-40,40},{-24,40}},          color={0,127,255}));
  connect(boundary2.ports[1], pipe.port_a) annotation (Line(points={{-40,-40},{-40,-40},{-18,-40}},
                           color={0,127,255}));
  connect(pipe.port_b, boundary3.ports[1])
    annotation (Line(points={{18,-40},{32,-40},{40,-40}}, color={0,127,255}));

  connect(fixedTemperature.port, thermalConductor.port_a)
    annotation (Line(points={{-98,80},{-80,80},{-80,-10},{-40,-10}}, color={191,0,0}));
  connect(pipeHeatLoss.heatPort, fixedTemperature[1].port)
    annotation (Line(points={{0,64},{0,64},{0,80},{-98,80}}, color={191,0,0}));
  connect(thermalConductor.port_b, pipe.heatPorts)
    annotation (Line(points={{-20,-10},{0.18,-10},{0.18,-32.08}}, color={191,0,0}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)));
end Annex60pipeVsDynamicPipe;
