within DCOL.Distribution.Pipes.Testing.Distribution;
model DynamicPipe300nodes

  Modelica.Fluid.Pipes.DynamicPipe pipe(
    use_HeatTransfer=true,
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.LocalPipeFlowHeatTransfer,
    length=length,
    diameter=diameter,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    nNodes=nNodes)
    annotation (Placement(transformation(extent={{-14,-54},{22,-18}})));

  Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor[
    nNodes](G=(2*Modelica.Constants.pi*length/nNodes)*lambdaI/(((diameter/2) +
        thicknessIns)/(diameter/2)))
    annotation (Placement(transformation(extent={{-32,-24},{-12,-4}})));
  parameter Modelica.SIunits.Diameter diameter=0.2540 "Pipe diameter";
  parameter Modelica.SIunits.Length length=1000 "Pipe length";
  parameter Modelica.SIunits.Length thicknessIns=0.04
    "Thickness of pipe insulation";
  parameter Modelica.SIunits.ThermalConductivity lambdaI=0.026
    "Heat conductivity";
  Modelica.Fluid.Sources.MassFlowSource_T boundary2(
    nPorts=1,
    m_flow=2,
    T=280.15,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    annotation (Placement(transformation(extent={{-92,-48},{-72,-28}})));
  Modelica.Fluid.Sources.FixedBoundary boundary3(nPorts=1, redeclare package Medium =
               Modelica.Media.Water.StandardWater) annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={78,-36})));
  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature fixedTemperature(T=313.15)
    annotation (Placement(transformation(extent={{-118,70},{-98,90}})));
  parameter Integer nNodes=500 "Number of discrete flow volumes";
equation
  connect(pipe.heatPorts, thermalConductor.port_b) annotation (Line(points={{4.18,
          -28.08},{4.18,-14},{-12,-14}}, color={127,0,0}));
  connect(boundary2.ports[1], pipe.port_a) annotation (Line(points={{-72,-38},{-14,
          -38},{-14,-36}}, color={0,127,255}));
  connect(pipe.port_b, boundary3.ports[1])
    annotation (Line(points={{22,-36},{68,-36}},          color={0,127,255}));
  for i in 1:nNodes loop
  connect(thermalConductor[i].port_a, fixedTemperature.port)
    annotation (Line(points={{-32,-14},{-98,-14},{-98,80}}, color={191,0,0}));
  end for;
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)));
end DynamicPipe300nodes;
