within DCOL.Distribution.Pipes.Testing;
model LongPipePF
  parameter Integer n = 50;
  parameter Real T_start = 9 +273.15;
  parameter Real L = 2000;
  parameter Real d = 0.2;
  parameter Real Text = 24 +273.15;
  parameter Real m_flow_start = 200;
  Real mflow;
  Real Tin_a;
  Real Tin_b;

  Pipes.DynamicPipePlugFlow pipe(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    nNodes=n,
    length=L,
    diameter=d,
    use_HeatTransfer=true,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (                        dp_nominal=2000, m_flow_nominal=m_flow_start),
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.LocalPipeFlowHeatTransfer,
    modelStructure=Modelica.Fluid.Types.ModelStructure.a_v_b) annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica.Fluid.Sources.MassFlowSource_T source(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    use_T_in=true)
              annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
  Modelica.Fluid.Sources.Boundary_pT   sink(nPorts=1, redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_T_in=true,
    p=system.p_ambient)                                                                                                            annotation (Placement(transformation(extent={{70,-10},{50,10}})));
  Modelica.Blocks.Sources.RealExpression mflowRE(y=mflow) annotation (Placement(transformation(extent={{-100,6},{-80,26}})));
  Modelica.Blocks.Sources.RealExpression Tin_aRE(y=Tin_a) annotation (Placement(transformation(extent={{-100,-6},{-80,14}})));
  Modelica.Blocks.Sources.RealExpression Tin_bRE(y=Tin_b) annotation (Placement(transformation(extent={{100,-6},{80,14}})));
  Modelica.Fluid.Sensors.TemperatureTwoPort T_a(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                                                                    annotation (Placement(transformation(extent={{-40,-10},{-20,10}})));
  Modelica.Fluid.Sensors.TemperatureTwoPort T_b(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                                                                    annotation (Placement(transformation(extent={{20,-10},{40,10}})));
  Modelica.Fluid.Sensors.RelativePressure dP(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                                                                 annotation (Placement(transformation(extent={{-10,-40},{10,-20}})));
  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature fixedTemperature[n](each T=Text) annotation (Placement(transformation(extent={{36,44},{20,60}})));
  inner Modelica.Fluid.System system(T_ambient=Text,
    m_flow_start=m_flow_start,
    T_start=T_start)                                 annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));
  .Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.ThermalVolumes.HollowCylinder tube(
    use_angularDim=false,
    nRadial=1,
    nLongitudinal=n,
    nAngular=1,
    r_int=d/2,
    alpha=2*Modelica.Constants.pi,
    length=L,
    redeclare package Material =
        .Modelica_IK4_TEKNIKER.Thermal.Materials.Copper,
    r_ext=0.002 + d/2,
    use_longitudinalDim=false) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={0,20})));
  .Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.ThermalVolumes.HollowCylinder isolation(
    use_angularDim=false,
    nRadial=1,
    nLongitudinal=n,
    nAngular=1,
    alpha=2*Modelica.Constants.pi,
    length=L,
    redeclare package Material =
        .Modelica_IK4_TEKNIKER.Thermal.Materials.Armaflex_ClassO,
    r_int=0.002 + d/2,
    r_ext=0.005 + 0.002 + d/2,
    use_longitudinalDim=false) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={0,40})));
equation
  mflow = if time<10*60 then m_flow_start else -m_flow_start;
  Tin_a = if time<2*60 then 1 +273.15 else 2 +273.15;
  Tin_b = 1 +273.15;

  connect(mflowRE.y, source.m_flow_in) annotation (Line(points={{-79,16},{-76,16},{-76,8},{-70,8}},   color={0,0,127}));
  connect(Tin_aRE.y, source.T_in) annotation (Line(points={{-79,4},{-72,4}},     color={0,0,127}));
  connect(Tin_bRE.y, sink.T_in) annotation (Line(points={{79,4},{72,4}},     color={0,0,127}));
  connect(source.ports[1], T_a.port_a) annotation (Line(points={{-50,0},{-50,0},{-40,0}},
                                                                                      color={0,127,255}));
  connect(T_a.port_b, pipe.port_a) annotation (Line(points={{-20,0},{-20,0},{-10,0}},
                                                                                  color={0,127,255}));
  connect(pipe.port_b, T_b.port_a) annotation (Line(points={{10,0},{20,0}},     color={0,127,255}));
  connect(T_b.port_b, sink.ports[1]) annotation (Line(points={{40,0},{50,0}},     color={0,127,255}));
  connect(dP.port_a, T_a.port_b) annotation (Line(points={{-10,-30},{-14,-30},{-14,0},{-20,0}},     color={0,127,255}));
  connect(dP.port_b, T_b.port_a) annotation (Line(points={{10,-30},{14,-30},{14,0},{20,0}},     color={0,127,255}));
  connect(isolation.port_b_3, isolation.port_a_3) annotation (Line(points={{6.4,33.6},{-0.2,33.6},{-0.2,46.4},{-6.4,46.4}}, color={191,0,0}));
  connect(tube.port_b_3, tube.port_a_3) annotation (Line(points={{6.4,13.6},{0,13.6},{0,26.4},{-6.4,26.4}},     color={191,0,0}));
  connect(fixedTemperature.port, isolation.port_a_1[1, :]) annotation (Line(points={{20,52},{10,52},{0,52},{0,48}}, color={191,0,0}));
  connect(isolation.port_b_1, tube.port_a_1) annotation (Line(points={{0,32},{0,28}}, color={191,0,0}));
  connect(tube.port_b_1[1, :], pipe.heatPorts) annotation (Line(points={{0,12},{0,4.4},{0.1,4.4}}, color={191,0,0}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(preserveAspectRatio=false)),
    experiment(StopTime=1200, __Dymola_Algorithm="Dassl"),
    __Dymola_experimentSetupOutput);
end LongPipePF;
