within DCOL.Distribution.Pipes.Testing;
model PipeDP
  import Modelica_IK4_TEKNIKER;
  parameter Integer n = 100;
  parameter Real T_start = 9 +273.15;
  parameter Real length = 2000;
  parameter Real diameter_int = 0.2;
  parameter Real tube_thickness = 0.002;
  parameter Real isolation_thickness = 0.002;
  parameter Real Text = 24 +273.15;
  parameter Real m_flow_start = 200;
  Real mflow;
  Real Tin;

  Modelica.Fluid.Pipes.DynamicPipe
                      pipe(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    nNodes=n,
    diameter=diameter_int,
    use_HeatTransfer=true,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (                        dp_nominal=2000, m_flow_nominal=m_flow_start),
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.LocalPipeFlowHeatTransfer,
    allowFlowReversal=false,
    nParallel=1,
    length=length,
    isCircular=true,
    useLumpedPressure=false,
    useInnerPortProperties=false,
    modelStructure=Modelica.Fluid.Types.ModelStructure.a_v_b) annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica.Fluid.Sources.Boundary_pT IN_pT(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_T_in=true,
    nPorts=1,
    use_p_in=true) annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
  Modelica.Fluid.Sources.MassFlowSource_T IN_m_flow(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_T_in=false,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{-50,-50},{-30,-30}})));
  Modelica.Blocks.Sources.RealExpression m_flow_in(y=mflow) annotation (Placement(transformation(extent={{-100,-42},{-80,-22}})));
  Modelica.Blocks.Sources.RealExpression T_in(y=Tin) annotation (Placement(transformation(extent={{-100,-6},{-80,14}})));
  Modelica.Blocks.Sources.RealExpression p_in(y=system.p_ambient) annotation (Placement(transformation(extent={{-100,10},{-80,30}})));
  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
                                                         fixedTemperature[n]              annotation (Placement(transformation(extent={{36,52},{20,68}})));
  inner Modelica.Fluid.System system(T_ambient=Text,
    m_flow_start=m_flow_start,
    T_start=T_start)                                 annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));
  Modelica_IK4_TEKNIKER.DCOL.Distribution1.Thermal_temp.HollowCylinder tube(
    nRadial=1,
    nLongitudinal=n,
    nAngular=1,
    alpha=2*Modelica.Constants.pi,
    redeclare package Material =
        .Modelica_IK4_TEKNIKER.Thermal.Materials.Copper,
    use_radialDim=true,
    r_int=diameter_int/2,
    r_ext=tube_thickness + diameter_int/2,
    length=length,
    modelStructure_longitudinal=Modelica.Fluid.Types.ModelStructure.av_vb,
    modelStructure_angular=Modelica.Fluid.Types.ModelStructure.a_v_b,
    use_longitudinalDim=false,
    use_angularDim=false,
    modelStructure_radial=Modelica.Fluid.Types.ModelStructure.a_vb) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={0,20})));
  Modelica_IK4_TEKNIKER.DCOL.Distribution1.Thermal_temp.HollowCylinder isolation(
    nLongitudinal=n,
    alpha=2*Modelica.Constants.pi,
    use_radialDim=true,
    r_int=tube_thickness + diameter_int/2,
    r_ext=isolation_thickness + tube_thickness + diameter_int/2,
    length=length,
    nAngular=1,
    modelStructure_longitudinal=Modelica.Fluid.Types.ModelStructure.av_vb,
    modelStructure_angular=Modelica.Fluid.Types.ModelStructure.a_v_b,
    use_longitudinalDim=false,
    use_angularDim=false,
    nRadial=1,
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.Armaflex_ClassO,
    modelStructure_radial=Modelica.Fluid.Types.ModelStructure.a_vb) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={0,40})));
  Modelica.Blocks.Sources.RealExpression T_ambient[n](each y=Text)
    annotation (Placement(transformation(extent={{68,50},{48,70}})));
  Modelica.Fluid.Sensors.TemperatureTwoPort temperature(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{20,-10},{40,10}})));
  Modelica.Fluid.Sensors.Pressure pressure(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{70,0},{90,20}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlowRate(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{50,-10},{70,10}})));
  Modelica.Blocks.Interfaces.RealOutput T_out
    annotation (Placement(transformation(extent={{40,4},{52,16}})));
  Modelica.Blocks.Interfaces.RealOutput p_out
    annotation (Placement(transformation(extent={{94,4},{106,16}})));
  Modelica.Blocks.Interfaces.RealOutput m_flow_out
    annotation (Placement(transformation(extent={{58,20},{70,32}})));
  Modelica.Blocks.Math.Gain gain(k=-1)
    annotation (Placement(transformation(extent={{-68,-36},{-60,-28}})));

equation
  mflow = if time<10*60 then m_flow_start else 0.2*m_flow_start;
  Tin = if time<2*60 then 1 +273.15 else 3 +273.15;

  connect(T_in.y, IN_pT.T_in) annotation (Line(points={{-79,4},{-72,4}}, color={0,0,127}));
  connect(IN_pT.ports[1], pipe.port_a) annotation (Line(points={{-50,0},{-30,0},{-10,0}}, color={0,127,255}));
  connect(T_ambient.y, fixedTemperature.T) annotation (Line(points={{47,60},{37.6,60}}, color={0,0,127}));
  connect(pipe.port_b, temperature.port_a) annotation (Line(points={{10,0},{20,0}}, color={0,127,255}));
  connect(temperature.T, T_out) annotation (Line(points={{30,11},{40,11},{40,10},{46,10}}, color={0,0,127}));
  connect(p_out, pressure.p) annotation (Line(points={{100,10},{100,10},{91,10}}, color={0,0,127}));
  connect(p_in.y, IN_pT.p_in) annotation (Line(points={{-79,20},{-72,20},{-72,8}}, color={0,0,127}));
  connect(temperature.port_b, massFlowRate.port_a) annotation (Line(points={{40,0},{45,0},{50,0}}, color={0,127,255}));
  connect(massFlowRate.port_b, pressure.port) annotation (Line(points={{70,0},{75,0},{80,0}}, color={0,127,255}));
  connect(pressure.port, IN_m_flow.ports[1]) annotation (Line(points={{80,0},{80,0},{80,-40},{-30,-40}}, color={0,127,255}));
  connect(massFlowRate.m_flow, m_flow_out) annotation (Line(points={{60,11},{60,26},{64,26}}, color={0,0,127}));
  connect(m_flow_in.y, gain.u) annotation (Line(points={{-79,-32},{-68.8,-32}}, color={0,0,127}));
  connect(gain.y, IN_m_flow.m_flow_in) annotation (Line(points={{-59.6,-32},{-50,-32}}, color={0,0,127}));
  connect(isolation.port_a_radial[1, :], fixedTemperature.port) annotation (Line(points={{0,48},{0,48},{0,60},{20,60}}, color={191,0,0}));
  connect(isolation.port_b_radial, tube.port_a_radial) annotation (Line(points={{0,32},{0,30},{0,28}}, color={191,0,0}));
  connect(tube.port_b_radial[1, :], pipe.heatPorts) annotation (Line(points={{0,12},{0,4.4},{0.1,4.4}}, color={191,0,0}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(preserveAspectRatio=false), graphics={Text(
          extent={{0,80},{-80,100}},
          lineColor={28,108,200},
          textString="Advanced.SparseActivate=true")}),
    experiment(
      StopTime=1200,
      Tolerance=1e-006,
      __Dymola_Algorithm="Cvode"),
    __Dymola_experimentSetupOutput);
end PipeDP;
