within DCOL.Distribution.Pipes.Testing;
model PipeFMI
  parameter Integer n = 3;
  parameter Real T_start = 9 +273.15;
  parameter Real length = 2000;
  parameter Real diameter_int = 0.2;
  parameter Real tube_thickness = 0.002;
  parameter Real isolation_thickness = 0.002;
  parameter Real Text = 24 +273.15;
  parameter Real m_flow_start = 200;
  Real mflow;
  Real Tin;

  Modelica.Blocks.Sources.RealExpression m_flow_in(y=mflow) annotation (Placement(transformation(extent={{-98,-18},{-78,2}})));
  Modelica.Blocks.Sources.RealExpression T_in(y=Tin) annotation (Placement(transformation(extent={{-72,8},{-52,28}})));
  Modelica.Blocks.Sources.RealExpression p_in(y=system.p_ambient) annotation (Placement(transformation(extent={{-72,-6},{-52,14}})));
  inner Modelica.Fluid.System system(T_ambient=Text,
    m_flow_start=m_flow_start,
    T_start=T_start)                                 annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));
  Modelica.Blocks.Sources.RealExpression T_ambient[n](each y=Text)
    annotation (Placement(transformation(extent={{-86,-32},{-66,-12}})));
  Modelica.Blocks.Interfaces.RealOutput T_out
    annotation (Placement(transformation(extent={{40,22},{52,34}})));
  Modelica.Blocks.Interfaces.RealOutput p_out
    annotation (Placement(transformation(extent={{94,4},{106,16}})));
  Modelica.Blocks.Interfaces.RealOutput m_flow_out
    annotation (Placement(transformation(extent={{52,-10},{64,2}})));

  Modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu(
    m_flow_in(start=m_flow_start),
    _m_flow_in_start=m_flow_start,
    p_start(displayUnit="bar") = 500000)
                 annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
equation
  mflow = if time<10*60 then m_flow_start else 0.2*m_flow_start;
  Tin = if time<2*60 then 1 +273.15 else 3 +273.15;

  connect(p_in.y, modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu.p_in) annotation (Line(points={{-51,4},{-20.8,4}}, color={0,0,127}));
  connect(T_in.y, modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu.T_in) annotation (Line(points={{-51,18},{-36,18},{-20.8,18},{-20.8,12}}, color={0,0,127}));
  connect(m_flow_in.y, modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu.m_flow_in) annotation (Line(points={{-77,-8},{-50,-8},{-50,-4},{-20.8,-4}}, color={0,0,127}));
  connect(T_ambient[1].y, modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu.T_ambient) annotation (Line(points={{-65,-22},{-46,-22},{-46,-12},{-20.8,-12}}, color={0,0,127}));
  connect(modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu.T_out, T_out) annotation (Line(points={{24,10},{34,10},{34,28},{46,28}},     color={0,0,127}));
  connect(modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu.p_out, p_out) annotation (Line(points={{24,0},{60,0},{60,10},{100,10}},     color={0,0,127}));
  connect(modelica_0IK4_0TEKNIKER_DCOL_Distribution_FMI_Pipe_fmu.m_flow_out, m_flow_out) annotation (Line(points={{24,-10},{38,-10},{38,-4},{58,-4}},
                                                                                                                                                  color={0,0,127}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(preserveAspectRatio=false), graphics={Text(
          extent={{0,80},{-80,100}},
          lineColor={28,108,200},
          textString="Advanced.SparseActivate=true")}),
    experiment(
      StopTime=1200,
      Tolerance=1e-006,
      __Dymola_Algorithm="Cvode"),
    __Dymola_experimentSetupOutput);
end PipeFMI;
