within DCOL.Distribution.Thermal_temp.BaseClasses;
partial model DistributedThermalVolume
  import SI = Modelica.SIunits;
  import Modelica.Fluid.Types.ModelStructure;
  import Modelica.Thermal.HeatTransfer.Interfaces;
  import Modelica_IK4_TEKNIKER;

  //Heat transfer direction
  parameter Boolean dim_1 = true;
  parameter Boolean dim_2 = true;
  parameter Boolean dim_3 = true;

  // Discretization
  parameter Integer n_1(min=0) = 2 "Number of segments";
  parameter Integer n_2(min=0) = 2 "Number of segments";
  parameter Integer n_3(min=0) = 2 "Number of segments";

  // Model structure
  parameter ModelStructure modelStructure_1 = ModelStructure.av_vb;
  parameter ModelStructure modelStructure_2 = ModelStructure.av_vb;
  parameter ModelStructure modelStructure_3 = ModelStructure.av_vb;

  // Initialization
  parameter SI.Temperature T_start= 293.15 "Temperature for the average temperature of cylinder"
    annotation(Dialog(tab="Initialization"));
  parameter SI.TemperatureSlope der_T_start=0 "Derivative of temperature (= der(T))"
    annotation(Dialog(tab="Initialization"));

  SI.Temperature[n_3, n_2, n_1] Ts;

  SI.Temperature[n_3, n_2, nG_1] Ts_1;
  SI.Temperature[n_3, nG_2, n_1] Ts_2;
  SI.Temperature[nG_3, n_2, n_1] Ts_3;

  SI.HeatCapacity[n_3, n_2, n_1] Cs;

  SI.ThermalConductance[n_3, n_2, nG_1] Gs_1;
  SI.ThermalConductance[n_3, nG_2, n_1] Gs_2;
  SI.ThermalConductance[nG_3, n_2, n_1] Gs_3;

protected
  HeatCapacitor[n_3, n_2, n_1] heatCapacitors(T(each start=T_start));

  ThermalConductor[n_3, n_2, n_1-1] thermalConductors_int_1 if (dim_1 and n_1>1);
  ThermalConductor[n_3, n_2-1, n_1] thermalConductors_int_2 if (dim_2 and n_2>1);
  ThermalConductor[n_3-1, n_2, n_1] thermalConductors_int_3 if (dim_3 and n_3>1);

  // Discretization conductance
  final parameter Integer nG_1 = if dim_1 then n_1 +
    (if modelStructure_1==ModelStructure.av_vb then -1
    elseif modelStructure_1==ModelStructure.a_v_b then 1
    else 0) else 0 "Number of segments";
  final parameter Integer nG_2 = if dim_2 then n_2 +
    (if modelStructure_2==ModelStructure.av_vb then -1
    elseif modelStructure_2==ModelStructure.a_v_b then 1
    else 0) else 0 "Number of segments";
  final parameter Integer nG_3 = if dim_3 then n_3 +
    (if modelStructure_3==ModelStructure.av_vb then -1
    elseif modelStructure_3==ModelStructure.a_v_b then 1
    else 0) else 0 "Number of segments";

  final parameter Boolean use_G_a_1=
    (modelStructure_1==ModelStructure.a_v_b) or (modelStructure_1==ModelStructure.a_vb);
  final parameter Boolean use_G_b_1=
    (modelStructure_1==ModelStructure.a_v_b) or (modelStructure_1==ModelStructure.av_b);
  final parameter Boolean use_G_a_2=
    (modelStructure_2==ModelStructure.a_v_b) or (modelStructure_2==ModelStructure.a_vb);
  final parameter Boolean use_G_b_2=
    (modelStructure_2==ModelStructure.a_v_b) or (modelStructure_2==ModelStructure.av_b);
  final parameter Boolean use_G_a_3=
    (modelStructure_3==ModelStructure.a_v_b) or (modelStructure_3==ModelStructure.a_vb);
  final parameter Boolean use_G_b_3=
    (modelStructure_3==ModelStructure.a_v_b) or (modelStructure_3==ModelStructure.av_b);

  ThermalConductor[n_3, n_2] thermalConductors_a_1 if (dim_1 and use_G_a_1);
  ThermalConductor[n_3, n_2] thermalConductors_b_1 if (dim_1 and use_G_b_1);
  ThermalConductor[n_3, n_1] thermalConductors_a_2 if (dim_2 and use_G_a_2);
  ThermalConductor[n_3, n_1] thermalConductors_b_2 if (dim_2 and use_G_b_2);
  ThermalConductor[n_2, n_1] thermalConductors_a_3 if (dim_3 and use_G_a_3);
  ThermalConductor[n_2, n_1] thermalConductors_b_3 if (dim_3 and use_G_b_3);

  Interfaces.HeatPort_a[n_3, n_2] portC_int_a_1 if (dim_1 and not use_G_a_1);
  Interfaces.HeatPort_b[n_3, n_2] portC_int_b_1 if (dim_1 and not use_G_b_1);
  Interfaces.HeatPort_a[n_3, n_1] portC_int_a_2 if (dim_2 and not use_G_a_2);
  Interfaces.HeatPort_b[n_3, n_1] portC_int_b_2 if (dim_2 and not use_G_b_2);
  Interfaces.HeatPort_a[n_2, n_1] portC_int_a_3 if (dim_3 and not use_G_a_3);
  Interfaces.HeatPort_b[n_2, n_1] portC_int_b_3 if (dim_3 and not use_G_b_3);

  Interfaces.HeatPort_a[n_3, n_2] port_int_a_1 if dim_1;
  Interfaces.HeatPort_b[n_3, n_2] port_int_b_1 if dim_1;
  Interfaces.HeatPort_a[n_3, n_1] port_int_a_2 if dim_2;
  Interfaces.HeatPort_b[n_3, n_1] port_int_b_2 if dim_2;
  Interfaces.HeatPort_a[n_2, n_1] port_int_a_3 if dim_3;
  Interfaces.HeatPort_b[n_2, n_1] port_int_b_3 if dim_3;

  Modelica_IK4_TEKNIKER.DCOL.Distribution.Thermal_temp.Interfaces.ThermalConductanceConnector[n_3,n_2,if dim_1 then n_1 + 1 else 0] Gs_int_1;
  Modelica_IK4_TEKNIKER.DCOL.Distribution.Thermal_temp.Interfaces.ThermalConductanceConnector[n_3,if dim_2 then n_2 + 1 else 0,n_1] Gs_int_2;
  Modelica_IK4_TEKNIKER.DCOL.Distribution.Thermal_temp.Interfaces.ThermalConductanceConnector[if dim_3 then n_3 + 1 else 0,n_2,n_1] Gs_int_3;

  Modelica_IK4_TEKNIKER.DCOL.Distribution.Thermal_temp.Interfaces.TemperatureConnector[n_3,n_2,if dim_1 then n_1 + 1 else 0] Ts_int_1;
  Modelica_IK4_TEKNIKER.DCOL.Distribution.Thermal_temp.Interfaces.TemperatureConnector[n_3,if dim_2 then n_2 + 1 else 0,n_1] Ts_int_2;
  Modelica_IK4_TEKNIKER.DCOL.Distribution.Thermal_temp.Interfaces.TemperatureConnector[if dim_3 then n_3 + 1 else 0,n_2,n_1] Ts_int_3;

equation
//   assert(n_1>1 or modelStructure_1<>ModelStructure.av_vb,
//      "Number of nodes needs to be at least 2 for modelStructure av_vb");
//   assert(n_2>1 or modelStructure_2<>ModelStructure.av_vb,
//      "Number of nodes needs to be at least 2 for modelStructure av_vb");
//   assert(n_3>1 or modelStructure_3<>ModelStructure.av_vb,
//      "Number of nodes needs to be at least 2 for modelStructure av_vb");

  connect(heatCapacitors[:, :, 1:n_1-1].port, thermalConductors_int_1[:, :, 1:n_1-1].port_a);
  connect(thermalConductors_int_1[:, :, 1:n_1-1].port_b, heatCapacitors[:, :, 2:n_1].port);
  connect(heatCapacitors[:, 1:n_2-1, :].port, thermalConductors_int_2[:, 1:n_2-1, :].port_a);
  connect(thermalConductors_int_2[:, 1:n_2-1, :].port_b, heatCapacitors[:, 2:n_2, :].port);
  connect(heatCapacitors[1:n_3-1, :, :].port, thermalConductors_int_3[1:n_3-1, :, :].port_a);
  connect(thermalConductors_int_3[1:n_3-1, :, :].port_b, heatCapacitors[2:n_3, :, :].port);

  connect(portC_int_a_1, heatCapacitors[:, :, 1].port);
  connect(portC_int_b_1, heatCapacitors[:, :, n_1].port);
  connect(portC_int_a_2, heatCapacitors[:, 1, :].port);
  connect(portC_int_b_2, heatCapacitors[:, n_2, :].port);
  connect(portC_int_a_3, heatCapacitors[1, :, :].port);
  connect(portC_int_b_3, heatCapacitors[n_3, :, :].port);

  connect(thermalConductors_a_1.port_b, heatCapacitors[:, :, 1].port);
  connect(heatCapacitors[:, :, n_1].port, thermalConductors_b_1.port_a);
  connect(thermalConductors_a_2.port_b, heatCapacitors[:, 1, :].port);
  connect(heatCapacitors[:, n_2, :].port, thermalConductors_b_2.port_a);
  connect(thermalConductors_a_3.port_b, heatCapacitors[1, :, :].port);
  connect(heatCapacitors[n_3, :, :].port, thermalConductors_b_3.port_a);

  connect(port_int_a_1, portC_int_a_1);
  connect(port_int_a_1, thermalConductors_a_1.port_a);
  connect(port_int_b_1, portC_int_b_1);
  connect(port_int_b_1, thermalConductors_b_1.port_b);
  connect(port_int_a_2, portC_int_a_2);
  connect(port_int_a_2, thermalConductors_a_2.port_a);
  connect(port_int_b_2, portC_int_b_2);
  connect(port_int_b_2, thermalConductors_b_2.port_b);
  connect(port_int_a_3, portC_int_a_3);
  connect(port_int_a_3, thermalConductors_a_3.port_a);
  connect(port_int_b_3, portC_int_b_3);
  connect(port_int_b_3, thermalConductors_b_3.port_b);

  connect(Gs_int_1[:, :, 1], thermalConductors_a_1.G);
  connect(Gs_int_1[:, :, 2:n_1], thermalConductors_int_1.G);
  connect(Gs_int_1[:, :, n_1+1], thermalConductors_b_1.G);
  connect(Gs_int_2[:, 1, :], thermalConductors_a_2.G);
  connect(Gs_int_2[:, 2:n_2, :], thermalConductors_int_2.G);
  connect(Gs_int_2[:, n_2+1, :], thermalConductors_b_2.G);
  connect(Gs_int_3[1, :, :], thermalConductors_a_3.G);
  connect(Gs_int_3[2:n_3, :, :], thermalConductors_int_3.G);
  connect(Gs_int_3[n_3+1, :, :], thermalConductors_b_3.G);

  connect(Ts_int_1[:, :, 1], thermalConductors_a_1.T);
  connect(Ts_int_1[:, :, 2:n_1], thermalConductors_int_1.T);
  connect(Ts_int_1[:, :, n_1+1], thermalConductors_b_1.T);
  connect(Ts_int_2[:, 1, :], thermalConductors_a_2.T);
  connect(Ts_int_2[:, 2:n_2, :], thermalConductors_int_2.T);
  connect(Ts_int_2[:, n_2+1, :], thermalConductors_b_2.T);
  connect(Ts_int_3[1, :, :], thermalConductors_a_3.T);
  connect(Ts_int_3[2:n_3, :, :], thermalConductors_int_3.T);
  connect(Ts_int_3[n_3+1, :, :], thermalConductors_b_3.T);

  heatCapacitors.C = Cs;
  Ts = heatCapacitors.T;

  if dim_1 then
  if modelStructure_1==ModelStructure.av_vb then
    Gs_int_1[:, :, 1] = zeros(n_3, n_2);
    Gs_int_1[:, :, 2:n_1] = Gs_1;
    Gs_int_1[:, :, n_1+1] = zeros(n_3, n_2);
    Ts_int_1[:, :, 1] = zeros(n_3, n_2);
    Ts_int_1[:, :, 2:n_1] = Ts_1;
    Ts_int_1[:, :, n_1+1] = zeros(n_3, n_2);
  elseif modelStructure_1==ModelStructure.a_vb then
    Gs_int_1[:, :, 1:n_1] = Gs_1;
    Gs_int_1[:, :, n_1+1] = zeros(n_3, n_2);
    Ts_int_1[:, :, 1:n_1] = Ts_1;
    Ts_int_1[:, :, n_1+1] = zeros(n_3, n_2);
  elseif modelStructure_1==ModelStructure.av_b then
    Gs_int_1[:, :, 1] = zeros(n_3, n_2);
    Gs_int_1[:, :, 2:n_1+1] = Gs_1;
    Ts_int_1[:, :, 1] = zeros(n_3, n_2);
    Ts_int_1[:, :, 2:n_1+1] = Ts_1;
  else
    Gs_int_1 = Gs_1;
    Ts_int_1 = Ts_1;
  end if;
  end if;

  if dim_2 then
  if modelStructure_2==ModelStructure.av_vb then
    Gs_int_2[:, 1, :] = zeros(n_3, n_1);
    Gs_int_2[:, 2:n_2, :] = Gs_2;
    Gs_int_2[:, n_2+1, :] = zeros(n_3, n_1);
    Ts_int_2[:, 1, :] = zeros(n_3, n_1);
    Ts_int_2[:, 2:n_2, :] = Ts_2;
    Ts_int_2[:, n_2+1, :] = zeros(n_3, n_1);
  elseif modelStructure_2==ModelStructure.a_vb then
    Gs_int_2[:, 1:n_2, :] = Gs_2;
    Gs_int_2[:, n_2+1, :] = zeros(n_3, n_1);
    Ts_int_2[:, 1:n_2, :] = Ts_2;
    Ts_int_2[:, n_2+1, :] = zeros(n_3, n_1);
  elseif modelStructure_2==ModelStructure.av_b then
    Gs_int_2[:, 1, :] = zeros(n_3, n_1);
    Gs_int_2[:, 2:n_2+1, :] = Gs_2;
    Ts_int_2[:, 1, :] = zeros(n_3, n_1);
    Ts_int_2[:, 2:n_2+1, :] = Ts_2;
  else
    Gs_int_2 = Gs_2;
    Ts_int_2 = Ts_2;
  end if;
  end if;

  if dim_3 then
  if modelStructure_3==ModelStructure.av_vb then
    Gs_int_3[1, :, :] = zeros(n_2, n_1);
    Gs_int_3[2:n_3, :, :] = Gs_3;
    Gs_int_3[n_3+1, :, :] = zeros(n_2, n_1);
    Ts_int_3[1, :, :] = zeros(n_2, n_1);
    Ts_int_3[2:n_3, :, :] = Ts_3;
    Ts_int_3[n_3+1, :, :] = zeros(n_2, n_1);
  elseif modelStructure_3==ModelStructure.a_vb then
    Gs_int_3[1:n_3, :, :] = Gs_3;
    Gs_int_3[n_3+1, :, :] = zeros(n_2, n_1);
    Ts_int_3[1:n_3, :, :] = Ts_3;
    Ts_int_3[n_3+1, :, :] = zeros(n_2, n_1);
  elseif modelStructure_3==ModelStructure.av_b then
    Gs_int_3[1, :, :] = zeros(n_2, n_1);
    Gs_int_3[2:n_3+1, :, :] = Gs_3;
    Ts_int_3[1, :, :] = zeros(n_2, n_1);
    Ts_int_3[2:n_3+1, :, :] = Ts_3;
  else
    Gs_int_3 = Gs_3;
    Ts_int_3 = Ts_3;
  end if;
  end if;

end DistributedThermalVolume;
