within DCOL.Distribution.Thermal_temp;
model HollowCylinder
  import SI = Modelica.SIunits;
  import Modelica.Fluid.Types.ModelStructure;
  extends Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Interfaces.HollowCylinderIcon;
  extends BaseClasses.DistributedThermalMaterial(
    final dim_1=use_radialDim,
    final dim_2=use_longitudinalDim,
    final dim_3=use_angularDim,
    final n_1=nRadial,
    final n_2=nLongitudinal,
    final n_3=nAngular,
    final modelStructure_1=modelStructure_radial,
    final modelStructure_2=modelStructure_longitudinal,
    final modelStructure_3=modelStructure_angular);

  parameter Integer nParallel = 1;

  parameter Boolean use_radialDim = true "Use heat transfer in radial direction";
  parameter Boolean use_longitudinalDim = true "Use heat transfer in longitudinal direction";
  parameter Boolean use_angularDim = true "Use heat transfer in angular direction";

  parameter Integer nRadial = 2
    annotation (Dialog(tab="General"));
  parameter Integer nLongitudinal = 2
    annotation (Dialog(tab="General"));
  parameter Integer nAngular = 2
    annotation (Dialog(tab="General"));

  parameter SI.Length r_int "Inner radius of cylinder"
    annotation (Dialog(tab="General", group="Geometry"));
  parameter SI.Length r_ext "Outer radius of cylinder"
    annotation (Dialog(tab="General", group="Geometry"));
  parameter SI.Length length "Length of cylinder"
    annotation (Dialog(tab="General", group="Geometry"));
  parameter SI.Angle alpha = Modelica.Constants.pi "Swept angle"
    annotation (Dialog(tab="General", group="Geometry"));

  // Model structure
  parameter ModelStructure modelStructure_radial = ModelStructure.av_vb;
  parameter ModelStructure modelStructure_longitudinal = ModelStructure.av_vb;
  parameter ModelStructure modelStructure_angular = ModelStructure.av_vb;

  final parameter SI.Volume[n_3, n_2, n_1] Vs=
    (length/n_2)*(alpha/n_3)*
    fill((rs_C[n_1+1:-1:2].*rs_C[n_1+1:-1:2].-rs_C[n_1:-1:1].*rs_C[n_1:-1:1])/2, n_3, n_2)
    "Volume of thermal capacitance nodes";

  final parameter SI.Mass[n_3, n_2, n_1] ms=
    Vs*Material.density_T(Material.reference_T)
    "Mass of thermal capacitance nodes";

protected
  final parameter SI.Length rs_G_1[nG_1+1] = linspace(r_int, r_ext, nG_1+1);

  final parameter SI.Length rs_C[n_1+1] = linspace(r_int, r_ext, n_1+1);

public
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_radial[nAngular, nLongitudinal] if use_radialDim
    annotation (Placement(transformation(extent={{-110,-10},{-90,10}}, rotation=0)));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_longitudinal[nAngular, nRadial] if use_longitudinalDim
    annotation (Placement(transformation(extent={{-10,-88},{10,-108}}, rotation=0)));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_angular[nLongitudinal, nRadial] if use_angularDim
    annotation (Placement(transformation(extent={{-90,-70},{-70,-90}}, rotation=0)));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_radial[nAngular, nLongitudinal] if use_radialDim
    annotation (Placement(transformation(extent={{90,-10},{110,10}}, rotation=0)));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_longitudinal[nAngular, nRadial] if use_longitudinalDim
    annotation (Placement(transformation(extent={{-10,90},{10,110}}, rotation=0)));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_angular[nLongitudinal, nRadial] if use_angularDim
    annotation (Placement(transformation(extent={{70,70},{90,90}},rotation=0)));

equation
  assert(abs(alpha)<=2*Modelica.Constants.pi, "abs(alpha) must be <= to 2*pi");

  connect(port_a_radial, port_int_a_1);
  connect(port_a_longitudinal, port_int_a_2);
  connect(port_a_angular, port_int_a_3);
  connect(port_b_radial, port_int_b_1);
  connect(port_b_longitudinal, port_int_b_2);
  connect(port_b_angular, port_int_b_3);

  Cs = cps.*ms*nParallel;

  Gs_1 = nParallel.*ks_1.*((alpha/n_3)*(length/n_2))./
         fill(Modelica.Math.log(rs_G_1[nG_1+1:-1:2]./rs_G_1[nG_1:-1:1]), n_3, n_2);
  Gs_2 = nParallel.*ks_2.*((alpha/n_3)/(length/nG_2)).*
         fill((rs_C[n_1+1:-1:2].*rs_C[n_1+1:-1:2].-rs_C[n_1:-1:1].*rs_C[n_1:-1:1])/2, n_3, nG_2);
  Gs_3 = nParallel.*ks_3.*((length/n_2)/(alpha/nG_3)).*
         fill((rs_C[n_1+1:-1:2].-rs_C[n_1:-1:1])./((rs_C[n_1+1:-1:2].+rs_C[n_1:-1:1])/2), nG_3, n_2);

end HollowCylinder;
