within DCOL.Generation.AbsorptionChillers.BaseClasses;
model AbsorptionCycle "Refrigeration system by absorption"
  import SI = Modelica.SIunits;
  extends Icons.AbsorptionCycle;

  package Medium_sol =
      DCOL.Generation.AbsorptionChillers.BaseClasses.LiBrH2O
    "Solution medium";
  package Medium_l = Modelica.Media.Water.WaterIF97_R1pT
    "Refrigerant liquid medium";
  package Medium_v = Modelica.Media.Water.WaterIF97_R2pT
    "Refrigerant vapour medium";
  package Medium_EXV = Modelica.Media.Water.StandardWater
    "Expansion valve medium";

//Generator
  parameter SI.Height height_gen
    "Height of vessel" annotation (Dialog(tab="Generator"));
  parameter SI.Area crossArea_gen
    "Area of vessel" annotation (Dialog(tab="Generator"));
//Generator::Nominal
  parameter SI.AbsolutePressure p_gen_nominal
    "Pressure" annotation (Dialog(tab="Generator", group="Nominal"));
//Generator::Initialization
  parameter SI.Height level_gen_start
     "Liquid level" annotation (Dialog(tab="Generator", group="Initialization"));
  parameter SI.AbsolutePressure p_gen_start = p_gen_nominal
    "Pressure" annotation (Dialog(tab="Generator", group="Initialization"));

//Absorber
  parameter SI.Height height_abs
    "Height of vessel" annotation (Dialog(tab="Absorber"));
  parameter SI.Area crossArea_abs
    "Area of vessel" annotation (Dialog(tab="Absorber"));
//Absorber::Nominal
  parameter SI.AbsolutePressure p_abs_nominal
    "Pressure" annotation (Dialog(tab="Absorber", group="Nominal"));
//Absorber::Initialization
  parameter SI.Height level_abs_start
     "Liquid level" annotation (Dialog(tab="Absorber", group="Initialization"));
  parameter SI.AbsolutePressure p_abs_start = p_abs_nominal
    "Pressure" annotation (Dialog(tab="Absorber", group="Initialization"));

//Condenser
  parameter SI.Height height_con
    "Height of vessel" annotation (Dialog(tab="Condenser"));
  parameter SI.Area crossArea_con
    "Area of vessel" annotation (Dialog(tab="Condenser"));
//Condenser::Initialization
  parameter SI.Height level_con_start
     "Liquid level" annotation (Dialog(tab="Condenser", group="Initialization"));

//Evaporator
  parameter SI.Height height_eva
    "Height of vessel" annotation (Dialog(tab="Evaporator"));
  parameter SI.Area crossArea_eva
    "Area of vessel" annotation (Dialog(tab="Evaporator"));
//Evaporator::Initialization
  parameter SI.Height level_eva_start
     "Liquid level" annotation (Dialog(tab="Evaporator", group="Initialization"));

//Solution
  parameter SI.ThermalConductance G_HXsol
    "Thermal conductance, heat exchanger" annotation (Dialog(tab="Solution"));
//Solution::Nominal
  parameter SI.MassFlowRate m_flow_str_nominal
    "Mass flow rate, strong solution" annotation (Dialog(tab="Solution", group="Nominal"));
  parameter Real opening_str_nominal(min=0, max=1)
    "Solution valve opening" annotation (Dialog(tab="Solution", group="Nominal"));
  final parameter SI.MassFlowRate m_flow_wea_nominal = m_flow_str_nominal + m_flow_ref_nominal;
//Solution::Initialization
  parameter SI.MassFraction X_wea_start
    "Mass fraction, weak solution" annotation (Dialog(tab="Solution", group="Initialization"));
  parameter SI.MassFraction X_str_start
    "Mass fraction, strong solution" annotation (Dialog(tab="Solution", group="Initialization"));
  parameter SI.MassFlowRate m_flow_str_start = m_flow_str_nominal
    "Mass flow rate, strong solution" annotation (Dialog(tab="Solution", group="Initialization"));
  parameter Real opening_str_start(min=0, max=1)
    "Solution valve opening" annotation (Dialog(tab="Solution", group="Initialization"));
  parameter SI.Temperature T_HXw_start
    "Temperature, heat exchanger at weak sol. side" annotation (Dialog(tab="Solution", group="Initialization"));
  parameter SI.Temperature T_HXs_start
    "Temperature, heat exchanger at strong sol. side" annotation (Dialog(tab="Solution", group="Initialization"));
  final parameter SI.MassFlowRate m_flow_wea_start = m_flow_str_start + m_flow_ref_start;

//Refrigerant::Nominal
  parameter SI.MassFlowRate m_flow_ref_nominal
    "Mass fraction" annotation (Dialog(tab="Refrigerant", group="Nominal"));
  parameter Real opening_ref_nominal(min=0, max=1)
    "Refrigerant valve opening" annotation (Dialog(tab="Refrigerant", group="Nominal"));
//Refrigerant::Initialization
  parameter SI.MassFlowRate m_flow_ref_start = m_flow_ref_nominal
    "Mass fraction" annotation (Dialog(tab="Refrigerant", group="Initialization"));
  parameter Real opening_ref_start(min=0, max=1) = opening_ref_nominal
    "Refrigerant valve opening" annotation (Dialog(tab="Refrigerant", group="Initialization"));

//Components
  AbsorberGeneratorVessel generator(
    X_l_start={X_str_start,1 - X_str_start},
    psat_start(displayUnit="Pa") = p_gen_start,
    V_l_start=level_gen_start*crossArea_gen,
    redeclare package Medium_v = Medium_v,
    redeclare package Medium_l = Medium_sol,
    use_p_start=true,
    height=height_gen,
    crossArea=crossArea_gen)
                      annotation (Placement(transformation(extent={{130,90},{150,110}})));
  AbsorberGeneratorVessel absorber(
    psat_start(displayUnit="Pa") = p_abs_start,
    X_l_start={X_wea_start,1 - X_wea_start},
    V_l_start=level_abs_start*crossArea_abs,
    redeclare package Medium_v = Medium_v,
    redeclare package Medium_l = Medium_sol,
    use_p_start=true,
    height=height_abs,
    crossArea=crossArea_abs)
                      annotation (Placement(transformation(extent={{130,-190},{150,-170}})));
  EvaporatorCondenserVessel condenser(
    V_l_start=level_con_start*crossArea_con,
    redeclare package Medium_v = Medium_v,
    redeclare package Medium_l = Medium_l,
    psat_start=p_gen_start - 0.001,
    height=height_con,
    crossArea=crossArea_con)               annotation (Placement(transformation(extent={{-150,90},{-130,110}})));
  EvaporatorCondenserVessel evaporator(
    V_l_start=level_eva_start*crossArea_eva,
    redeclare package Medium_v = Medium_v,
    redeclare package Medium_l = Medium_l,
    psat_start=p_abs_start + 0.001,
    height=height_eva,
    crossArea=crossArea_eva)               annotation (Placement(transformation(extent={{-130,-190},{-110,-170}})));

  Modelica.Fluid.Machines.ControlledPump pump(
    allowFlowReversal=false,
    p_a_start(displayUnit="Pa") = p_abs_start,
    m_flow_start=m_flow_wea_start,
    X_start={X_wea_start,1 -X_wea_start},
    T_start=LiBrH2O.temperature_psatX(                                                                    p_gen_start,X_wea_start),
    p_b_start(displayUnit="Pa") = p_gen_start,
    control_m_flow=true,
    medium(Xi(stateSelect=StateSelect.avoid)),
    redeclare package Medium = Medium_sol,
    rho_nominal=LiBrH2O.density_TX(                                                                    LiBrH2O.temperature_psatX(                                                                    p_gen_nominal, X_wea_start), X_wea_start),
    p_a_nominal(displayUnit="Pa") = p_abs_nominal,
    p_b_nominal(displayUnit="Pa") = p_gen_nominal,
    m_flow_nominal=0.5*m_flow_wea_nominal,
    use_m_flow_set=true)
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={120,-74})));

  Modelica.Fluid.Pipes.DynamicPipe pipe_wea(
    allowFlowReversal=false,
    roughness=0,
    use_HeatTransfer=true,
    length=0.1,
    diameter=1,
    p_a_start(displayUnit="Pa") = p_gen_start,
    X_start={X_wea_start,1 -X_wea_start},
    m_flow_start=m_flow_wea_start,
    nNodes=2,
    final T_start=T_HXw_start,
    modelStructure=Modelica.Fluid.Types.ModelStructure.a_v_b,
    nParallel=1,
    isCircular=true,
    height_ab=0,
    useInnerPortProperties=false,
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.IdealFlowHeatTransfer,
    useLumpedPressure=false,
    momentumDynamics=Modelica.Fluid.Types.Dynamics.SteadyState,
    energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
    massDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (                        dp_nominal(displayUnit="Pa") = 0.001, m_flow_nominal=m_flow_wea_nominal),
    redeclare package Medium = Medium_sol)
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={120,60})));
  Modelica.Fluid.Pipes.DynamicPipe pipe_str(
    allowFlowReversal=false,
    roughness=0,
    use_HeatTransfer=true,
    length=0.1,
    diameter=1,
    X_start={X_str_start,1 -X_str_start},
    m_flow_start=m_flow_str_start,
    nNodes=2,
    p_a_start(displayUnit="Pa") = p_gen_start,
    T_start=T_HXs_start,
    modelStructure=Modelica.Fluid.Types.ModelStructure.a_vb,
    nParallel=1,
    isCircular=true,
    height_ab=0,
    useInnerPortProperties=false,
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.IdealFlowHeatTransfer,
    use_T_start=true,
    useLumpedPressure=false,
    momentumDynamics=Modelica.Fluid.Types.Dynamics.SteadyState,
    energyDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
    massDynamics=Modelica.Fluid.Types.Dynamics.FixedInitial,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (                        dp_nominal(displayUnit="Pa") = 0.001, m_flow_nominal=m_flow_str_nominal),
    redeclare package Medium = Medium_sol)                   annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=-90,
        origin={160,60})));
  Modelica.Fluid.Valves.ValveLinear valve_sol(
    allowFlowReversal=false,
    dp_start(displayUnit="Pa") = p_gen_start - p_abs_start,
    m_flow_start=m_flow_str_start/opening_str_start,
    dp_nominal(displayUnit="Pa") = p_gen_nominal - p_abs_nominal,
    m_flow_nominal=m_flow_str_nominal/opening_str_nominal,
    redeclare package Medium = Medium_sol)
    annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=90,
        origin={160,0})));
  Modelica.Fluid.Valves.ValveLinear valve_ref(
    allowFlowReversal=false,
    dp_start(displayUnit="Pa") = p_gen_start - p_abs_start,
    m_flow_start=m_flow_ref_start/opening_ref_start,
    dp_nominal(displayUnit="Pa") = p_gen_nominal - p_abs_nominal,
    m_flow_nominal=m_flow_ref_nominal/opening_ref_nominal,
    redeclare package Medium = Medium_EXV)
    annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={-140,0})));
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor HX_sol[2](each G=G_HXsol/2)
    annotation (Placement(transformation(extent={{150,50},{130,70}})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice flowRes_gc(
    m_flow_start=m_flow_ref_start,
    diameter=1,
    zeta=1,
    use_zeta=false,
    dp_nominal(displayUnit="Pa") = 0.001,
    m_flow_nominal=m_flow_ref_nominal,
    redeclare package Medium = Medium_v,
    allowFlowReversal=true,
    dp_start=100) annotation (Placement(transformation(extent={{10,100},{-10,120}})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice flowRes_ea(
    m_flow_start=m_flow_ref_start,
    diameter=1,
    zeta=1,
    use_zeta=false,
    dp_nominal(displayUnit="Pa") = 0.001,
    m_flow_nominal=m_flow_ref_nominal,
    redeclare package Medium = Medium_v,
    allowFlowReversal=true,
    dp_start=100)  annotation (Placement(transformation(extent={{-10,-180},{10,-160}})));
  Modelica.Fluid.Pipes.StaticPipe flowRes_sol(
    allowFlowReversal=false,
    m_flow_start=m_flow_wea_start,
    length=0.1,
    diameter=1,
    roughness=0,
    height_ab=0,
    p_a_start=p_abs_start,
    redeclare package Medium = Medium_sol,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (                        dp_nominal(displayUnit="Pa") = 0.001, m_flow_nominal=m_flow_wea_nominal))
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={120,-110})));

//Variables of interest
  Types.VesselState state_a(
    p=absorber.p,
    T=absorber.T,
    X=absorber.medium_l.Xi[1],
    V=absorber.V_l);
  Types.VesselState state_g(
    p=generator.p,
    T=generator.T,
    X=generator.medium_l.Xi[1],
    V=generator.V_l);
  Types.VesselState state_e(
    p=evaporator.p,
    T=evaporator.T,
    X=1,
    V=evaporator.V_l);
  Types.VesselState state_c(
    p=condenser.p,
    T=condenser.T,
    X=1,
    V=condenser.V_l);
  Real COP(min=0, nominal=1, unit="W/W") = abs(sum(evaporator.Qb_flow))/max(abs(sum(generator.Qb_flow)),Modelica.Constants.small);

//Ports
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_g annotation (Placement(transformation(extent={{190,90},{210,110}}), iconTransformation(extent={{190,90},{210,110}})));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_e annotation (Placement(transformation(extent={{-210,-190},{-190,-170}}), iconTransformation(extent={{-210,-190},{-190,-170}})));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_c annotation (Placement(transformation(extent={{-210,90},{-190,110}}), iconTransformation(extent={{-210,90},{-190,110}})));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_a annotation (Placement(transformation(extent={{190,-190},{210,-170}}), iconTransformation(extent={{190,-190},{210,-170}})));
  Modelica.Blocks.Interfaces.RealInput pump_sol annotation (Placement(transformation(extent={{240,-100},{200,-60}}), iconTransformation(extent={{240,-100},{200,-60}})));
  Modelica.Blocks.Interfaces.RealInput opening_sol annotation (Placement(transformation(extent={{240,-20},{200,20}}), iconTransformation(extent={{240,0},{200,40}})));
  Modelica.Blocks.Interfaces.RealInput opening_ref annotation (Placement(transformation(extent={{-240,-20},{-200,20}}), iconTransformation(extent={{-240,-20},{-200,20}})));

equation
  connect(generator.port_l_b, pipe_str.port_a) annotation (Line(points={{145.8,90},{160,90},{160,70}}, color={0,127,255}));
  connect(pipe_str.port_b, valve_sol.port_a) annotation (Line(points={{160,50},{160,10}},          color={0,127,255}));
  connect(valve_sol.port_b, absorber.port_l_b) annotation (Line(points={{160,-10},{160,-10},{160,-190},{145.8,-190}}, color={0,127,255}));
  connect(pump.port_b, pipe_wea.port_a) annotation (Line(points={{120,-64},{120,-64},{120,50}}, color={0,127,255}));
  connect(pipe_wea.port_b, generator.port_l_a) annotation (Line(points={{120,70},{120,70},{120,90},{134,90}}, color={0,127,255}));
  connect(condenser.port_l, valve_ref.port_a) annotation (Line(points={{-140,90},{-140,10}},           color={0,127,255}));
  connect(valve_ref.port_b, evaporator.port_l) annotation (Line(points={{-140,-10},{-140,-190},{-120,-190}}, color={0,127,255}));
  connect(absorber.port_v,flowRes_ea. port_b) annotation (Line(points={{140,-170},{10,-170}}, color={0,127,255}));
  connect(flowRes_ea.port_a, evaporator.port_v) annotation (Line(points={{-10,-170},{-120,-170}}, color={0,127,255}));
  connect(generator.port_v, flowRes_gc.port_a) annotation (Line(points={{140,110},{10,110}}, color={0,127,255}));
  connect(flowRes_gc.port_b, condenser.port_v) annotation (Line(points={{-10,110},{-140,110}}, color={0,127,255}));
  connect(HX_sol.port_b, pipe_wea.heatPorts) annotation (Line(points={{130,60},{124.4,60},{124.4,60.1}}, color={191,0,0}));
  connect(HX_sol.port_a, pipe_str.heatPorts) annotation (Line(points={{150,60},{155.6,60},{155.6,59.9}}, color={191,0,0}));

  connect(pipe_str.port_b, valve_sol.port_a) annotation (Line(points={{160,50},{160,10}},          color={0,127,255}));
  connect(port_a, absorber.heatPort) annotation (Line(points={{200,-180},{172,-180},{140,-180}},            color={191,0,0}));
  connect(port_g, generator.heatPort) annotation (Line(points={{200,100},{170,100},{140,100}}, color={191,0,0}));
  connect(port_c, condenser.heatPort) annotation (Line(points={{-200,100},{-170,100},{-140,100}}, color={191,0,0}));
  connect(port_e, evaporator.heatPort) annotation (Line(points={{-200,-180},{-160,-180},{-120,-180}}, color={191,0,0}));
  connect(pump_sol, pump.m_flow_set) annotation (Line(points={{220,-80},{128.2,-80},{128.2,-79}}, color={0,0,127}));
  connect(opening_sol, valve_sol.opening) annotation (Line(points={{220,0},{194,0},{194,-4.44089e-016},{168,-4.44089e-016}},
                                                                                             color={0,0,127}));
  connect(opening_ref, valve_ref.opening) annotation (Line(points={{-220,0},{-184,0},{-148,0}}, color={0,0,127}));

  connect(absorber.port_l_a, flowRes_sol.port_a) annotation (Line(points={{134,-190},{120,-190},{120,-120}}, color={0,127,255}));
  connect(flowRes_sol.port_b, pump.port_a) annotation (Line(points={{120,-100},{120,-84}}, color={0,127,255}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-200,-200},{200,200}}), graphics={
        Polygon(
          points={{-110,-20},{-90,18},{-110,-20}},
          pattern=LinePattern.None,
          fillColor={170,255,255},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-106,94},{-94,106}},
          lineColor={0,0,0},
          fillColor={255,0,0},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{94,94},{106,106}},
          lineColor={0,0,0},
          fillColor={255,0,0},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-110,-186},{-98,-174}},
          lineColor={0,0,0},
          fillColor={255,0,0},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{94,-186},{106,-174}},
          lineColor={0,0,0},
          fillColor={255,0,0},
          fillPattern=FillPattern.Solid),
        Line(points={{-200,100},{-102,100}}, color={255,0,0}),
        Line(points={{-200,-180},{-102,-180}}, color={255,0,0}),
        Line(points={{102,100},{200,100}}, color={255,0,0}),
        Line(points={{102,-180},{200,-180}}, color={255,0,0}),
        Line(points={{100,20},{220,20}}, color={0,0,0}),
        Line(points={{-220,0},{-100,0}}, color={0,0,0}),
        Text(
          extent={{-100,260},{100,200}},
          lineColor={28,108,200},
          textString="%name")}),                           Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-200,-200},{200,200}})),
    Documentation(info="<html>
<p><span style=\"font-family: MS Shell Dlg 2,sans-serif;\">Absorption cycle with LiBr+H2O as refrigerant solution. Refer to the documentation of the components for information about the main assumptions.</span> </p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end AbsorptionCycle;
