within DCOL.Generation.AbsorptionChillers.BaseClasses;
model EvaporatorCondenserVessel
  import SI = Modelica.SIunits;
  extends PartialLiquidVapourVessel(
    redeclare replaceable package Medium_v=Modelica.Media.Water.WaterIF97_R2pT,
    redeclare replaceable package Medium_l=Modelica.Media.Water.WaterIF97_R1pT,
    final T_start=Tsat_start,
    final p_start=psat_start,
    T(stateSelect = StateSelect.prefer),
    V_l(stateSelect = StateSelect.prefer));

  parameter Boolean use_p_start = true
  "=true to use pressure during initialisation, otherwise temperature is used"
    annotation(Dialog(tab = "Initialization"));

  parameter SI.AbsolutePressure psat_start = if use_p_start then system.p_start
                                             else Medium_l.saturationPressure(Tsat_start)
  "Initial liquid-vapor equilibrium pressure (saturation state)"
    annotation(Dialog(tab = "Initialization", enable=use_p_start));
  parameter SI.Temperature Tsat_start = if not use_p_start then system.T_start
                                        else Medium_l.saturationTemperature(psat_start)
  "Initial liquid-vapor equilibrium temperature (saturation state)"
    annotation(Dialog(tab = "Initialization",  enable=not use_p_start));

//PORTS
  Modelica.Fluid.Interfaces.FluidPort_a port_v(redeclare package Medium = Medium_v)
  "Fluid port. Water vapor"
    annotation (Placement(transformation(extent={{-10,90},{10,110}}), iconTransformation(extent={{-10,90},{10,110}})));
  Modelica.Fluid.Interfaces.FluidPort_a port_l(redeclare package Medium = Medium_l)
  "Fluid port. Liquid water"
    annotation (Placement(transformation(extent={{-10,-110},{10,-90}}), iconTransformation(extent={{-10,-110},{10,-90}})));
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort
  "Heat port"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}})));

equation
  Qb_flow = heatPort.Q_flow;
  heatPort.T = T;

  //Definition of port variables
  port_v.p = p;
  port_l.p = p_static;

  port_v.h_outflow = medium_v.h;
  port_l.h_outflow = medium_l.h;

  port_v.Xi_outflow = medium_v.Xi;
  port_l.Xi_outflow = medium_l.Xi;

  Hb_flow = port_v.m_flow*actualStream(port_v.h_outflow) + port_l.m_flow*actualStream(port_l.h_outflow);
  Wb_flow = p * der(V_v);
  mb_flow = port_v.m_flow + port_l.m_flow;
  mbXi_flow_v = port_v.m_flow*actualStream(port_v.Xi_outflow);
  mbXi_flow_l = port_l.m_flow*actualStream(port_l.Xi_outflow);

  p = Medium_l.saturationPressure(T);

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>Model of a simple <b>evaporator (or condenser)</b> with two states where water is the evaporating or condensing medium. The model assumes two-phase equilibrium inside the component, i.e. the vapor (liquid) that exits the evaporator (condenser) is at saturated state. The flow properties are computed from the upstream quantities, pressures are equal in all nodes. Heat transfer through a thermal port is possible, it equals zero if the port remains unconnected. Ideal heat transfer is assumed per default; the thermal port temperature is equal to the medium temperature.</p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end EvaporatorCondenserVessel;
