within DCOL.Generation.AbsorptionChillers.BaseClasses.LiBrH2O;
function specificHeatCapacity_TX_der
"Specific enthalpy of the H2O/LiBr solution as a function of T and X_LiBr"
  input Temperature T "Temperature [K] of the solution";
  input MassFraction X_LiBr "LiBr mass fraction in the solution";
  input Real der_T "Derivative of temperature [K] of the solution";
  input Real der_X_LiBr "Derivative of LiBr mass fraction in the solution";
  output Real der_cp "Specific heat capacity of the solution";
protected
  constant Real[2] A = {3.462023, -2.679895E-2};
  constant Real[2] B = {1.3499E-3, -6.55E-6};
  Real[2] X = {(X_LiBr*100)^i for i in 0:1} "Aux. array";
  Real[2] der_X = {i*(X_LiBr*100)^(i-1)*der_X_LiBr for i in 0:1} "Aux. array";
  Real[2] Tc = {(T-273.15)^i for i in 0:1} "Aux. array";
  Real[2] der_Tc = {i*(T-273.15)^(i-1)*der_T for i in 0:1} "Aux. array";
algorithm
  der_cp := {A*der_X, B*der_X}*Tc + {A*X, B*X}*der_Tc;
end specificHeatCapacity_TX_der;
