within DCOL.Generation.AbsorptionChillers.Testing;
model ASHRAE_wControl
  import SI = Modelica.SIunits;
  extends Partial_ASHRAE;

  SI.Duration dTime = 5*60;
  // Evaporator temperature
  SI.Time sT_eva = 24*60*60;
  SI.TemperatureDifference dT = 1;
  SI.Temperature Tset_eva=
    7+273.15 + (if time<sT_eva then 0 else if time<(sT_eva +dTime) then (time-sT_eva)*dT/dTime else dT);
    //if time<18*60*60 then 7+273.15 else 11+273.15;
  parameter Real kp_eva = 1;//1E0;
  parameter Real Ti_eva = 60;//60;
  parameter Real Td_eva = 1;

  // Generator level
  parameter Real Vset_gen = 5.0;
  parameter Real kp_gen = 0.1;//5E-2;
  parameter Real Ti_gen = 10*60;

  // Condenser level
  parameter Real Vset_con = 5.0;
  parameter Real kp_con = 1.0;//1E-1;
  parameter Real Ti_con = 10*60;

  // Generator consent.
  SI.Time sT_gen = 12*60*60;
  Real dX = 0.10;
  Real Xset=
    X_str_start + (if time<sT_gen then 0 else if time<(sT_gen +dTime) then (time-sT_gen)*dX/dTime else dX);
  //if time<18*60*60 then X_str_start else 0.75;
  parameter Real kp_X = 1E1;
  parameter Real Ti_X = 5*60;

  AbsorptionChiller absorptionChiller(
    X_wea_start=X_wea_start,
    X_str_start=X_str_start,
    m_flow_str_start=m_flow_str_start,
    m_flow_ref_start=m_flow_ref_start,
    level_abs_start=level_abs_start,
    p_abs_start=p_abs_start,
    level_gen_start=level_gen_start,
    p_gen_start=p_gen_start,
    level_eva_start=level_eva_start,
    level_con_start=level_con_start,
    m_flow_gen_start=m_flow_gen_start,
    m_flow_abs_start=m_flow_abs_start,
    m_flow_con_start=m_flow_con_start,
    m_flow_eva_start=m_flow_eva_start,
    G_abs=G_abs,
    G_con=G_con,
    redeclare package Medium_gen = Modelica.Media.Water.StandardWater,
    redeclare package Medium_abs = Modelica.Media.Water.StandardWater,
    redeclare package Medium_con = Modelica.Media.Water.StandardWater,
    redeclare package Medium_eva = Modelica.Media.Water.StandardWater,
    modelStructure_abs=Modelica.Fluid.Types.ModelStructure.a_v_b,
    modelStructure_eva=Modelica.Fluid.Types.ModelStructure.a_v_b,
    modelStructure_con=Modelica.Fluid.Types.ModelStructure.av_b,
    G_eva=G_eva,
    modelStructure_gen=Modelica.Fluid.Types.ModelStructure.a_vb,
    T_HX_start=(T_HXw_start + T_HXs_start)/2,
    G_gen=G_gen,
    opening_ref_start=0.3,
    opening_str_start=0.3,
    G_HXsol=G_HXsol,
    p_gen_nominal=p_gen_start,
    p_abs_nominal=p_abs_start,
    m_flow_str_nominal=m_flow_str_start,
    opening_str_nominal=0.3,
    m_flow_ref_nominal=m_flow_ref_start,
    opening_ref_nominal=0.3,
    T_genPipe_start=T_gen,
    p_genPipe_start(displayUnit="MPa") = 400000,
    T_absPipe_start=T_abs,
    p_absPipe_start=system.p_ambient,
    T_conPipe_start=T_con,
    p_conPipe_start=system.p_ambient,
    T_evaPipe_start=T_eva,
    p_evaPipe_start=system.p_ambient,
    C_gen=5000000,
    C_abs=5000000,
    C_con=5000000,
    C_eva=5000000,
    height_gen=height_gen,
    crossArea_gen=crossArea_gen,
    height_abs=height_abs,
    crossArea_abs=crossArea_abs,
    height_con=height_con,
    crossArea_con=crossArea_con,
    height_eva=height_eva,
    crossArea_eva=crossArea_eva)                annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
  Modelica.Fluid.Sources.MassFlowSource_T sou_gen(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    m_flow=m_flow_gen_start,
    use_T_in=false,
    use_m_flow_in=true,
    T=398.15)                                                       annotation (Placement(transformation(extent={{48,4},{28,24}})));
  Modelica.Fluid.Sources.MassFlowSource_T sou_abs(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    m_flow=m_flow_abs_start,
    T=300.15) annotation (Placement(transformation(extent={{48,-4},{28,-24}})));
  Modelica.Fluid.Sources.MassFlowSource_T sou_eva(
    nPorts=1,
    T=273.15 + 12,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    use_m_flow_in=false,
    use_T_in=false,
    m_flow=0.9*m_flow_eva_start)                                    annotation (Placement(transformation(extent={{-48,-4},{-28,-24}})));
  Modelica.Fluid.Sources.Boundary_pT sin_gen(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    p(displayUnit="MPa") = 400000,
    T=388.15)                                                       annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={14,50})));
  Modelica.Fluid.Sources.Boundary_pT sin_con(
    T=308.15,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater)  annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=-90,
        origin={-14,50})));
  Modelica.Fluid.Sources.Boundary_pT sin_eva(
    T=279.15,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater)  annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=-90,
        origin={-14,-50})));
  Modelica.Fluid.Sensors.Temperature T_e(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={-40,-34})));
  Modelica.Fluid.Sensors.Temperature T_g(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={40,34})));
  Modelica.Fluid.Sensors.Temperature T_a(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=90,
        origin={40,-34})));
  Modelica.Fluid.Sensors.Temperature T_c(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-40,34})));
  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-80,-100},{-60,-80}})));

  Modelica.Blocks.Sources.RealExpression m_flow_ag(y=12.5) annotation (Placement(transformation(extent={{100,-58},{80,-38}})));
  Modelica.Blocks.Continuous.LimPID PI_m_flow_g(
    k=kp_eva,
    y_start=m_flow_gen_start,
    Ti(displayUnit="min") = Ti_eva,
    yMin=0.1*m_flow_gen_start,
    u_s=-Tset_eva,
    u_m=-T_e.T,
    xi_start=m_flow_gen_start/kp_eva,
    yMax=3*m_flow_gen_start,
    Td=Td_eva,
    controllerType=Modelica.Blocks.Types.SimpleController.PI)
                                    annotation (Placement(transformation(extent={{84,18},{76,26}})));
  Modelica.Blocks.Discrete.Sampler sampler_m_flow_g(                  startTime=10, samplePeriod=60)
    annotation (Placement(transformation(extent={{64,22},{56,30}})));
  Modelica.Blocks.Continuous.LimPID PI_V_g(
    yMin=0,
    k=kp_gen,
    yMax=1,
    y_start=1/3,
    Ti(displayUnit="min") = Ti_gen,
    Ni=1,
    u_s=-Vset_gen,
    u_m=-absorptionChiller.state_g.V,
    xi_start=0.3/kp_gen,
    controllerType=Modelica.Blocks.Types.SimpleController.P)
                                      annotation (Placement(transformation(extent={{78,-2},{70,6}})));
  Modelica.Blocks.Discrete.Sampler sampler_V_g(startTime=0, samplePeriod=5*60)
    annotation (Placement(transformation(extent={{54,-2},{46,6}})));
  Modelica.Blocks.Continuous.LimPID PI_V_c(
    yMin=0,
    yMax=1,
    y_start=1/3,
    k=kp_con,
    Ti(displayUnit="min") = Ti_con,
    u_s=-Vset_con,
    u_m=-absorptionChiller.state_c.V,
    xi_start=0.3/kp_con,
    controllerType=Modelica.Blocks.Types.SimpleController.P)
              annotation (Placement(transformation(extent={{-68,-4},{-60,4}})));
  Modelica.Blocks.Discrete.Sampler sampler_V_c(startTime=5, samplePeriod=10*60)
    annotation (Placement(transformation(extent={{-44,-4},{-36,4}})));
equation
  connect(sou_gen.ports[1], absorptionChiller.port_a_gen) annotation (Line(points={{28,14},{24,14},{20,14}}, color={0,127,255}));
  connect(sou_abs.ports[1], absorptionChiller.port_a_abs) annotation (Line(points={{28,-14},{24,-14},{20,-14}}, color={0,127,255}));
  connect(sou_eva.ports[1], absorptionChiller.port_a_eva) annotation (Line(points={{-28,-14},{-24,-14},{-20,-14}}, color={0,127,255}));
  connect(absorptionChiller.port_b_gen, sin_gen.ports[1]) annotation (Line(points={{14,20},{14,40}}, color={0,127,255}));
  connect(absorptionChiller.port_b_con, sin_con.ports[1]) annotation (Line(points={{-14,20},{-14,20},{-14,40}}, color={0,127,255}));
  connect(absorptionChiller.port_b_eva, sin_eva.ports[1]) annotation (Line(points={{-14,-20},{-14,-20},{-14,-40}}, color={0,127,255}));
  connect(T_e.port, absorptionChiller.port_b_eva) annotation (Line(points={{-30,-34},{-20,-34},{-20,-20},{-14,-20}}, color={0,127,255}));
  connect(T_g.port, absorptionChiller.port_b_gen) annotation (Line(points={{30,34},{20,34},{20,20},{14,20}}, color={0,127,255}));
  connect(T_a.port, absorptionChiller.port_b_abs) annotation (Line(points={{30,-34},{20,-34},{20,-20},{14,-20}}, color={0,127,255}));
  connect(T_c.port, absorptionChiller.port_b_con) annotation (Line(points={{-30,34},{-20,34},{-20,20},{-14,20}}, color={0,127,255}));
  connect(absorptionChiller.port_b_abs, absorptionChiller.port_a_con) annotation (Line(points={{14,-20},{14,-20},{0,-20},{0,-18},{0,-4},{0,14},{-20,14}},
                                                                                                                                               color={0,127,255}));
  connect(PI_m_flow_g.y, sampler_m_flow_g.u) annotation (Line(points={{75.6,22},{70,22},{70,26},{64.8,26}},
                                                                                            color={0,0,127}));
  connect(PI_V_g.y, sampler_V_g.u) annotation (Line(points={{69.6,2},{54.8,2}}, color={0,0,127}));
  connect(sampler_V_g.y, absorptionChiller.opening_sol) annotation (Line(points={{45.6,2},{22,2}}, color={0,0,127}));
  connect(PI_V_c.y,sampler_V_c. u) annotation (Line(points={{-59.6,0},{-52,0},{-44.8,0}}, color={0,0,127}));
  connect(sampler_V_c.y, absorptionChiller.opening_ref) annotation (Line(points={{-35.6,0},{-22,0}}, color={0,0,127}));
  connect(m_flow_ag.y, absorptionChiller.pump_sol) annotation (Line(points={{79,-48},{52,-48},{52,-6},{22,-6}}, color={0,0,127}));
  connect(sampler_m_flow_g.y, sou_gen.m_flow_in) annotation (Line(points={{55.6,26},{52,26},{52,22},{48,22}}, color={0,0,127}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    experiment(
      StopTime=172800,
      Interval=1080000,
      Tolerance=1e-06,
      __Dymola_fixedstepsize=36000,
      __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>The absorbtion chiller is model using steady state data taken from:</p>
<p>[1] ASHRAE. ASHRAE Handbook: Fundamentals (SI edition). Atlanta, GA: American Society of Heating, Refrigerating and Air-conditioning Engineers; 2009.</p>
<p>The dynamics parameters were chosen arbitrarily to test a generic control system based on PID controllers.</p>
</html>"));
end ASHRAE_wControl;
