within DCOL.Generation.AbsorptionChillers.Testing;
model ASHRAE_wControl_Simplified
  import SI = Modelica.SIunits;
  extends Partial_ASHRAE;

  SI.Duration dTime = 2*60*60;
  // Evaporator temperature
  SI.Time sT_eva = 12*60*60;
  SI.TemperatureDifference dT = 3;
  SI.Temperature Tset_eva=
    7+273.15 + (if time<sT_eva then 0 else if time<(sT_eva +dTime) then (time-sT_eva)*dT/dTime else dT);
    //if time<18*60*60 then 7+273.15 else 11+273.15;
  parameter Real kp_eva = 0.1;//1E0;
  parameter Real Ti_eva = 60;//60;

  // Generator level
  parameter Real Vset_gen = level_gen_start*crossArea_gen;

  // Condenser level
  parameter Real Vset_con = level_con_start*crossArea_con;

  // Generator consent.
  SI.Time sT_gen = sT_eva;
  Real dX = -dT*0.15/5.0; //0.10*dT/3;
  Real Xset=
    X_str_start + (if time<sT_gen then 0 else if time<(sT_gen +dTime) then (time-sT_gen)*dX/dTime else dX);
  //if time<18*60*60 then X_str_start else 0.75;
  parameter Real kp_X = 0.1;
  parameter Real Ti_X = 60;

  AbsorptionChiller_Simplified
                    absorptionChiller_Simplified(
    X_wea_start=X_wea_start,
    X_str_start=X_str_start,
    m_flow_str_start=m_flow_str_start,
    m_flow_ref_start=m_flow_ref_start,
    level_abs_start=level_abs_start,
    p_abs_start=p_abs_start,
    level_gen_start=level_gen_start,
    p_gen_start=p_gen_start,
    level_eva_start=level_eva_start,
    level_con_start=level_con_start,
    m_flow_gen_start=m_flow_gen_start,
    m_flow_abs_start=m_flow_abs_start,
    m_flow_con_start=m_flow_con_start,
    m_flow_eva_start=m_flow_eva_start,
    G_abs=G_abs,
    G_con=G_con,
    redeclare package Medium_gen = Modelica.Media.Water.StandardWater,
    redeclare package Medium_abs = Modelica.Media.Water.StandardWater,
    redeclare package Medium_con = Modelica.Media.Water.StandardWater,
    redeclare package Medium_eva = Modelica.Media.Water.StandardWater,
    modelStructure_abs=Modelica.Fluid.Types.ModelStructure.a_v_b,
    modelStructure_eva=Modelica.Fluid.Types.ModelStructure.a_v_b,
    modelStructure_con=Modelica.Fluid.Types.ModelStructure.av_b,
    G_eva=G_eva,
    modelStructure_gen=Modelica.Fluid.Types.ModelStructure.a_vb,
    T_HX_start=(T_HXw_start + T_HXs_start)/2,
    G_gen=G_gen,
    opening_ref_start=0.3,
    opening_str_start=0.3,
    G_HXsol=G_HXsol,
    p_gen_nominal=p_gen_start,
    p_abs_nominal=p_abs_start,
    m_flow_str_nominal=m_flow_str_start,
    opening_str_nominal=0.3,
    m_flow_ref_nominal=m_flow_ref_start,
    opening_ref_nominal=0.3,
    T_genPipe_start=T_gen,
    p_genPipe_start(displayUnit="MPa") = 400000,
    T_absPipe_start=T_abs,
    p_absPipe_start=system.p_ambient,
    T_conPipe_start=T_con,
    p_conPipe_start=system.p_ambient,
    T_evaPipe_start=T_eva,
    p_evaPipe_start=system.p_ambient,
    height_gen=height_gen,
    crossArea_gen=crossArea_gen,
    height_abs=height_abs,
    crossArea_abs=crossArea_abs,
    height_con=height_con,
    crossArea_con=crossArea_con,
    height_eva=height_eva,
    crossArea_eva=crossArea_eva,
    C_gen=1e6,
    C_abs=1e6,
    C_con=1e6,
    C_eva=1e6)                                  annotation (Placement(transformation(extent={{-20,-20},{20,20}})));
  Modelica.Fluid.Sources.MassFlowSource_T sou_gen(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    m_flow=m_flow_gen_start,
    use_T_in=false,
    use_m_flow_in=true,
    T=398.15)                                                       annotation (Placement(transformation(extent={{48,4},{28,24}})));
  Modelica.Fluid.Sources.MassFlowSource_T sou_abs(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    m_flow=m_flow_abs_start,
    T=300.15) annotation (Placement(transformation(extent={{48,-4},{28,-24}})));
  Modelica.Fluid.Sources.MassFlowSource_T sou_eva(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    use_m_flow_in=false,
    use_T_in=false,
    m_flow=0.9*m_flow_eva_start,
    T=285.15)                                                       annotation (Placement(transformation(extent={{-48,-4},{-28,-24}})));
  Modelica.Fluid.Sources.Boundary_pT sin_gen(
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    p(displayUnit="MPa") = 400000,
    T=388.15)                                                       annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={14,50})));
  Modelica.Fluid.Sources.Boundary_pT sin_con(
    T=308.15,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater)  annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=-90,
        origin={-14,50})));
  Modelica.Fluid.Sources.Boundary_pT sin_eva(
    T=279.15,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWater)  annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=-90,
        origin={-14,-50})));
  Modelica.Fluid.Sensors.Temperature T_e(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={-40,-34})));
  Modelica.Fluid.Sensors.Temperature T_g(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={40,34})));
  Modelica.Fluid.Sensors.Temperature T_a(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=90,
        origin={40,-34})));
  Modelica.Fluid.Sensors.Temperature T_c(redeclare package Medium =
        Modelica.Media.Water.StandardWater)                                                             annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-40,34})));
  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-80,-100},{-60,-80}})));

  Modelica.Blocks.Continuous.LimPID PI_m_flow_g(
    k=kp_eva,
    y_start=m_flow_gen_start,
    Ti(displayUnit="min") = Ti_eva,
    u_s=-Tset_eva,
    u_m=-T_e.T,
    xi_start=m_flow_gen_start/kp_eva,
    yMax=3*m_flow_gen_start,
    yMin=0.05*m_flow_gen_start,
    controllerType=Modelica.Blocks.Types.SimpleController.PID)
                                    annotation (Placement(transformation(extent={{68,18},{60,26}})));
  Modelica.Blocks.Continuous.LimPID PI_X(
    yMin=0,
    k=kp_X,
    yMax=10*m_flow_wea_start,
    y_start=m_flow_wea_start,
    Ti(displayUnit="min") = Ti_X,
    u_s=-Xset,
    controllerType=Modelica.Blocks.Types.SimpleController.PI,
    xi_start=m_flow_wea_start/kp_X,
    u_m=-absorptionChiller_Simplified.state_g.X)
                              annotation (Placement(transformation(extent={{68,-10},{60,-2}})));
equation
  connect(sou_gen.ports[1], absorptionChiller_Simplified.port_a_gen) annotation (Line(points={{28,14},{24,14},{20,14}}, color={0,127,255}));
  connect(sou_abs.ports[1], absorptionChiller_Simplified.port_a_abs) annotation (Line(points={{28,-14},{24,-14},{20,-14}}, color={0,127,255}));
  connect(sou_eva.ports[1], absorptionChiller_Simplified.port_a_eva) annotation (Line(points={{-28,-14},{-20,-14}},           color={0,127,255}));
  connect(absorptionChiller_Simplified.port_b_gen, sin_gen.ports[1]) annotation (Line(points={{14,20},{14,40}}, color={0,127,255}));
  connect(absorptionChiller_Simplified.port_b_con, sin_con.ports[1]) annotation (Line(points={{-14,20},{-14,20},{-14,40}}, color={0,127,255}));
  connect(absorptionChiller_Simplified.port_b_eva, sin_eva.ports[1]) annotation (Line(points={{-14,-20},{-14,-20},{-14,-40}}, color={0,127,255}));
  connect(T_e.port, absorptionChiller_Simplified.port_b_eva) annotation (Line(points={{-30,-34},{-20,-34},{-20,-20},{-14,-20}}, color={0,127,255}));
  connect(T_g.port, absorptionChiller_Simplified.port_b_gen) annotation (Line(points={{30,34},{20,34},{20,20},{14,20}}, color={0,127,255}));
  connect(T_a.port, absorptionChiller_Simplified.port_b_abs) annotation (Line(points={{30,-34},{20,-34},{20,-20},{14,-20}}, color={0,127,255}));
  connect(T_c.port, absorptionChiller_Simplified.port_b_con) annotation (Line(points={{-30,34},{-20,34},{-20,20},{-14,20}}, color={0,127,255}));
  connect(absorptionChiller_Simplified.port_b_abs, absorptionChiller_Simplified.port_a_con) annotation (Line(points={{14,-20},{14,-20},{0,-20},{0,-18},{0,-4},{0,14},{-20,14}}, color={0,127,255}));
  connect(PI_X.y, absorptionChiller_Simplified.pump_sol) annotation (Line(points={{59.6,-6},{22,-6}}, color={0,0,127}));
  connect(PI_m_flow_g.y, sou_gen.m_flow_in) annotation (Line(points={{59.6,22},{48,22}}, color={0,0,127}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    experiment(
      StopTime=172800,
      Tolerance=1e-06,
      __Dymola_fixedstepsize=0.1,
      __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>The absorbtion chiller is model using steady state data taken from:</p>
<p>[1] ASHRAE. ASHRAE Handbook: Fundamentals (SI edition). Atlanta, GA: American Society of Heating, Refrigerating and Air-conditioning Engineers; 2009.</p>
<p>The dynamics parameters were chosen arbitrarily to test a generic control system based on PID controllers.</p>
</html>"));
end ASHRAE_wControl_Simplified;
