within DCOL.Generation.AbsorptionChillers.Testing;
model Partial_ASHRAE
  import SI = Modelica.SIunits;
  import Modelica.Fluid.Types.ModelStructure;

  parameter SI.MassFraction X_wea_start = 0.596;
  parameter SI.MassFraction X_str_start = 0.646;
  parameter SI.MassFlowRate m_flow_str_start = 11.06;
  parameter SI.MassFlowRate m_flow_ref_start = 0.93;
  final parameter SI.MassFlowRate m_flow_wea_start = m_flow_str_start + m_flow_ref_start;
  parameter SI.AbsolutePressure p_abs_start = 0.697E3;
  parameter SI.AbsolutePressure p_gen_start = 10.2E3;
  parameter SI.Efficiency Eff_HXsol = 0.654;
  parameter SI.ThermalConductance G_HXsol = 33.8E3;
  parameter SI.Temperature T_HXw_start = 76.1 +273.15;
  parameter SI.Temperature T_HXs_start = 62.4 +273.15;

  parameter Real T_abs=BaseClasses.LiBrH2O.temperature_psatX(p_abs_start, X_wea_start);
  parameter Real T_eva = Modelica.Media.Water.WaterIF97_base.saturationTemperature(p_abs_start);
  parameter Real T_gen=BaseClasses.LiBrH2O.temperature_psatX(p_gen_start, X_str_start);
  parameter Real T_con = Modelica.Media.Water.WaterIF97_base.saturationTemperature(p_gen_start);

  parameter SI.Height height_abs = 3;
  parameter SI.Area crossArea_abs = 1;
  parameter Real level_abs_start = height_abs/2;
  parameter SI.Height height_gen = 3;
  parameter SI.Area crossArea_gen = 1;
  parameter Real level_gen_start = height_gen/2;
  parameter SI.Height height_eva = 3;
  parameter SI.Area crossArea_eva = 1;
  parameter Real level_eva_start = height_eva/2;
  parameter SI.Height height_con = 3;
  parameter SI.Area crossArea_con = 1;
  parameter Real level_con_start = height_con/2;

  parameter Real Q_abs = -2984E3;
  parameter Real Q_gen = 3158E3;
  parameter Real Q_sol = 825E3;
  parameter Real Q_con = -2322E3;
  parameter Real Q_eva = 2148E3;

  parameter SI.MassFlowRate m_flow_gen_start = 74.4;
  parameter SI.MassFlowRate m_flow_abs_start = 158.7;
  parameter SI.MassFlowRate m_flow_con_start = 158.7;
  parameter SI.MassFlowRate m_flow_eva_start = 85.3;

  parameter SI.ThermalConductance G_gen = 143.4E3;
  parameter SI.ThermalConductance G_abs = 186.9E3;
  parameter SI.ThermalConductance G_con = 180.6E3;
  parameter SI.ThermalConductance G_eva = 319.2E3;

  parameter ModelStructure modelStructure_gen=ModelStructure.av_vb;
  parameter ModelStructure modelStructure_abs=ModelStructure.av_vb;
  parameter ModelStructure modelStructure_con=ModelStructure.av_vb;
  parameter ModelStructure modelStructure_eva=ModelStructure.av_vb;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>The steady state parameters were taken from:</p>
<p>[1] ASHRAE. ASHRAE Handbook: Fundamentals (SI edition). Atlanta, GA: American Society of Heating, Refrigerating and Air-conditioning Engineers; 2009.</p>
</html>"));
end Partial_ASHRAE;
