within DCOL.Generation.ConventionalChillers.BaseClasses;
model ControlledPump_P
  extends Modelica.Fluid.Machines.BaseClasses.PartialPump(
    N_nominal=1500,
    N(start=N_nominal),
    redeclare replaceable function flowCharacteristic =
        Modelica.Fluid.Machines.BaseClasses.PumpCharacteristics.quadraticFlow (
          V_flow_nominal={0, V_flow_op, 1.5*V_flow_op},
          head_nominal={2*head_op, head_op, 0}));

  // nominal values
  parameter Medium.AbsolutePressure p_a_nominal
    "Nominal inlet pressure for predefined pump characteristics";
  parameter Medium.AbsolutePressure p_b_nominal
    "Nominal outlet pressure, fixed if not control_m_flow and not use_p_set";
  parameter Medium.MassFlowRate m_flow_nominal
    "Nominal mass flow rate, fixed if control_m_flow and not use_m_flow_set";

  // exemplary characteristics
  final parameter Modelica.SIunits.VolumeFlowRate V_flow_op = m_flow_nominal/rho_nominal
    "operational volume flow rate according to nominal values";
  final parameter Modelica.SIunits.Height head_op = (p_b_nominal-p_a_nominal)/(rho_nominal*g)
    "operational pump head according to nominal values";

  Modelica.Blocks.Interfaces.RealInput P_in(unit="W")
    "Prescribed power"
    annotation (Placement(transformation(
        extent={{-20,-20},{20,20}},
        rotation=-90,
        origin={0,100}), iconTransformation(
        extent={{-20,-20},{20,20}},
        rotation=-90,
        origin={0,100})));

equation

  W_total = P_in;
  annotation (Documentation(info="<html>
<p>Based on <a href=\"Modelica.Fluid.Machines.ControlledPump\">Modelica.Fluid.Machines.ControlledPump</a>, this model describes a centrifugal pump (or a group of nParallel pumps) with prescribed power, provided by an external signal. </p>
<p>Nominal values are used to predefine an exemplary pump characteristics and to define the operation of the pump. The input connector P_in provides time varying supplied power. </p>
<p>Use this model if the pump characteristics is of secondary interest. The actual characteristics can be configured later on for the appropriate rotational speed N. Then the model can be replaced with a Pump with rotational shaft or with a PrescribedPump.</p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end ControlledPump_P;
