within DCOL.Generation.ConventionalChillers;
model ControlledChiller

  extends Interfaces.PartialChiller;

  parameter Integer n=3;

  replaceable package ChillerData =
    ChillerSpecs.McQuay_AWS_XE_XN_280_2
                        constrainedby ChillerSpecs.Base
    annotation (choicesAllMatching = true);

  final parameter Modelica.SIunits.HeatFlowRate Q_flow_ref=
    ChillerData.modelData.Qflow_eva_ref "Reference cooling capacity";
  final parameter Modelica.SIunits.Power P_ref=
    Q_flow_ref/ChillerData.modelData.COP_ref "Reference power";
  final parameter Medium_eva.MassFlowRate m_flow_eva_nominal=
     ChillerData.modelData.mflow_eva_nominal "Nominal mflow of evaporator";
  final parameter Modelica.SIunits.TemperatureDifference dT_evaporating_nominal=
    Q_flow_ref/(
      Medium_eva.specificHeatCapacityCp(Medium_eva.setState_pTX(Medium_eva.p_default, Medium_eva.T_default))*
      ChillerData.modelData.mflow_eva_nominal);
  final parameter Modelica.SIunits.Temperature T_evaporating_nominal=
    T_out_eva_nominal + dT_evaporating_nominal;
  final parameter Modelica.SIunits.Temperature T_out_eva_nominal=
    ChillerData.modelData.T_out_eva_nominal;
  final parameter Medium_con.MassFlowRate m_flow_con_nominal=
     ChillerData.modelData.mflow_con_nominal "Nominal mflow of evaporator";
  final parameter Modelica.SIunits.TemperatureDifference dT_condensing_nominal=
    (Q_flow_ref+P_ref)/(
      Medium_con.specificHeatCapacityCp(Medium_con.setState_pTX(Medium_con.p_default, Medium_con.T_default))*
      ChillerData.modelData.mflow_con_nominal);
  final parameter Modelica.SIunits.Temperature T_condensing_nominal=
    ChillerData.modelData.T_in_con_nominal;
  final parameter Modelica.SIunits.Temperature T_out_con_nominal=
    T_condensing_nominal + dT_condensing_nominal;

  //Refrigerant circuit
  replaceable package Medium_ref =
    Modelica.Media.R134a.R134a_ph
    constrainedby Modelica.Media.Interfaces.PartialTwoPhaseMedium "Refrigerant"
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));

//   parameter Modelica.SIunits.TemperatureDifference dT_evaporating_nominal=-5
//     annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
  parameter Medium_ref.Temperature T_low_nominal=T_out_eva_nominal-5
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
  parameter Medium_ref.AbsolutePressure dp_eva_nominal=20
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
  parameter Modelica.SIunits.TemperatureDifference dT_superHeat_nominal=5
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
//   parameter Modelica.SIunits.TemperatureDifference dT_condensing_nominal=0.0
//     annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
  parameter Medium_ref.Temperature T_high_nominal=T_out_con_nominal+5
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
  parameter Medium_ref.AbsolutePressure dp_con_nominal=20
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
  parameter Modelica.SIunits.TemperatureDifference dT_subCool_nominal=5
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));
  parameter Real valve_opening_nominal=0.5
    annotation(choicesAllMatching=true, Dialog(tab="Refrigerant"));

  BaseClasses.RefrigerantCircuit refrigerantCircuit(
    final n=n,
    redeclare package Medium = Medium_ref,
    final Q_flow_req_nominal=Q_flow_ref,
    final P_nominal=P_ref,
    final dp_eva_nominal=dp_eva_nominal,
    final dp_con_nominal=dp_con_nominal,
    final valve_opening_nominal=valve_opening_nominal,
    final T_low_nominal=T_low_nominal,
    final T_high_nominal=T_high_nominal,
    final dT_superHeat_nominal=dT_superHeat_nominal,
    final dT_subCool_nominal=dT_subCool_nominal) annotation (Placement(transformation(extent={{-10,-10},{10,10}})));

  //Evaporator
  //Evaporator - Geometry
  parameter Modelica.SIunits.Length length_eva
    "Length"
    annotation(Dialog(tab="Evaporator", group="Geometry"));
  parameter Boolean isCircular_eva=true
    "= true if cross sectional area is circular"
    annotation (Evaluate, Dialog(tab="Evaporator", group="Geometry"));
  parameter Modelica.SIunits.Diameter diameter_eva
    "Diameter of circular evaporator"
    annotation(Dialog(tab="Evaporator", group="Geometry", enable=isCircular_eva));
  parameter Modelica.SIunits.Area crossArea_eva=Modelica.Constants.pi*diameter_eva*diameter_eva/4
    "Inner cross section area"
    annotation(Dialog(tab="Evaporator", group="Geometry", enable=not isCircular_eva));
  parameter Modelica.SIunits.Length perimeter_eva=Modelica.Constants.pi*diameter_eva
    "Inner perimeter"
    annotation(Dialog(tab="Evaporator", group="Geometry", enable=not isCircular_eva));
  parameter Modelica.SIunits.HeatCapacity C_eva
    "Heat capacity of evaporator (= cp*m)"
    annotation(Dialog(tab="Evaporator", group="Geometry"));
  //Evaporator - Advanced
  parameter Modelica.Fluid.Types.ModelStructure modelStructure_eva=Modelica.Fluid.Types.ModelStructure.a_vb
    annotation(Dialog(tab="Evaporator", group="Advanced"));
  final parameter Modelica.SIunits.Temperature[n+1] Ts_eva_ext=
    linspace(T_evaporating_nominal, T_out_eva_nominal, n+1);
  final parameter Modelica.SIunits.Enthalpy[n+1] hs_eva_int=
    linspace(refrigerantCircuit.state4_nominal.h, refrigerantCircuit.state1_nominal.h, n+1);
  final parameter Modelica.SIunits.Pressure[n+1] ps_eva_int=
    linspace(refrigerantCircuit.state4_nominal.p, refrigerantCircuit.state1_nominal.p, n+1);
  final parameter Modelica.SIunits.Temperature[n+1] Ts_eva_int=
    {Medium_ref.temperature_ph(ps_eva_int[i], hs_eva_int[i]) for i in 1:(n+1)};

  final parameter Modelica.SIunits.ThermalConductance G_eva0=
    Q_flow_ref/sum(Ts_eva_ext[2:n+1] .- Ts_eva_int[2:n+1]);

  final parameter Real A_eva[n, 1]=
    [Ts_eva_ext[2:n+1] .- Ts_eva_int[2:n+1]];
  final parameter Real b_eva[n]=
    fill(Q_flow_ref/n, n);
  final parameter Modelica.SIunits.ThermalConductance[1] G_eva=
    Modelica.Math.Matrices.leastSquares(A_eva, b_eva);

  final parameter Modelica.SIunits.ThermalConductance[n] Gs_eva=
    fill(Q_flow_ref/n, n)./
    (Ts_eva_ext[n+1:-1:2] .- Ts_eva_int[2:n+1]);
    //(Ts_eva_ext[2:n+1] .- Ts_eva_int[2:n+1]);

  //Condenser
  //Condenser - Geometry
  parameter Modelica.SIunits.Length length_con
    "Length"
    annotation(Dialog(tab="Condenser", group="Geometry"));
  parameter Boolean isCircular_con=true
    "= true if cross sectional area is circular"
    annotation (Evaluate, Dialog(tab="Condenser", group="Geometry"));
  parameter Modelica.SIunits.Diameter diameter_con
    "Diameter of circular evaporator"
    annotation(Dialog(tab="Condenser", group="Geometry", enable=isCircular_con));
  parameter Modelica.SIunits.Area crossArea_con=Modelica.Constants.pi*diameter_con*diameter_con/4
    "Inner cross section area"
    annotation(Dialog(tab="Condenser", group="Geometry", enable=not isCircular_con));
  parameter Modelica.SIunits.Length perimeter_con=Modelica.Constants.pi*diameter_con
    "Inner perimeter"
    annotation(Dialog(tab="Condenser", group="Geometry", enable=not isCircular_con));
  parameter Modelica.SIunits.HeatCapacity C_con
    "Heat capacity of condenser (= cp*m)"
    annotation(Dialog(tab="Condenser", group="Geometry"));
  //Condenser - Advanced
//   parameter Boolean useLumpedPressure_con=true;
  parameter Modelica.Fluid.Types.ModelStructure modelStructure_con=Modelica.Fluid.Types.ModelStructure.a_vb
    annotation(Dialog(tab="Condenser", group="Advanced"));
  final parameter Modelica.SIunits.Temperature[n+1] Ts_con_ext=
    linspace(T_condensing_nominal, T_out_con_nominal, n+1);
  final parameter Modelica.SIunits.Enthalpy[n+1] hs_con_int=
    linspace(refrigerantCircuit.state2_nominal.h, refrigerantCircuit.state3_nominal.h, n+1);
  final parameter Modelica.SIunits.Pressure[n+1] ps_con_int=
    linspace(refrigerantCircuit.state2_nominal.p, refrigerantCircuit.state3_nominal.p, n+1);
  final parameter Modelica.SIunits.Temperature[n+1] Ts_con_int=
    {Medium_ref.temperature_ph(ps_con_int[i], hs_con_int[i]) for i in 1:(n+1)};

  final parameter Modelica.SIunits.ThermalConductance G_con0=
    (Q_flow_ref+P_ref)/sum(Ts_con_int[2:n+1] .- Ts_con_ext[2:n+1]);

  final parameter Real A_con[n, 1]=
    [Ts_con_int[2:n+1] .- Ts_con_ext[2:n+1]];
  final parameter Real b_con[n]=
    fill((Q_flow_ref+P_ref)/n, n);
  final parameter Modelica.SIunits.ThermalConductance[1] G_con=
    Modelica.Math.Matrices.leastSquares(A_con, b_con);

  final parameter Modelica.SIunits.ThermalConductance[n] Gs_con=
    fill((Q_flow_ref+P_ref)/n, n)./
    (Ts_con_int[2:n+1] .- Ts_con_ext[n+1:-1:2]);
    //(Ts_con_int[2:n+1] .- Ts_con_ext[2:n+1]);

  //Controller
  parameter Real k_controller(min=0, unit="1") = P_ref/dT_evaporating_nominal
    "Gain of controller"
    annotation (Dialog(tab="Controller"));
  parameter Modelica.SIunits.Time Ti_controller(min=Modelica.Constants.small)=1
    "Time constant of Integrator block"
    annotation (Dialog(tab="Controller"));
  parameter Real yMax_controller(start=1) = 3.0*P_ref "Upper limit of output"
    annotation (Dialog(tab="Controller"));
  // parameter Real yMax_controller(start=1) = 3.0*P_ref "Upper limit of output"
  //   annotation (Dialog(tab="Controller"));
  parameter Real wp_controller(min=0) = 1
    "Set-point weight for Proportional block (0..1)"
    annotation (Dialog(tab="Controller"));
  parameter Real Ni_controller(min=100*Modelica.Constants.eps) = 0.1
    "Ni*Ti is time constant of anti-windup compensation"
    annotation (Dialog(tab="Controller"));
  parameter Real xi_start_controller = dT_evaporating_nominal "Initial value of integer output"
    annotation (Dialog(tab="Controller"));
  parameter Real y_start_controller = P_ref "Initial value of output"
    annotation (Dialog(tab="Controller"));

  Modelica.Blocks.Interfaces.RealInput T_eva_set(
    final quantity="ThermodynamicTemperature",
    final unit = "K", displayUnit = "degC", min=0)
    "Evaporator outlet temperature setpoint"
    annotation (Placement(transformation(
        extent={{20,-20},{-20,20}},
        rotation=-90,
        origin={60,-120})));

  Modelica.Fluid.Pipes.DynamicPipe evaporator(
    final nNodes=n,
    redeclare package Medium = Medium_eva,
    final length=length_eva,
    final isCircular=isCircular_eva,
    final diameter=diameter_eva,
    final crossArea=crossArea_eva,
    final perimeter=perimeter_eva,
    final useLumpedPressure=true,
    final modelStructure=modelStructure_eva,
    T_start=T_out_eva_nominal,
    nParallel=1,
    roughness=2.5E-5,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.DetailedPipeFlow,
    use_HeatTransfer=true,
    allowFlowReversal=true,
    m_flow_start=m_flow_con_nominal)
    annotation (Placement(transformation(extent={{-10,-90},{10,-70}})));
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor G_eva_ext[n](final G=Gs_eva*2)
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={0,-58})));
  Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor_eva[n](each final C=C_eva)
    annotation (Placement(transformation(extent={{-30,-40},{-10,-20}})));
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor G_eva_int[n](final G=Gs_eva*2)
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={0,-24})));

  Modelica.Fluid.Sensors.TemperatureTwoPort T_eva_out(redeclare package Medium = Medium_eva, allowFlowReversal=false) annotation (Placement(transformation(extent={{30,-90},{50,-70}})));
  Modelica.Fluid.Pipes.DynamicPipe condenser(
    final nNodes=n,
    final allowFlowReversal=false,
    redeclare package Medium = Medium_con,
    final length=length_con,
    final isCircular=isCircular_con,
    final diameter=diameter_con,
    final crossArea=crossArea_con,
    final perimeter=perimeter_con,
    final useLumpedPressure=true,
    final modelStructure=modelStructure_con,
    T_start=T_out_con_nominal,
    nParallel=1,
    roughness=2.5E-5,
    use_HeatTransfer=true,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.DetailedPipeFlow,
    m_flow_start=m_flow_con_nominal)
    annotation (Placement(transformation(extent={{10,90},{-10,70}})));
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor G_con_ext[n](final G=Gs_con*2)
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={0,58})));
  Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor_con[n]( each final C=C_con)
    annotation (Placement(transformation(extent={{-30,40},{-10,60}})));
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor G_con_int[n](final G=Gs_con*2)
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={0,24})));
  Modelica.Fluid.Sensors.TemperatureTwoPort T_con_in(redeclare package Medium = Medium_con, allowFlowReversal=false)
    annotation (Placement(transformation(extent={{50,90},{30,70}})));

  Modelica.Blocks.Continuous.LimPID controller_PI(
    final k=k_controller,
    final yMax=yMax_controller,
    final Ti=Ti_controller,
    final Ni=Ni_controller,
    final wp=1,
    final y_start=y_start_controller,
    final initType=Modelica.Blocks.Types.InitPID.InitialOutput,
    final controllerType=Modelica.Blocks.Types.SimpleController.PI,
    final yMin=0,
    final xi_start=xi_start_controller)
    annotation (Placement(transformation(extent={{46,-6},{34,6}})));

  Modelica.Blocks.Sources.RealExpression controller_set(y=-T_eva_set)
    annotation (Placement(transformation(extent={{80,-10},{60,10}})));
  Modelica.Blocks.Math.Gain gain(k=-1)
    annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=90,
        origin={40,-34})));

//*********** Outputs ***********************************************************//
  output Modelica.SIunits.HeatFlowRate Q_flow_total_eva = -sum(evaporator.Qb_flows)
    "Evaporator heat flow rate";
  output Modelica.SIunits.HeatFlowRate Q_flow_total_con = sum(condenser.Qb_flows)
    "Condenser heat flow rate";
  output Medium_eva.ThermodynamicState state_in_eva=
    Medium_eva.setState_phX(evaporator.port_a.p, inStream(evaporator.port_a.h_outflow))
    "Fluid state at the evaporator input";
  output Medium_eva.ThermodynamicState state_out_eva=
    Medium_eva.setState_phX(evaporator.port_b.p, evaporator.port_b.h_outflow)
    "Fluid state at the evaporator output";
  output Medium_con.ThermodynamicState state_in_con=
    Medium_con.setState_phX(condenser.port_a.p, inStream(condenser.port_a.h_outflow))
    "Fluid state at the condenser input";
  output Medium_con.ThermodynamicState state_out_con=
    Medium_con.setState_phX(condenser.port_b.p, condenser.port_b.h_outflow)
    "Fluid state at the condenser input";

initial equation
  evaporator.mediums.T = Ts_eva_ext[2:n+1];
  condenser.mediums.T = Ts_con_ext[2:n+1];
  //heatCapacitor_eva.T = (Ts_eva_int[2:n+1] .+ Ts_eva_ext[2:n+1])/2;
  heatCapacitor_eva.T = (Ts_eva_int[2:n+1] .+ Ts_eva_ext[n+1:-1:2])/2;
  //heatCapacitor_con.T = (Ts_con_int[2:n+1] .+ Ts_con_ext[2:n+1])/2;
  heatCapacitor_con.T = (Ts_con_int[2:n+1] .+ Ts_con_ext[n+1:-1:2])/2;
  refrigerantCircuit.evaporator.mediums.h =
    linspace(refrigerantCircuit.state4_nominal.h+(refrigerantCircuit.state1_nominal.h-refrigerantCircuit.state4_nominal.h)/n,refrigerantCircuit.state1_nominal.h,n);
  refrigerantCircuit.evaporator.mediums.p = refrigerantCircuit.evaporator.ps_start;
  refrigerantCircuit.condenser.mediums.h =
    linspace(refrigerantCircuit.state2_nominal.h+(refrigerantCircuit.state3_nominal.h-refrigerantCircuit.state2_nominal.h)/n,refrigerantCircuit.state3_nominal.h,n);
  refrigerantCircuit.condenser.mediums.p = refrigerantCircuit.condenser.ps_start;

equation
  connect(port_a_1, evaporator.port_a)
    annotation (Line(points={{-100,-80},{-56,-80},{-10,-80}},
                                                    color={0,127,255}));
  connect(condenser.port_b, port_b_2)
    annotation (Line(points={{-10,80},{-100,80}},          color={0,127,255}));
  connect(port_a_2, port_a_2)
    annotation (Line(points={{100,80},{100,80},{100,80}}, color={0,127,255}));
  connect(port_a_2, T_con_in.port_a) annotation (Line(points={{100,80},{50,80}}, color={0,127,255}));
  connect(T_con_in.port_b, condenser.port_a) annotation (Line(points={{30,80},{10,80}}, color={0,127,255}));
  connect(evaporator.port_b, T_eva_out.port_a) annotation (Line(points={{10,-80},{30,-80}}, color={0,127,255}));
  connect(T_eva_out.port_b, port_b_1) annotation (Line(points={{50,-80},{100,-80}}, color={0,127,255}));
  connect(controller_set.y, controller_PI.u_s) annotation (Line(points={{59,0},{47.2,0}}, color={0,0,127}));
  connect(gain.y, controller_PI.u_m) annotation (Line(points={{40,-27.4},{40,-18},{40,-7.2}},
                                                                                     color={0,0,127}));
  connect(G_eva_ext.port_b, heatCapacitor_eva.port) annotation (Line(points={{0,-48},{0,-48},{0,-40},{-20,-40}}, color={191,0,0}));
  //connect(G_eva_ext.port_a, evaporator.heatPorts) annotation (Line(points={{0,-68},{0,-75.6},{0.1,-75.6}}, color={191,0,0}));
  connect(G_eva_ext[end:-1:1].port_a, evaporator.heatPorts) annotation (Line(points={{0,-68},{0,-75.6},{0.1,-75.6}}, color={191,0,0}));
  connect(G_con_ext.port_a, heatCapacitor_con.port) annotation (Line(points={{-4.44089e-016,48},{0,48},{0,40},{-20,40}}, color={191,0,0}));
  //connect(G_con_ext.port_b, condenser.heatPorts) annotation (Line(points={{0,68},{0,75.6},{-0.1,75.6}}, color={191,0,0}));
  connect(G_con_ext[end:-1:1].port_b, condenser.heatPorts) annotation (Line(points={{0,68},{0,75.6},{-0.1,75.6}}, color={191,0,0}));
  connect(G_con_int.port_a, refrigerantCircuit.heatPorts_b) annotation (Line(points={{0,14},{0,9.8}}, color={191,0,0}));
  connect(G_con_int.port_b, heatCapacitor_con.port) annotation (Line(points={{0,34},{0,40},{-20,40}}, color={191,0,0}));
  connect(G_eva_int.port_a, heatCapacitor_eva.port) annotation (Line(points={{0,-34},{0,-40},{-20,-40}}, color={191,0,0}));
  connect(G_eva_int.port_b, refrigerantCircuit.heatPorts_a) annotation (Line(points={{0,-14},{0,-9.8}}, color={191,0,0}));
  connect(controller_PI.y, refrigerantCircuit.control_in) annotation (Line(points={{33.4,0},{14,0}}, color={0,0,127}));
  connect(T_eva_out.T, gain.u) annotation (Line(points={{40,-69},{40,-41.2}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), Icon(coordinateSystem(preserveAspectRatio=false,
          extent={{-100,-100},{100,100}})),
    Documentation(revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>",
        info="<html>
<p>Physics-based model of a typical vapour-compression systems (VCS). The model is constructed by integrating the vapour-compression cycle model, <a href=\"Modelica_IK4_TEKNIKER.DCOL.Generation.ConventionalChillers.BaseClasses.RefrigerantCircuit\">RefrigerantCircuit</a>, and the modified <a href=\"Modelica_IK4_TEKNIKER.DCOL.Generation.ConventionalChillers.BaseClasses.DynamicPipe_inverseAlpha_T\">DynamicPipe</a> in order to complete both heat exchanger models, the condenser and the evaporator. The VCS model includes a PID controller which modulates the compressor power, so the temperature of the outlet water at the evaporator matches a set point given as an input. </p>
</html>"));
end ControlledChiller;
