within DCOL.Generation.ConventionalChillers.Experiments;
model CTandCh "Conventional chiller with large inertia"
  parameter Modelica.SIunits.Time base_period = 4 *60*60;
  final parameter Modelica.SIunits.Time period = 7*base_period;

  parameter Integer n = 4;

  parameter Modelica.SIunits.Temperature T_out_req=
    chiller.T_out_eva_nominal;
  parameter Modelica.SIunits.Temperature T_in_eva=
    chiller.T_evaporating_nominal;
  parameter Modelica.SIunits.Temperature T_out_con=
    chiller.T_out_con_nominal;
  parameter Modelica.SIunits.Temperature T_in_con=
    chiller.T_condensing_nominal;

  parameter Modelica.SIunits.MassFlowRate mflow_in_eva=chiller.ChillerData.modelData.mflow_eva_nominal;
  parameter Modelica.SIunits.MassFlowRate mflow_in_con=chiller.ChillerData.modelData.mflow_con_nominal;

  inner Modelica.Fluid.System system(
    m_flow_small=1e-4)
    annotation (Placement(transformation(extent={{40,-100},{60,-80}},  rotation=0)));
  inner Modelica.Blocks.Noise.GlobalSeed globalSeed(useAutomaticSeed=false, fixedSeed=147749248) annotation (Placement(transformation(extent={{80,-100},{100,-80}})));
  ControlledChiller_N
                    chiller(
    redeclare package Medium_eva =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    n=n,
    length_eva=1.0,
    length_con=1.0,
    T_low_nominal=chiller.T_out_eva_nominal - 5,
    T_high_nominal=chiller.T_out_con_nominal + 5,
    dT_superHeat_nominal=2,
    dT_subCool_nominal=2,
    diameter_con=0.5,
    diameter_eva=0.5,
    valve_opening_nominal=0.2,
    redeclare package ChillerData = ChillerSpecs.Trane_RTD_300,
    redeclare package Medium_con = Modelica.Media.Water.ConstantPropertyLiquidWater,
    C_eva=1e6,
    C_con=1e6,
    Ti_controller=30*60,
    refrigerantCircuit(compressor(P(fixed=false))),
    consumption_coeff={8.48306439e+04,7.09691537e-01,-9.17255830e-07},
    modelStructure_con=Modelica.Fluid.Types.ModelStructure.av_b)
                          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica.Fluid.Sources.MassFlowSource_T evaSource(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    T=T_in_eva,
    use_T_in=true,
    m_flow=mflow_in_eva,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{-60,-26},{-48,-14}})));
  Modelica.Fluid.Sources.FixedBoundary evaSink(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater, nPorts=1) annotation (Placement(transformation(extent={{46,-26},{34,-14}})));
  Modelica.Fluid.Sensors.Temperature temperature_eva(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{10,-20},{30,-40}})));

  Modelica.Fluid.Sensors.Temperature temperature_con(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-10,10},{-30,30}})));
  Modelica.Fluid.Sensors.Temperature temperature_ct(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{26,8},{6,28}})));
  Modelica.Fluid.Sensors.Temperature temperature_demand(redeclare package Medium =
               Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-30,-20},{-10,-40}})));
  Modelica.Fluid.Sensors.MassFlowRate m_flow_eva(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{-38,-26},{-26,-14}})));
  Modelica.Fluid.Sensors.MassFlowRate m_flow_con(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{-30,2},{-42,14}})));
  Modelica.Blocks.Sources.BooleanExpression on(y=true) annotation (Placement(transformation(extent={{-40,-52},{-26,-40}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tin_eva(
    y_off=Tin_eva.mu,
    fixedLocalSeed=59635744,
    enableNoise=true,
    startTime(displayUnit="h") = 1*base_period,
    samplePeriod(displayUnit="h") = period,
    y_min=(5 + Tset_eva.y_max) + 273.15,
    y_max=(12 + Tset_eva.y_min) + 273.15,
    useAutomaticLocalSeed=true)
                       annotation (Placement(transformation(extent={{-100,-24},{-92,-16}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tin_eva_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    xr_start=Tin_eva.mu,
    y_start=Tin_eva.mu,
    n=1,
    f=1/60)             annotation (Placement(transformation(extent={{-88,-24},{-80,-16}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tset_eva(
    y_off=Tset_eva.mu,
    fixedLocalSeed=60398256,
    y_min=2,
    enableNoise=true,
    startTime(displayUnit="h") = 0*base_period,
    samplePeriod(displayUnit="h") = period,
    y_max=5,
    useAutomaticLocalSeed=true)            annotation (Placement(transformation(extent={{-80,-64},{-72,-56}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tset_eva_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    n=1,
    xr_start=Tin_eva.mu - Tset_eva.mu,
    y_start=Tin_eva.mu - Tset_eva.mu,
    f=1/60)              annotation (Placement(transformation(extent={{-28,-64},{-20,-56}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tset_con(
    y_off=Tset_con.mu,
    fixedLocalSeed=152941984,
    samplePeriod(displayUnit="h") = period,
    enableNoise=true,
    startTime(displayUnit="h") = 4*base_period,
    y_min=25 + 273.15,
    y_max=35 + 273.15,
    useAutomaticLocalSeed=true)
                       annotation (Placement(transformation(extent={{120,54},{112,62}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tset_con_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    n=1,
    f=1/60,
    xr_start=Tset_con.mu,
    y_start=Tset_con.mu)
            annotation (Placement(transformation(extent={{104,54},{96,62}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise mhat_eva(
    y_off=mhat_eva.mu,
    fixedLocalSeed=245346912,
    mu=mflow_in_eva,
    enableNoise=true,
    startTime(displayUnit="h") = 2*base_period,
    samplePeriod(displayUnit="h") = period,
    y_min=mflow_in_eva*0.75,
    y_max=mflow_in_eva*1.25,
    useAutomaticLocalSeed=true)
                            annotation (Placement(transformation(extent={{-100,-4},{-92,4}})));
  Modelica.Blocks.Continuous.LowpassButterworth mhat_eva_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    xr_start=mhat_eva.mu,
    y_start=mhat_eva.mu,
    n=1,
    f=1/60)              annotation (Placement(transformation(extent={{-88,-4},{-80,4}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise mhat_con(
    fixedLocalSeed=152941984,
    y_off=mhat_con.mu,
    enableNoise=true,
    startTime(displayUnit="h") = 3*base_period,
    samplePeriod(displayUnit="h") = period,
    y_min=mflow_in_con*0.75,
    y_max=mflow_in_con*1.25,
    useAutomaticLocalSeed=true)
                       annotation (Placement(transformation(extent={{-100,36},{-92,44}})));
  Modelica.Blocks.Continuous.LowpassButterworth mhat_con_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    n=1,
    xr_start=mhat_con.mu,
    y_start=mhat_con.mu,
    f=1/60)             annotation (Placement(transformation(extent={{-88,36},{-80,44}})));
  Modelica.Blocks.Math.MultiSum multiSum(k={1,-1}, nu=2) annotation (Placement(transformation(extent={{-62,-64},{-54,-56}})));

  Modelica.Blocks.Discrete.Sampler sampler(samplePeriod(displayUnit="h") = Tset_eva.samplePeriod, startTime=Tset_eva.startTime)
                                                                                               annotation (Placement(transformation(extent={{-44,-64},{-36,-56}})));
  CoolingTowers.OpenCoolingTower_controlled cooling_tower(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321,
    mAir1_start=1,
    e(displayUnit="mm") = 0.005,
    hmax=1.5) annotation (Placement(transformation(extent={{38,38},{62,62}})));
  Modelica.Fluid.Sources.MassFlowSource_T overflow(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=mflow_in_eva,
    use_m_flow_in=true,
    nPorts=1,
    use_T_in=false,
    T=302.123) annotation (Placement(transformation(extent={{24,40},{34,50}})));
  Modelica.Fluid.Sources.Boundary_pT airSource(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    p=system.p_ambient,
    use_T_in=true,
    use_X_in=true,
    nPorts=1)      annotation (Placement(transformation(
        extent={{6,-6},{-6,6}},
        rotation=-90,
        origin={70,8.88178e-16})));
  Modelica.Fluid.Sources.FixedBoundary airSink(nPorts=1, redeclare package Medium = Modelica.Media.Air.MoistAir,
    p=system.p_ambient)                                                                                          annotation (Placement(transformation(extent={{80,74},{68,86}})));
  Modelica.Fluid.Machines.ControlledPump pump(
    use_m_flow_set=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    p_a_nominal=system.p_ambient,
    m_flow_nominal=mflow_in_con,
    m_flow_start=mflow_in_con,
    p_a_start=system.p_ambient,
    p_b_start=system.p_ambient + 50000,
    p_b_nominal=system.p_ambient + 50000) annotation (Placement(transformation(
        extent={{6,-6},{-6,6}},
        rotation=0,
        origin={30,8})));
  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floorTemperature(T=293.15) annotation (Placement(transformation(extent={{60,20},{52,28}})));
  CoolingTowers.BaseClasses.LevelControl levelControl(hmin=0.1, hmax=1.4)
                                                      annotation (Placement(transformation(extent={{46,62},{34,74}})));
  Modelica.Fluid.Sensors.Temperature temperature_ambient(redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{70,40},{90,20}})));
  Modelica.Fluid.Sensors.Temperature temperature_exhaust(redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=-90,
        origin={30,80})));
  Modelica.Blocks.Noise.TruncatedNormalNoise T_ambient(
    fixedLocalSeed=152941984,
    enableNoise=true,
    y_off=T_ambient.mu,
    samplePeriod(displayUnit="h") = period,
    startTime(displayUnit="h") = 5*base_period,
    y_min=20 + 273.15,
    y_max=30 + 273.15,
    useAutomaticLocalSeed=true)
                       annotation (Placement(transformation(extent={{120,-24},{112,-16}})));
  Modelica.Blocks.Continuous.LowpassButterworth T_ambient_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    n=1,
    f=1/60,
    xr_start=T_ambient.mu,
    y_start=T_ambient.mu)
            annotation (Placement(transformation(extent={{104,-24},{96,-16}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise phi_ambient(
    fixedLocalSeed=152941984,
    enableNoise=true,
    samplePeriod(displayUnit="h") = period,
    startTime(displayUnit="h") = 6*base_period,
    y_max=0.95,
    y_off=phi_ambient.mu,
    y_min=0.3,
    useAutomaticLocalSeed=true)
                annotation (Placement(transformation(extent={{100,-44},{92,-36}})));
  Modelica.Blocks.Continuous.LowpassButterworth phi_ambient_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    n=1,
    f=1/60,
    xr_start=phi_ambient.mu,
    y_start=phi_ambient.mu)
            annotation (Placement(transformation(extent={{88,-44},{80,-36}})));

  Modelica.Blocks.Sources.RealExpression X_ambient[2](y={Modelica.Media.Air.MoistAir.massFraction_pTphi(
        system.p_ambient,
        T_ambient_filter.y,
        phi_ambient_filter.y),1 - X_ambient[1].y}) annotation (Placement(transformation(extent={{96,-68},{80,-52}})));

  Modelica.Blocks.Math.Min min_T_amb(u2=temperature_con.T - 2)
                                                           annotation (Placement(transformation(extent={{88,-24},{80,-16}})));
  Modelica.Blocks.Nonlinear.VariableLimiter variableLimiter(limit1=temperature_con.T, limit2=min_T_amb.y) annotation (Placement(transformation(extent={{88,54},{80,62}})));

  output Modelica.SIunits.Temperature _T_set_eva = chiller.T_eva_set;
  output Modelica.SIunits.MassFlowRate _m_flow_eva = m_flow_eva.m_flow;
  output Modelica.SIunits.Temperature _T_in_eva = temperature_demand.T;
  output Modelica.SIunits.MassFlowRate _m_flow_con = m_flow_con.m_flow;
  output Modelica.SIunits.Temperature _T_set_ct = cooling_tower.T_reference;
  output Modelica.SIunits.Temperature _T_amb = temperature_ambient.T;
  output Real _phi_amb = phi_ambient_filter.y;

  output Modelica.SIunits.Temperature _T_out_eva = temperature_eva.T;
  output Modelica.SIunits.Temperature _T_in_con = temperature_ct.T;
  output Modelica.SIunits.Temperature _T_out_con = temperature_con.T;
  output Modelica.SIunits.Temperature _T_exh = temperature_exhaust.T;
  output Modelica.SIunits.Power _P_ch = chiller.refrigerantCircuit.compressor.P;
  output Modelica.SIunits.Power _P_ct = cooling_tower.fan.W_total;
  output Modelica.SIunits.Power _P_pump = pump.W_total;
  output Modelica.SIunits.Power _P_out = _P_ch + _P_ct + _P_pump;

  output Integer _seed = globalSeed.seed;

equation
  connect(temperature_eva.port, evaSink.ports[1]) annotation (Line(points={{20,-20},{34,-20}}, color={0,127,255}));
  connect(temperature_eva.port, chiller.port_b_1)
    annotation (Line(points={{20,-20},{20,-20},{20,-8},{10,-8}}, color={0,127,255}));
  connect(temperature_demand.port, chiller.port_a_1) annotation (Line(points={{-20,-20},{-20,-20},{-20,-8},{-10,-8}},
                                             color={0,127,255}));

  connect(evaSource.ports[1], m_flow_eva.port_a) annotation (Line(points={{-48,-20},{-38,-20}}, color={0,127,255}));
  connect(m_flow_eva.port_b, temperature_demand.port) annotation (Line(points={{-26,-20},{-20,-20}}, color={0,127,255}));
  connect(Tset_eva_filter.y, chiller.T_eva_set) annotation (Line(points={{-19.6,-60},{6,-60},{6,-12}}, color={0,0,127}));
  connect(Tin_eva.y, Tin_eva_filter.u) annotation (Line(points={{-91.6,-20},{-88.8,-20}}, color={0,0,127}));
  connect(Tin_eva_filter.y, evaSource.T_in) annotation (Line(points={{-79.6,-20},{-72,-20},{-72,-17.6},{-61.2,-17.6}},
                                                                                                                 color={0,0,127}));
  connect(mhat_eva.y, mhat_eva_filter.u) annotation (Line(points={{-91.6,0},{-88.8,0}}, color={0,0,127}));
  connect(mhat_eva_filter.y, evaSource.m_flow_in) annotation (Line(points={{-79.6,0},{-72,0},{-72,-15.2},{-60,-15.2}},
                                                                                                                   color={0,0,127}));
  connect(Tin_eva.y, multiSum.u[1]) annotation (Line(points={{-91.6,-20},{-90,-20},{-90,-40},{-62,-40},{-62,-58.6}},             color={0,0,127}));
  connect(Tset_eva.y, multiSum.u[2]) annotation (Line(points={{-71.6,-60},{-62,-60},{-62,-61.4}},             color={0,0,127}));
  connect(on.y, chiller.on) annotation (Line(points={{-25.3,-46},{-6,-46},{-6,-12}}, color={255,0,255}));
  connect(mhat_con.y, mhat_con_filter.u) annotation (Line(points={{-91.6,40},{-88.8,40}},
                                                                                      color={0,0,127}));
  connect(multiSum.y, sampler.u) annotation (Line(points={{-53.32,-60},{-44.8,-60}}, color={0,0,127}));
  connect(sampler.y, Tset_eva_filter.u) annotation (Line(points={{-35.6,-60},{-28.8,-60}}, color={0,0,127}));
  connect(temperature_ct.port, chiller.port_a_2) annotation (Line(points={{16,8},{10,8}}, color={0,127,255}));
  connect(chiller.port_b_2, temperature_con.port) annotation (Line(points={{-10,8},{-20,8},{-20,10}},
                                                                                             color={0,127,255}));
  connect(floorTemperature.port, cooling_tower.port_a_floor) annotation (Line(points={{52,24},{50,24},{50,40}}, color={191,0,0}));
  connect(overflow.ports[1], cooling_tower.port_a_Owater) annotation (Line(points={{34,45},{38,45},{38,44.8},{40,44.8}}, color={0,127,255}));
  connect(cooling_tower.level, levelControl.level) annotation (Line(points={{60,42},{68,42},{68,68},{47.2,68}}, color={0,0,127}));
  connect(levelControl.m_outflow, overflow.m_flow_in) annotation (Line(points={{33.4,68},{20,68},{20,49},{24,49}}, color={0,0,127}));
  connect(cooling_tower.port_b_air, airSink.ports[1]) annotation (Line(points={{56,61},{56,80},{68,80}},         color={0,127,255}));
  connect(cooling_tower.port_b_water, pump.port_a) annotation (Line(points={{40,40},{40,8},{36,8}}, color={0,127,255}));
  connect(pump.port_b, temperature_ct.port) annotation (Line(points={{24,8},{16,8}}, color={0,127,255}));
  connect(temperature_con.port, m_flow_con.port_a) annotation (Line(points={{-20,10},{-20,8},{-30,8}},
                                                                                              color={0,127,255}));
  connect(m_flow_con.port_b, cooling_tower.port_a_water) annotation (Line(points={{-42,8},{-52,8},{-52,58},{40,58}}, color={0,127,255}));
  connect(mhat_con_filter.y, pump.m_flow_set) annotation (Line(points={{-79.6,40},{33,40},{33,12.92}},                   color={0,0,127}));
  connect(phi_ambient.y, phi_ambient_filter.u) annotation (Line(points={{91.6,-40},{88.8,-40}}, color={0,0,127}));
  connect(X_ambient.y, airSource.X_in) annotation (Line(points={{79.2,-60},{67.6,-60},{67.6,-7.2}}, color={0,0,127}));
  connect(airSource.ports[1], temperature_ambient.port) annotation (Line(points={{70,6},{70,40},{80,40}}, color={0,127,255}));
  connect(cooling_tower.port_a_air, temperature_ambient.port) annotation (Line(points={{60,47},{70,47},{70,40},{80,40}}, color={0,127,255}));
  connect(temperature_exhaust.port, cooling_tower.port_b_air) annotation (Line(points={{40,80},{56,80},{56,61}}, color={0,127,255}));
  connect(T_ambient_filter.y, min_T_amb.u1) annotation (Line(points={{95.6,-20},{92,-20},{92,-17.6},{88.8,-17.6}}, color={0,0,127}));
  connect(T_ambient.y, T_ambient_filter.u) annotation (Line(points={{111.6,-20},{104.8,-20}}, color={0,0,127}));
  connect(min_T_amb.y, airSource.T_in) annotation (Line(points={{79.6,-20},{72.4,-20},{72.4,-7.2}}, color={0,0,127}));
  connect(Tset_con_filter.y, variableLimiter.u) annotation (Line(points={{95.6,58},{88.8,58}}, color={0,0,127}));
  connect(Tset_con.y, Tset_con_filter.u) annotation (Line(points={{111.6,58},{104.8,58}}, color={0,0,127}));
  connect(variableLimiter.y, cooling_tower.T_reference) annotation (Line(points={{79.6,58},{61,58}}, color={0,0,127}));
  annotation (                             Documentation(info="<html>
</html>", revisions="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">2016-05-16 <a href=\"mailto: jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"></p><p><b>Copyright &copy; IK4-TEKNIKER</span></b></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"><img src=\"modelica://ModelicaTEK/Resources/Images/IK4-TEKNIKER_logo.jpg\"/></span></p>
</html>"), experiment(
      StopTime=31536000,
      Interval=600,
      Tolerance=1e-07,
      __Dymola_fixedstepsize=0.001,
      __Dymola_Algorithm="cvode"),
    __Dymola_Commands(file(ensureSimulated=true)=
        "modelica://Modelica/Resources/Scripts/Dymola/Fluid/HeatingSystem/plotResults.mos"
        "plotResults"),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-100},{140,100}})),
    __Dymola_experimentSetupOutput,
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-100},{140,100}})));
end CTandCh;
