within DCOL.Generation.ConventionalChillers.Experiments;
model LargeInertia "Conventional chiller with large inertia"
  parameter Integer n = 4;

  parameter Modelica.SIunits.Temperature T_out_req=
    chiller.T_out_eva_nominal;
  parameter Modelica.SIunits.Temperature T_in_eva=
    chiller.T_evaporating_nominal;
  parameter Modelica.SIunits.Temperature T_out_con=
    chiller.T_out_con_nominal;
  parameter Modelica.SIunits.Temperature T_in_con=
    chiller.T_condensing_nominal;

  parameter Modelica.SIunits.MassFlowRate mflow_in_eva=chiller.ChillerData.modelData.mflow_eva_nominal;
  parameter Modelica.SIunits.MassFlowRate mflow_in_con=chiller.ChillerData.modelData.mflow_con_nominal;

  inner Modelica.Fluid.System system(
    m_flow_small=1e-4)
    annotation (Placement(transformation(extent={{40,-100},{60,-80}},  rotation=0)));
  Modelica.Fluid.Sources.MassFlowSource_T evaSource(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    T=T_in_eva,
    use_T_in=true,
    m_flow=mflow_in_eva,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{-64,-30},{-44,-10}})));
  Modelica.Fluid.Sources.FixedBoundary evaSink(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater, nPorts=1) annotation (Placement(transformation(extent={{50,-30},{30,-10}})));
  Modelica.Fluid.Sources.FixedBoundary conSink(
                                       nPorts=1, redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-50,10},{-30,30}})));
  Modelica.Fluid.Sources.MassFlowSource_T conSource(
    nPorts=1,
    T=T_in_con,
    use_T_in=true,
    m_flow=mflow_in_con,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
                annotation (Placement(transformation(extent={{64,30},{44,10}})));
  Modelica.Fluid.Sensors.Temperature temperature_eva(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{10,-20},{30,-40}})));

  ControlledChiller_N
                    chiller(
    redeclare package Medium_eva =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    n=n,
    length_eva=1.0,
    length_con=1.0,
    T_low_nominal=chiller.T_out_eva_nominal - 5,
    T_high_nominal=chiller.T_out_con_nominal + 5,
    dT_superHeat_nominal=2,
    dT_subCool_nominal=2,
    diameter_con=0.5,
    diameter_eva=0.5,
    valve_opening_nominal=0.2,
    redeclare package ChillerData = ChillerSpecs.Trane_RTD_300,
    redeclare package Medium_con = Modelica.Media.Water.ConstantPropertyLiquidWater,
    C_eva=1e6,
    C_con=1e6,
    Ti_controller=30*60,
    refrigerantCircuit(compressor(P(fixed=false))),
    consumption_coeff={8.48306439e+04,7.09691537e-01,-9.17255830e-07})
                          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica.Fluid.Sensors.Temperature temperature_con(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-10,20},{-30,40}})));
  Modelica.Fluid.Sensors.Temperature temperature_ambient(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{30,20},{10,40}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tin_eva(
    y_off=Tin_eva.mu,
    enableNoise=true,
    useAutomaticLocalSeed=false,
    fixedLocalSeed=59635744,
    y_min=(3 + Tset_eva.y_max) + 273.15,
    y_max=(11 + Tset_eva.y_min) + 273.15,
    samplePeriod(displayUnit="h") = 72000,
    startTime(displayUnit="h") = 14400)
                       annotation (Placement(transformation(extent={{-100,-24},{-92,-16}})));
  Modelica.Fluid.Sensors.Temperature temperature_demand(redeclare package Medium =
               Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-30,-20},{-10,-40}})));
  Modelica.Fluid.Sensors.MassFlowRate m_flow_eva(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{-38,-26},{-26,-14}})));
  Modelica.Fluid.Sensors.MassFlowRate m_flow_con(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{38,14},{26,26}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tin_eva_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    xr_start=Tin_eva.mu,
    y_start=Tin_eva.mu,
    n=1,
    f=1/60)             annotation (Placement(transformation(extent={{-88,-24},{-80,-16}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tset_eva(
    y_off=Tset_eva.mu,
    enableNoise=true,
    useAutomaticLocalSeed=false,
    fixedLocalSeed=60398256,
    y_min=2,
    y_max=6,
    startTime(displayUnit="h") = 0,
    samplePeriod(displayUnit="h") = 72000) annotation (Placement(transformation(extent={{-84,-64},{-76,-56}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tset_eva_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    n=1,
    xr_start=Tin_eva.mu - Tset_eva.mu,
    y_start=Tin_eva.mu - Tset_eva.mu,
    f=1/60)              annotation (Placement(transformation(extent={{-28,-64},{-20,-56}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tin_con(
    y_off=Tin_con.mu,
    enableNoise=true,
    useAutomaticLocalSeed=false,
    fixedLocalSeed=152941984,
    y_min=20 + 273.15,
    y_max=40 + 273.15,
    samplePeriod(displayUnit="h") = 72000,
    startTime(displayUnit="h") = 57600)
                       annotation (Placement(transformation(extent={{100,16},{92,24}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tin_con_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    xr_start=Tin_con.mu,
    y_start=Tin_con.mu,
    n=1,
    f=1/60)             annotation (Placement(transformation(extent={{88,16},{80,24}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise mhat_eva(
    y_off=mhat_eva.mu,
    enableNoise=true,
    useAutomaticLocalSeed=false,
    fixedLocalSeed=245346912,
    mu=mflow_in_eva,
    y_min=mflow_in_eva*0.5,
    y_max=mflow_in_eva*1.5,
    samplePeriod(displayUnit="h") = 72000,
    startTime(displayUnit="h") = 28800)
                            annotation (Placement(transformation(extent={{-100,-4},{-92,4}})));
  Modelica.Blocks.Continuous.LowpassButterworth mhat_eva_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    xr_start=mhat_eva.mu,
    y_start=mhat_eva.mu,
    n=1,
    f=1/60)              annotation (Placement(transformation(extent={{-88,-4},{-80,4}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise mhat_con(
    enableNoise=true,
    useAutomaticLocalSeed=false,
    fixedLocalSeed=152941984,
    y_min=mflow_in_con*0.5,
    y_max=mflow_in_con*1.5,
    y_off=mhat_con.mu,
    samplePeriod(displayUnit="h") = 72000,
    startTime(displayUnit="h") = 43200)
                       annotation (Placement(transformation(extent={{100,-4},{92,4}})));
  Modelica.Blocks.Continuous.LowpassButterworth mhat_con_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    n=1,
    xr_start=mhat_con.mu,
    y_start=mhat_con.mu,
    f=1/60)             annotation (Placement(transformation(extent={{88,-4},{80,4}})));
  Modelica.Blocks.Math.MultiSum multiSum(k={1,-1}, nu=2) annotation (Placement(transformation(extent={{-62,-64},{-54,-56}})));
  Modelica.Blocks.Sources.BooleanExpression on(y=true) annotation (Placement(transformation(extent={{-40,-52},{-26,-40}})));
  inner Modelica.Blocks.Noise.GlobalSeed globalSeed(useAutomaticSeed=false, fixedSeed=74103464)  annotation (Placement(transformation(extent={{82,-98},{102,-78}})));

// Outputs
  output Modelica.SIunits.Temperature _T_set_eva = chiller.T_eva_set;
  output Modelica.SIunits.MassFlowRate _m_flow_eva = m_flow_eva.m_flow;
  output Modelica.SIunits.Temperature _T_in_eva = temperature_demand.T;
  output Modelica.SIunits.MassFlowRate _m_flow_con = m_flow_con.m_flow;
  output Modelica.SIunits.Temperature _T_in_con = temperature_ambient.T;
  output Modelica.SIunits.Temperature _T_out_eva = temperature_eva.T;
  output Modelica.SIunits.Temperature _T_out_con = temperature_con.T;
  output Modelica.SIunits.Power _P_out = chiller.refrigerantCircuit.compressor.P;
  output Modelica.SIunits.Efficiency _COP = chiller.refrigerantCircuit.Q_flow_total_eva/_P_out;
  output Integer _seed = globalSeed.seed;

  Modelica.Blocks.Discrete.Sampler sampler(samplePeriod(displayUnit="h") = 72000, startTime=0) annotation (Placement(transformation(extent={{-44,-64},{-36,-56}})));
equation
  connect(chiller.port_b_2, temperature_con.port)
    annotation (Line(points={{-10,8},{-20,8},{-20,20}}, color={0,127,255}));
  connect(temperature_con.port, conSink.ports[1])
    annotation (Line(points={{-20,20},{-30,20}},          color={0,127,255}));
  connect(temperature_eva.port, evaSink.ports[1]) annotation (Line(points={{20,-20},{30,-20}}, color={0,127,255}));
  connect(temperature_eva.port, chiller.port_b_1)
    annotation (Line(points={{20,-20},{20,-20},{20,-8},{10,-8}}, color={0,127,255}));
  connect(temperature_ambient.port, chiller.port_a_2) annotation (Line(points={{20,20},{20,20},{20,8},{10,8}},
                                         color={0,127,255}));
  connect(temperature_demand.port, chiller.port_a_1) annotation (Line(points={{-20,-20},{-20,-20},{-20,-8},{-10,-8}},
                                             color={0,127,255}));

  connect(evaSource.ports[1], m_flow_eva.port_a) annotation (Line(points={{-44,-20},{-38,-20}}, color={0,127,255}));
  connect(m_flow_eva.port_b, temperature_demand.port) annotation (Line(points={{-26,-20},{-20,-20}}, color={0,127,255}));
  connect(Tset_eva_filter.y, chiller.T_eva_set) annotation (Line(points={{-19.6,-60},{6,-60},{6,-12}}, color={0,0,127}));
  connect(Tin_eva.y, Tin_eva_filter.u) annotation (Line(points={{-91.6,-20},{-88.8,-20}}, color={0,0,127}));
  connect(Tin_eva_filter.y, evaSource.T_in) annotation (Line(points={{-79.6,-20},{-72,-20},{-72,-16},{-66,-16}}, color={0,0,127}));
  connect(Tin_con.y, Tin_con_filter.u) annotation (Line(points={{91.6,20},{88.8,20}}, color={0,0,127}));
  connect(mhat_eva.y, mhat_eva_filter.u) annotation (Line(points={{-91.6,0},{-88.8,0}}, color={0,0,127}));
  connect(mhat_eva_filter.y, evaSource.m_flow_in) annotation (Line(points={{-79.6,0},{-72,0},{-72,-12},{-64,-12}}, color={0,0,127}));
  connect(Tin_eva.y, multiSum.u[1]) annotation (Line(points={{-91.6,-20},{-90,-20},{-90,-40},{-62,-40},{-62,-58.6}},             color={0,0,127}));
  connect(Tset_eva.y, multiSum.u[2]) annotation (Line(points={{-75.6,-60},{-62,-60},{-62,-61.4}},             color={0,0,127}));
  connect(on.y, chiller.on) annotation (Line(points={{-25.3,-46},{-6,-46},{-6,-12}}, color={255,0,255}));
  connect(conSource.ports[1], m_flow_con.port_a) annotation (Line(points={{44,20},{38,20}}, color={0,127,255}));
  connect(m_flow_con.port_b, chiller.port_a_2) annotation (Line(points={{26,20},{20,20},{20,8},{10,8}}, color={0,127,255}));
  connect(mhat_con.y, mhat_con_filter.u) annotation (Line(points={{91.6,0},{88.8,0}}, color={0,0,127}));
  connect(mhat_con_filter.y, conSource.m_flow_in) annotation (Line(points={{79.6,0},{72,0},{72,12},{64,12}}, color={0,0,127}));
  connect(Tin_con_filter.y, conSource.T_in) annotation (Line(points={{79.6,20},{72,20},{72,16},{66,16}}, color={0,0,127}));
  connect(multiSum.y, sampler.u) annotation (Line(points={{-53.32,-60},{-44.8,-60}}, color={0,0,127}));
  connect(sampler.y, Tset_eva_filter.u) annotation (Line(points={{-35.6,-60},{-28.8,-60}}, color={0,0,127}));
  annotation (                             Documentation(info="<html>
</html>", revisions="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">2016-05-16 <a href=\"mailto: jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"></p><p><b>Copyright &copy; IK4-TEKNIKER</span></b></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"><img src=\"modelica://ModelicaTEK/Resources/Images/IK4-TEKNIKER_logo.jpg\"/></span></p>
</html>"), experiment(
      StopTime=31536000,
      Interval=600,
      Tolerance=1e-07,
      __Dymola_fixedstepsize=0.001,
      __Dymola_Algorithm="cvode"),
    __Dymola_Commands(file(ensureSimulated=true)=
        "modelica://Modelica/Resources/Scripts/Dymola/Fluid/HeatingSystem/plotResults.mos"
        "plotResults"),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
            100,100}})),
    __Dymola_experimentSetupOutput,
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
end LargeInertia;
