within DCOL.Generation.ConventionalChillers.Experiments;
model McQuay_N_data "Simple model of a heating system"
  parameter Integer n = 5;

  parameter Modelica.SIunits.Temperature T_out_req=
    chiller.T_out_eva_nominal;
  parameter Modelica.SIunits.Temperature T_in_eva=
    chiller.T_evaporating_nominal;
  parameter Modelica.SIunits.Temperature T_out_con=
    chiller.T_out_con_nominal;
  parameter Modelica.SIunits.Temperature T_in_con=
    chiller.T_condensing_nominal;

  parameter Modelica.SIunits.MassFlowRate mflow_in_eva=ChillerSpecs.McQuay_AWS_XE_XN_280_2.modelData.mflow_eva_nominal;
  parameter Modelica.SIunits.MassFlowRate mflow_in_con=ChillerSpecs.McQuay_AWS_XE_XN_280_2.modelData.mflow_con_nominal;

  inner Modelica.Fluid.System system(
    m_flow_small=1e-4)
    annotation (Placement(transformation(extent={{-100,-100},{-80,-80}},
                                                                       rotation=0)));
  Modelica.Fluid.Sources.MassFlowSource_T source(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    T=T_in_eva,
    use_T_in=true,
    m_flow=mflow_in_eva,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{-64,-30},{-44,-10}})));
  Modelica.Fluid.Sources.FixedBoundary sink(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater, nPorts=1)
    annotation (Placement(transformation(extent={{50,-30},{30,-10}})));
  Modelica.Fluid.Sources.FixedBoundary conSink(
                                       nPorts=1, redeclare package Medium =
        Modelica.Media.Air.DryAirNasa)
    annotation (Placement(transformation(extent={{-50,10},{-30,30}})));
  Modelica.Fluid.Sources.MassFlowSource_T conSource(
    nPorts=1,
    T=T_in_con,
    use_T_in=true,
    redeclare package Medium = Modelica.Media.Air.DryAirNasa,
    m_flow=mflow_in_con,
    use_m_flow_in=true)
                annotation (Placement(transformation(extent={{50,30},{30,10}})));
  Modelica.Fluid.Sensors.Temperature temperature_eva(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{10,-20},{30,-40}})));

  Modelica.Fluid.Sensors.Temperature temperature_con(redeclare package Medium =
        Modelica.Media.Air.DryAirNasa)
    annotation (Placement(transformation(extent={{-10,20},{-30,40}})));
  Modelica.Fluid.Sensors.Temperature temperature_ambient(redeclare package Medium =
               Modelica.Media.Air.DryAirNasa)
    annotation (Placement(transformation(extent={{30,20},{10,40}})));
  ControlledChiller_N
                    chiller(
    redeclare package Medium_eva =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    n=n,
    redeclare package ChillerData = ChillerSpecs.McQuay_AWS_XE_XN_280_2,
    redeclare package Medium_con = Modelica.Media.Air.DryAirNasa,
    length_eva=1.0,
    length_con=1.0,
    T_low_nominal=chiller.T_out_eva_nominal - 5,
    T_high_nominal=chiller.T_out_con_nominal + 5,
    diameter_con=0.5,
    diameter_eva=0.5,
    Ti_controller(displayUnit="min") = 60,
    Ni_controller=5,
    yMin_controller=190,
    dT_superHeat_nominal=2,
    dT_subCool_nominal=2,
    C_eva=10000,
    C_con=10000,
    valve_opening_nominal=0.2,
    N_com_nominal=1750,
    consumption_coeff={0.0,1.1,0.0})
                          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica.Fluid.Sensors.Temperature temperature_demand(redeclare package Medium =
               Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-30,-20},{-10,-40}})));
  Modelica.Blocks.Continuous.LimPID fan_controller(
    final wp=1,
    final Ni=0.01,
    final controllerType=Modelica.Blocks.Types.SimpleController.PI,
    final yMin=0.1,
    final y_start=mflow_in_con,
    limitsAtInit=true,
    final yMax=5*mflow_in_con,
    initType=Modelica.Blocks.Types.InitPID.InitialOutput,
    final Ti=10,
    final xi_start=chiller.refrigerantCircuit.state2_nominal.p,
    k=mflow_in_con/chiller.refrigerantCircuit.state2_nominal.p)
    "Valve P controller"
    annotation (Placement(transformation(extent={{80,-6},{68,6}})));
  Modelica.Blocks.Sources.RealExpression refCir_con_p(y=-chiller.refrigerantCircuit.state2.p) annotation (Placement(transformation(extent={{100,-26},{80,-6}})));
  Modelica.Blocks.Sources.Constant refCir_con_p_nominal(k=-chiller.refrigerantCircuit.state2_nominal.p) annotation (Placement(transformation(extent={{96,-4},{88,4}})));
  Modelica.Fluid.Sensors.MassFlowRate m_flow_eva(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{-38,-26},{-26,-14}})));
  Modelica.Blocks.Sources.RealExpression     Tin_eva(y=data.y[3])
                       annotation (Placement(transformation(extent={{-100,-24},{-92,-16}})));
  Modelica.Blocks.Sources.RealExpression     Tset_eva(y=data.y[1])
                                           annotation (Placement(transformation(extent={{-48,-64},{-40,-56}})));
  Modelica.Blocks.Sources.RealExpression     Tin_con(y=data.y[4])
                       annotation (Placement(transformation(extent={{100,16},{92,24}})));
  Modelica.Blocks.Sources.RealExpression     mhat_eva(y=data.y[2])
                            annotation (Placement(transformation(extent={{-100,-4},{-92,4}})));

// Outputs
  output Modelica.SIunits.Temperature _T_set_eva = chiller.T_eva_set;
  output Modelica.SIunits.MassFlowRate _m_flow_eva = m_flow_eva.m_flow;
  output Modelica.SIunits.Temperature _T_in_eva = temperature_demand.T;
  output Modelica.SIunits.Temperature _T_in_con = temperature_ambient.T;
  output Modelica.SIunits.Temperature _T_out_eva = temperature_eva.T;
  output Modelica.SIunits.Temperature _P_out = chiller.refrigerantCircuit.compressor.P;
  output Modelica.SIunits.Efficiency _COP = chiller.refrigerantCircuit.Q_flow_total_eva/_P_out;

  Modelica.Blocks.Sources.CombiTimeTable data(
    tableOnFile=true,
    columns=2:9,
    fileName="D:/Users/jfebres/Desktop/DymolaWD/McQuay_data/DataBasurto/20170909/20170909.txt",
    tableName="data") annotation (Placement(transformation(extent={{-100,20},{-80,40}})));
  Modelica.Blocks.Sources.BooleanExpression on_source(y=data.y[8] > 0.5 or time < 200120) annotation (Placement(transformation(extent={{-62,-56},{-42,-36}})));
equation
  connect(conSource.ports[1], chiller.port_a_2) annotation (Line(points={{30,20},{20,20},{20,8},{10,8}},
                                          color={0,127,255}));
  connect(chiller.port_b_2, temperature_con.port)
    annotation (Line(points={{-10,8},{-20,8},{-20,20}}, color={0,127,255}));
  connect(temperature_con.port, conSink.ports[1])
    annotation (Line(points={{-20,20},{-30,20}},          color={0,127,255}));
  connect(temperature_eva.port, sink.ports[1])
    annotation (Line(points={{20,-20},{30,-20}}, color={0,127,255}));
  connect(temperature_eva.port, chiller.port_b_1)
    annotation (Line(points={{20,-20},{20,-8},{10,-8}},          color={0,127,255}));
  connect(temperature_ambient.port, chiller.port_a_2) annotation (Line(points={{20,20},{20,8},{10,8}},
                                         color={0,127,255}));
  connect(temperature_demand.port, chiller.port_a_1) annotation (Line(points={{-20,-20},{-20,-8},{-10,-8}},
                                             color={0,127,255}));

  connect(refCir_con_p.y, fan_controller.u_m) annotation (Line(points={{79,-16},{74,-16},{74,-7.2}},          color={0,0,127}));
  connect(refCir_con_p_nominal.y, fan_controller.u_s) annotation (Line(points={{87.6,0},{81.2,0}}, color={0,0,127}));
  connect(source.ports[1], m_flow_eva.port_a) annotation (Line(points={{-44,-20},{-38,-20}}, color={0,127,255}));
  connect(m_flow_eva.port_b, temperature_demand.port) annotation (Line(points={{-26,-20},{-20,-20}}, color={0,127,255}));
  connect(fan_controller.y, conSource.m_flow_in) annotation (Line(points={{67.4,0},{60,0},{60,12},{50,12}}, color={0,0,127}));
  connect(Tin_con.y, conSource.T_in) annotation (Line(points={{91.6,20},{72,20},{72,16},{52,16}}, color={0,0,127}));
  connect(Tset_eva.y, chiller.T_eva_set) annotation (Line(points={{-39.6,-60},{6,-60},{6,-12}}, color={0,0,127}));
  connect(Tin_eva.y, source.T_in) annotation (Line(points={{-91.6,-20},{-80,-20},{-80,-16},{-66,-16}}, color={0,0,127}));
  connect(mhat_eva.y, source.m_flow_in) annotation (Line(points={{-91.6,0},{-78,0},{-78,-12},{-64,-12}}, color={0,0,127}));
  connect(on_source.y, chiller.on) annotation (Line(points={{-41,-46},{-6,-46},{-6,-12}}, color={255,0,255}));
  annotation (                             Documentation(info="<html>
</html>", revisions="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">2016-05-16 <a href=\"mailto: jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"></p><p><b>Copyright &copy; IK4-TEKNIKER</span></b></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"><img src=\"modelica://ModelicaTEK/Resources/Images/IK4-TEKNIKER_logo.jpg\"/></span></p>
</html>"), experiment(
      StartTime=200000,
      StopTime=250000,
      Tolerance=1e-005,
      __Dymola_fixedstepsize=0.001,
      __Dymola_Algorithm="cvode"),
    __Dymola_Commands(file(ensureSimulated=true)=
        "modelica://Modelica/Resources/Scripts/Dymola/Fluid/HeatingSystem/plotResults.mos"
        "plotResults"),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
            100,100}})),
    __Dymola_experimentSetupOutput,
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
end McQuay_N_data;
