within DCOL.Generation.ConventionalChillers.FMI;
model McQuay
  parameter Modelica.SIunits.HeatCapacity C_con=1E6 "Heat capacity of condenser (= cp*m)";
  parameter Modelica.SIunits.HeatCapacity C_eva=5E6 "Heat capacity of evaporator (= cp*m)";

protected
  parameter Integer n(min=1)=5;

  inner Modelica.Fluid.System system(
    m_flow_small=1e-4)
    annotation (Placement(transformation(extent={{80,-100},{100,-80}}, rotation=0)));
  Modelica.Blocks.Sources.BooleanConstant booleanConstant
    annotation (Placement(transformation(extent={{-28,-64},{-20,-56}})));
  Modelica.Fluid.Sources.MassFlowSource_T source_eva(
    use_T_in=true,
    use_m_flow_in=true,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.StandardWaterOnePhase)
              annotation (Placement(transformation(extent={{-50,-10},{-30,-30}})));
  Modelica.Fluid.Sources.MassFlowSource_T source_con(
    use_T_in=true,
    use_m_flow_in=true,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Air.SimpleAir)
              annotation (Placement(transformation(extent={{50,10},{30,30}})));
  Modelica.Fluid.Sources.Boundary_pT   sink_eva(                                               nPorts=1,
    use_p_in=true,
    redeclare package Medium = Modelica.Media.Water.StandardWaterOnePhase)                                                             annotation (Placement(transformation(extent={{50,-30},{30,-10}})));
  Modelica.Fluid.Sources.Boundary_pT   sink_con(nPorts=1,
    use_p_in=true,
    redeclare package Medium = Modelica.Media.Air.SimpleAir)                                              annotation (Placement(transformation(extent={{-50,10},{-30,30}})));
  Modelica.Fluid.Sensors.Temperature temperature_eva(redeclare package Medium =
        Modelica.Media.Water.StandardWaterOnePhase)
    annotation (Placement(transformation(extent={{10,-30},{30,-50}})));

  Modelica.Fluid.Sensors.Temperature temperature_con(redeclare package Medium =
        Modelica.Media.Air.SimpleAir)
    annotation (Placement(transformation(extent={{-30,30},{-10,50}})));
public
  Modelica.Fluid.Sensors.Pressure pressure_eva(redeclare package Medium =
        Modelica.Media.Water.StandardWaterOnePhase)                                           annotation (Placement(transformation(extent={{-30,-26},{-10,-46}})));
protected
  Modelica.Fluid.Sensors.Pressure pressure_con(redeclare package Medium =
        Modelica.Media.Air.SimpleAir)                                                         annotation (Placement(transformation(extent={{10,26},{30,46}})));
  Modelica_IK4_TEKNIKER.Obsolete.DCOL.Generation.ConventionalChillers.Chiller chiller(
    n=n,
    diameter_eva=0.05,
    diameter_con=0.05,
    final C_con=C_con,
    T_high_nominal=chiller.T_out_con_nominal + 5,
    length_eva=1.0,
    length_con=1.0,
    T_low_nominal=chiller.T_out_eva_nominal - 5,
    final C_eva=C_eva,
    redeclare package ChillerData = ChillerSpecs.McQuay_AWS_XE_XN_280_2,
    redeclare package Medium_ref = Modelica.Media.R134a.R134a_ph,
    valve_opening_nominal=0.5,
    isCircular_eva=true,
    isCircular_con=true,
    dT_superHeat_nominal=2,
    dT_subCool_nominal=2,
    modelStructure_eva=Modelica.Fluid.Types.ModelStructure.av_b,
    modelStructure_con=Modelica.Fluid.Types.ModelStructure.av_b,
    redeclare package Medium_eva = Modelica.Media.Water.StandardWaterOnePhase,
    redeclare package Medium_con = Modelica.Media.Air.SimpleAir,
    dp_eva_nominal=20,
    dp_con_nominal=20) annotation (Placement(transformation(extent={{-10,-10},{10,10}})));

public
  TemperatureInput                     Tin_con "Inlet temperature, condenser" annotation (Placement(transformation(extent={{-140,60},{-100,100}})));
  MassFlowRateInput                    m_flow_con "Mass flow rate, condenser" annotation (Placement(transformation(extent={{-140,40},{-100,80}})));
  PressureInput pout_con "Outlet pressure, condenser"
                                                     annotation (Placement(transformation(extent={{-140,20},{-100,60}})));
  TemperatureInput                     Tin_eva "Inlet temperature, evaporator" annotation (Placement(transformation(extent={{-140,-60},{-100,-20}})));
  MassFlowRateInput                    m_flow_eva "Mass flow rate, evaporator" annotation (Placement(transformation(extent={{-140,-80},{-100,-40}})));
  PressureInput pout_eva "Outlet pressure, evaporator"
                                                     annotation (Placement(transformation(extent={{-140,-100},{-100,-60}})));
  Modelica.Blocks.Interfaces.RealInput P_com "Compressor power" annotation (Placement(transformation(
        extent={{-20,-20},{20,20}},
        rotation=90,
        origin={0,-120})));
  TemperatureOutput                     Tout_con "Outlet temperature, condenser" annotation (Placement(transformation(extent={{100,30},{120,50}})));
  TemperatureOutput                     Tout_eva "Outlet temperature, evaporator" annotation (Placement(transformation(extent={{100,-50},{120,-30}})));
  PressureOutput pin_con annotation (Placement(transformation(extent={{100,10},{120,30}})));
  PressureOutput pin_eva annotation (Placement(transformation(extent={{100,-70},{120,-50}})));

equation
  connect(chiller.port_b_2, temperature_con.port)
    annotation (Line(points={{-10,8},{-20,8},{-20,30}}, color={0,127,255}));
  connect(temperature_con.port, sink_con.ports[1]) annotation (Line(points={{-20,30},{-20,30},{-20,20},{-30,20}}, color={0,127,255}));
  connect(temperature_eva.port, sink_eva.ports[1]) annotation (Line(points={{20,-30},{20,-30},{20,-20},{30,-20}}, color={0,127,255}));
  connect(temperature_eva.port, chiller.port_b_1)
    annotation (Line(points={{20,-30},{20,-30},{20,-8},{10,-8}}, color={0,127,255}));
  connect(booleanConstant.y, chiller.on) annotation (Line(points={{-19.6,-60},{-6,-60},{-6,-12}},
                          color={255,0,255}));

  connect(m_flow_eva, source_eva.m_flow_in) annotation (Line(points={{-120,-60},{-100,-60},{-80,-60},{-80,-28},{-50,-28}}, color={0,0,127}));
  connect(Tin_eva, source_eva.T_in) annotation (Line(points={{-120,-40},{-104,-40},{-86,-40},{-86,-24},{-52,-24}}, color={0,0,127}));
  connect(m_flow_con, source_con.m_flow_in) annotation (Line(points={{-120,60},{-30,60},{60,60},{60,28},{50,28}}, color={0,0,127}));
  connect(Tin_con, source_con.T_in) annotation (Line(points={{-120,80},{-28,80},{66,80},{66,24},{52,24}}, color={0,0,127}));
  connect(source_eva.ports[1], chiller.port_a_1) annotation (Line(points={{-30,-20},{-26,-20},{-20,-20},{-20,-8},{-10,-8}}, color={0,127,255}));
  connect(temperature_con.T, Tout_con) annotation (Line(points={{-13,40},{-13,40},{110,40}}, color={0,0,127}));
  connect(temperature_eva.T, Tout_eva) annotation (Line(points={{27,-40},{68,-40},{110,-40}},  color={0,0,127}));
  connect(source_con.ports[1], chiller.port_a_2) annotation (Line(points={{30,20},{20,20},{20,8},{10,8}}, color={0,127,255}));
  connect(P_com, chiller.P_com) annotation (Line(points={{0,-120},{0,-120},{0,-20},{14,-20},{14,0}}, color={0,0,127}));
  connect(pout_con, sink_con.p_in) annotation (Line(points={{-120,40},{-90,40},{-60,40},{-60,28},{-52,28}}, color={0,0,127}));
  connect(pout_eva, sink_eva.p_in) annotation (Line(points={{-120,-80},{60,-80},{60,-12},{52,-12}}, color={0,0,127}));
  connect(pressure_con.port, chiller.port_a_2) annotation (Line(points={{20,26},{20,26},{20,8},{10,8}}, color={0,127,255}));
  connect(pressure_eva.port, chiller.port_a_1) annotation (Line(points={{-20,-26},{-20,-26},{-20,-8},{-10,-8}}, color={0,127,255}));
  connect(pressure_eva.p, pin_eva) annotation (Line(points={{-9,-36},{36,-36},{80,-36},{80,-60},{110,-60}}, color={0,0,127}));
  connect(pressure_con.p, pin_con) annotation (Line(points={{31,36},{56,36},{80,36},{80,20},{110,20}}, color={0,0,127}));
  annotation (
  Documentation(info="<html>
</html>", revisions="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">2016-05-16 <a href=\"mailto: jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"></p><p><b>Copyright &copy; IK4-TEKNIKER</span></b></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"><img src=\"modelica://ModelicaTEK/Resources/Images/IK4-TEKNIKER_logo.jpg\"/></span></p>
</html>"), experiment(
      StopTime=3600,
      __Dymola_NumberOfIntervals=5000,
      __Dymola_fixedstepsize=0.001,
      __Dymola_Algorithm="Dassl"),
    __Dymola_Commands(file(ensureSimulated=true)=
        "modelica://Modelica/Resources/Scripts/Dymola/Fluid/HeatingSystem/plotResults.mos"
        "plotResults"),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
            100,100}})),
    __Dymola_experimentSetupOutput,
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
end McQuay;
