within DCOL.Generation.ConventionalChillers.Testing;
model McQuay_N "Simple model of a heating system"
  parameter Integer n = 4;

  parameter Modelica.SIunits.Temperature T_out_req=
    chiller.T_out_eva_nominal;
  parameter Modelica.SIunits.Temperature T_in_eva=
    chiller.T_evaporating_nominal;
  parameter Modelica.SIunits.Temperature T_out_con=
    chiller.T_out_con_nominal;
  parameter Modelica.SIunits.Temperature T_in_con=
    chiller.T_condensing_nominal;

  parameter Modelica.SIunits.MassFlowRate mflow_in_eva=chiller.ChillerData.modelData.mflow_eva_nominal;
  parameter Modelica.SIunits.MassFlowRate mflow_in_con=chiller.ChillerData.modelData.mflow_con_nominal;

  inner Modelica.Fluid.System system(
    m_flow_small=1e-4)
    annotation (Placement(transformation(extent={{-100,-100},{-80,-80}},
                                                                       rotation=0)));
  Modelica.Blocks.Tables.CombiTable2D CC_tab(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,25,30,35,40,46,48,50; 4,955,927,895,853,786,721,632; 5,983,955,921,877,798,734,637; 6,1012,982,947,903,812,746,641; 7,1041,
        1011,974,928,825,749,641; 8,1070,1039,1001,954,838,752,644; 9,1099,1068,1029,980,851,753,646; 10,1129,1096,1057,1006,864,758,650; 11,1159,1125,1084,1032,867,761,658; 12,1189,1155,1112,1059,872,764,657; 13,1219,1184,1140,1086,873,
        769,660; 14,1249,1213,1169,1112,877,770,666; 15,1280,1243,1197,1136,880,774,667])
                           "Cooling capacity table"
    annotation (Placement(transformation(extent={{-40,80},{-26,94}})));
  Modelica.Blocks.Tables.CombiTable2D PI_tab(smoothness=Modelica.Blocks.Types.Smoothness.LinearSegments, table=[0,25,30,35,40,46,48,50; 4,248,271,294,320,335,350,333; 5,253,275,299,325,356,351,330; 6,257,280,304,331,357,351,328; 7,261,285,
        309,336,359,348,323; 8,266,290,315,342,360,346,320; 9,270,294,320,347,361,342,316; 10,275,299,325,353,361,339,313; 11,279,304,331,359,358,336,311; 12,284,309,336,365,356,333,306; 13,289,315,342,371,352,330,303; 14,294,320,347,377,
        349,326,301; 15,299,325,353,381,346,323,296])
    "Power table"
    annotation (Placement(transformation(extent={{-40,60},{-26,74}})));
  Modelica.Blocks.Math.Gain CC(k=1e3) "Cooling capacity"
    annotation (Placement(transformation(extent={{-14,80},{0,94}})));
  Modelica.Blocks.Math.Gain PI(k=1e3) "Power"
    annotation (Placement(transformation(extent={{-14,60},{0,74}})));
  Modelica.Blocks.Sources.RealExpression T_req(y=ELWT.y)
    annotation (Placement(transformation(extent={{-40,-86},{-20,-66}})));
  Modelica.Blocks.Sources.RealExpression T_ambient_source(y=CIAT.y)
    annotation (Placement(transformation(extent={{92,6},{72,26}})));
  Modelica.Blocks.Sources.RealExpression mflow_con(y=mflow_in_con + 0*((CC.y + PI.y)/(chiller.Q_flow_ref + chiller.P_ref))*((16)/(51 + 273.15 - CIAT.y)))
    annotation (Placement(transformation(extent={{100,-50},{80,-30}})));
  Modelica.Blocks.Sources.RealExpression mflow_eva(y=mflow_in_eva*(CC.y/chiller.Q_flow_ref))
    annotation (Placement(transformation(extent={{-94,-10},{-74,10}})));
  Modelica.Blocks.Sources.RealExpression T_demand(y=T_req.y + 5)
    annotation (Placement(transformation(extent={{-94,-26},{-74,-6}})));
  Modelica.Fluid.Sources.MassFlowSource_T source(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    T=T_in_eva,
    use_T_in=true,
    m_flow=mflow_in_eva,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{-64,-30},{-44,-10}})));
  Modelica.Fluid.Sources.FixedBoundary sink(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater, nPorts=1)
    annotation (Placement(transformation(extent={{50,-30},{30,-10}})));
  Modelica.Fluid.Sources.FixedBoundary conSink(
                                       nPorts=1, redeclare package Medium =
        Modelica.Media.Air.DryAirNasa)
    annotation (Placement(transformation(extent={{-50,10},{-30,30}})));
  Modelica.Fluid.Sources.MassFlowSource_T conSource(
    nPorts=1,
    T=T_in_con,
    use_T_in=true,
    redeclare package Medium = Modelica.Media.Air.DryAirNasa,
    m_flow=mflow_in_con,
    use_m_flow_in=true)
                annotation (Placement(transformation(extent={{50,30},{30,10}})));
  Modelica.Fluid.Sensors.Temperature temperature_eva(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{10,-20},{30,-40}})));

  Modelica.Fluid.Sensors.Temperature temperature_con(redeclare package Medium =
        Modelica.Media.Air.DryAirNasa)
    annotation (Placement(transformation(extent={{-10,20},{-30,40}})));
  Modelica.Fluid.Sensors.Temperature temperature_ambient(redeclare package Medium =
               Modelica.Media.Air.DryAirNasa)
    annotation (Placement(transformation(extent={{30,20},{10,40}})));
  ControlledChiller_N
                    chiller(
    redeclare package Medium_eva =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    n=n,
    redeclare package ChillerData = ChillerSpecs.McQuay_AWS_XE_XN_280_2,
    redeclare package Medium_con = Modelica.Media.Air.DryAirNasa,
    length_eva=1.0,
    length_con=1.0,
    T_low_nominal=chiller.T_out_eva_nominal - 5,
    T_high_nominal=chiller.T_out_con_nominal + 5,
    dT_superHeat_nominal=2,
    dT_subCool_nominal=2,
    Ti_controller=0.1,
    diameter_con=0.5,
    diameter_eva=0.5,
    valve_opening_nominal=0.2,
    C_eva=5000,
    C_con=5000,
    consumption_coeff={0.0*6.46944975e+05,1.0 - 0.0*1.23801772e+00,0.0*4.11301966e-07})
                          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica.Blocks.Sources.RealExpression COP(y=CC.y/PI.y)
    annotation (Placement(transformation(extent={{60,66},{80,86}})));
  Modelica.Blocks.Sources.RealExpression COP_model(y=chiller.refrigerantCircuit.Q_flow_total_eva/chiller.refrigerantCircuit.compressor.P)
    annotation (Placement(transformation(extent={{60,46},{80,66}})));
  Modelica.Blocks.Sources.RealExpression P_error(y=100*(PI.y - chiller.refrigerantCircuit.compressor.P)/PI.y)
    annotation (Placement(transformation(extent={{60,-74},{80,-54}})));
  Modelica.Blocks.Sources.RealExpression CC_error(y=100*(CC.y - chiller.refrigerantCircuit.Q_flow_total_eva)
        /CC.y)
    annotation (Placement(transformation(extent={{60,-94},{80,-74}})));
  Modelica.Fluid.Sensors.Temperature temperature_demand(redeclare package Medium =
               Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-30,-20},{-10,-40}})));
  Modelica.Blocks.Continuous.LimPID fan_controller(
    final wp=1,
    final Ni=0.01,
    final controllerType=Modelica.Blocks.Types.SimpleController.PI,
    final yMin=0.1,
    final y_start=mflow_in_con,
    limitsAtInit=true,
    final yMax=5*mflow_in_con,
    initType=Modelica.Blocks.Types.InitPID.InitialOutput,
    final Ti=10,
    final xi_start=chiller.refrigerantCircuit.state2_nominal.p,
    k=mflow_in_con/chiller.refrigerantCircuit.state2_nominal.p)
    "Valve P controller"
    annotation (Placement(transformation(extent={{72,-6},{60,6}})));
  Modelica.Blocks.Sources.RealExpression refCir_con_p(y=-chiller.refrigerantCircuit.state2.p) annotation (Placement(transformation(extent={{100,-26},{80,-6}})));
  Modelica.Blocks.Sources.Constant refCir_con_p_nominal(k=-chiller.refrigerantCircuit.state2_nominal.p) annotation (Placement(transformation(extent={{88,-4},{80,4}})));
  Modelica.Blocks.Sources.RealExpression CP(y=CC.y - PI.y) annotation (Placement(transformation(extent={{10,64},{30,84}})));
  Modelica.Blocks.Sources.RealExpression COP_error(y=100*(COP.y - COP_model.y)/COP.y) annotation (Placement(transformation(extent={{20,-86},{40,-66}})));
  Modelica.Blocks.Sources.Sine     ELWT(
    y(final quantity="ThermodynamicTemperature",
      final unit = "K", displayUnit = "degC", min=0),
    startTime=10*60,
    offset=7 + 0*(15 + 4)/2 + 273.15,
    freqHz=1/(40*60),
    amplitude=2 + 0*(15 - 4)/2)       "Evaporator Leaving Water Temperature"
    annotation (Placement(transformation(extent={{-92,80},{-80,92}})));
  Modelica.Blocks.Sources.Sine CIAT(
    y(final quantity="ThermodynamicTemperature",
      final unit="K",
      displayUnit="degC",
      min=0),
    startTime=10*60,
    freqHz=1/(80*60),
    amplitude=10 + 0*(49 - 26)/2,
    offset=35 + 0*(49 + 26)/2 + 273.15)
                                 "Condenser Inlet Air Temperature"
    annotation (Placement(transformation(extent={{-92,60},{-80,72}})));
  Modelica.Thermal.HeatTransfer.Celsius.FromKelvin fromKelvin annotation (Placement(transformation(extent={{-74,82},{-66,90}})));
  Modelica.Thermal.HeatTransfer.Celsius.FromKelvin fromKelvin1 annotation (Placement(transformation(extent={{-74,62},{-66,70}})));
  Modelica.Fluid.Sensors.MassFlowRate m_flow_eva(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                                                                     annotation (Placement(transformation(extent={{-38,-26},{-26,-14}})));
  Modelica.Blocks.Sources.BooleanExpression on(y=true) annotation (Placement(transformation(extent={{-54,-56},{-40,-44}})));

  output Modelica.SIunits.Temperature _P_out_mea = PI.y;
  output Modelica.SIunits.Temperature _P_out_mod = chiller.refrigerantCircuit.compressor.P;
equation
  connect(chiller.T_eva_set, T_req.y)
    annotation (Line(points={{6,-12},{6,-76},{-19,-76}},   color={0,0,127}));
  connect(conSource.ports[1], chiller.port_a_2) annotation (Line(points={{30,20},{30,20},{20,20},{20,8},{10,8}},
                                          color={0,127,255}));
  connect(chiller.port_b_2, temperature_con.port)
    annotation (Line(points={{-10,8},{-20,8},{-20,20}}, color={0,127,255}));
  connect(temperature_con.port, conSink.ports[1])
    annotation (Line(points={{-20,20},{-30,20}},          color={0,127,255}));
  connect(temperature_eva.port, sink.ports[1])
    annotation (Line(points={{20,-20},{30,-20}}, color={0,127,255}));
  connect(temperature_eva.port, chiller.port_b_1)
    annotation (Line(points={{20,-20},{20,-20},{20,-8},{10,-8}}, color={0,127,255}));
  connect(T_demand.y, source.T_in)
    annotation (Line(points={{-73,-16},{-66,-16}},           color={0,0,127}));
  connect(CC_tab.y, CC.u)
    annotation (Line(points={{-25.3,87},{-15.4,87}}, color={0,0,127}));
  connect(PI_tab.y, PI.u)
    annotation (Line(points={{-25.3,67},{-15.4,67}}, color={0,0,127}));
  connect(temperature_ambient.port, chiller.port_a_2) annotation (Line(points={{20,20},{20,20},{20,8},{10,8}},
                                         color={0,127,255}));
  connect(T_ambient_source.y, conSource.T_in)
    annotation (Line(points={{71,16},{71,16},{52,16}}, color={0,0,127}));
  connect(temperature_demand.port, chiller.port_a_1) annotation (Line(points={{-20,-20},{-20,-20},{-20,-8},{-10,-8}},
                                             color={0,127,255}));
  connect(mflow_eva.y, source.m_flow_in) annotation (Line(points={{-73,0},{-70,0},{-70,-12},{-64,-12}},
                                    color={0,0,127}));

  connect(refCir_con_p.y, fan_controller.u_m) annotation (Line(points={{79,-16},{66,-16},{66,-7.2}},          color={0,0,127}));
  connect(refCir_con_p_nominal.y, fan_controller.u_s) annotation (Line(points={{79.6,0},{73.2,0}}, color={0,0,127}));
  connect(fan_controller.y, conSource.m_flow_in) annotation (Line(points={{59.4,0},{54,0},{54,12},{50,12}}, color={0,0,127}));
  connect(CIAT.y,fromKelvin1. Kelvin) annotation (Line(points={{-79.4,66},{-74.8,66}}, color={0,0,127}));
  connect(fromKelvin1.Celsius, CC_tab.u2) annotation (Line(points={{-65.6,66},{-58,66},{-58,82.8},{-41.4,82.8}}, color={0,0,127}));
  connect(fromKelvin1.Celsius, PI_tab.u2) annotation (Line(points={{-65.6,66},{-58,66},{-58,62.8},{-41.4,62.8}}, color={0,0,127}));
  connect(ELWT.y,fromKelvin. Kelvin) annotation (Line(points={{-79.4,86},{-74.8,86}}, color={0,0,127}));
  connect(fromKelvin.Celsius, CC_tab.u1) annotation (Line(points={{-65.6,86},{-52,86},{-52,91.2},{-41.4,91.2}}, color={0,0,127}));
  connect(fromKelvin.Celsius, PI_tab.u1) annotation (Line(points={{-65.6,86},{-52,86},{-52,71.2},{-41.4,71.2}}, color={0,0,127}));
  connect(source.ports[1], m_flow_eva.port_a) annotation (Line(points={{-44,-20},{-38,-20}}, color={0,127,255}));
  connect(m_flow_eva.port_b, temperature_demand.port) annotation (Line(points={{-26,-20},{-20,-20}}, color={0,127,255}));
  connect(on.y, chiller.on) annotation (Line(points={{-39.3,-50},{-6,-50},{-6,-12}}, color={255,0,255}));
  annotation (                             Documentation(info="<html>
</html>", revisions="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">2016-05-16 <a href=\"mailto: jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"></p><p><b>Copyright &copy; IK4-TEKNIKER</span></b></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"><img src=\"modelica://ModelicaTEK/Resources/Images/IK4-TEKNIKER_logo.jpg\"/></span></p>
</html>"), experiment(
      StopTime=14400,
      Interval=60,
      Tolerance=1e-005,
      __Dymola_fixedstepsize=0.001,
      __Dymola_Algorithm="Cvode"),
    __Dymola_Commands(file(ensureSimulated=true)=
        "modelica://Modelica/Resources/Scripts/Dymola/Fluid/HeatingSystem/plotResults.mos"
        "plotResults"),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
            100,100}}), graphics={Text(
          extent={{30,100},{90,80}},
          lineColor={28,108,200},
          textString="See simulation setting!!!")}),
    __Dymola_experimentSetupOutput,
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
end McQuay_N;
