within DCOL.Generation.ConventionalChillers.Testing;
model RTHD_N "Simple model of a heating system"
  parameter Integer n = 4;

  parameter Modelica.SIunits.Temperature T_out_req=
    chiller.T_out_eva_nominal;
  parameter Modelica.SIunits.Temperature T_in_eva=
    chiller.T_evaporating_nominal;
  parameter Modelica.SIunits.Temperature T_out_con=
    chiller.T_out_con_nominal;
  parameter Modelica.SIunits.Temperature T_in_con=
    chiller.T_condensing_nominal;

  parameter Modelica.SIunits.MassFlowRate mflow_in_eva=chiller.ChillerData.modelData.mflow_eva_nominal;
  parameter Modelica.SIunits.MassFlowRate mflow_in_con=chiller.ChillerData.modelData.mflow_con_nominal;

  inner Modelica.Fluid.System system(
    m_flow_small=1e-4)
    annotation (Placement(transformation(extent={{-100,-100},{-80,-80}},
                                                                       rotation=0)));
  Modelica.Blocks.Sources.Sine     EEWT(
    y(final quantity="ThermodynamicTemperature",
      final unit = "K", displayUnit = "degC", min=0),
    startTime=10*60,
    freqHz=1/(40*60),
    amplitude=(12 - 8.5)/2,
    offset=(12 + 8.5)/2 + 273.15) "Evaporator Entering Water Temperature"
    annotation (Placement(transformation(extent={{-92,74},{-80,86}})));
  Modelica.Blocks.Tables.CombiTable1Ds CCandPI_tab(table=[8.5,316.5,96.3; 9,422.0,101.4; 9.5,527.5,110.5; 10,633.0,124.7; 10.5,738.4,139.7; 11,843.9,157.5; 11.5,949.4,176.4; 12,1054.9,196.3]) "Cooling capacity table"
    annotation (Placement(transformation(extent={{-48,72},{-32,88}})));
  Modelica.Blocks.Math.Gain CC(k=1e3) "Cooling capacity"
    annotation (Placement(transformation(extent={{-14,80},{0,94}})));
  Modelica.Blocks.Sources.RealExpression T_req(y=T_out_req)
    annotation (Placement(transformation(extent={{-40,-86},{-20,-66}})));
  Modelica.Blocks.Sources.RealExpression T_coolingTower(y=T_in_con) annotation (Placement(transformation(extent={{94,6},{74,26}})));
  Modelica.Blocks.Sources.RealExpression mflow_con(y=mflow_in_con)
    annotation (Placement(transformation(extent={{94,-10},{74,10}})));
  Modelica.Blocks.Sources.RealExpression mflow_eva(y=mflow_in_eva*(CC.y/chiller.Q_flow_ref))
    annotation (Placement(transformation(extent={{-94,-10},{-74,10}})));
  Modelica.Blocks.Sources.RealExpression T_demand(y=EEWT.y)
    annotation (Placement(transformation(extent={{-94,-26},{-74,-6}})));
  Modelica.Fluid.Sources.MassFlowSource_T source(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    T=T_in_eva,
    use_T_in=true,
    m_flow=mflow_in_eva,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{-64,-30},{-44,-10}})));
  Modelica.Fluid.Sources.FixedBoundary sink(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater, nPorts=1)
    annotation (Placement(transformation(extent={{50,-30},{30,-10}})));
  Modelica.Fluid.Sources.FixedBoundary conSink(
                                       nPorts=1, redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-50,10},{-30,30}})));
  Modelica.Fluid.Sources.MassFlowSource_T conSource(
    nPorts=1,
    T=T_in_con,
    use_T_in=true,
    m_flow=mflow_in_con,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
                annotation (Placement(transformation(extent={{64,30},{44,10}})));
  Modelica.Fluid.Sensors.Temperature temperature_eva(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{10,-20},{30,-40}})));

  Modelica.Fluid.Sensors.Temperature temperature_con(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-10,20},{-30,40}})));
  Modelica.Fluid.Sensors.Temperature temperature_ambient(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{30,20},{10,40}})));
  ControlledChiller_N
                    chiller(
    redeclare package Medium_eva =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    n=n,
    length_eva=1.0,
    length_con=1.0,
    T_low_nominal=chiller.T_out_eva_nominal - 5,
    T_high_nominal=chiller.T_out_con_nominal + 5,
    dT_superHeat_nominal=2,
    dT_subCool_nominal=2,
    C_eva=100,
    C_con=100,
    Ti_controller=0.1,
    diameter_con=0.5,
    diameter_eva=0.5,
    valve_opening_nominal=0.2,
    redeclare package Medium_con = Modelica.Media.Water.ConstantPropertyLiquidWater,
    redeclare package ChillerData = ChillerSpecs.Trane_RTD_300,
    consumption_coeff={8.48306439e+04,7.09691537e-01,-9.17255830e-07})
                          annotation (Placement(transformation(extent={{-10,-10},{10,10}})));
  Modelica.Blocks.Sources.RealExpression COP(y=CC.y/PI.y)
    annotation (Placement(transformation(extent={{60,66},{80,86}})));
  Modelica.Blocks.Sources.RealExpression COP_model(y=chiller.refrigerantCircuit.Q_flow_total_eva/chiller.refrigerantCircuit.compressor.P)
    annotation (Placement(transformation(extent={{60,46},{80,66}})));
  Modelica.Blocks.Sources.RealExpression P_error(y=100*(PI.y - chiller.refrigerantCircuit.compressor.P)/PI.y)
    annotation (Placement(transformation(extent={{60,-74},{80,-54}})));
  Modelica.Blocks.Sources.RealExpression CC_error(y=100*(CC.y - chiller.refrigerantCircuit.Q_flow_total_eva)
        /CC.y)
    annotation (Placement(transformation(extent={{60,-94},{80,-74}})));
  Modelica.Fluid.Sensors.Temperature temperature_demand(redeclare package Medium =
               Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-30,-20},{-10,-40}})));
  Modelica.Blocks.Sources.RealExpression CP(y=CC.y - PI.y) annotation (Placement(transformation(extent={{10,64},{30,84}})));
  Modelica.Blocks.Sources.RealExpression COP_error(y=100*(COP.y - COP_model.y)/COP.y) annotation (Placement(transformation(extent={{20,-86},{40,-66}})));
  Modelica.Thermal.HeatTransfer.Celsius.FromKelvin fromKelvin annotation (Placement(transformation(extent={{-74,76},{-66,84}})));
  Modelica.Blocks.Sources.BooleanExpression on(y=true) annotation (Placement(transformation(extent={{-54,-56},{-40,-44}})));
  Modelica.Fluid.Sensors.MassFlowRate m_flow_eva(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{-38,-26},{-26,-14}})));

  output Modelica.SIunits.Temperature _P_out_mea = PI.y;
  output Modelica.SIunits.Temperature _P_out_mod = chiller.refrigerantCircuit.compressor.P;
  Modelica.Fluid.Sensors.MassFlowRate m_flow_con(redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{38,14},{26,26}})));
  Modelica.Blocks.Math.Gain PI(k=1e3) "Power"
    annotation (Placement(transformation(extent={{-14,60},{0,74}})));
equation
  connect(chiller.T_eva_set, T_req.y)
    annotation (Line(points={{6,-12},{6,-76},{-19,-76}},   color={0,0,127}));
  connect(chiller.port_b_2, temperature_con.port)
    annotation (Line(points={{-10,8},{-20,8},{-20,20}}, color={0,127,255}));
  connect(temperature_con.port, conSink.ports[1])
    annotation (Line(points={{-20,20},{-30,20}},          color={0,127,255}));
  connect(temperature_eva.port, sink.ports[1])
    annotation (Line(points={{20,-20},{30,-20}}, color={0,127,255}));
  connect(temperature_eva.port, chiller.port_b_1)
    annotation (Line(points={{20,-20},{20,-20},{20,-8},{10,-8}}, color={0,127,255}));
  connect(T_demand.y, source.T_in)
    annotation (Line(points={{-73,-16},{-66,-16}},           color={0,0,127}));
  connect(temperature_ambient.port, chiller.port_a_2) annotation (Line(points={{20,20},{20,20},{20,8},{10,8}},
                                         color={0,127,255}));
  connect(T_coolingTower.y, conSource.T_in) annotation (Line(points={{73,16},{66,16}}, color={0,0,127}));
  connect(temperature_demand.port, chiller.port_a_1) annotation (Line(points={{-20,-20},{-20,-20},{-20,-8},{-10,-8}},
                                             color={0,127,255}));

  connect(EEWT.y, fromKelvin.Kelvin) annotation (Line(points={{-79.4,80},{-74.8,80}}, color={0,0,127}));
  connect(on.y, chiller.on) annotation (Line(points={{-39.3,-50},{-6,-50},{-6,-12}}, color={255,0,255}));
  connect(source.ports[1], m_flow_eva.port_a) annotation (Line(points={{-44,-20},{-38,-20}}, color={0,127,255}));
  connect(m_flow_eva.port_b, temperature_demand.port) annotation (Line(points={{-26,-20},{-20,-20}}, color={0,127,255}));
  connect(mflow_eva.y, source.m_flow_in) annotation (Line(points={{-73,0},{-70,0},{-70,-12},{-64,-12}}, color={0,0,127}));
  connect(mflow_con.y, conSource.m_flow_in) annotation (Line(points={{73,0},{70,0},{70,12},{64,12}}, color={0,0,127}));
  connect(conSource.ports[1], m_flow_con.port_a) annotation (Line(points={{44,20},{38,20}}, color={0,127,255}));
  connect(m_flow_con.port_b, chiller.port_a_2) annotation (Line(points={{26,20},{20,20},{20,8},{10,8}}, color={0,127,255}));
  connect(CCandPI_tab.y[1], CC.u) annotation (Line(points={{-31.2,80},{-22,80},{-22,87},{-15.4,87}}, color={0,0,127}));
  connect(CCandPI_tab.y[2], PI.u) annotation (Line(points={{-31.2,80},{-22,80},{-22,67},{-15.4,67}}, color={0,0,127}));
  connect(fromKelvin.Celsius, CCandPI_tab.u) annotation (Line(points={{-65.6,80},{-49.6,80}}, color={0,0,127}));
  annotation (                             Documentation(info="<html>
</html>", revisions="<html>
<p><span style=\"font-family: MS Shell Dlg 2;\">2016-05-16 <a href=\"mailto: jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</span></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"></p><p><b>Copyright &copy; IK4-TEKNIKER</span></b></p>
<p><span style=\"font-family: MS Shell Dlg 2;\"><img src=\"modelica://ModelicaTEK/Resources/Images/IK4-TEKNIKER_logo.jpg\"/></span></p>
</html>"), experiment(
      StopTime=14400,
      Interval=60,
      Tolerance=1e-005,
      __Dymola_fixedstepsize=0.001,
      __Dymola_Algorithm="Cvode"),
    __Dymola_Commands(file(ensureSimulated=true)=
        "modelica://Modelica/Resources/Scripts/Dymola/Fluid/HeatingSystem/plotResults.mos"
        "plotResults"),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
            100,100}}), graphics={Text(
          extent={{30,100},{90,80}},
          lineColor={28,108,200},
          textString="See simulation setting!!!")}),
    __Dymola_experimentSetupOutput,
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
end RTHD_N;
