within DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents;
model ClosedHTX

extends DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.PartialModels.PartialHTXClosed;

initial equation
  coilWall[1].thermalNode[1, 1, 1].heatCapacitor.T=TMaterial_start;
  coilWall[1].thermalNode[1, 2, 1].heatCapacitor.T=TMaterial_start;
  coilWall[2].thermalNode[1, 1, 1].heatCapacitor.T=TMaterial_start;
  coilWall[2].thermalNode[1, 2, 1].heatCapacitor.T=TMaterial_start;
  pipe[1].mediums[1].T = T_start_coil;
  pipe[1].mediums[2].T = T_start_coil;
  pipe[2].mediums[1].T = T_start_coil;
  pipe[2].mediums[2].T = T_start_coil;

equation

  efficiency=(TCWater1 - TCWater2)/(TCWater1 - closedHeatToAirPressureDrop.TAir1);

  TCWater1=Medium.temperature(Medium.setState_ph(p=port_a_Cwater.p, h=inStream(
    port_a_Cwater.h_outflow)))
    "Medium properties at the entrace";

  TCWater2=Medium.temperature(Medium.setState_ph(p=port_b_Cwater.p, h=
    port_b_Cwater.h_outflow))
    "Medium properties at the entrace";
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})),                                  Diagram(
        coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
            100}})),
    Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>", info="<html>
<p>This model represents the behaviour of a closed cooling tower. It is considered closed as the heat transference happens between a chilled water flowing through a closed pipe circuit and the sprayed water and air. The tower is divided in nSeg segments.</p>
<h4>Assumptions</h4>
<ul>
<li>The pressure drop of both the air and the chilled fluid is considered, the pressure drop of the chilled water requires the parameters &QUOT;a&QUOT; (Coefficient of the quadratic term) and &QUOT;b&QUOT; (Coefficient for the lineal term);</li>
<li>It is not considered pressure drop during the water flow through the pipe;</li>
<li>The air is saturated at the exit of the cooling tower.</li>
<li>Some sprayed water is evaporated during the cooling process;</li>
<li>All the heat is transferred from the water to the air, heat losses during the water cooling are not considered;</li>
<li>The NTU (Number of Transfer Units) is used to calculate the amount of heat transferred from the water to the air. NTU is given by the n anc c design parameters of the tower;</li>
<li>The heat transferred from the chilled fluid to the sprayed water is defined by the model &QUOT;SympleCylinder&QUOT; from the Thermal library. This allows to use the thermal properties of the pipe by selecting its material.</li>
</ul>
<h4>References</h4>
<ul>
<li>Lu, L. and Cai, W., &QUOT;A Universal Engineering Model For Cooling Towers&QUOT; (2002). International Refrigeration and Air Conditioning, Conference. Paper 625.;</li>
<li>Li, Xiao; Li, Yaoyu; and Seem, John E., &QUOT;Dynamic Modeling of Mechanical Draft Counter-Flow Wet Cooling Tower with Modelica&QUOT;(2010). International Refrigeration and Air Conditioning Conference. Paper 1094.;</li>
<li>Baker, Donald. R and Shryock, Howard A., &QUOT;A Compresive Aproach To The Analysis Of Cooling Tower Performance&QUOT; (2013). SPX Corporation. Thermal Science.;</li>
<li>http://che.sharif.edu/~heatlab/Lab/Benefit&percnt;20Book&percnt;20&AMP;&percnt;20Journal/Benefit&percnt;20book/Cooling&percnt;20Tower&percnt;20Thermal&percnt;20Design&percnt;20Manual.pdf;</li>
</ul>
</html>"));
end ClosedHTX;
