within DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents;
model OpenHTX
  import DCOL;
  extends DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.PartialModels.PartialHeatTransferOpen;
  extends DCOL.Generation.CoolingTowers.Icons.OpenHeatExchanger;

  //WATER IN
  Modelica.SIunits.Temperature TWater1 "Inlet water temperature in K";
  Modelica.SIunits.SpecificEnthalpy hWater1 "Specific enthalpy of the inlet water";
  Modelica.SIunits.MassFlowRate mWater1 "Inlet water mass flow";
  Modelica.SIunits.Temp_C TWater1C "Inlet water temperature in C";
protected
  parameter Modelica.SIunits.MassFlowRate mWater1_small=Modelica.Constants.small "Used when mAir1 is really small";

  //WATER OUT
public
  Modelica.SIunits.Temperature TWater2(start=TWater2_start) "Outlet water temperature in K";
  Modelica.SIunits.SpecificEnthalpy hWater2 "Specific enthalpy of the outlet water";
  Modelica.SIunits.MassFlowRate mWater2 "Outlet water mass flow";
  Modelica.SIunits.Temp_C TWater2C(start=TWater2_start-273.15) "Outlet water temperature in C";

  //AIR IN
  Modelica.SIunits.Temperature TAir1 "Inlet air temperature in K";
  Modelica.SIunits.SpecificEnthalpy hAir1 "Specific enthalpy of the inlet air";
  Modelica.SIunits.MassFlowRate mAir1(start=mAir1_start) "Inlet air mass flow";
  Modelica.SIunits.MassFraction X1 "Vapour mass fraction in the inlet air [kg_vapour/kg_moist_air]";
  Modelica.SIunits.Temp_C TAir1C "Inlet air temperature in C";
  Modelica.SIunits.MassFraction H1 "Inlet air absolute humidity=0.0184560958649";
  Modelica.SIunits.MassFlowRate mDAir1 "Inlet dry air mass flow";
  Modelica.SIunits.MassFlowRate mVap1 "Inlet vapour mass flow";
  Modelica.SIunits.SpecificEnthalpy hsw1 "Air saturation enthalpy at inlet water temperature";
  Modelica.SIunits.MassFraction Hsat1 "Inlet air saturation absolute humidity";
  Modelica.SIunits.MassFraction Hsat1w "Inlet air saturation absolute humidity at inlet water temperature";
  Modelica.SIunits.Pressure pSat1 "Air saturation pressure at TWater1";
  Modelica.SIunits.Density rho1 "Density of air-water vapor mixture at the entrace";
  Modelica.SIunits.MolarMass N1 "Inlet air molar mass";

  //AIR OUT
  Modelica.SIunits.Temperature TAir2(start=TAir2_start) "Inlet air temperature in K";
  Modelica.SIunits.SpecificEnthalpy hAir2 "specific enthalpy of the outlet Air";
  Modelica.SIunits.MassFlowRate mAir2(start=mAir1_start) "Outlet air mass flow";
  Modelica.SIunits.MassFraction X2 "Vapour mass fraction in the outlet air [kg_vapour/kg_moist_air]";
  Modelica.SIunits.MassFlowRate mDAir2 "Outlet dry air mass flow";
  Modelica.SIunits.MassFlowRate mVap2 "Outlet vapour mass flow";
  Modelica.SIunits.MassFraction H2(start=H2_start) "Outlet air absolute humidity";
  Modelica.SIunits.Temp_C TAir2C(start=TAir2_start-273.15) "Inlet air temperature in C";
  Modelica.SIunits.SpecificEnthalpy hsw2 "Air saturation enthalpy at outlet water temperature";
  Modelica.SIunits.MassFraction Hsat2 "Outlet air saturation absolute humidity";
  Modelica.SIunits.MassFraction Hsat2w "Outlet air saturation absolute humidity at water temperature";
  Modelica.SIunits.Pressure pSat2 "Air saturation pressure at TAir2";
  Modelica.SIunits.Density rho2 "Density of air-water vapor mixture at the exit";
  Modelica.SIunits.MolarMass N2 "Outlet air molar mass";
  Real phi2 "Realitive humidity at the exit of the tower";
protected
  parameter Modelica.SIunits.MassFlowRate mAir2_small=1e-5 "Used when mAir1 is really small";

  //VAPOUR
public
  Modelica.SIunits.MassFlowRate mEvap "Evaported mass flow";
  Modelica.SIunits.SpecificEnthalpy hvap "Vapour specific enthalpy";
  Modelica.SIunits.Temperature Tvap "Vapour temperature in K";
  Modelica.SIunits.Temp_C TvapC "Vapour temperature in C";

  //GENERAL DATA
protected
  parameter Modelica.SIunits.SpecificHeatCapacity Cpa=1007 "Air specific heat capacity" annotation (Dialog(group="Thermal properties"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cpw=4184 "Water specific heat capacity" annotation (Dialog(group="Thermal properties"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cpv=1820 "Vapour specific heat capacity" annotation (Dialog(group="Thermal properties"));
  parameter Modelica.SIunits.SpecificEnthalpy hfg=2448.15*10^3 "Enthalpy of vaporization of water at ambient presure" annotation (Dialog(group="Thermal properties"));

public
  Modelica.SIunits.HeatFlowRate Qsen "Sensible heat transferred to the water";
  Modelica.SIunits.HeatFlowRate Qlat "Latent heat transferred to the water";
  Modelica.SIunits.HeatFlowRate Qtot "Total heat transferred to the water";

  parameter Real Kfi(unit="1/m")=3.5 "Loss coefficient in the fill" annotation (Dialog(group="Fluid properties"));
  Modelica.SIunits.MassFlowRate mMed "Mean air-vapor flow rate";
  Modelica.SIunits.Density rhoMed "harmonic mean density of air-water vapor mixtures";
  parameter Modelica.SIunits.Length hfi=2.11455 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.28346 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.2197/2 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  Modelica.SIunits.Pressure IncP "Air pressure change between the entrace and the exit";

  //DESING OF THE COOLING TOWER
  Real e_a;
  Real efficiency "Efficiency of the tower";
  parameter Real c=2.3 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Real n=-0.72 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  Real NTU "Number of Transfer Units of the tower";
  //parameter Real NTU=0.74164 "Number of Transfer Units of the tower" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  Real C_s "Derivative of saturated ha with respect to Tw";
  Real m_ratio "Ratio of air to water effective capacitance rate";

  parameter Modelica.SIunits.Pressure pAmbient=system.p_ambient "Ambient pressure" annotation (Dialog(group="Ambient properties"));

  //parameter Real A=0.00165;
  parameter Modelica.SIunits.Area Afr=wfi*lfi "cross-sectional packing area" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Volume Vfi=hfi*wfi*lfi "Volume of the filter" annotation (Dialog(group="Geometric properties"));

  //START VALUES
  parameter Modelica.SIunits.MassFlowRate mAir1_start=32 "Inlet water mass flow" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TWater2_start=29+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=34+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));

equation

//PROPERTIES OF THE INLET WATER
  if abs(port_a_water.m_flow) < mWater1_small then
    mWater1=mWater1_small;
  else
    mWater1=port_a_water.m_flow;
  end if;
  hWater1=inStream(port_a_water.h_outflow);
  hWater1=port_a_water.h_outflow;
  TWater1=Medium.temperature(Medium.setState_ph(p=port_a_water.p,
                                     h=inStream(port_a_water.h_outflow)))
    "Medium properties at the entrace";
  TWater1C=TWater1-273.15;

//PROPERTIES OF THE OUTLET WATER
  mWater2=-port_b_water.m_flow;
  hWater2=port_b_water.h_outflow;
  TWater2=TWater2C+273.15;
  //hWater2=Cpw*(TWater2C);
  hWater2=Medium.specificEnthalpy_pT(port_b_water.p, TWater2);

//PROPERTIES OF THE INLET AIR
  mAir1=port_a_air.m_flow;
  hAir1=inStream(port_a_air.h_outflow);
  hAir1=port_a_air.h_outflow;
  TAir1=Medium1.temperature(Medium1.setState_phX(p=port_a_air.p,
                                      h=inStream(port_a_air.h_outflow),
                                      X=inStream(port_a_air.Xi_outflow)))
    "Medium properties at the entrace";
  inStream(port_a_air.Xi_outflow[1]) = X1;
  port_a_air.Xi_outflow[1] = X1;
  pSat1=Modelica.Media.Air.MoistAir.saturationPressure(Tsat=TWater1);
  //hsw1=(Cpa*(TWater1C)+Hsat1*(hfg+Cpv*(TWater1C))*(mDAir1/mAir1));
  hsw1=(Cpa*(TWater1C)+Hsat1w*(hfg+Cpv*(TWater1C)));
  Hsat1=Medium1.xsaturation_pT(p=port_a_air.p, T=TAir1);
  Hsat1w=Medium1.xsaturation_pT(p=port_a_air.p, T=TWater1);
  X1=H1/(1+H1);
  TAir1C=TAir1-273.15;
  rho1=Medium1.density(Medium1.setState_phX(p=port_a_air.p,
                                 h=inStream(port_a_air.h_outflow),
                                 X=inStream(port_a_air.Xi_outflow)));
  N1=(1-X1)*0.02896968+X1*0.0180152;
  //Hsat1=Medium1.saturationPressure(TWater1)/port_b_air.p;

//PROPERTIES OF THE OUTLET AIR
  if abs(port_b_air.m_flow) < mAir2_small then
    mAir2=mAir2_small;
  else
    mAir2=-port_b_air.m_flow;
  end if;

  hAir2=port_b_air.h_outflow;
  X2=port_b_air.Xi_outflow[1];
  TAir2=TAir2C+273.15;
  //hsw2=(Cpa*(TWater2C)+Hsat2*(hfg+Cpv*(TWater2C))*(mDAir2/mAir2));
  hsw2=(Cpa*(TWater2C)+Hsat2w*(hfg+Cpv*(TWater2C)));
  hAir2=Medium1.specificEnthalpy_pTX(port_b_air.p,
                                     TAir2,
                                     port_b_air.Xi_outflow);
  pSat2=Medium1.saturationPressure(TAir2);
  phi2=(1/((pSat2/pAmbient)*((0.621964713077499/H2)+1)));
  X2=H2/(1+H2);
  rho2=Medium1.density(Medium1.setState_phX(p=port_b_air.p,
                                            h=port_b_air.h_outflow,
                                            X=port_b_air.Xi_outflow));
  N2=(1-X2)*0.02896968+X2*0.0180152;
  Hsat2w=Medium1.xsaturation_pT(p=port_b_air.p, T=TWater2);
  Hsat2=Medium1.xsaturation_pT(p=port_b_air.p, T=TAir2);
  (1/4186.8)*hAir2=(1/4186.8)*hAir1+(mWater1/mAir1)*((TAir2C*(9/5)+32)-(TAir1C*(9/5)+32));

//PROPERTIES OF THE EXCHANGED VAPOUR
  Tvap=TvapC+273.15;
  hvap=hfg+Cpv*(TvapC);
  Tvap=TAir2;

//PRESSURE DROP CONSIDERED
  rhoMed=(1/((1/rho1)+(1/rho2)));
  port_a_water.p = port_b_water.p;
  port_a_air.p - port_b_air.p = IncP;
  IncP=(5/3)*(((Kfi*hfi*mMed^2)/(2*rhoMed*Afr^2))+((6.5*mMed^2)/(2*rhoMed*Afr^2)));
  //IncP=Modelica.Constants.small;

//AIR MASS BALANCE
  mMed=(mAir1+mAir2)/2;
  mAir1=mDAir1+mVap1;
  mVap1=mAir1*X1;

  mAir2=mDAir2+mVap2;
  mVap2=mAir2*X2;

  mAir1+mEvap=mAir2;
  mDAir1=mDAir2;

//AIR ENERGY BALANCE
  Qsen=mDAir1*(Cpa+H1*Cpv)*(TAir2C-TAir1C);
  Qlat=mEvap*hvap;
  //Qtot=mAir2*hAir2-mAir1*hAir1;
  Qtot=Qsen+Qlat;

//WATER MASS BALANCE
  mWater1=mWater2+mEvap;

//WATER ENERGY BALANCE
  Qtot=mWater1*hWater1-mWater2*hWater2;

//DESIGN PARAMETERS
  C_s=(hsw1-hsw2)/(TWater1C-TWater2C);
  m_ratio=(mAir1/mWater1)*(C_s/Cpw);
  NTU=c*((mAir1/mWater1)^(-(1+n)));
  e_a=(1-exp(-NTU*(1-m_ratio)))/(1-m_ratio*exp(-NTU*(1-m_ratio)));
  //TAir1 in C
  //Qtot=e_a*mAir1*(hsw1-Cpa*(TAir1C));
  Qtot=e_a*mAir1*(hsw1-hAir1);
  efficiency=(TWater1C-TWater2C)/(TWater1C-TAir1C);

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model representes heat exchanger in a open cooling tower. Calculates the heat and mass exchanged between the water and the air.</p>
<h4>Assumptions</h4>
<ul>
<li>The pressure drop of the air is considered;</li>
<li>Some sprayed water is evaporated during the cooling process;</li>
<li>All the heat is transferred from the water to the air, heat losses during the water cooling are not considered;</li>
<li>The NTU (Number of Transfer Units) is used to calculate the amount of heat transferred from the water to the air. NTU is given by the n anc c design parameters of the tower.</li>
</ul>
<h4>Resolutions</h4>
<p>Mass and energy balance:</p>
<p>(1)Mass conservation of air:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/MBAir_Generation_CoolingTower_OpenHeatExch.png\" alt=\"m_ai+m_e=m_ao\"/></p>
<p>(2)Heat conservation of air:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-g3ezjsS9.png\" alt=\"m_ai*h_ai+Q_tot=m_ao*h_ao
\"/></p>
<p>(3)Mass conservation of condenser water:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/MBWater_Generation_CoolingTower_OpenHeatExch.png\" alt=\"m_wi-m_e=m_wo\"/></p>
<p>(4)Heat conservation of condenser water:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-zbf6EQp8.png\" alt=\"m_wi*T_wi*C_pw-Q_tot=m_wo*T_wo*C_pw
\"/></p>
<p>Heat transferred from water to air:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-VwRv06QU.png\" alt=\"Q_tot=epsilon_a*m_a*(h_swi-h_ai)\"/></p>
<p><br>Efficiency:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/efficiency_Generation_CoolingTower_OpenHeatExch.png\" alt=\"epsilon_a=(1-exp(-NTU*(1-m_ratio)))/(1-m_ratio*exp(-NTU*(1-m_ratio)))\"/></p>
<p>NTU, m* and Cs:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/NTU_Generation_CoolingTower_OpenHeatExch.png\" alt=\"NTU=c*(m_a/m_w)^(-(1+n))\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/m_ratio_Generation_CoolingTower_OpenHeatExch.png\" alt=\"m_ratio=(m_a/m_w)*(C_s/C_pw)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/Cs_Generation_CoolingTower_OpenHeatExch.png\" alt=\"C_s=(h_swi-h_swo)/(T_wi-T_wo)\"/></p>
<p><br>where c and n are characteristic constants which depend on the cooling tower</p>
<p>To calculate the temperature of the air at the exit of the tower is used the the next correlation:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-OfEqC80p.png\" alt=\"h_ao-h_ai=(m_wi/m_ai)*(T_ao-T_ai)
\"/></p>
<h4>References</h4>
<ul>
<li>Lu, L. and Cai, W., &QUOT;A Universal Engineering Model For Cooling Towers&QUOT; (2002). International Refrigeration and Air Conditioning, Conference. Paper 625.;</li>
<li>Li, Xiao; Li, Yaoyu; and Seem, John E., &QUOT;Dynamic Modeling of Mechanical Draft Counter-Flow Wet Cooling Tower with Modelica&QUOT;(2010). International Refrigeration and Air Conditioning Conference. Paper 1094.;</li>
<li>Baker, Donald. R and Shryock, Howard A., &QUOT;A Compresive Aproach To The Analysis Of Cooling Tower Performance&QUOT; (2013). SPX Corporation. Thermal Science.;</li>
<li>http://che.sharif.edu/~heatlab/Lab/Benefit&percnt;20Book&percnt;20&AMP;&percnt;20Journal/Benefit&percnt;20book/Cooling&percnt;20Tower&percnt;20Thermal&percnt;20Design&percnt;20Manual.pdf;</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end OpenHTX;
