within DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents;
model OpenHTXCalibrated

  extends DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.PartialModels.PartialHeatTransferOpen;

  extends DCOL.Generation.CoolingTowers.Icons.OpenHeatExchanger;

  parameter Modelica.SIunits.Pressure pAmbient=101325 "Ambient pressure" annotation (Dialog(group="Ambient properties"));

  parameter Real Kfi=3.5 "Loss coefficient in the fill" annotation(Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=2.11455 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.28346 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.2197/2 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area Afr=wfi*lfi "cross-sectional packing area" annotation(Dialog(group="Geometric properties"));

  //OPERATION POINTS
  parameter Modelica.SIunits.MassFlowRate mWater1_1=100 "Inlet water mass flow for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater1C_1=35 "Inlet water temperature in C for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater2C_1=29 "Outlet water temperature in C for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.MassFlowRate mAir1_1=48 "Inlet air mass flow for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TAir1C_1=25 "Inlet air temperature in C for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.MassFraction H1_1=0.0184560958649 "Inlet air absolute humidity for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Pressure pAmbient_1=101325 "Ambient pressure for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));

  parameter Modelica.SIunits.MassFlowRate mWater1_2=80 "Inlet water mass flow for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater1C_2=38 "Inlet water temperature in C for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater2C_2=30 "Outlet water temperature in C for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.MassFlowRate mAir1_2=40 "Inlet air mass flow for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TAir1C_2=20 "Inlet air temperature in C for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.MassFraction H1_2=0.0184560958649 "Inlet air absolute humidity for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Pressure pAmbient_2=101325 "Ambient pressure for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));

  //START VALUES
  parameter Modelica.SIunits.Temperature TWater2_start=29+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=34+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFlowRate mAir1_start=20 "Inlet air mass flow" annotation(Dialog(tab = "Initialization"));

  Interfaces.HeatTransferComponents.OpenHTXCalibrated openHTXCalibrated(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    allowFlowReversal=allowFlowReversal,
    Kfi=Kfi,
    Afr=Afr,
    TWater2_start=TWater2_start,
    TAir2_start=TAir2_start,
    H2_start=H2_start,
    pAmbient=pAmbient,
    hfi=hfi,
    wfi=wfi,
    lfi=lfi,
    mAir1_start=mAir1_start)
    annotation (Placement(transformation(extent={{-20,-40},{60,40}})));

  CalibrationComponents.CalibrationComponent calibrationComponent(
    mWater1_1=mWater1_1,
    TWater1C_1=TWater1C_1,
    TWater2C_1=TWater2C_1,
    mAir1_1=mAir1_1,
    TAir1C_1=TAir1C_1,
    H1_1=H1_1,
    pAmbient_1=pAmbient_1,
    mWater1_2=mWater1_2,
    TWater1C_2=TWater1C_2,
    TWater2C_2=TWater2C_2,
    mAir1_2=mAir1_2,
    TAir1C_2=TAir1C_2,
    H1_2=H1_2,
    pAmbient_2=pAmbient_2) annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));

equation

  connect(calibrationComponent.c, openHTXCalibrated.c) annotation (Line(points=
          {{-58,6},{-42,6},{-42,16},{-24,16}}, color={0,0,127}));
  connect(calibrationComponent.n, openHTXCalibrated.n) annotation (Line(points=
          {{-58,-6},{-44,-6},{-44,-16},{-24,-16}}, color={0,0,127}));
  connect(port_a_water, openHTXCalibrated.port_a_water)
    annotation (Line(points={{-70,90},{-8,90},{-8,36}}, color={0,127,255}));
  connect(port_a_air, openHTXCalibrated.port_a_air) annotation (Line(points={{
          70,-90},{60,-90},{48,-90},{48,-36}}, color={0,127,255}));
  connect(port_b_air, openHTXCalibrated.port_b_air) annotation (Line(points={{
          70,90},{60,90},{48,90},{48,36}}, color={0,127,255}));
  connect(port_b_water, openHTXCalibrated.port_b_water) annotation (Line(points=
         {{-70,-90},{-40,-90},{-8,-90},{-8,-36}}, color={0,127,255}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>", info="<html>
<p>This model representes heat exchanger in a open cooling tower. Calculates the heat and mass exchanged between the water and the air.</p>
<h4>Assumptions</h4>
<ul>
<li>The pressure drop of the air is considered;</li>
<li>The air is saturated at the exit of the cooling tower;</li>
<li>Some sprayed water is evaporated during the cooling process;</li>
<li>All the heat is transferred from the water to the air, heat losses during the water cooling are not considered;</li>
<li>The model needs 2 operation points to calculate the value of NTU (Number of Transfer Units).The NTU is used to calculate the amount of heat transferred from the water to the air.</li>
</ul>
<h4>References</h4>
<ul>
<li>Lu, L. and Cai, W., &QUOT;A Universal Engineering Model For Cooling Towers&QUOT; (2002). International Refrigeration and Air Conditioning, Conference. Paper 625.;</li>
<li>Li, Xiao; Li, Yaoyu; and Seem, John E., &QUOT;Dynamic Modeling of Mechanical Draft Counter-Flow Wet Cooling Tower with Modelica&QUOT;(2010). International Refrigeration and Air Conditioning Conference. Paper 1094.;</li>
<li>Baker, Donald. R and Shryock, Howard A., &QUOT;A Compresive Aproach To The Analysis Of Cooling Tower Performance&QUOT; (2013). SPX Corporation. Thermal Science.;</li>
<li>http://che.sharif.edu/~heatlab/Lab/Benefit&percnt;20Book&percnt;20&AMP;&percnt;20Journal/Benefit&percnt;20book/Cooling&percnt;20Tower&percnt;20Thermal&percnt;20Design&percnt;20Manual.pdf;</li>
</ul>
</html>"));
end OpenHTXCalibrated;
