within DCOL.Generation.CoolingTowers.BaseClasses;
model WaterSpray

  extends DCOL.Generation.CoolingTowers.Icons.WaterSpray;
  extends Modelica.Fluid.Interfaces.PartialTwoPortTransport(final allowFlowReversal = false);

  parameter Modelica.SIunits.AbsolutePressure p_ambient= system.p_ambient;
  parameter Modelica.SIunits.Diameter d_a=0.02505 "Diameter of the entrace";
  parameter Modelica.SIunits.Diameter d_b=0.025 "Diameter of the exit";

  Modelica.SIunits.Area A_a "Area of the entrace";
  Modelica.SIunits.Area A_b "Area of the exit";

  Modelica.SIunits.Velocity V_a "Velocity of the fluid at the entrace";
  Modelica.SIunits.Velocity V_b "Velocity of the fluid at the exit";

  Modelica.SIunits.Density rho_a "Density of the fluid at the entrace";
  Modelica.SIunits.Density rho_b "Density of the fluid at the exit";

equation
//ENERGY BALANCE
  port_a.h_outflow = inStream(port_b.h_outflow);
  port_b.h_outflow = inStream(port_a.h_outflow);

//ENERGY BALANCE
  //dp = port_a.p - p_ambient;
  dp=0.5*(rho_b*V_b^2-rho_a*V_a^2);
  rho_b=Medium.density(Medium.setState_phX(p=port_b.p,
                                             h=port_b.h_outflow));
  rho_a=Medium.density(Medium.setState_phX(p=port_a.p,
                                             h=port_a.h_outflow));
  V_a=abs(port_a.m_flow/(rho_a*A_a));
  V_b=abs(port_b.m_flow/(rho_b*A_b));
  A_a=Modelica.Constants.pi*(d_a/2)^2;
  A_b=Modelica.Constants.pi*(d_b/2)^2;

  //port_b.p=p_ambient;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents the water sprays located at the top of a cooling tower.</p>
<p>The model represents the pressure drop during the sprayation of the water.</p>
<h4>Assumptions</h4>
<ul>
<li>The pressure drop depends on the different diameters of the orifices at the entrace and the exit.</li>
</ul>
<p><br>Equation:</p><p><br><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-5MKsKNPP.png\" alt=\"dP=1/2*(rho_b*v_b^2-rho_a*v_a^2)\"/></p>
<h4>References</h4>
<ul>
<li>http://www.pnr.eu/catalogo_sfoglia/spray-engineering-handbook/spray-engineering-handbook.pdf;</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end WaterSpray;
