within DCOL.Generation.CoolingTowers.CalibrationComponents.BaseClasses;
model CalibrationComponentData

  //WATER IN
  parameter Modelica.SIunits.MassFlowRate mWater1=0.0172 "Inlet water mass flow";
  Modelica.SIunits.Temperature TWater1 "Inlet water temperature in K";
  parameter Modelica.SIunits.Temp_C TWater1C=39.1 "Inlet water temperature in C";
  Modelica.SIunits.SpecificEnthalpy hW1 "Specific enthalpy of the inlet water";

  //WATER OUT
  Modelica.SIunits.MassFlowRate mWater2 "Outlet water mass flow";
  Modelica.SIunits.Temperature TWater2 "Outlet water temperature in K";
  parameter Modelica.SIunits.Temp_C TWater2C=28.3 "Water outlet temperature in C";
  Modelica.SIunits.SpecificEnthalpy hW2 "Water outlet specific enthalpy";

  //AIR IN
  Modelica.SIunits.Temperature TAir1 "Inlet air temperature in K";
  Modelica.SIunits.SpecificEnthalpy hAir1 "Specific enthalpy of the inlet air";
  parameter Modelica.SIunits.MassFlowRate mAir1=0.036666 "Inlet air mass flow";
  Modelica.SIunits.MassFraction X1 "Vapour mass fraction in the inlet air [kg_vapour/kg_moist_air]";
  parameter Modelica.SIunits.Temp_C TAir1C=29.3 "Inlet air temperature in C";
  parameter Modelica.SIunits.MassFraction H1=0.0113 "Inlet air absolute humidity=0.0184560958649";
  Modelica.SIunits.MassFlowRate mDAir1 "Inlet  dry air mass flow";
  Modelica.SIunits.MassFlowRate mVap1 "Inlet vapour mass flow";
  Modelica.SIunits.SpecificEnthalpy hsw1 "Air saturation enthalpy at inlet water temperature";
  Modelica.SIunits.MassFraction Hsat1 "Inlet air saturation absolute humidity";
  Modelica.SIunits.MassFraction Hsat1w "Inlet air saturation absolute humidity at inlet water temperature";
  Modelica.SIunits.Pressure pSat1 "Air saturation pressure at TWater1";
  Modelica.SIunits.Density rho1 "Density of air-water vapor mixture at the entrace";
  Modelica.SIunits.MolarMass N1 "Inlet air molar mass";
  Modelica.SIunits.AbsolutePressure pA1;

  parameter Modelica.SIunits.Pressure pAmbient=101325 "Ambient pressure";
  //Modelica.SIunits.SpecificEnthalpy hint "Specific enthalpy of the inlet air";

  //AIR OUT
  Modelica.SIunits.Temperature TAir2(start=20+273.15) "Inlet air temperature in K";
  Modelica.SIunits.SpecificEnthalpy hAir2 "specific enthalpy of the outlet Air";
  Modelica.SIunits.MassFlowRate mAir2 "Outlet Air mass flow";
  Modelica.SIunits.MassFraction X2 "Vapour mass fraction in the outlet air [kg_vapour/kg_moist_air]";
  Modelica.SIunits.MassFlowRate mDAir2 "Outlet dry air mass flow";
  Modelica.SIunits.MassFlowRate mVap2 "Outlet vapour mass flow";
  Modelica.SIunits.MassFraction H2(start=0.015) "Outlet air absolute humidity";
  Modelica.SIunits.Temp_C TAir2C(start=20) "Inlet air temperature in C";
  Modelica.SIunits.SpecificEnthalpy hsw2 "Air saturation enthalpy at outlet water temperature";
  Modelica.SIunits.MassFraction Hsat2 "Outlet air saturation absolute humidity";
  Modelica.SIunits.MassFraction Hsat2w "Outlet air saturation absolute humidity at water temperature";
  Modelica.SIunits.Pressure pSat2 "Air saturation pressure at TAir2";
  Modelica.SIunits.Density rho2 "Density of air-water vapor mixture at the exit";
  Modelica.SIunits.MolarMass N2 "Outlet air molar mass";
  Real phi2 "Realitive humidity at the exit of the tower";
  Modelica.SIunits.AbsolutePressure pA2;

  //VAPOUR
public
  Modelica.SIunits.MassFlowRate mEvap "Evaported mass flow";
  Modelica.SIunits.SpecificEnthalpy hvap "Vapour specific enthalpy";
  Modelica.SIunits.Temperature Tvap "Vapour temperature in K";
  Modelica.SIunits.Temp_C TvapC "Vapour temperature in C";

  //GENERAL DATA
protected
  parameter Modelica.SIunits.SpecificHeatCapacity Cpa=1007 "Air specific heat capacity";
  parameter Modelica.SIunits.SpecificHeatCapacity Cpw=4184 "Water specific heat capacity";
  parameter Modelica.SIunits.SpecificHeatCapacity Cpv=1820 "Vapour specific heat capacity";
  parameter Modelica.SIunits.SpecificEnthalpy hfg=2448.15*10^3 "enthalpy of vaporization of water at ambient presure";

public
  Modelica.SIunits.HeatFlowRate Qsen "Sensible heat transferred to the water";
  Modelica.SIunits.HeatFlowRate Qlat "Latent heat transferred to the water";
  Modelica.SIunits.HeatFlowRate Qtot "Total heat transferred to the water";

  parameter Real Kfi(unit="1/m")=3.5 "Loss coefficient in the fill" annotation (Dialog(group="Fluid properties"));
  Modelica.SIunits.MassFlowRate mMed "Mean air-vapor flow rate";
  Modelica.SIunits.Density rhoMed "harmonic mean density of air-water vapor mixtures";
  parameter Modelica.SIunits.Length hfi=2.11455 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.28346 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.2197/2 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  Modelica.SIunits.Pressure IncP "Air pressure change between the entrace and the exit";

  //DESING OF THE COOLING TOWER
  //Real c "Calculated for a operation point where the outlet water temperature is of 29C";
  //Real n "Calculated for a operation point where the outlet water temperature is of 29C";
  Real e_a "efficiency of the tower";
  Real C_s "derivative of saturated ha with respect to Tw";
  Real m_ratio "ratio of air to water effective capacitance rate";

  parameter Modelica.SIunits.Area Afr=wfi*lfi "cross-sectional packing area" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Volume Vfi=hfi*wfi*lfi "Volume of the filter" annotation (Dialog(group="Geometric properties"));

  Modelica.Blocks.Interfaces.RealOutput NTU "Number of Transfer Units of the tower" annotation (Placement(transformation(extent={{100,20},{120,40}})));

  Modelica.Blocks.Interfaces.RealOutput mWaterIn "Inlet Water mass flow" annotation (Placement(transformation(extent={{100,-40},{120,-20}})));

  Modelica.Blocks.Interfaces.RealOutput mAirIn "Inlet Air mas flow" annotation (Placement(transformation(extent={{100,-10},{120,10}})));

equation
//INLET WATER
  //hW1=Cpw*(TWater1C);
  //hW1=Modelica.Media.Water.ConstantPropertyLiquidWater.specificEnthalpy_pT(pAmbient, TWater1);
  TWater1=Modelica.Media.Water.ConstantPropertyLiquidWater.temperature(
            Modelica.Media.Water.ConstantPropertyLiquidWater.setState_ph(
                p=pAmbient,
                h=hW1))
    "Water properties at the entrace";
  TWater1=TWater1C+273.15;
  mWaterIn=mWater1;

//OUTLET WATER
  TWater2=TWater2C+273.15;
  TWater2=Modelica.Media.Water.ConstantPropertyLiquidWater.temperature(
            Modelica.Media.Water.ConstantPropertyLiquidWater.setState_ph(
                p=pAmbient,
                h=hW2))
    "Water properties at the entrace";
  //hW2=Cpw*(TWater2C);

//INLET AIR
  //hAir1=Cpa*(TAir1C)+H1*(hfg+Cpv*(TAir1C));
  TAir1=Modelica.Media.Air.MoistAir.temperature(
          Modelica.Media.Air.MoistAir.setState_phX(
              p=pAmbient,
              h=hAir1,
              X={X1,1-X1}))
    "Medium properties at the entrace";
  TAir1=TAir1C+273.15;
  pSat1=Modelica.Media.Air.MoistAir.saturationPressure(Tsat=TWater1);
  hsw1=Cpa*(TWater1C)+Hsat1*(hfg+Cpv*(TWater1C));
  mAirIn=mAir1;
  X1=H1/(1+H1);
  Hsat1=Modelica.Media.Air.MoistAir.xsaturation_pT(p=pAmbient, T=TAir1);
  Hsat1w=Modelica.Media.Air.MoistAir.xsaturation_pT(p=pAmbient, T=TWater1);
  rho1=Modelica.Media.Air.MoistAir.density(
         Modelica.Media.Air.MoistAir.setState_phX(
             p=pA1,
             h=hAir1,
             X={X1,1-X1}));
  N1=(1-X1)*0.02896968+X1*0.0180152;
  //Hsat1=Medium1.saturationPressure(TWater1)/port_b_air.p;

//OUTLET AIR
  TAir2=TAir2C+273.15;

  hsw2=(Cpa*(TWater2C)+Hsat2w*(hfg+Cpv*(TWater2C)));
  hAir2=Modelica.Media.Air.MoistAir.specificEnthalpy_pTX(
            p=pA2,
            T=TAir2,
            X={X2, 1-X2});
  pSat2=Modelica.Media.Air.MoistAir.saturationPressure(TAir2);
  phi2=(1/((pA2/pAmbient)*((0.621964713077499/H2)+1)));
  X2=H2/(1+H2);
  rho2=Modelica.Media.Air.MoistAir.density(
         Modelica.Media.Air.MoistAir.setState_phX(
             p=pA2,
             h=hAir2,
             X={X2,1-X2}));
  N2=(1-X2)*0.02896968+X2*0.0180152;
  Hsat2w=Modelica.Media.Air.MoistAir.xsaturation_pT(p=pA2, T=TWater2);
  Hsat2=Modelica.Media.Air.MoistAir.xsaturation_pT(p=pA2, T=TAir2);
  pA2=pAmbient;
  (1/4186.8)*hAir2=(1/4186.8)*hAir1+(mWater1/mAir1)*((TAir2C*(9/5)+32)-(TAir1C*(9/5)+32));

//VAPOUR
  Tvap=TvapC+273.15;
  hvap=hfg+Cpv*(TvapC);
  Tvap=TAir2;

//PRESSURE DROP CONSIDERED
  rhoMed=(1/((1/rho1)+(1/rho2)));
  pA1 - pA2 = IncP;
  IncP=(5/3)*(((Kfi*hfi*mMed^2)/(2*rhoMed*Afr^2))+((6.5*mMed^2)/(2*rhoMed*Afr^2)));
  //IncP=Modelica.Constants.small;

//AIR MASS BALANCE
  mMed=(mAir1+mAir2)/2;
  mAir1=mDAir1+mVap1;
  H1=mVap1/mDAir1;

  mAir2=mDAir2+mVap2;
  H2=mVap2/mDAir2;

  mAir1+mEvap=mAir2;
  mDAir1=mDAir2;

//AIR ENERGY BALANCE
  Qsen=mDAir1*(Cpa+H1*Cpv)*(TAir2C-TAir1C);
  Qlat=mEvap*hvap;
  //Qtot=mAir2*hAir2-mAir1*hAir1;
  Qtot=Qsen+Qlat;

//WATER MASS BALANCE
  mWater1=mWater2+mEvap;

//WATER ENERGY BALANCE
  Qtot=mWater1*hW1-mWater2*hW2;

//DESIGN PARAMETERS
  C_s=(hsw1-hsw2)/(TWater1C-TWater2C);
  m_ratio=(mAir1/mWater1)*(C_s/Cpw);
  //NTU=c*((mAir1/mWater1)^(-(1+n)));
  e_a=(1-exp(-NTU*(1-m_ratio)))/(1-m_ratio*exp(-NTU*(1-m_ratio)));
  //TAir1 in C
  //Qtot=e_a*mAir1*(hsw1-Cpa*(TAir1C));
  Qtot=e_a*mAir1*(hsw1-hAir1);

    annotation (Placement(transformation(extent={{100,-10},{120,10}})),
              Documentation(info="<html>
<p>This component is used to obtain the values of the characteristic parameters of the cooling tower &QUOT;n&QUOT; and &QUOT;c&QUOT;. </p>
<p><br><p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p></p>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"), Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
            {100,100}})));
end CalibrationComponentData;
