within DCOL.Generation.CoolingTowers.CalibrationComponents;
model CalibrationComponent

  BaseClasses.CalibrationComponentData  calibrationComponentData(
    mWater1=mWater1_1,
    TWater1C=TWater1C_1,
    TWater2C=TWater2C_1,
    mAir1=mAir1_1,
    TAir1C=TAir1C_1,
    H1=H1_1,
    pAmbient=pAmbient_1) annotation (Placement(transformation(extent={{-80,40},
            {-40,80}})));

  BaseClasses.CalibrationComponentData  calibrationComponentData1(
    mWater1=mWater1_2,
    TWater1C=TWater1C_2,
    TWater2C=TWater2C_2,
    mAir1=mAir1_2,
    TAir1C=TAir1C_2,
    H1=H1_2,
    pAmbient=pAmbient_2) annotation (Placement(transformation(extent={{-80,-40},{-40,-80}})));

  BaseClasses.CalibrationComponentEquation calibrationComponentEquation annotation (Placement(transformation(extent={{6,-42},{66,38}})));

  Modelica.Blocks.Interfaces.RealOutput c annotation (Placement(transformation(
          extent={{100,30},{120,50}}), iconTransformation(extent={{100,40},{140,
            80}})));

  Modelica.Blocks.Interfaces.RealOutput n annotation (Placement(transformation(
          extent={{100,-60},{120,-40}}), iconTransformation(extent={{100,-80},{
            140,-40}})));

  parameter Modelica.SIunits.MassFlowRate mWater1_1=100 "Inlet water mass flow for the first operation point" annotation (Dialog(group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater1C_1=35 "Inlet water temperature in C for the first operation point" annotation (Dialog(group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater2C_1=29 "Outlet water temperature in C for the first operation point" annotation (Dialog(group="First Operation Point"));
  parameter Modelica.SIunits.MassFlowRate mAir1_1=48 "Inlet air mass flow for the first operation point" annotation (Dialog(group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TAir1C_1=25 "Inlet air temperature in C for the first operation point" annotation (Dialog(group="First Operation Point"));
  parameter Modelica.SIunits.MassFraction H1_1=0.0184560958649 "Inlet air absolute humidity for the first operation point" annotation (Dialog(group="First Operation Point"));
  parameter Modelica.SIunits.Pressure pAmbient_1=101325 "Ambient pressure for the first operation point" annotation (Dialog(group="First Operation Point"));

  parameter Modelica.SIunits.MassFlowRate mWater1_2=80 "Inlet water mass flow for the second operation point" annotation (Dialog(group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater1C_2=32 "Inlet water temperature in C for the second operation point" annotation (Dialog(group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater2C_2=27 "Outlet water temperature in C for the second operation point" annotation (Dialog(group="Second Operation Point"));
  parameter Modelica.SIunits.MassFlowRate mAir1_2=45 "Inlet air mass flow for the second operation point" annotation (Dialog(group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TAir1C_2=24 "Inlet air temperature in C for the second operation point" annotation (Dialog(group="Second Operation Point"));
  parameter Modelica.SIunits.MassFraction H1_2=0.0184560958649 "Inlet air absolute humidity for the second operation point" annotation (Dialog(group="Second Operation Point"));
  parameter Modelica.SIunits.Pressure pAmbient_2=101325 "Ambient pressure for the second operation point" annotation (Dialog(group="Second Operation Point"));

equation
  connect(calibrationComponentData.NTU, calibrationComponentEquation.NTU1) annotation (Line(points={{-38,66},
          {-22,66},{-22,34},{3,34}},                              color={0,0,127}));
  connect(calibrationComponentData.mAirIn, calibrationComponentEquation.mAir1) annotation (Line(points={{-38,60},
          {-24,60},{-24,22},{3,22}},                                                                                                         color={0,0,127}));
  connect(calibrationComponentData.mWaterIn, calibrationComponentEquation.mWater1) annotation (Line(points={{-38,54},
          {-38,54},{-26,54},{-26,10},{3,10}},                                                                                                    color={0,0,127}));
  connect(calibrationComponentData1.NTU, calibrationComponentEquation.NTU2) annotation (Line(points={{-38,-66},
          {-38,-66},{-22,-66},{-22,-38},{3,-38}},                     color={0,0,
          127}));
  connect(calibrationComponentEquation.c, c) annotation (Line(points={{69,10},{
          84,10},{84,40},{110,40}},
                                 color={0,0,127}));
  connect(calibrationComponentEquation.n, n) annotation (Line(points={{69,-14},
          {84,-14},{84,-50},{110,-50}},color={0,0,127}));
  connect(calibrationComponentData1.mWaterIn, calibrationComponentEquation.mWater2)
    annotation (Line(points={{-38,-54},{-26,-54},{-26,-14},{3,-14}}, color={0,0,
          127}));
  connect(calibrationComponentData1.mAirIn, calibrationComponentEquation.mAir2)
    annotation (Line(points={{-38,-60},{-24,-60},{-24,-26},{3,-26}}, color={0,0,
          127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), Icon(coordinateSystem(extent={{-100,-100},{100,
            100}},
          preserveAspectRatio=false), graphics={
                               Rectangle(extent={{-100,100},{100,-100}},
            lineColor={28,108,200}),
        Text(
          extent={{-100,30},{100,-30}},
          lineColor={0,0,255},
          textString="%name")}),
    Documentation(info="<html>
<p>This model is used for the calibration of a cooling tower; the calibration consists in giving value to two characteristic parameters (c and n). These parameters are especific for each cooilng tower, and define the heat transferred from the water to the air.</p>
<p>For the functioning of this model, it is necessary the introduction of two operation points. </p>
<p><br><p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p></p>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CalibrationComponent;
