within DCOL.Generation.CoolingTowers;
model ClosedCoolingTower
  import DCOL;
  extends DCOL.Generation.CoolingTowers.Icons.ClosedCT;

  replaceable package Medium =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
    Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Air medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium2 =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Working fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
    Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coil" annotation (choicesAllMatching = true,Dialog(tab="General", group="Materials"));

  replaceable package Material1 =
    Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the storage wall" annotation (choicesAllMatching = true,Dialog(tab="General", group="Materials"));

  outer Modelica.Fluid.System system "System wide properties";

  parameter Boolean allowFlowReversal=false
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);
  parameter Boolean homotopyInitialization=true
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Modelica.SIunits.Height hmax=0.377825 "Maximum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Height hmin=0.092075 "Minimum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_basin=5.486 "Length of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_char=2*L_basin + 2*w "Characteristic length, length of the plate" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length w=2.388 "Width of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Water basin data"));

  parameter Integer nSeg=10 "Number of section in which is divided de fill";
  parameter Integer nCoil=2 "Number of steps of each coil";
  parameter Integer nParallel=2 "Number of parallel coils in the fill";

  parameter Modelica.SIunits.Length L=5 "Length of the tube" annotation (Dialog(group="Geometric parameter of the cooling tower"));
  parameter Modelica.SIunits.Radius R_ext=0.03 "Extermal radious of the tube" annotation (Dialog(group="Geometric parameter of the cooling tower"));
  parameter Modelica.SIunits.Radius R_int=0.025 "Intermal radious of the tube" annotation (Dialog(group="Geometric parameter of the cooling tower"));

  parameter Modelica.Blocks.Interfaces.RealOutput mWaterIn=52.766 "Value for pumped water" annotation(Dialog(group="Pump data"));
  parameter Modelica.SIunits.Pressure pPumpedWater=135496.772 "Pressure of the sprayed water" annotation(Dialog(group="Pump data"));

  parameter Real c=2.3 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Real n=-0.72 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  //parameter Real NTU=0.74164 "Number of Transfer Units of the tower" annotation (Dialog(group="Characteristic parameters of the cooling tower"));
  parameter Modelica.SIunits.Height roughness=2.5e-5 "Average height of surface asperities (default: smooth steel pipe)" annotation(Dialog(group="Properties of the cooled water pipe"));
  parameter Real a=1000 "Coefficient for quadratic term of the pressure drop" annotation(Dialog(group="Coefficient for the calculation of the pressure drop in the pipe"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coefficient for the calculation of the pressure drop in the pipe"));

  parameter Modelica.SIunits.Diameter d_a=0.02505 "Diameter at the entrace of the sprayer" annotation(Dialog(group="Sprayer properties"));
  parameter Modelica.SIunits.Diameter d_b=0.025 "Diameter at the exit of the sprayer" annotation(Dialog(group="Sprayer properties"));

  parameter Real Kfi=3.5 "Loss coefficient in the fill" annotation(Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=3 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.388 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.486 "Length of the filter" annotation (Dialog(group="Geometric properties"));

  //START VALUES
  parameter Modelica.SIunits.Temperature TWater2_start=293.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=307.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature T_start_coil= 293.15 "Start temperature for the average temperature of cylinder" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature TMaterial_start=293.15  "start temperature of the material of the coil" annotation(Dialog(tab = "Initialization"));

  DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents.ClosedHTX
    heatExchangerThroughReal(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    redeclare package Medium2 = Medium2,
    redeclare package Material = Material,
    allowFlowReversal=allowFlowReversal,
    homotopyInitialization=homotopyInitialization,
    nSeg=nSeg,
    nCoil=nCoil,
    nParallel=nParallel,
    L=L,
    R_ext=R_ext,
    R_int=R_int,
    roughness=roughness,
    Kfi=Kfi,
    hfi=hfi,
    wfi=wfi,
    lfi=lfi,
    a=a,
    b=b,
    TWater2_start=TWater2_start,
    TAir2_start=TAir2_start,
    H2_start=H2_start,
    T_start_coil=T_start_coil,
    TMaterial_start=TMaterial_start,
    c=c,
    n=n) annotation (Placement(transformation(extent={{-10,14},{70,94}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_air(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Inlet air fluid connector a (positive design flow direction is from port_a_air to port_b_air)" annotation (Placement(transformation(extent={{99,-44},{119,-24}}),
        iconTransformation(extent={{99,-44},{119,-24}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_air(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Outlet air fluid connector b (positive design flow direction is from port_a_air to port_b_air)" annotation (Placement(transformation(extent={{40,92},{60,112}}),
        iconTransformation(extent={{40,92},{60,112}})));

  Modelica.Fluid.Vessels.OpenTank waterBasin(
    redeclare package Medium = Medium,
    nPorts=3,
    use_HeatTransfer=true,
    crossArea=w*L_basin,
    heatTransfer(surfaceAreas={w*L_basin+2*(w+L_basin)*waterBasin.level}),
    use_portsData=true,
    portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.5),
               Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.5),
               Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=
               (L_basin*w)/(2*(w + L_basin)), height=hmax)},height=hmax) annotation (Placement(transformation(extent={{-46,-20},
            {-6,20}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Plate.NaturalConvectionVerticalPlateVariableArea naturalConvectionVerticalPlate(L=L_char, Tc(start=TWater2_start))
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={-90,70})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_floor
    "Heat Losses of the WaterBasin to the floor" annotation (Placement(
        transformation(extent={{-10,-110},{10,-90}}), iconTransformation(extent=
           {{-5,-105},{5,-95}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Cwater(
    redeclare package Medium = Medium2,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Inlet cooling water fluid connector a (positive design flow direction is from port_a_Cwater to port_b_Cwater)" annotation (Placement(transformation(extent={{90,30},{110,50}}),
        iconTransformation(extent={{90,30},{110,50}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_Cwater(
    redeclare package Medium = Medium2,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Outlet cooling water fluid connector b (positive design flow direction is from port_a_Cwater to port_b_Cwater)" annotation (Placement(transformation(extent={{90,-10},{110,10}}),
        iconTransformation(extent={{90,-10},{110,10}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Owater(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default)) "Overflow water fluid connector a" annotation (Placement(transformation(extent={{-100,
            -70},{-80,-50}}), iconTransformation(extent={{-100,-70},{-80,-50}})));

  DCOL.Generation.CoolingTowers.BaseClasses.WaterSpray waterSpray(
    redeclare package Medium = Medium,
    d_a=d_a,
    d_b=d_b) annotation (Placement(transformation(extent={{-40,80},{-20,100}})));

  Modelica.Fluid.Machines.ControlledPump pump(p_b_nominal=pPumpedWater,
    redeclare package Medium = Medium,
    allowFlowReversal=allowFlowReversal,
    use_m_flow_set=true,
    m_flow_nominal=mWaterIn,
    V=0.01,
    massDynamics=Modelica.Fluid.Types.Dynamics.DynamicFreeInitial,
    T_start=TWater2_start + 5,
    p_a_nominal=system.p_ambient)
                               annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-50,50})));

  Modelica.Blocks.Sources.RealExpression realExpression(y=mWaterIn) annotation (Placement(transformation(extent={{-84,35},
            {-64,55}})));

  Modelica.Blocks.Sources.RealExpression A(
    y=2*w*waterBasin.level + 2*L_basin*waterBasin.level) "Area of the wet walls of the tank" annotation (Placement(transformation(extent={{-52,62},
            {-72,82}})));

  DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.WaterBasinWall
    storageWall(
    redeclare package Material = Material1,
    h=hmax,
    w=w,
    l=L_basin,
    e=e) annotation (Placement(transformation(extent={{-100,-18},{-60,22}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_ambient
    "Heat Losses of the WaterBasin to the ambient" annotation (Placement(
        transformation(extent={{-100,80},{-80,100}}), iconTransformation(extent=
           {{-100,65},{-90,75}})));

  Modelica.Blocks.Interfaces.RealOutput level=waterBasin.level
    "Level of the water in the waterBasin"                     annotation (Placement(transformation(extent={{100,-70},
            {120,-50}}), iconTransformation(extent={{100,-70},{120,-50}})));

initial equation
  waterBasin.level = 0.5*hmax;
  waterBasin.medium.T = system.T_start;

equation
  connect(heatExchangerThroughReal.port_b_air, port_b_air) annotation (Line(points={{50,90},{50,96},{50,102}}, color={0,127,255}));
  connect(heatExchangerThroughReal.port_a_Cwater, port_a_Cwater) annotation (
      Line(points={{70.8,74},{70.8,74},{84,74},{84,40},{100,40}}, color={0,127,
          255}));
  connect(heatExchangerThroughReal.port_b_Cwater, port_b_Cwater) annotation (
      Line(points={{70,34},{80,34},{80,0},{100,0}}, color={0,127,255}));
  connect(heatExchangerThroughReal.port_a_air, port_a_air) annotation (Line(
        points={{50,18},{50,-34},{106,-34},{110,-34},{109,-34}}, color={0,127,
          255}));
  connect(realExpression.y, pump.m_flow_set) annotation (Line(points={{-63,45},{
          -63,45},{-58.2,45}},                                                               color={0,0,127}));
  connect(waterBasin.ports[2],port_a_Owater)  annotation (Line(points={{-26,-20},
          {-26,-20},{-26,-60},{-90,-60}},                                                                                      color={0,127,255}));
  connect(waterBasin.heatPort, storageWall.T_water) annotation (Line(points={{-46,0},{-46,
          0},{-80,0}},                                                                                 color={191,0,0}));
  connect(storageWall.ambient, naturalConvectionVerticalPlate.solid) annotation (Line(points={{-59.2,20.4},{-59.2,30},{-90,30},{-90,60}}, color={
          191,0,0}));
  connect(naturalConvectionVerticalPlate.fluid, port_a_ambient) annotation (Line(points={{-90,80},{-90,85},{-90,90}}, color={191,0,0}));
  connect(storageWall.floor, port_a_floor) annotation (Line(points={{-80,-24},{
          -80,-40},{0,-40},{0,-100}}, color={191,0,0}));
  connect(A.y, naturalConvectionVerticalPlate.A) annotation (Line(points={{-73,72},
          {-76,72},{-76,54},{-83,54},{-83,60}}, color={0,0,127}));
  connect(waterBasin.ports[1], pump.port_a) annotation (Line(points={{-31.3333,
          -20},{-31.3333,-20},{-31.3333,-30},{-50,-30},{-50,40}},
                                              color={0,127,255}));
  connect(pump.port_b, waterSpray.port_a) annotation (Line(points={{-50,60},{-50,
          60},{-50,90},{-40,90}}, color={0,127,255}));
  connect(waterSpray.port_b, heatExchangerThroughReal.port_a_water) annotation (Line(points={{-20,90},{10,90}}, color={0,127,255}));
  connect(heatExchangerThroughReal.port_b_water, waterBasin.ports[3]) annotation (Line(points={{10,18},
          {10,18},{10,-30},{-20.6667,-30},{-20.6667,-20}},
        color={0,127,255}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), Icon(coordinateSystem(preserveAspectRatio=false,
          extent={{-100,-100},{100,100}})),
    Documentation(info="<html>
<p>This model represents a complete closed cooling tower.</p>
<p>In this type of cooling tower both sprayed water and air are used to cool a fluid that flows through a pipe in the tower. The sprayed water extracts the heat of the chilled fluid, when being in contact with the external layer of the pipe; at the same time the air is heated when contacting the sprayed water (sensible heat and latent heat is transferred to the air). There is a water basin at the bottom of the tower, where the chilled water is storaged. The tower is divided in nSeg segments.</p>
<h4>Assumptions</h4>
<ul>
<li>The chilled fluid flows through a pipe;</li>
<li>Some sprayed water is evaporated during the cooling process;</li>
<li>The pressure drop of both the air and the chilled fluid is considered, the pressure drop of the chilled water requires the parameters &QUOT;a&QUOT; (Coefficient of the quadratic term) and &QUOT;b&QUOT; (Coefficient for the lineal term);</li>
<li>All the heat is transferred from the chilled fluid to the water and to the air, heat losses during the water cooling are not considered;</li>
<li>The NTU (Number of Transfer Units) is used to calculate the amount of heat transferred from the sprayed water to the air. NTU is given by the n anc c design parameters of the tower;</li>
<li>The heat transferred from the chilled fluid to the sprayed water is defined by the model &QUOT;SympleCylinder&QUOT; from the Thermal library. This allows to use the thermal properties of the pipe by selecting its material.</li>
</ul>
<h4>Use</h4>
<p>The air blower has been supposed to be located at the entrace of the tower, so the mass flow source is shoul be connected to the por_a_air. </p>
<p>All the air, the cooling water and the sprayed water flows are from port_a to port_b.</p>
<h4>References</h4>
<ul>
<li>Lu, L. and Cai, W., &QUOT;A Universal Engineering Model For Cooling Towers&QUOT; (2002). International Refrigeration and Air Conditioning, Conference. Paper 625.;</li>
<li>Li, Xiao; Li, Yaoyu; and Seem, John E., &QUOT;Dynamic Modeling of Mechanical Draft Counter-Flow Wet Cooling Tower with Modelica&QUOT;(2010). International Refrigeration and Air Conditioning Conference. Paper 1094.;</li>
<li>Baker, Donald. R and Shryock, Howard A., &QUOT;A Compresive Aproach To The Analysis Of Cooling Tower Performance&QUOT; (2013). SPX Corporation. Thermal Science.;</li>
<li>http://che.sharif.edu/~heatlab/Lab/Benefit&percnt;20Book&percnt;20&AMP;&percnt;20Journal/Benefit&percnt;20book/Cooling&percnt;20Tower&percnt;20Thermal&percnt;20Design&percnt;20Manual.pdf;</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end ClosedCoolingTower;
