within DCOL.Generation.CoolingTowers.Experiments;
model CompleteCCT
  import DCOL;

  parameter Modelica.SIunits.Temperature T_in_wat=35+273.15;
  parameter Modelica.SIunits.Temperature T_floor=15+273.15;
  parameter Modelica.SIunits.Temperature T_in_air=26.5+273.15;

  parameter Modelica.SIunits.MassFlowRate mflow_in_wat=13.440411;
  parameter Modelica.SIunits.MassFlowRate mflow_out_air=57.3619;

  DCOL.Generation.CoolingTowers.ClosedCoolingTower_inertia closedCTPressureDrop(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel,
    R_ext=0.03,
    R_int=0.025,
    nParallel=2,
    H2_start=0.02,
    C_iner=1000,
    redeclare package Material1 = Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel,
    nSeg=10,
    nCoil=4,
    TAir2_start=293.15,
    T_start_coil=308.15)
    annotation (Placement(transformation(extent={{-54,-40},{26,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T airIn(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=true,
    m_flow=48,
    X={0.007713153,(1 - 0.007713153)},
    use_m_flow_in=true,
    nPorts=1,
    use_X_in=true,
    T=298.15) annotation (Placement(transformation(extent={{87,-40},{67,-20}})));

  Modelica.Fluid.Sources.FixedBoundary airOut(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{80,60},{60,80}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-70,70},
            {-50,90}})));

  Modelica.Fluid.Sources.MassFlowSource_T cWaterIn(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=13.440411,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    T=313.15) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={60,30})));

  Modelica.Fluid.Sources.FixedBoundary cWaterOut(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{10,-10},{-10,10}},
        rotation=0,
        origin={88,0})));

  Modelica.Fluid.Sensors.Temperature T_Cwat_out(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{64,6},{74,16}})));

  Modelica.Fluid.Sensors.Temperature T_air_out(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{34,76},{46,86}})));
  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floor_temperature(T=298.15)
    annotation (Placement(transformation(extent={{-40,-70},{-20,-50}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature T_ambient annotation (Placement(transformation(extent={{-80,18},
            {-60,38}})));

  Modelica.Fluid.Sources.MassFlowSource_T waterOverFlow(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    use_m_flow_in=true) annotation (Placement(transformation(extent={{-80,-34},{-60,-14}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
      m_Out=0, m_In=1)
    annotation (Placement(transformation(extent={{0,-100},{-20,-80}})));

  Modelica.Blocks.Noise.TruncatedNormalNoise Tw_in(
    y_min=20 + 273.15,
    y_max=50 + 273.15,
    samplePeriod(displayUnit="min") = 1800)
    annotation (Placement(transformation(extent={{118,30},{110,38}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/Tw_in.samplePeriod,
    xr_start=Tw_in.mu,
    y_start=Tw_in.mu)
    annotation (Placement(transformation(extent={{98,30},{90,38}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise mw_in(
    y_min=mflow_in_wat*0.5,
    y_max=mflow_in_wat*1.5,
    samplePeriod(displayUnit="min") = 60)
    annotation (Placement(transformation(extent={{116,44},{108,52}})));
  Modelica.Blocks.Continuous.LowpassButterworth mw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/mw_in.samplePeriod,
    xr_start=mw_in.mu,
    y_start=mw_in.mu)
    annotation (Placement(transformation(extent={{98,44},{90,52}})));
  Modelica.Blocks.Continuous.LowpassButterworth ma_out_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/ma_out.samplePeriod,
    xr_start=ma_out.mu,
    y_start=ma_out.mu)
    annotation (Placement(transformation(extent={{120,-10},{112,-2}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise ma_out(
    samplePeriod(displayUnit="h") = 3600,
    y_min=0,
    y_max=50)
    annotation (Placement(transformation(extent={{138,-10},{130,-2}})));
  Modelica.Blocks.Continuous.LowpassButterworth No_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/No_in.samplePeriod,
    xr_start=No_in.mu,
    y_start=No_in.mu)
    annotation (Placement(transformation(extent={{-78,2},{-86,10}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise No_in(
    samplePeriod(displayUnit="min") = 300,
    y_min=0 + 273.15,
    y_max=40 + 273.15)
    annotation (Placement(transformation(extent={{-62,2},{-70,10}})));
  Modelica.Fluid.Sensors.Temperature T_Cwat_in(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{34,34},{46,44}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air1(redeclare package Medium =
        Modelica.Media.Air.MoistAir)                        annotation (Placement(transformation(extent={{59,-35},
            {49,-25}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air2(redeclare package Medium =
        Modelica.Media.Air.MoistAir)                        annotation (Placement(transformation(extent={{5,-5},{
            -5,5}},
        rotation=-90,
        origin={6,56})));
  Modelica.Fluid.Sensors.Temperature T_air_in(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{46,-14},{58,-4}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise No_in1(
    samplePeriod(displayUnit="min") = 300,
    y_min=-1,
    y_max=1)
    annotation (Placement(transformation(extent={{170,84},{162,92}})));
  Modelica.Blocks.Continuous.LowpassButterworth No_in_filter1(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/No_in.samplePeriod,
    xr_start=No_in.mu,
    y_start=No_in.mu)
    annotation (Placement(transformation(extent={{154,84},{146,92}})));
  Modelica.Blocks.Math.Sum Ta_IN(nin=2)
    annotation (Placement(transformation(extent={{116,70},{108,62}})));
  Modelica.Blocks.Sources.RealExpression Sum(y=(T_Cwat_in.T + 0 + 273.15)/2)
    annotation (Placement(transformation(extent={{148,44},{128,64}})));
  Modelica.Blocks.Math.Product product
    annotation (Placement(transformation(extent={{132,80},{124,88}})));
  Modelica.Blocks.Sources.RealExpression aper(y=(T_Cwat_in.T - (0 + 273.15))/2)
    annotation (Placement(transformation(extent={{162,60},{142,80}})));
  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{121,-59},
            {112,-50}})));
  Modelica.Blocks.Continuous.LowpassButterworth Xa_filter1(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/Xa_1.samplePeriod,
    xr_start=Xa_1.mu,
    y_start=Xa_1.mu)
    annotation (Placement(transformation(extent={{138,-48},{130,-40}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Xa_1(
    y_min=0.015,
    y_max=0.025,
    samplePeriod(displayUnit="h") = 10800)
    annotation (Placement(transformation(extent={{158,-48},{150,-40}})));
  Modelica.Blocks.Math.Sum Xa_2(nin=2)
    annotation (Placement(transformation(extent={{104,-50},{96,-58}})));
  Modelica.Blocks.Sources.RealExpression Sum2(y=1)
    annotation (Placement(transformation(extent={{132,-78},{112,-58}})));
equation
  connect(waterOverFlow.ports[1],closedCTPressureDrop.port_a_Owater)  annotation (Line(points={{-60,-24},
          {-50,-24}},                                                                                                color={0,127,255}));
  connect(cWaterIn.ports[1], closedCTPressureDrop.port_a_Cwater) annotation (
      Line(points={{50,30},{34,30},{34,16},{26,16}},         color={0,127,255}));
  connect(closedCTPressureDrop.port_b_Cwater, cWaterOut.ports[1]) annotation (
      Line(points={{26,0},{78,0}},                 color={0,127,255}));
  connect(T_Cwat_out.port, closedCTPressureDrop.port_b_Cwater)
    annotation (Line(points={{69,6},{69,0},{26,0}}, color={0,127,255}));
  connect(floor_temperature.port, closedCTPressureDrop.port_a_floor)
    annotation (Line(points={{-20,-60},{-14,-60},{-14,-40}}, color={191,0,0}));
  connect(T_ambient.port, closedCTPressureDrop.port_a_ambient) annotation (Line(points={{-60,28},
          {-52,28}},                                                                                        color={191,0,0}));
  connect(closedCTPressureDrop.level, levelControl.level) annotation (Line(
        points={{30,-24},{40,-24},{40,-90},{2,-90}}, color={0,0,127}));
  connect(waterOverFlow.m_flow_in, levelControl.m_outflow) annotation (Line(
        points={{-80,-16},{-86,-16},{-86,-90},{-21,-90}}, color={0,0,127}));
  connect(Tw_in.y, Tw_in_filter.u)
    annotation (Line(points={{109.6,34},{98.8,34}},  color={0,0,127}));
  connect(mw_in.y, mw_in_filter.u)
    annotation (Line(points={{107.6,48},{98.8,48}},  color={0,0,127}));
  connect(ma_out.y, ma_out_filter.u)
    annotation (Line(points={{129.6,-6},{120.8,-6}}, color={0,0,127}));
  connect(No_in.y, No_in_filter.u)
    annotation (Line(points={{-70.4,6},{-77.2,6}},     color={0,0,127}));
  connect(mw_in_filter.y, cWaterIn.m_flow_in) annotation (Line(points={{89.6,48},
          {80,48},{80,38},{70,38}}, color={0,0,127}));
  connect(Tw_in_filter.y, cWaterIn.T_in)
    annotation (Line(points={{89.6,34},{72,34}}, color={0,0,127}));
  connect(T_Cwat_in.port, closedCTPressureDrop.port_a_Cwater) annotation (Line(
        points={{40,34},{40,30},{34,30},{34,16},{26,16}}, color={0,127,255}));
  connect(ma_out_filter.y, airIn.m_flow_in) annotation (Line(points={{111.6,-6},
          {98,-6},{98,-22},{87,-22}}, color={0,0,127}));
  connect(closedCTPressureDrop.port_b_air, massFlow_Air2.port_a)
    annotation (Line(points={{6,40.8},{6,51}}, color={0,127,255}));
  connect(massFlow_Air2.port_b, airOut.ports[1])
    annotation (Line(points={{6,61},{6,70},{60,70}}, color={0,127,255}));
  connect(massFlow_Air2.port_b, T_air_out.port) annotation (Line(points={{6,61},
          {6,70},{40,70},{40,76}}, color={0,127,255}));
  connect(airIn.ports[1], massFlow_Air1.port_a)
    annotation (Line(points={{67,-30},{59,-30}}, color={0,127,255}));
  connect(massFlow_Air1.port_b, closedCTPressureDrop.port_a_air) annotation (
      Line(points={{49,-30},{42,-30},{42,-13.6},{29.6,-13.6}}, color={0,127,255}));
  connect(T_air_in.port, closedCTPressureDrop.port_a_air) annotation (Line(
        points={{52,-14},{34,-14},{34,-13.6},{29.6,-13.6}}, color={0,127,255}));
  connect(No_in1.y, No_in_filter1.u)
    annotation (Line(points={{161.6,88},{154.8,88}},   color={0,0,127}));
  connect(Sum.y, Ta_IN.u[2]) annotation (Line(points={{127,54},{120,54},{120,66},
          {116.8,66},{116.8,65.6}},      color={0,0,127}));
  connect(product.u1, No_in_filter1.y) annotation (Line(points={{132.8,86.4},{
          139.4,86.4},{139.4,88},{145.6,88}},    color={0,0,127}));
  connect(product.y, Ta_IN.u[1]) annotation (Line(points={{123.6,84},{120,84},{
          120,66.4},{116.8,66.4}},  color={0,0,127}));
  connect(product.u2, aper.y) annotation (Line(points={{132.8,81.6},{132.8,82},
          {136,82},{136,70},{141,70}},    color={0,0,127}));
  connect(T_ambient.T, No_in_filter.y) annotation (Line(points={{-82,28},{-96,
          28},{-96,6},{-86.4,6}}, color={0,0,127}));
  connect(No_in_filter.y, airIn.T_in) annotation (Line(points={{-86.4,6},{-96,6},
          {-96,-80},{66,-80},{66,-40},{98,-40},{98,-26},{89,-26}}, color={0,0,
          127}));
  connect(Xa_1.y,Xa_filter1. u)
    annotation (Line(points={{149.6,-44},{138.8,-44}}, color={0,0,127}));
  connect(Xa_filter1.y,gain. u) annotation (Line(points={{129.6,-44},{124,-44},
          {124,-54.5},{121.9,-54.5}},color={0,0,127}));
  connect(gain.y,Xa_2. u[1]) annotation (Line(points={{111.55,-54.5},{108.775,
          -54.5},{108.775,-53.6},{104.8,-53.6}},
                                         color={0,0,127}));
  connect(Xa_2.u[2],Sum2. y) annotation (Line(points={{104.8,-54.4},{108,-54.4},
          {108,-68},{111,-68}},color={0,0,127}));
  connect(Xa_filter1.y, airIn.X_in[1]) annotation (Line(points={{129.6,-44},{
          106,-44},{106,-34},{89,-34}}, color={0,0,127}));
  connect(Xa_2.y, airIn.X_in[2]) annotation (Line(points={{95.6,-54},{94,-54},{
          94,-34},{89,-34}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{120,100}})), Icon(coordinateSystem(extent={{-100,-100},{
            120,100}})),
    experiment(
      StopTime=86400,
      __Dymola_fixedstepsize=0.1,
      __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>Test to show how the variation of the inlet air mass flow affects to the Closed Cooling Tower.</p>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteCCT;
