within DCOL.Generation.CoolingTowers.Experiments;
model CompleteCCT_controlled
  import DCOL;

  parameter Modelica.SIunits.Temperature T_in_wat=35+273.15;
  parameter Modelica.SIunits.Temperature T_floor=15+273.15;
  parameter Modelica.SIunits.Temperature T_in_air=26.5+273.15;

  parameter Modelica.SIunits.MassFlowRate mflow_in_wat=13.440411;
  parameter Modelica.SIunits.MassFlowRate mflow_out_air=57.3619;

  //Sensors
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Cwat_in(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{54,26},{46,34}})));

  Modelica.Fluid.Sensors.Temperature T_Cwat_in(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{34,34},{46,44}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_Cwat_out(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{36,-4},
            {44,4}})));

  Modelica.Fluid.Sensors.Temperature T_Cwat_out(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{46,6},{
            54,14}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_air_in(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{56,-32},
            {48,-24}})));

  Modelica.Fluid.Sensors.Temperature T_air_in(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{46,-14},{58,-4}})));

  Modelica.Fluid.Sensors.Pressure p_air_in(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{56,-14},
            {64,-6}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_air_out(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(
        extent={{4,-4},{-4,4}},
        rotation=-90,
        origin={6,56})));

  Modelica.Fluid.Sensors.Temperature T_air_out(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{10,76},
            {20,84}})));

  Modelica.Fluid.Sensors.Pressure p_air_out(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{2,76},{10,84}})));

  DCOL.Generation.CoolingTowers.ClosedCoolingTower_controlled closedCTPressureDrop(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.Copper,
    R_ext=0.03,
    R_int=0.025,
    nParallel=2,
    H2_start=0.02,
    nSeg=10,
    nCoil=2,
    C_iner=1000,
    redeclare package Material1 = Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel,
    TAir2_start=293.15,
    T_start_coil=308.15) annotation (Placement(transformation(extent={{-52,-38},
            {28,42}})));

  Modelica.Fluid.Sources.Boundary_pT airIn(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=true,
    X={0.007713153,(1 - 0.007713153)},
    nPorts=1,
    use_X_in=true,
    T=298.15) annotation (Placement(transformation(extent={{87,-38},{67,-18}})));

  Modelica.Fluid.Sources.FixedBoundary airOut(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{40,60},{20,80}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-70,70},
            {-50,90}})));

  Modelica.Fluid.Sources.MassFlowSource_T cWaterIn(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=13.440411,
    use_m_flow_in=true,
    use_T_in=true,
    T=313.15,
    nPorts=1) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={70,30})));

  Modelica.Fluid.Sources.FixedBoundary cWaterOut(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{10,-10},{-10,10}},
        rotation=0,
        origin={76,0})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floor_temperature(T=T_floor) annotation (Placement(transformation(extent={{18,-70},{-2,-50}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature T_ambient annotation (Placement(transformation(extent={{-80,18},
            {-60,38}})));

  Modelica.Fluid.Sources.MassFlowSource_T waterOverFlow(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    use_m_flow_in=true) annotation (Placement(transformation(extent={{-80,-34},{-60,-14}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
     m_Out=0,
     m_In=1,
    hmax=0.377825)
             annotation (Placement(transformation(extent={{0,-100},{-20,-80}})));

  Modelica.Blocks.Noise.TruncatedNormalNoise mw_in(
    y_min=mflow_in_wat*0.5,
    y_max=mflow_in_wat*1.5,
    samplePeriod(displayUnit="h") = 21600)
                                          annotation (Placement(transformation(extent={{120,44},{112,52}})));

  Modelica.Blocks.Continuous.LowpassButterworth mw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/mw_in.samplePeriod,
    xr_start=mw_in.mu,
    y_start=mw_in.mu) annotation (Placement(transformation(extent={{100,44},{92,52}})));

  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{121,-59},
            {112,-50}})));

  Modelica.Blocks.Continuous.LowpassButterworth phi_filter1(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/phi_1.samplePeriod,
    xr_start=phi_1.mu,
    y_start=phi_1.mu)
    annotation (Placement(transformation(extent={{138,-34},{130,-26}})));

  Modelica.Blocks.Noise.TruncatedNormalNoise phi_1(
    samplePeriod(displayUnit="h") = 10800,
    y_max=0.90,
    y_min=0.50)
    annotation (Placement(transformation(extent={{158,-34},{150,-26}})));

  Modelica.Blocks.Math.Sum Xa_2(nin=2) annotation (Placement(transformation(extent={{104,-50},{96,-58}})));

  Modelica.Blocks.Sources.RealExpression Sum2(y=1) annotation (Placement(transformation(extent={{132,-78},{112,-58}})));

  Modelica.Blocks.Sources.RealExpression Tref(y=min(T_refer_filter.y + 273.15,
        T_Cwat_in.T) - 0.5) annotation (Placement(transformation(extent={{-80,-54},{-60,-34}})));

  Modelica.Blocks.Continuous.LowpassButterworth T_refer_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/T_refer.samplePeriod,
    xr_start=T_refer.mu,
    y_start=T_refer.mu)
    annotation (Placement(transformation(extent={{-60,-60},{-52,-52}})));

  Modelica.Blocks.Noise.TruncatedNormalNoise T_refer(
    samplePeriod(displayUnit="h") = 21600,
    y_min=20,
    y_max=45) annotation (Placement(transformation(extent={{-80,-60},{-72,-52}})));

  Modelica.Blocks.Noise.TruncatedNormalNoise No_In(
    y_min=-1,
    y_max=1,
    samplePeriod(displayUnit="min") = 600)
    annotation (Placement(transformation(extent={{158,78},{150,86}})));
  Modelica.Blocks.Continuous.LowpassButterworth No_In_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/No_In.samplePeriod,
    xr_start=No_In.mu,
    y_start=No_In.mu)
    annotation (Placement(transformation(extent={{138,78},{130,86}})));
  Modelica.Blocks.Math.Sum Tcw_In(nin=2)
                                        annotation (Placement(transformation(extent={{100,74},
            {92,66}})));
  Modelica.Blocks.Sources.RealExpression Sum1(y=((if T_air_in.T > 20 + 273.15
         then T_air_in.T else 20 + 273.15) + 50 + 273.15)/2)                 annotation (Placement(transformation(extent={{130,54},
            {110,74}})));
  Modelica.Blocks.Math.Product product1
                                       annotation (Placement(transformation(extent={{118,74},
            {110,82}})));
  Modelica.Blocks.Sources.RealExpression aper1(y=((50 + 273.15) - (if T_air_in.T
         > 20 + 273.15 then T_air_in.T else 20 + 273.15))/2)                    annotation (Placement(transformation(extent={{154,58},
            {134,78}})));
  Modelica.Blocks.Continuous.LowpassButterworth Ta_in_filter1(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/Ta_in1.samplePeriod,
    xr_start=Ta_in1.mu,
    y_start=Ta_in1.mu)
                      annotation (Placement(transformation(extent={{128,16},{
            120,24}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Ta_in1(
    samplePeriod(displayUnit="h") = 10800,
    y_min=0 + 273.15,
    y_max=40 + 273.15)                      annotation (Placement(transformation(extent={{148,16},
            {140,24}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/Tw_in.samplePeriod,
    xr_start=Tw_in.mu,
    y_start=Tw_in.mu) annotation (Placement(transformation(extent={{100,30},{92,
            38}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tw_in(
    y_min=20 + 273.15,
    y_max=50 + 273.15,
    samplePeriod(displayUnit="min") = 600)  annotation (Placement(transformation(extent={{120,30},
            {112,38}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise No_in(
    y_min=-1,
    y_max=1,
    samplePeriod(displayUnit="h") = 10800) annotation (Placement(transformation(extent={{160,0},
            {152,8}})));
  Modelica.Blocks.Continuous.LowpassButterworth No_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/No_in.samplePeriod,
    xr_start=No_in.mu,
    y_start=No_in.mu) annotation (Placement(transformation(extent={{140,0},{132,
            8}})));
  Modelica.Blocks.Math.Sum Ta_In(nin=2) annotation (Placement(transformation(extent={{106,-6},
            {98,-14}})));
  Modelica.Blocks.Sources.RealExpression Sum(y=(T_Cwat_in.T + 0 + 273.15)/2) annotation (Placement(transformation(extent={{132,-30},
            {112,-10}})));
  Modelica.Blocks.Math.Product product annotation (Placement(transformation(extent={{120,-4},
            {112,4}})));
  Modelica.Blocks.Sources.RealExpression aper(y=(T_Cwat_in.T - (0 + 273.15))/2) annotation (Placement(transformation(extent={{148,-20},
            {128,0}})));
  Modelica.Blocks.Sources.RealExpression AbsHumidity(y=
        DCOL.Generation.CoolingTowers.Utilities.Functions.AbsHumidity(
        system.p_ambient,
        Ta_in_filter1.y,
        phi_filter1.y))
    annotation (Placement(transformation(extent={{154,-56},{134,-36}})));
equation
  connect(waterOverFlow.ports[1],closedCTPressureDrop.port_a_Owater)  annotation (Line(points={{-60,-24},
          {-54,-24},{-54,-22},{-48,-22}},                                                                            color={0,127,255}));
  connect(floor_temperature.port, closedCTPressureDrop.port_a_floor)
    annotation (Line(points={{-2,-60},{-12,-60},{-12,-38}},  color={191,0,0}));
  connect(T_ambient.port, closedCTPressureDrop.port_a_ambient) annotation (Line(points={{-60,28},
          {-56,28},{-56,30},{-50,30}},                                                                      color={191,0,0}));
  connect(closedCTPressureDrop.level, levelControl.level) annotation (Line(
        points={{32,-18},{40,-18},{40,-90},{2,-90}}, color={0,0,127}));
  connect(waterOverFlow.m_flow_in, levelControl.m_outflow) annotation (Line(
        points={{-80,-16},{-86,-16},{-86,-90},{-21,-90}}, color={0,0,127}));
  connect(mw_in.y, mw_in_filter.u)
    annotation (Line(points={{111.6,48},{100.8,48}}, color={0,0,127}));
  connect(mw_in_filter.y, cWaterIn.m_flow_in) annotation (Line(points={{91.6,48},{86,48},{86,
          38},{80,38}},             color={0,0,127}));
  connect(T_Cwat_in.port, closedCTPressureDrop.port_a_Cwater) annotation (Line(
        points={{40,34},{40,30},{34,30},{34,18},{28,18}}, color={0,127,255}));
  connect(closedCTPressureDrop.port_b_air, massFlow_air_out.port_a)
    annotation (Line(points={{8,42.8},{8,48},{6,48},{6,52}},
                                               color={0,127,255}));
  connect(massFlow_air_out.port_b, airOut.ports[1])
    annotation (Line(points={{6,60},{6,70},{20,70}}, color={0,127,255}));
  connect(massFlow_air_out.port_b, T_air_out.port)
    annotation (Line(points={{6,60},{6,70},{15,70},{15,76}}, color={0,127,255}));
  connect(airIn.ports[1], massFlow_air_in.port_a)
    annotation (Line(points={{67,-28},{56,-28}}, color={0,127,255}));
  connect(massFlow_air_in.port_b, closedCTPressureDrop.port_a_air) annotation (Line(points={{48,-28},
          {42,-28},{42,-11.6},{31.6,-11.6}},          color={0,127,255}));
  connect(T_air_in.port, closedCTPressureDrop.port_a_air) annotation (Line(
        points={{52,-14},{34,-14},{34,-11.6},{31.6,-11.6}}, color={0,127,255}));
  connect(phi_1.y, phi_filter1.u)
    annotation (Line(points={{149.6,-30},{138.8,-30}}, color={0,0,127}));
  connect(gain.y,Xa_2. u[1]) annotation (Line(points={{111.55,-54.5},{108.775,-54.5},
          {108.775,-53.6},{104.8,-53.6}},color={0,0,127}));
  connect(Xa_2.u[2],Sum2. y) annotation (Line(points={{104.8,-54.4},{108,-54.4},
          {108,-68},{111,-68}},color={0,0,127}));
  connect(Xa_2.y, airIn.X_in[2]) annotation (Line(points={{95.6,-54},{94,-54},{94,
          -32},{89,-32}}, color={0,0,127}));
  connect(T_refer.y,T_refer_filter. u)
    annotation (Line(points={{-71.6,-56},{-60.8,-56}},
                                                    color={0,0,127}));
  connect(Tref.y, closedCTPressureDrop.T_reference) annotation (Line(points={{-59,-44},
          {-56,-44},{-56,-34},{-48,-34}},      color={0,0,127}));
  connect(p_air_in.port, massFlow_air_in.port_a)
    annotation (Line(points={{60,-14},{60,-28},{56,-28}}, color={0,127,255}));
  connect(p_air_out.port, massFlow_air_out.port_b)
    annotation (Line(points={{6,76},{6,60}}, color={0,127,255}));
  connect(cWaterIn.ports[1], massFlow_Cwat_in.port_a)
    annotation (Line(points={{60,30},{54,30}}, color={0,127,255}));
  connect(massFlow_Cwat_in.port_b, closedCTPressureDrop.port_a_Cwater)
    annotation (Line(points={{46,30},{34,30},{34,18},{28,18}}, color={0,127,255}));
  connect(closedCTPressureDrop.port_b_Cwater, massFlow_Cwat_out.port_a)
    annotation (Line(points={{28,2},{32,2},{32,0},{36,0}},
                                             color={0,127,255}));
  connect(massFlow_Cwat_out.port_b, T_Cwat_out.port)
    annotation (Line(points={{44,0},{50,0},{50,6}}, color={0,127,255}));
  connect(massFlow_Cwat_out.port_b, cWaterOut.ports[1])
    annotation (Line(points={{44,0},{66,0}}, color={0,127,255}));
  connect(Sum1.y, Tcw_In.u[2]) annotation (Line(points={{109,64},{104,64},{104,
          70},{100,70},{100,69.6},{100.8,69.6}}, color={0,0,127}));
  connect(product1.u1, No_In_filter.y) annotation (Line(points={{118.8,80.4},{
          123.4,80.4},{123.4,82},{129.6,82}}, color={0,0,127}));
  connect(product1.y, Tcw_In.u[1]) annotation (Line(points={{109.6,78},{104,78},
          {104,70.4},{100.8,70.4}}, color={0,0,127}));
  connect(product1.u2, aper1.y) annotation (Line(points={{118.8,75.6},{118.8,76},
          {130,76},{130,68},{133,68}}, color={0,0,127}));
  connect(No_In.y, No_In_filter.u)
    annotation (Line(points={{149.6,82},{138.8,82}}, color={0,0,127}));
  connect(Ta_in1.y, Ta_in_filter1.u)
    annotation (Line(points={{139.6,20},{128.8,20}}, color={0,0,127}));
  connect(Tcw_In.y, cWaterIn.T_in) annotation (Line(points={{91.6,70},{88,70},{
          88,34},{82,34}}, color={0,0,127}));
  connect(Ta_in_filter1.y, airIn.T_in) annotation (Line(points={{119.6,20},{92,
          20},{92,-24},{89,-24}}, color={0,0,127}));
  connect(Ta_in_filter1.y, T_ambient.T) annotation (Line(points={{119.6,20},{92,
          20},{92,-16},{64,-16},{64,-80},{-90,-80},{-90,28},{-82,28}}, color={0,
          0,127}));
  connect(Tw_in.y,Tw_in_filter. u)
    annotation (Line(points={{111.6,34},{100.8,34}}, color={0,0,127}));
  connect(No_in.y,No_in_filter. u)
    annotation (Line(points={{151.6,4},{140.8,4}}, color={0,0,127}));
  connect(Sum.y,Ta_In. u[2]) annotation (Line(points={{111,-20},{110,-20},{110,
          -10},{106.8,-10},{106.8,-10.4}},
                                      color={0,0,127}));
  connect(product.u1,No_in_filter. y) annotation (Line(points={{120.8,2.4},{
          125.4,2.4},{125.4,4},{131.6,4}},
                                     color={0,0,127}));
  connect(product.y,Ta_In. u[1]) annotation (Line(points={{111.6,0},{110,0},{
          110,-9.6},{106.8,-9.6}},
                                 color={0,0,127}));
  connect(product.u2,aper. y) annotation (Line(points={{120.8,-2.4},{120.8,-2},
          {122,-2},{122,-10},{127,-10}},color={0,0,127}));
  connect(AbsHumidity.y, airIn.X_in[1]) annotation (Line(points={{133,-46},{100,
          -46},{100,-32},{89,-32}}, color={0,0,127}));
  connect(AbsHumidity.y, gain.u) annotation (Line(points={{133,-46},{128,-46},{128,
          -54.5},{121.9,-54.5}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{120,100}})), Icon(coordinateSystem(extent={{-100,-100},{
            120,100}})),
    experiment(
      StopTime=604800,
      __Dymola_fixedstepsize=0.1,
      __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>Test to show how the variation of the inlet air mass flow affects to the Closed Cooling Tower.</p>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteCCT_controlled;
