within DCOL.Generation.CoolingTowers.Experiments;
model CompleteOCT
  import DCOL;

  parameter Modelica.SIunits.Temperature T_in_wat=35+273.15;
  parameter Modelica.SIunits.Temperature T_floor=15+273.15;
  parameter Modelica.SIunits.Temperature T_in_air=26.5+273.15;

  parameter Modelica.SIunits.MassFlowRate mflow_in_wat=97.259;
  parameter Modelica.SIunits.MassFlowRate mflow_out_air=57.3619;

  DCOL.Generation.CoolingTowers.OpenCoolingTower_inertia openCT2(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321,
    hmax=0.377825,
    hmin=0.092075,
    w=2.348,
    e(displayUnit="m") = 0.02,
    L_basin=7.346,
    wfi=2.348,
    lfi=7.346,
    TWater2_start=293.15)
    annotation (Placement(transformation(extent={{-40,-40},{40,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T inletWater(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=100,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    T=308.15) annotation (Placement(transformation(extent={{-60,60},{-40,80}})));

  Modelica.Fluid.Sources.MassFlowSource_T outletWater(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=-50,
    use_m_flow_in=true,
    use_T_in=false,
    nPorts=1) annotation (Placement(transformation(extent={{-60,-84},{-40,-64}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Fluid.Sources.MassFlowSource_T overflowWater(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=10,
    use_m_flow_in=true,
    nPorts=1,
    T=302.123) annotation (Placement(transformation(extent={{-60,-28},{-40,-8}})));

  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{-5,-5},
            {5,5}},
        rotation=-90,
        origin={-80,-45})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
    ambientTemperature annotation (Placement(transformation(extent={{68,-3},
            {48,17}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floorTemperature(T=T_floor)
                                                                                    annotation (Placement(transformation(extent={{24,-80},
            {4,-60}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
    hmin=0.092075,
    hmax=0.377825,
    m_Out=0,
    m_In=4)
    annotation (Placement(transformation(extent={{10,40},{-10,60}})));

  Modelica.Fluid.Sources.MassFlowSource_T outletAir(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=false,
    m_flow=-31.5258,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{60,52},{40,72}})));

  Modelica.Fluid.Sources.Boundary_pT inletAir(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=true,
    nPorts=1,
    X={0.017623194,(1 - 0.017623194)},
    use_X_in=true,
    p=101325) annotation (Placement(transformation(extent={{80,-60},{60,-40}})));

  Modelica.Blocks.Math.Gain gain1(k=-1) annotation (Placement(transformation(extent={{-5,-5},
            {5,5}},
        rotation=180,
        origin={74,70})));

  Modelica.Fluid.Sensors.Temperature T_waterOut(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{-60,-52},
            {-40,-32}})));

  Modelica.Fluid.Sensors.Temperature T_airOut(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{20,70},{40,90}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air1(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{55,-55},{45,-45}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_Water1(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(
        transformation(
        extent={{5,-5},{-5,5}},
        rotation=90,
        origin={-30,60})));
  Modelica.Blocks.Noise.TruncatedNormalNoise Tw_in(
    samplePeriod(displayUnit="min") = 1800,
    y_min=20 + 273.15,
    y_max=40 + 273.15)
    annotation (Placement(transformation(extent={{-124,60},{-116,68}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/Tw_in.samplePeriod,
    xr_start=Tw_in.mu,
    y_start=Tw_in.mu)
    annotation (Placement(transformation(extent={{-104,60},{-96,68}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise mw_in(
    samplePeriod(displayUnit="min") = 60,
    y_min=mflow_in_wat*0.5,
    y_max=mflow_in_wat*1.5)
    annotation (Placement(transformation(extent={{-124,74},{-116,82}})));
  Modelica.Blocks.Continuous.LowpassButterworth mw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/mw_in.samplePeriod,
    xr_start=mw_in.mu,
    y_start=mw_in.mu)
    annotation (Placement(transformation(extent={{-104,74},{-96,82}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise No_in(
    samplePeriod(displayUnit="min") = 300,
    y_min=-1,
    y_max=1)
    annotation (Placement(transformation(extent={{152,-8},{144,0}})));
  Modelica.Blocks.Continuous.LowpassButterworth No_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/No_in.samplePeriod,
    xr_start=No_in.mu,
    y_start=No_in.mu)
    annotation (Placement(transformation(extent={{136,-8},{128,0}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise ma_out(
    samplePeriod(displayUnit="h") = 3600,
    y_min=mflow_out_air*0.5,
    y_max=mflow_out_air*1.5)
    annotation (Placement(transformation(extent={{120,66},{112,74}})));
  Modelica.Blocks.Continuous.LowpassButterworth ma_out_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/ma_out.samplePeriod,
    xr_start=ma_out.mu,
    y_start=ma_out.mu)
    annotation (Placement(transformation(extent={{102,66},{94,74}})));
  inner Modelica.Blocks.Noise.GlobalSeed globalSeed(useAutomaticSeed=false,
      fixedSeed=161585936)                                                                       annotation (Placement(transformation(extent={{-100,
            -96},{-80,-76}})));
  Modelica.Blocks.Math.Sum Ta_IN(nin=2)
    annotation (Placement(transformation(extent={{98,-42},{90,-50}})));
  Modelica.Fluid.Sensors.Temperature T_waterIn(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-40,80},{-20,100}})));
  Modelica.Fluid.Sensors.Temperature T_airIn(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{42,-30},{62,-10}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air2(redeclare package Medium =
        Modelica.Media.Air.MoistAir)                        annotation (Placement(transformation(extent={{5,-5},{
            -5,5}},
        rotation=-90,
        origin={20,56})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Water2(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(
        transformation(
        extent={{5,-5},{-5,5}},
        rotation=90,
        origin={-30,-52})));
  Modelica.Blocks.Sources.RealExpression realExpression
    annotation (Placement(transformation(extent={{-48,-122},{-28,-102}})));
  Modelica.Blocks.Sources.RealExpression Sum(y=(T_waterIn.T + 0 + 273.15)/2)
    annotation (Placement(transformation(extent={{130,-46},{110,-26}})));
  Modelica.Blocks.Math.Product product
    annotation (Placement(transformation(extent={{114,-12},{106,-4}})));
  Modelica.Blocks.Sources.RealExpression aper(y=(T_waterIn.T - (0 + 273.15))/2)
    annotation (Placement(transformation(extent={{144,-32},{124,-12}})));
  Modelica.Blocks.Math.Gain gain2(k=-1)
                                       annotation (Placement(transformation(extent={{115,-91},
            {106,-82}})));
  Modelica.Blocks.Continuous.LowpassButterworth phi_filter1(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/phi_1.samplePeriod,
    xr_start=phi_1.mu,
    y_start=phi_1.mu)
    annotation (Placement(transformation(extent={{132,-66},{124,-58}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise phi_1(
    samplePeriod(displayUnit="h") = 10800,
    y_max=0.90,
    y_min=0.50)
    annotation (Placement(transformation(extent={{152,-66},{144,-58}})));
  Modelica.Blocks.Math.Sum Xa_2(nin=2) annotation (Placement(transformation(extent={{98,-82},
            {90,-90}})));
  Modelica.Blocks.Sources.RealExpression Sum2(y=1) annotation (Placement(transformation(extent={{126,
            -110},{106,-90}})));
  Modelica.Blocks.Sources.RealExpression AbsHumidity(y=
        DCOL.Generation.CoolingTowers.Utilities.Functions.AbsHumidity(
        system.p_ambient,
        Ta_IN.y,
        phi_filter1.y))
    annotation (Placement(transformation(extent={{148,-88},{128,-68}})));
equation

  connect(gain.y, outletWater.m_flow_in) annotation (Line(points={{-80,-50.5},{
          -80,-66},{-60,-66}},
                           color={0,0,127}));
  connect(openCT2.level, levelControl.level) annotation (Line(points={{33.3333,
          -26.6667},{40,-26.6667},{40,50},{12,50}},
                                           color={0,0,127}));
  connect(levelControl.m_outflow, overflowWater.m_flow_in) annotation (Line(
        points={{-11,50},{-70,50},{-70,-10},{-60,-10}}, color={0,0,127}));
  connect(overflowWater.ports[1],openCT2.port_a_Owater)  annotation (Line(
        points={{-40,-18},{-30,-18}},           color={0,127,255}));
  connect(openCT2.port_a_floor, floorTemperature.port) annotation (Line(points={{0,
          -33.3333},{0,-33.3333},{0,-70},{4,-70}},     color={191,0,0}));
  connect(gain1.y, outletAir.m_flow_in) annotation (Line(points={{68.5,70},{66,70},{64,
          70},{60,70}},                                                                      color={0,0,127}));
  connect(ambientTemperature.port, openCT2.port_a_ambient) annotation (Line(
        points={{48,7},{48,7},{48,6.66667},{33.3333,6.66667}}, color={191,0,0}));
  connect(inletAir.ports[1], massFlow_Air1.port_a) annotation (Line(points={{60,-50},{55,-50}}, color={0,127,255}));
  connect(massFlow_Air1.port_b, openCT2.port_a_air) annotation (Line(points={{45,-50},
          {38,-50},{38,-10},{33.3333,-10}},         color={0,127,255}));
  connect(inletWater.ports[1], massFlow_Water1.port_a) annotation (Line(points={{-40,70},{-30,70},{-30,65}}, color={0,127,255}));
  connect(massFlow_Water1.port_b, openCT2.port_a_water) annotation (Line(points=
         {{-30,55},{-30,42.5},{-30,30}}, color={0,127,255}));
  connect(Tw_in.y, Tw_in_filter.u)
    annotation (Line(points={{-115.6,64},{-104.8,64}}, color={0,0,127}));
  connect(mw_in.y, mw_in_filter.u)
    annotation (Line(points={{-115.6,78},{-104.8,78}}, color={0,0,127}));
  connect(ma_out.y, ma_out_filter.u)
    annotation (Line(points={{111.6,70},{102.8,70}}, color={0,0,127}));
  connect(mw_in_filter.y, inletWater.m_flow_in)
    annotation (Line(points={{-95.6,78},{-60,78}}, color={0,0,127}));
  connect(Tw_in_filter.y, inletWater.T_in) annotation (Line(points={{-95.6,64},
          {-70,64},{-70,74},{-62,74}}, color={0,0,127}));
  connect(mw_in_filter.y, gain.u)
    annotation (Line(points={{-95.6,78},{-80,78},{-80,-39}}, color={0,0,127}));
  connect(gain1.u, ma_out_filter.y)
    annotation (Line(points={{80,70},{93.6,70}}, color={0,0,127}));
  connect(T_waterIn.port, massFlow_Water1.port_a)
    annotation (Line(points={{-30,80},{-30,65}}, color={0,127,255}));
  connect(T_airIn.port, massFlow_Air1.port_b) annotation (Line(points={{52,-30},
          {38,-30},{38,-50},{45,-50}}, color={0,127,255}));
  connect(openCT2.port_b_air, massFlow_Air2.port_a)
    annotation (Line(points={{20,36.6667},{20,51}}, color={0,127,255}));
  connect(massFlow_Air2.port_b, outletAir.ports[1])
    annotation (Line(points={{20,61},{20,62},{40,62}}, color={0,127,255}));
  connect(T_airOut.port, massFlow_Air2.port_b) annotation (Line(points={{30,70},
          {30,62},{20,62},{20,61}}, color={0,127,255}));
  connect(openCT2.port_b_water, massFlow_Water2.port_a)
    annotation (Line(points={{-30,-30},{-30,-47}}, color={0,127,255}));
  connect(T_waterOut.port, massFlow_Water2.port_b) annotation (Line(points={{
          -50,-52},{-40,-52},{-40,-57},{-30,-57}}, color={0,127,255}));
  connect(massFlow_Water2.port_b, outletWater.ports[1]) annotation (Line(points=
         {{-30,-57},{-30,-74},{-40,-74}}, color={0,127,255}));
  connect(No_in.y, No_in_filter.u)
    annotation (Line(points={{143.6,-4},{136.8,-4}},   color={0,0,127}));
  connect(Sum.y, Ta_IN.u[2]) annotation (Line(points={{109,-36},{102,-36},{102,
          -46},{98.8,-46},{98.8,-46.4}}, color={0,0,127}));
  connect(product.u1, No_in_filter.y) annotation (Line(points={{114.8,-5.6},{
          115.4,-5.6},{115.4,-4},{127.6,-4}},    color={0,0,127}));
  connect(product.y, Ta_IN.u[1]) annotation (Line(points={{105.6,-8},{102,-8},{
          102,-45.6},{98.8,-45.6}},  color={0,0,127}));
  connect(product.u2, aper.y) annotation (Line(points={{114.8,-10.4},{114.8,-10},
          {118,-10},{118,-22},{123,-22}}, color={0,0,127}));
  connect(ambientTemperature.T, Ta_IN.y) annotation (Line(points={{70,7},{88,7},
          {88,-46},{89.6,-46}}, color={0,0,127}));
  connect(inletAir.T_in, Ta_IN.y)
    annotation (Line(points={{82,-46},{89.6,-46}}, color={0,0,127}));
  connect(phi_1.y, phi_filter1.u)
    annotation (Line(points={{143.6,-62},{132.8,-62}}, color={0,0,127}));
  connect(gain2.y, Xa_2.u[1]) annotation (Line(points={{105.55,-86.5},{102.775,
          -86.5},{102.775,-85.6},{98.8,-85.6}}, color={0,0,127}));
  connect(Xa_2.u[2],Sum2. y) annotation (Line(points={{98.8,-86.4},{102,-86.4},
          {102,-100},{105,-100}},
                               color={0,0,127}));
  connect(AbsHumidity.y, gain2.u) annotation (Line(points={{127,-78},{122,-78},
          {122,-86.5},{115.9,-86.5}}, color={0,0,127}));
  connect(AbsHumidity.y, inletAir.X_in[1]) annotation (Line(points={{127,-78},{
          100,-78},{100,-54},{82,-54}}, color={0,0,127}));
  connect(Xa_2.y, inletAir.X_in[2])
    annotation (Line(points={{89.6,-86},{82,-86},{82,-54}}, color={0,0,127}));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), experiment(StopTime=86400, __Dymola_Algorithm=
          "Cvode"),
    Documentation(info="<html>
<p>Test to show how the variation of the inlet air mass flow affects to the Open Cooling Tower.</p>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteOCT;
