within DCOL.Generation.CoolingTowers.Experiments;
model CompleteOCT_controlled
  import DCOL;

  parameter Modelica.SIunits.Temperature T_in_wat=35+273.15;
  parameter Modelica.SIunits.Temperature T_floor=15+273.15;
  parameter Modelica.SIunits.Temperature T_in_air=26.5+273.15;
  parameter Modelica.SIunits.Temperature T_ref=29+273.15;

  parameter Modelica.SIunits.MassFlowRate mflow_in_wat=97.259;
  parameter Modelica.SIunits.MassFlowRate mflow_out_air=57.3619;

  Modelica.SIunits.Temperature _T_ref_water=Tref.y;
  Modelica.SIunits.MassFlowRate _m_flow_water=massFlow_w_out.m_flow;
  Modelica.SIunits.Temperature _T_in_water=T_waterIn.T;
  Modelica.SIunits.Temperature _T_in_air=T_airIn.T;
  Real _RH_in_air=phi_filter.y;
  Modelica.SIunits.Temperature _T_out_water=T_waterOut.T;
  Modelica.SIunits.Power _P_fan=openCT2.fan.Wb_flow;
  Modelica.SIunits.Power _P_pump=pump.Wb_flow;

  //Sensors
  Modelica.Fluid.Sensors.MassFlowRate massFlow_w_in(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(
        transformation(
        extent={{5,-5},{-5,5}},
        rotation=90,
        origin={-30,60})));

  Modelica.Fluid.Sensors.Temperature T_waterIn(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{-56,80},
            {-46,90}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_w_out(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(
        transformation(
        extent={{5,-5},{-5,5}},
        rotation=90,
        origin={-30,-52})));

  Modelica.Fluid.Sensors.Temperature T_waterOut(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(transformation(extent={{-60,-60},
            {-48,-50}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_a_in(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{55,-55},{45,-45}})));

  Modelica.Fluid.Sensors.Temperature T_airIn(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{44,-30},{54,-20}})));

  Modelica.Fluid.Sensors.MassFractions Xa_in(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{24,-50},{32,-42}})));

  Modelica.Fluid.Sensors.Pressure p_air_in(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{54,-30},{62,-22}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_a_out(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(
        extent={{5,-5},{-5,5}},
        rotation=-90,
        origin={20,56})));

  Modelica.Fluid.Sensors.Temperature T_airOut(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{20,70},
            {30,80}})));

  Modelica.Fluid.Sensors.MassFractions Xa_out(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{12,68},{20,76}})));

  Modelica.Fluid.Sensors.Pressure p_air_out(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{30,70},{38,78}})));

  DCOL.Generation.CoolingTowers.OpenCoolingTower_controlled openCT2(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321,
    hmax=0.377825,
    hmin=0.092075,
    w=2.348,
    e(displayUnit="m") = 0.02,
    L_basin=7.346,
    wfi=2.348,
    lfi=7.346,
    TWater2_start=293.15)
    annotation (Placement(transformation(extent={{-40,-40},{40,40}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Fluid.Sources.MassFlowSource_T overflowWater(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=10,
    use_m_flow_in=true,
    nPorts=1,
    T=302.123) annotation (Placement(transformation(extent={{-56,-28},{-36,-8}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
    ambientTemperature annotation (Placement(transformation(extent={{68,-3},
            {48,17}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floorTemperature(T=T_floor)
                                                                                    annotation (Placement(transformation(extent={{24,-80},
            {4,-60}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
    hmin=0.092075,
    hmax=0.377825,
    m_Out=0,
    m_In=4)
    annotation (Placement(transformation(extent={{10,40},{-10,60}})));

  Modelica.Fluid.Sources.FixedBoundary outletAir(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    nPorts=1) annotation (Placement(transformation(extent={{60,52},{40,72}})));

  Modelica.Fluid.Sources.Boundary_pT inletAir(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=true,
    nPorts=1,
    X={0.017623194,(1 - 0.017623194)},
    use_X_in=true,
    p=system.p_ambient)
              annotation (Placement(transformation(extent={{80,-60},{60,-40}})));

  Modelica.Blocks.Noise.TruncatedNormalNoise Tw_in(
    y_min=20 + 273.15,
    y_max=40 + 273.15,
    samplePeriod(displayUnit="min") = 600)
    annotation (Placement(transformation(extent={{-138,44},{-130,52}})));
  Modelica.Blocks.Continuous.LowpassButterworth Tw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/Tw_in.samplePeriod,
    xr_start=Tw_in.mu,
    y_start=Tw_in.mu)
    annotation (Placement(transformation(extent={{-118,44},{-110,52}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise mw_in(
    y_min=mflow_in_wat*0.5,
    y_max=mflow_in_wat*1.5,
    samplePeriod(displayUnit="h") = 21600)
    annotation (Placement(transformation(extent={{-138,-40},{-130,-32}})));
  Modelica.Blocks.Continuous.LowpassButterworth mw_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/mw_in.samplePeriod,
    xr_start=mw_in.mu,
    y_start=mw_in.mu)
    annotation (Placement(transformation(extent={{-112,-40},{-104,-32}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise No_in(
    y_min=-1,
    y_max=1,
    samplePeriod(displayUnit="h") = 10800)
    annotation (Placement(transformation(extent={{154,-28},{146,-20}})));
  Modelica.Blocks.Continuous.LowpassButterworth No_in_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/No_in.samplePeriod,
    xr_start=No_in.mu,
    y_start=No_in.mu)
    annotation (Placement(transformation(extent={{136,-28},{128,-20}})));
  inner Modelica.Blocks.Noise.GlobalSeed globalSeed(useAutomaticSeed=false,
      fixedSeed=161585936)                                                                       annotation (Placement(transformation(extent={{-100,
            -96},{-80,-76}})));
  Modelica.Blocks.Math.Sum Ta_IN(nin=2)
    annotation (Placement(transformation(extent={{98,-42},{90,-50}})));
  Modelica.Blocks.Sources.RealExpression x_steam(y=
        DCOL.Generation.CoolingTowers.Utilities.Functions.AbsHumidity(
        system.p_ambient,
        Ta_IN.y,
        phi_filter.y))
    annotation (Placement(transformation(extent={{144,-72},{124,-52}})));
  Modelica.Blocks.Sources.RealExpression Sum(y=(T_waterIn.T + 0 + 273.15)/2)
    annotation (Placement(transformation(extent={{130,-58},{110,-38}})));
  Modelica.Blocks.Math.Product product
    annotation (Placement(transformation(extent={{114,-32},{106,-24}})));
  Modelica.Blocks.Sources.RealExpression aper(y=(T_waterIn.T - (0 + 273.15))/2)
    annotation (Placement(transformation(extent={{150,-48},{130,-28}})));
  Modelica.Blocks.Sources.RealExpression Tref(y=min(T_refer_filter.y + 273.15,
        T_waterIn.T) - 0.5)
    annotation (Placement(transformation(extent={{100,18},{80,38}})));
  Modelica.Blocks.Continuous.LowpassButterworth T_refer_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/T_refer.samplePeriod,
    xr_start=T_refer.mu,
    y_start=T_refer.mu)
    annotation (Placement(transformation(extent={{94,42},{86,50}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise T_refer(
    samplePeriod(displayUnit="h") = 21600,
    y_min=15,
    y_max=35)
    annotation (Placement(transformation(extent={{122,42},{114,50}})));
  Modelica.Fluid.Machines.ControlledPump pump(
    use_m_flow_set=true,
    V=0.01,
    massDynamics=Modelica.Fluid.Types.Dynamics.DynamicFreeInitial,
    p_a_nominal=system.p_ambient,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow_nominal=97.259,
    T_start=302.15,
    p_b_nominal=system.p_ambient + 50000)
                               annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-76,-30})));

  Modelica.Fluid.Pipes.DynamicPipe pipe_BROAD(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    length=10,
    diameter(displayUnit="mm") = 0.05,
    use_HeatTransfer=true,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (
          m_flow_nominal=97.259, dp_nominal(displayUnit="Pa") = 50000))
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-76,48})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
    prescribedTemperature
    annotation (Placement(transformation(extent={{-96,44},{-88,52}})));
  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{114,-76},
            {104,-66}})));
  Modelica.Blocks.Continuous.LowpassButterworth phi_filter(
    initType=Modelica.Blocks.Types.Init.InitialOutput,
    f=1/phi_in.samplePeriod,
    xr_start=phi_in.mu,
    y_start=phi_in.mu)
    annotation (Placement(transformation(extent={{48,-72},{40,-64}})));
  Modelica.Blocks.Noise.TruncatedNormalNoise phi_in(
    samplePeriod(displayUnit="h") = 10800,
    y_max=0.9,
    y_min=0.5)
    annotation (Placement(transformation(extent={{68,-72},{60,-64}})));
  Modelica.Blocks.Math.Sum Xa_2(nin=2)
    annotation (Placement(transformation(extent={{98,-68},{90,-76}})));
  Modelica.Blocks.Sources.RealExpression Sum2(y=1)
    annotation (Placement(transformation(extent={{126,-96},{106,-76}})));

equation

  connect(openCT2.level, levelControl.level) annotation (Line(points={{33.3333,
          -26.6667},{42,-26.6667},{42,50},{12,50}},
                                           color={0,0,127}));
  connect(levelControl.m_outflow, overflowWater.m_flow_in) annotation (Line(
        points={{-11,50},{-60,50},{-60,-10},{-56,-10}}, color={0,0,127}));
  connect(overflowWater.ports[1],openCT2.port_a_Owater)  annotation (Line(
        points={{-36,-18},{-30,-18}},           color={0,127,255}));
  connect(openCT2.port_a_floor, floorTemperature.port) annotation (Line(points={{0,
          -33.3333},{0,-33.3333},{0,-70},{4,-70}},     color={191,0,0}));
  connect(ambientTemperature.port, openCT2.port_a_ambient) annotation (Line(
        points={{48,7},{48,7},{48,6.66667},{33.3333,6.66667}}, color={191,0,0}));
  connect(inletAir.ports[1],massFlow_a_in. port_a) annotation (Line(points={{60,-50},{55,-50}}, color={0,127,255}));
  connect(massFlow_a_in.port_b, openCT2.port_a_air) annotation (Line(points={{45,-50},
          {38,-50},{38,-10},{33.3333,-10}},         color={0,127,255}));
  connect(massFlow_w_in.port_b, openCT2.port_a_water) annotation (Line(points={{
          -30,55},{-30,42.5},{-30,30}}, color={0,127,255}));
  connect(Tw_in.y, Tw_in_filter.u)
    annotation (Line(points={{-129.6,48},{-118.8,48}}, color={0,0,127}));
  connect(mw_in.y, mw_in_filter.u)
    annotation (Line(points={{-129.6,-36},{-112.8,-36}},
                                                       color={0,0,127}));
  connect(T_waterIn.port, massFlow_w_in.port_a) annotation (Line(points={{-51,80},
          {-51,72},{-30,72},{-30,65}}, color={0,127,255}));
  connect(T_airIn.port,massFlow_a_in. port_b) annotation (Line(points={{49,-30},
          {38,-30},{38,-50},{45,-50}}, color={0,127,255}));
  connect(openCT2.port_b_air, massFlow_a_out.port_a)
    annotation (Line(points={{20,36.6667},{20,51}}, color={0,127,255}));
  connect(massFlow_a_out.port_b, outletAir.ports[1])
    annotation (Line(points={{20,61},{20,62},{40,62}}, color={0,127,255}));
  connect(T_airOut.port, massFlow_a_out.port_b) annotation (Line(points={{25,70},
          {25,62},{20,62},{20,61}}, color={0,127,255}));
  connect(openCT2.port_b_water, massFlow_w_out.port_a)
    annotation (Line(points={{-30,-30},{-30,-47}}, color={0,127,255}));
  connect(T_waterOut.port, massFlow_w_out.port_b) annotation (Line(points={{-54,
          -60},{-54,-66},{-30,-66},{-30,-57}}, color={0,127,255}));
  connect(No_in.y, No_in_filter.u)
    annotation (Line(points={{145.6,-24},{136.8,-24}}, color={0,0,127}));
  connect(Sum.y, Ta_IN.u[2]) annotation (Line(points={{109,-48},{102,-48},{102,
          -46},{98.8,-46},{98.8,-46.4}}, color={0,0,127}));
  connect(product.u1, No_in_filter.y) annotation (Line(points={{114.8,-25.6},{
          115.4,-25.6},{115.4,-24},{127.6,-24}}, color={0,0,127}));
  connect(product.y, Ta_IN.u[1]) annotation (Line(points={{105.6,-28},{102,-28},
          {102,-45.6},{98.8,-45.6}}, color={0,0,127}));
  connect(product.u2, aper.y) annotation (Line(points={{114.8,-30.4},{114.8,-30},
          {118,-30},{118,-38},{129,-38}}, color={0,0,127}));
  connect(ambientTemperature.T, Ta_IN.y) annotation (Line(points={{70,7},{88,7},
          {88,-46},{89.6,-46}}, color={0,0,127}));
  connect(inletAir.T_in, Ta_IN.y)
    annotation (Line(points={{82,-46},{89.6,-46}}, color={0,0,127}));
  connect(massFlow_w_out.port_b, pump.port_a) annotation (Line(points={{-30,-57},
          {-30,-66},{-76,-66},{-76,-40}}, color={0,127,255}));
  connect(pump.port_b, pipe_BROAD.port_a)
    annotation (Line(points={{-76,-20},{-76,38}}, color={0,127,255}));
  connect(pipe_BROAD.port_b, massFlow_w_in.port_a) annotation (Line(points={{-76,
          58},{-76,72},{-30,72},{-30,65}}, color={0,127,255}));
  connect(mw_in_filter.y, pump.m_flow_set) annotation (Line(points={{-103.6,-36},
          {-104,-36},{-104,-35},{-84.2,-35}}, color={0,0,127}));
  connect(Tw_in_filter.y, prescribedTemperature.T)
    annotation (Line(points={{-109.6,48},{-96.8,48}}, color={0,0,127}));
  connect(phi_in.y, phi_filter.u)
    annotation (Line(points={{59.6,-68},{48.8,-68}}, color={0,0,127}));
  connect(gain.y, Xa_2.u[1]) annotation (Line(points={{103.5,-71},{102.775,-71},
          {102.775,-71.6},{98.8,-71.6}}, color={0,0,127}));
  connect(Xa_2.y, inletAir.X_in[2]) annotation (Line(points={{89.6,-72},{86,-72},
          {86,-54},{82,-54}}, color={0,0,127}));
  connect(Xa_2.u[2], Sum2.y) annotation (Line(points={{98.8,-72.4},{102,-72.4},
          {102,-86},{105,-86}},color={0,0,127}));
  connect(prescribedTemperature.port, pipe_BROAD.heatPorts[2]) annotation (Line(
        points={{-88,48},{-84,48},{-84,48.1},{-80.4,48.1}}, color={191,0,0}));
  connect(p_air_out.port, massFlow_a_out.port_b)
    annotation (Line(points={{34,70},{34,61},{20,61}}, color={0,127,255}));
  connect(p_air_in.port, massFlow_a_in.port_b) annotation (Line(points={{58,-30},
          {58,-36},{38,-36},{38,-50},{45,-50}}, color={0,127,255}));
  connect(T_refer.y, T_refer_filter.u)
    annotation (Line(points={{113.6,46},{94.8,46}}, color={0,0,127}));
  connect(Tref.y, openCT2.T_reference) annotation (Line(points={{79,28},{58,28},
          {58,26.6667},{36.6667,26.6667}}, color={0,0,127}));
  connect(Xa_in.port, massFlow_a_in.port_b)
    annotation (Line(points={{28,-50},{45,-50}}, color={0,127,255}));
  connect(Xa_out.port, massFlow_a_out.port_b) annotation (Line(points={{16,68},{
          18,68},{18,61},{20,61}}, color={0,127,255}));
  connect(x_steam.y, gain.u) annotation (Line(points={{123,-62},{120,-62},{120,
          -71},{115,-71}}, color={0,0,127}));
  connect(x_steam.y, inletAir.X_in[1]) annotation (Line(points={{123,-62},{102,
          -62},{102,-54},{82,-54}}, color={0,0,127}));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), experiment(
      StopTime=604800,
      Interval=60,
      __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>Test to show how the variation of the inlet air mass flow affects to the Open Cooling Tower.</p>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteOCT_controlled;
