within DCOL.Generation.CoolingTowers.FMI;
model CompleteCCT_inertia_Dym
  import DCOL;

  replaceable package Medium =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
    Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Air medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium2 =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Working fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
    Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coil" annotation (choicesAllMatching = true,Dialog(tab="General", group="Materials"));

  replaceable package Material1 =
    Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the storage wall" annotation (choicesAllMatching = true,Dialog(tab="General", group="Materials"));

  parameter Modelica.SIunits.Height hmax=0.377825 "Maximum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Height hmin=0.092075 "Minimum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_basin=5.486 "Length of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length w=2.388 "Width of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Water basin data"));

  parameter Integer nSeg=10 "Number of section in which is divided de fill";
  parameter Integer nCoil=2 "Number of steps of each coil";
  parameter Integer nParallel=2 "Number of parallel coils in the fill";

  parameter Modelica.SIunits.Length L=5 "Length of the tube" annotation (Dialog(group="Geometric parameter of the cooling tower"));
  parameter Modelica.SIunits.Radius R_ext=0.03 "Extermal radious of the tube" annotation (Dialog(group="Geometric parameter of the cooling tower"));
  parameter Modelica.SIunits.Radius R_int=0.025 "Intermal radious of the tube" annotation (Dialog(group="Geometric parameter of the cooling tower"));

  parameter Modelica.Blocks.Interfaces.RealOutput mWaterIn=52.766 "Value for pumped water" annotation(Dialog(group="Pump data"));
  parameter Modelica.SIunits.Pressure pPumpedWater=135496.772 "Pressure of the sprayed water" annotation(Dialog(group="Pump data"));
  parameter Modelica.SIunits.Pressure pCWater2=system.p_ambient "Pressure of the sprayed water" annotation(Dialog(group="CWater data"));

  parameter Real c=2.3 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Real n=-0.72 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Modelica.SIunits.Height roughness=2.5e-5 "Average height of surface asperities (default: smooth steel pipe)" annotation(Dialog(group="Properties of the cooled water pipe"));
  parameter Real a=1000 "Coefficient for quadratic term of the pressure drop" annotation(Dialog(group="Coefficient for the calculation of the pressure drop in the pipe"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coefficient for the calculation of the pressure drop in the pipe"));

  parameter Modelica.SIunits.Diameter d_a=0.02505 "Diameter at the entrace of the sprayer" annotation(Dialog(group="Sprayer properties"));
  parameter Modelica.SIunits.Diameter d_b=0.025 "Diameter at the exit of the sprayer" annotation(Dialog(group="Sprayer properties"));

  parameter Real Kfi=3.5 "Loss coefficient in the fill" annotation(Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=3 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.388 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.486 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Real C_iner=10 "Constant defining the thermal inertia of the filter" annotation(Dialog(group="Filter properties"));

  parameter Modelica.SIunits.Temperature ToverflowWater=25+273.15 "Start value for the outlet water" annotation(Dialog(group = "Overflow water data"));
  parameter Modelica.SIunits.MassFlowRate moverflowWater=2 "Inlet air mass flow" annotation(Dialog(group = "Overflow water data"));
  //START VALUES
  parameter Modelica.SIunits.Temperature TWater2_start=293.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=307.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature T_start_coil= 293.15 "Start temperature for the average temperature of cylinder" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature TMaterial_start=293.15  "start temperature of the material of the coil" annotation(Dialog(tab = "Initialization"));

  DCOL.Generation.CoolingTowers.ClosedCoolingTower_inertia closedCTPressureDrop(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    redeclare package Medium2 = Medium2,
    redeclare package Material = Material,
    redeclare package Material1 = Material1,
    hmax=hmax,
    hmin=hmin,
    L_basin=L_basin,
    w=w,
    e=e,
    nSeg=nSeg,
    nCoil=nCoil,
    nParallel=nParallel,
    L=L,
    R_ext=R_ext,
    R_int=R_int,
    mWaterIn=mWaterIn,
    pPumpedWater=pPumpedWater,
    c=c,
    n=n,
    roughness=roughness,
    a=a,
    b=b,
    d_a=d_a,
    d_b=d_b,
    C_iner=C_iner,
    Kfi=Kfi,
    hfi=hfi,
    wfi=wfi,
    lfi=lfi,
    TWater2_start=TWater2_start,
    TAir2_start=TAir2_start,
    H2_start=H2_start,
    T_start_coil=T_start_coil,
    TMaterial_start=TMaterial_start)
    annotation (Placement(transformation(extent={{-40,-40},{40,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T airIn(
    redeclare package Medium = Medium1,
    use_T_in=true,
    m_flow=48,
    nPorts=1,
    use_m_flow_in=true,
    X={0.007713153,(1 - 0.007713153)},
    use_X_in=true,
    T=298.15) annotation (Placement(transformation(extent={{80,-34},
            {60,-14}})));

  Modelica.Fluid.Sources.FixedBoundary airOut(
    redeclare package Medium = Medium1,
    nPorts=1,
    p=system.p_ambient) annotation (Placement(transformation(extent={{80,60},{60,80}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{10,-70},
            {30,-50}})));

  Modelica.Fluid.Sources.MassFlowSource_T cWaterIn(
    redeclare package Medium = Medium2,
    m_flow=13.440411,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    T=313.15) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={60,18})));

  Modelica.Fluid.Sources.FixedBoundary cWaterOut(
    redeclare package Medium = Medium2,
    nPorts=1,
    p=pCWater2) annotation (Placement(transformation(extent={{10,-10},{-10,10}},
        rotation=0,
        origin={100,-4})));

  Modelica.Fluid.Sensors.Temperature T_airout(
    redeclare package Medium = Medium1) annotation (Placement(transformation(extent={{30,74},{50,94}})));

  Modelica.Fluid.Sensors.Temperature T_CWaterout(
    redeclare package Medium = Medium2) annotation (Placement(transformation(extent={{72,-4},
            {92,16}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_floor(T=288.15) annotation (Placement(transformation(extent={{-40,-66},
            {-20,-46}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature T_ambient annotation (Placement(transformation(extent={{-64,18},
            {-44,38}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealMassFlowInput
    inletCWater_m_flow "Inlet cooling water mass flow"
                       annotation (Placement(transformation(extent={{-140,60},{-100,100}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureInput
    inletCWater_T "INlet cooling water temperature"
                  annotation (Placement(transformation(extent={{-140,20},{-100,60}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealMassFlowInput
    inletAir_m_flow "Inlet air mass flow"
                    annotation (Placement(transformation(extent={{-140,-20},{-100,20}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureInput
    ambient_T "Ambient temperature"
              annotation (Placement(transformation(extent={{-140,-60},{-100,-20}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealMassFractionInput
    inletAir_X "Vapour fraction in the air at the entrace (m_vapour/m_air)"
               annotation (Placement(transformation(extent={{-140,-100},{-100,-60}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureOutput
    outletAir_T "Outlet cooling water temperature"
                annotation (Placement(transformation(extent={{120,40},{140,60}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureOutput
    outletCWater_T "Outle air temperature"
                   annotation (Placement(transformation(extent={{120,-60},{140,-40}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
    hmax=hmax,
    hmin=hmin,
    m_In=moverflowWater) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-80,-50})));

  Modelica.Fluid.Sources.MassFlowSource_T waterOverFlow1(
    redeclare package Medium = Medium,
    nPorts=1,
    m_flow=2,
    use_m_flow_in=true,
    T=ToverflowWater) annotation (Placement(transformation(extent={{-64,-34},{-44,-14}})));

  Modelica.Blocks.Discrete.Sampler sampler(samplePeriod=10) annotation (Placement(transformation(extent={{-46,-90},{-66,-70}})));

equation
  airIn.X_in[2]=1-inletAir_X;

  connect(airIn.ports[1], closedCTPressureDrop.port_a_air) annotation (Line(
        points={{60,-24},{56,-24},{56,-14},{56,-13.6},{43.6,-13.6}},
                                                            color={0,127,255}));
  connect(airOut.ports[1], closedCTPressureDrop.port_b_air) annotation (Line(points={{60,70},{20,70},{20,40.8}},
                                                       color={0,127,255}));
  connect(T_airout.port, closedCTPressureDrop.port_b_air) annotation (Line(
        points={{40,74},{40,74},{40,70},{20,70},{20,40.8}},
                                                          color={0,127,255}));
  connect(cWaterIn.ports[1], closedCTPressureDrop.port_a_Cwater) annotation (
      Line(points={{50,18},{44,18},{44,16},{40,16}},         color={0,127,255}));
  connect(closedCTPressureDrop.port_b_Cwater, cWaterOut.ports[1]) annotation (
      Line(points={{40,0},{50,0},{50,-4},{90,-4}}, color={0,127,255}));
  connect(T_CWaterout.port, closedCTPressureDrop.port_b_Cwater) annotation (
      Line(points={{82,-4},{50,-4},{50,0},{40,0}}, color={0,127,255}));
  connect(T_floor.port, closedCTPressureDrop.port_a_floor) annotation (Line(points={{-20,-56},{0,-56},{0,-40}},     color={191,0,0}));
  connect(T_ambient.port, closedCTPressureDrop.port_a_ambient) annotation (Line(points={{-44,28},{-38,28}}, color={191,0,0}));
  connect(inletCWater_m_flow, cWaterIn.m_flow_in) annotation (Line(points={{-120,80},
          {-60,80},{0,80},{0,54},{76,54},{76,26},{70,26}},
        color={0,0,127}));
  connect(inletCWater_T, cWaterIn.T_in) annotation (Line(points={{-120,40},{-90,
          40},{-90,52},{78,52},{78,22},{72,22}}, color={0,0,127}));
  connect(inletAir_m_flow, airIn.m_flow_in) annotation (Line(points={{-120,0},{-86,
          0},{-86,-90},{96,-90},{96,-16},{80,-16}},   color={0,0,127}));
  connect(ambient_T, airIn.T_in) annotation (Line(points={{-120,-40},{-90,-40},{
          -90,-94},{100,-94},{100,-20},{82,-20}}, color={0,0,127}));
  connect(inletAir_X, airIn.X_in[1]) annotation (Line(points={{-120,-80},{-120,-80},
          {-94,-80},{-94,-98},{104,-98},{104,-28},{82,-28}}, color={0,0,127}));
  connect(ambient_T, T_ambient.T) annotation (Line(points={{-120,-40},{-90,-40},
          {-90,28},{-66,28}}, color={0,0,127}));
  connect(T_airout.T, outletAir_T) annotation (Line(points={{47,84},{50,84},{50,
          86},{100,86},{100,50},{130,50}},
                             color={0,0,127}));
  connect(T_CWaterout.T, outletCWater_T) annotation (Line(points={{89,6},{90,6},
          {90,16},{116,16},{116,-50},{130,-50}}, color={0,0,127}));
  connect(levelControl.m_outflow, waterOverFlow1.m_flow_in) annotation (Line(points={{-80,-39},{-80,-16},{-64,-16}}, color={0,0,127}));
  connect(sampler.y,levelControl. level) annotation (Line(points={{-67,-80},{-80,
          -80},{-80,-62}},       color={0,0,127}));
  connect(sampler.u, closedCTPressureDrop.level) annotation (Line(points={{-44,-80},
          {2,-80},{50,-80},{50,-24},{44,-24}}, color={0,0,127}));
  connect(waterOverFlow1.ports[1], closedCTPressureDrop.port_a_Owater) annotation (Line(points={{-44,-24},{-36,-24}}, color={0,127,255}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{120,100}})), Icon(coordinateSystem(extent={{-100,-100},{
            120,100}})),
    Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteCCT_inertia_Dym;
