within DCOL.Generation.CoolingTowers.FMI;
model CompleteOCT_inertia_Dym
  import DCOL;

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water medium in the component" annotation (choicesAllMatching = true,
      Documentation(revisions="<html>
</html>"));

  replaceable package Medium1 = Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Air medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
      "Material of the storage wall" annotation (choicesAllMatching = true);

  parameter Modelica.SIunits.Height hmax=0.377825 "Maximum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Height hmin=0.092075 "Minimum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_basin=5.2197/2 "Length of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length w=2.28346 "Width of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Water basin data"));

  parameter Real c=2.3 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Real n=-0.72 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));

  parameter Real Kfi(unit="1/m")=3.5 "Loss coefficient in the fill" annotation (Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=2.11455 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.28346 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.2197/2 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Real C_iner=10 "Constant defining the thermal inertia of the filter" annotation(Dialog(group="Filter properties"));

  parameter Modelica.SIunits.Temperature ToverflowWater=25+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));

  //START VALUES
  parameter Modelica.SIunits.Temperature TWater2_start=29+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=34+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFlowRate mAir1_start=20 "Inlet air mass flow" annotation(Dialog(tab = "Initialization"));

  DCOL.Generation.CoolingTowers.OpenCoolingTower_inertia openCT2(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    redeclare package Material = Material,
    TWater2_start=TWater2_start,
    TAir2_start=TAir2_start,
    H2_start=H2_start,
    mAir1_start=mAir1_start,
    hmax=hmax,
    hmin=hmin,
    L_basin=L_basin,
    w=w,
    e=e,
    c=c,
    n=n,
    Kfi=Kfi,
    hfi=hfi,
    wfi=wfi,
    lfi=lfi,
    C_iner=C_iner)
    annotation (Placement(transformation(extent={{-40,-40},{40,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T inletWater(
    redeclare package Medium = Medium,
    use_m_flow_in=true,
    m_flow=100,
    use_T_in=true,
    nPorts=1,
    T=308.15) annotation (Placement(transformation(extent={{-60,60},{-40,80}})));

  Modelica.Fluid.Sources.MassFlowSource_T outletWater(
    redeclare package Medium = Medium,
    m_flow=-50,
    use_m_flow_in=true,
    use_T_in=false,
    nPorts=1) annotation (Placement(transformation(extent={{-60,-78},{-40,-58}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Fluid.Sources.MassFlowSource_T overflowWater(
    redeclare package Medium = Medium,
    m_flow=10,
    use_m_flow_in=true,
    nPorts=1,
    T=ToverflowWater) annotation (Placement(transformation(extent={{-60,-28},{-40,-8}})));

  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{-5,-5},
            {5,5}},
        rotation=0,
        origin={-75,-60})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
    ambientTemperature annotation (Placement(transformation(extent={{68,-3},
            {48,17}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floorTemperature(T=288.15) annotation (Placement(transformation(extent={{24,-80},
            {4,-60}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
    hmin=0.092075,
    hmax=0.377825,
    m_Out=0,
    m_In=1.34381)
    annotation (Placement(transformation(extent={{10,40},{-10,60}})));

  Modelica.Fluid.Sources.MassFlowSource_T outletAir(
    redeclare package Medium = Medium1,
    use_T_in=false,
    m_flow=-31.5258,
    use_m_flow_in=true,
    nPorts=1) annotation (Placement(transformation(extent={{60,52},{40,72}})));

  Modelica.Fluid.Sources.Boundary_pT inletAir(
    redeclare package Medium = Medium1,
    use_T_in=true,
    nPorts=1,
    X={0.017623194,(1 - 0.017623194)},
    use_X_in=true,
    p=system.p_ambient) annotation (Placement(transformation(extent={{80,-60},{60,-40}})));

  Modelica.Blocks.Math.Gain gain1(k=-1) annotation (Placement(transformation(extent={{-5,-5},
            {5,5}},
        rotation=180,
        origin={74,70})));

  Modelica.Fluid.Sensors.Temperature T_waterOut(
    redeclare package Medium = Medium) annotation (Placement(transformation(extent={{-50,-60},{-30,-40}})));

  Modelica.Fluid.Sensors.Temperature T_airOut(
    redeclare package Medium = Medium1) annotation (Placement(transformation(extent={{20,70},{40,90}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air1(
    redeclare package Medium = Medium1) annotation (Placement(transformation(extent={{55,-55},{45,-45}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlow_Water1(
    redeclare package Medium = Medium) annotation (Placement(
        transformation(
        extent={{5,-5},{-5,5}},
        rotation=90,
        origin={-30,60})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealMassFlowInput
    outletAir_m_flow "Outlet air mass flow"
                     annotation (Placement(transformation(extent={{-140,70},{-100,110}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealMassFlowInput
    inletWater_m_flow "Inlet water mass flow"
                      annotation (Placement(transformation(extent={{-140,35},{-100,75}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureInput
    inletWater_T "Inlet water temperature"
                 annotation (Placement(transformation(extent={{-140,0},{-100,40}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureInput
    ambient_T "Ambient temperature"
              annotation (Placement(transformation(extent={{-140,-40},{-100,0}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealMassFlowInput
    outletWater_m_flow "Outlet water mass flow"
                       annotation (Placement(transformation(extent={{-140,-75},{-100,-35}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealMassFractionInput
    inletAir_X "Vapour fraction in the air at the entrace (m_vapour/m_air)"
                                                             annotation (Placement(transformation(extent={{-140,-110},{-100,-70}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureOutput
    outletWater_T "Outlet water temperature"
                  annotation (Placement(transformation(extent={{100,-40},{120,-20}})));

  DCOL.Generation.CoolingTowers.FMI.RealConnectors.RealTemperatureOutput
    outletAir_T "Outlet air temperature"
                annotation (Placement(transformation(extent={{100,20},{120,40}})));

equation
  inletAir.X_in[2]=1-inletAir_X;

  connect(gain.y, outletWater.m_flow_in) annotation (Line(points={{-69.5,-60},{
          -69.5,-60},{-60,-60}},
                           color={0,0,127}));
  connect(openCT2.level, levelControl.level) annotation (Line(points={{33.3333,
          -26.6667},{42,-26.6667},{42,50},{12,50}},
                                           color={0,0,127}));
  connect(levelControl.m_outflow, overflowWater.m_flow_in) annotation (Line(
        points={{-11,50},{-70,50},{-70,-10},{-60,-10}}, color={0,0,127}));
  connect(openCT2.port_b_water, outletWater.ports[1]) annotation (Line(points={
          {-30,-30},{-30,-68},{-40,-68}}, color={0,127,255}));
  connect(overflowWater.ports[1],openCT2.port_a_Owater)  annotation (Line(
        points={{-40,-18},{-32,-18},{-30,-18}}, color={0,127,255}));
  connect(openCT2.port_a_floor, floorTemperature.port) annotation (Line(points={{0,
          -33.3333},{0,-33.3333},{0,-70},{4,-70}},     color={191,0,0}));
  connect(openCT2.port_b_air, outletAir.ports[1]) annotation (Line(points={{20,
          36.6667},{20,36.6667},{20,62},{40,62}}, color={0,127,255}));
  connect(gain1.y, outletAir.m_flow_in) annotation (Line(points={{68.5,70},{66,
          70},{64,70},{60,70}},                                                              color={0,0,127}));
  connect(ambientTemperature.port, openCT2.port_a_ambient) annotation (Line(
        points={{48,7},{48,7},{48,6.66667},{33.3333,6.66667}}, color={191,0,0}));
  connect(inletAir.ports[1], massFlow_Air1.port_a) annotation (Line(points={{60,-50},{55,-50}}, color={0,127,255}));
  connect(massFlow_Air1.port_b, openCT2.port_a_air) annotation (Line(points={{45,-50},
          {38,-50},{38,-10},{33.3333,-10}},         color={0,127,255}));
  connect(T_waterOut.port, openCT2.port_b_water) annotation (Line(points={{-40,
          -60},{-30,-60},{-30,-30}}, color={0,127,255}));
  connect(T_airOut.port, openCT2.port_b_air) annotation (Line(points={{30,70},{
          30,70},{30,62},{20,62},{20,36.6667}}, color={0,127,255}));
  connect(inletWater.ports[1], massFlow_Water1.port_a) annotation (Line(points={{-40,70},{-30,70},{-30,65}}, color={0,127,255}));
  connect(massFlow_Water1.port_b, openCT2.port_a_water) annotation (Line(points={{-30,55},{-30,40},{-30,30}}, color={0,127,255}));
  connect(gain1.u, outletAir_m_flow) annotation (Line(points={{80,70},{92,70},{
          92,98},{-70,98},{-70,90},{-120,90}}, color={0,0,127}));
  connect(ambient_T, inletAir.T_in) annotation (Line(points={{-120,-20},{-94,-20},
          {-94,-96},{92,-96},{92,-46},{82,-46}},      color={0,0,127}));
  connect(ambient_T, ambientTemperature.T) annotation (Line(points={{-120,-20},{
          -120,-20},{-94,-20},{-94,-96},{92,-96},{92,7},{70,7}},  color={0,0,
          127}));
  connect(inletWater_m_flow, inletWater.m_flow_in) annotation (Line(points={{-120,55},
          {-92,55},{-92,78},{-60,78}},          color={0,0,127}));
  connect(inletWater_T, inletWater.T_in) annotation (Line(points={{-120,20},{-90,
          20},{-90,74},{-62,74}},color={0,0,127}));
  connect(outletWater_m_flow, gain.u) annotation (Line(points={{-120,-55},{-90,-55},
          {-90,-60},{-84,-60},{-82,-60},{-81,-60}},
                 color={0,0,127}));
  connect(T_waterOut.T, outletWater_T) annotation (Line(points={{-33,-50},{34,-50},
          {34,-30},{110,-30}},               color={0,0,127}));
  connect(T_airOut.T, outletAir_T) annotation (Line(points={{37,80},{62,80},{88,
          80},{88,30},{110,30}}, color={0,0,127}));
  connect(inletAir_X, inletAir.X_in[1]) annotation (Line(points={{-120,-90},{-18,
          -90},{88,-90},{88,-54},{82,-54}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), experiment(StopTime=3000, __Dymola_Algorithm=
          "Cvode"));
end CompleteOCT_inertia_Dym;
