within DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents;
model ClosedHeatToAir_inertia
  import DCOL;
  extends DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.PartialModels.PartialHeatTransferClosed;
  extends DCOL.Generation.CoolingTowers.Icons.OpenHeatExchanger;

  //WATER IN
  Modelica.SIunits.Temperature TWater1 "Inlet water temperature in K";
  Modelica.SIunits.SpecificEnthalpy hWater1 "Specific enthalpy of the inlet water";
  Modelica.SIunits.MassFlowRate mWater1 "Inlet water mass flow";
  Modelica.SIunits.Temp_C TWater1C "Inlet water temperature in C";
protected
  parameter Modelica.SIunits.MassFlowRate mWater1_small=1e-5 "Used when mAir1 is really small";

  //WATER OUT
public
  Modelica.SIunits.Temperature TWater2(start=TWater2_start) "Outlet water temperature in K";
  Modelica.SIunits.SpecificEnthalpy hWater2 "Specific enthalpy of the outlet water";
  Modelica.SIunits.MassFlowRate mWater2 "Outlet water mass flow";
  Modelica.SIunits.Temp_C TWater2C(start=TWater2_start-273.15) "Outlet water temperature in C";

  //AIR IN
  Modelica.SIunits.Temperature TAir1 "Inlet air temperature in K";
  Modelica.SIunits.SpecificEnthalpy hAir1 "Specific enthalpy of the inlet Air";
  Modelica.SIunits.MassFlowRate mAir1 "Inlet air mass flow";
  Modelica.SIunits.MassFraction X1 "Vapour mass fraction in the inlet air [kg_vapour/kg_moist_air]";
  Modelica.SIunits.Temp_C TAir1C "Inlet air temperature in C";
  Modelica.SIunits.MassFraction H1 "Inlet air absolute humidity=0.0184560958649";
  Modelica.SIunits.MassFlowRate mDAir1 "Inlet dry air mass flow";
  Modelica.SIunits.MassFlowRate mVap1 "Inlet vapour mass flow";
  Modelica.SIunits.SpecificEnthalpy hsw1 "Air saturation enthalpy at inlet water temperature";
  Modelica.SIunits.MassFraction Hsat1 "Inlet air saturation absolute humidity";
  Modelica.SIunits.Pressure pSat1 "Air saturation pressure at TWater1";
  Modelica.SIunits.Density rho1 "Density of air-water vapor mixture at the entrace";
  Modelica.SIunits.MolarMass N1 "Inlet air molar mass";
protected
  parameter Modelica.SIunits.MassFlowRate mAir1_small=1e-5 "Used when mAir1 is really small";

  //AIR OUT
public
  Modelica.SIunits.Temperature TAir2(start=TAir2_start) "Inlet air temperature in K";
  Modelica.SIunits.SpecificEnthalpy hAir2 "specific enthalpy of the outlet Air";
  Modelica.SIunits.MassFlowRate mAir2 "Outlet air mass flow";
  Modelica.SIunits.MassFraction X2 "Vapour mass fraction in the outlet air [kg_vapour/kg_moist_air]";
  Modelica.SIunits.MassFlowRate mDAir2 "Outlet dry air mass flow";
  Modelica.SIunits.MassFlowRate mVap2 "Outlet vapour mass flow";
  Modelica.SIunits.MassFraction H2(start=H2_start) "Outlet Air absolute humidity";
  Modelica.SIunits.Temp_C TAir2C(start=TAir2_start-273.15) "Inlet air temperature in C";
  Modelica.SIunits.SpecificEnthalpy hsw2 "Air saturation enthalpy at outlet water temperature";
  Modelica.SIunits.MassFraction Hsat2 "Outlet air saturation absolute humidity";
  Modelica.SIunits.Pressure pSat2 "Air saturation pressure at TAir2";
  Modelica.SIunits.Density rho2 "Density of air-water vapor mixture at the exit";
  Modelica.SIunits.MolarMass N2 "Outlet air molar mass";
  Real phi2 "Realitive humidity at the exit of the tower";

  //VAPOUR
  Modelica.SIunits.MassFlowRate mEvap "Evaported mass flow";
  Modelica.SIunits.SpecificEnthalpy hvap "Vapour specific enthalpy";
  Modelica.SIunits.Temperature Tvap "Vapour temperature in K";
  Modelica.SIunits.Temp_C TvapC "Vapour temperature in C";

  //GENERAL DATA
protected
  parameter Modelica.SIunits.SpecificHeatCapacity Cpa=1007 "Air specific heat capacity";
  parameter Modelica.SIunits.SpecificHeatCapacity Cpw=4184 "Water specific heat capacity";
  parameter Modelica.SIunits.SpecificHeatCapacity Cpv=1820 "Vapour specific heat capacity";
  parameter Modelica.SIunits.SpecificEnthalpy hfg=2448.15*10^3 "enthalpy of vaporization of water at ambient presure";
  Modelica.SIunits.Temp_C Tinc "Temperature step";
  Modelica.SIunits.Temperature T_In "Inlet temperature";
  Modelica.SIunits.Temperature T_Out "Outlet temperature";

public
  Modelica.SIunits.HeatFlowRate Qsen "Sensible heat transferred to the water";
  Modelica.SIunits.HeatFlowRate Qlat "Latent heat transferred to the water";
  Modelica.SIunits.HeatFlowRate Qtot "Total heat transferred to the water";
  Modelica.SIunits.HeatFlowRate Qcol "Total heat transferred to the cooling water";
  Modelica.SIunits.HeatFlowRate Qfi "Total heat absorbed by the filter";
  parameter Real Kfi(unit="1/m")=3.5 "Loss coefficient in the fill" annotation (Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=3 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.388 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.486 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  Modelica.SIunits.MassFlowRate mMed(start=mMed_start) "Mean air-vapor flow rate";
  Modelica.SIunits.Density rhoMed "harmonic mean density of air-water vapor mixtures";
  parameter Modelica.SIunits.Area Afr=wfi*lfi "cross-sectional packing area" annotation (Dialog(group="Geometric properties"));
  Modelica.SIunits.Pressure IncP "Air pressure change between the entrace and the exit";

  //DESING OF THE COOLING TOWER
  Real e_a "Efficiency of the tower";
  parameter Real c=2.3 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Real n=-0.72 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  Real NTU "Number of Transfer Units of the tower";
  //parameter Real NTU=0.74164 "Number of Transfer Units of the tower" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  Real C_s "Derivative of saturated ha with respect to Tw";
  Real m_ratio "Ratio of air to water effective capacitance rate";

  parameter Modelica.SIunits.Pressure pAmbient=system.p_ambient "Ambient pressure" annotation (Dialog(group="Ambient conditions"));

  //START VALUES
  //parameter Modelica.SIunits.Temperature TWater1_start=20+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TWater2_start(fixed=true)=20+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=34+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFlowRate mMed_start=40 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));

  Modelica.SIunits.Temperature Tfi;
  parameter Real C_iner=10 "Constant defining the thermal inertia of the filter" annotation(Dialog(group="Filter properties"));

initial equation
  Tfi=TWater2_start-5;
  //mMed=mMed_start;
  //T_Out=TWater2_start;

equation

//PROPERTIES OF THE INLET WATER
  if port_a_water.m_flow < mWater1_small then
    mWater1=mWater1_small;
  else
    mWater1=port_a_water.m_flow;
  end if;
  hWater1=inStream(port_a_water.h_outflow);
  hWater1=port_a_water.h_outflow;
  TWater1=Medium.temperature(Medium.setState_ph(p=port_a_water.p, h=inStream(
    port_a_water.h_outflow)))
    "Medium properties at the entrace";
  TWater1C=TWater1-273.15;

//PROPERTIES OF THE OUTLET WATER
  mWater2=-port_b_water.m_flow;
  hWater2=port_b_water.h_outflow;
  TWater2=TWater2C+273.15;
  //hWater2=Cpw*(TWater2C);
  hWater2=Medium.specificEnthalpy_pT(port_b_water.p, TWater2);

//PROPERTIES OF THE INLET AIR
  if port_a_air.m_flow < mAir1_small then
    mAir1=mAir1_small;
  else
    mAir1=port_a_air.m_flow;
  end if;
  hAir1=inStream(port_a_air.h_outflow);
  hAir1=port_a_air.h_outflow;
  TAir1=Medium1.temperature(Medium1.setState_phX(
    p=port_a_air.p,
    h=inStream(port_a_air.h_outflow),
    X=inStream(port_a_air.Xi_outflow)))
    "Medium properties at the entrace";
  inStream(port_a_air.Xi_outflow[1]) = X1;
  port_a_air.Xi_outflow[1] = X1;
  pSat1=Modelica.Media.Air.MoistAir.saturationPressure(Tsat=TWater1);
  hsw1=(Cpa*(TWater1C)+Hsat1*(hfg+Cpv*(TWater1C))*(mDAir1/mAir1));
  Hsat1=Medium1.saturationPressure(TWater1)/port_b_air.p;
  X1=H1/(1+H1);
  TAir1C=TAir1-273.15;
  rho1=Medium1.density(Medium1.setState_phX(
    p=port_a_air.p,
    h=inStream(port_a_air.h_outflow),
    X=inStream(port_a_air.Xi_outflow)));
  N1=(1-X1)*0.02896968+X1*0.0180152;

//PROPERTIES OF THE OUTLET AIR
  mAir2=-port_b_air.m_flow;
  hAir2=port_b_air.h_outflow;
  X2=port_b_air.Xi_outflow[1];
  TAir2=TAir2C+273.15;
  hsw2=(Cpa*(TWater2C)+Hsat2*(hfg+Cpv*(TWater2C))*(mDAir2/mAir2));
  hAir2=Medium1.specificEnthalpy_pTX(
    port_b_air.p,
    TAir2,
    port_b_air.Xi_outflow);
  pSat2=Medium1.saturationPressure(TAir2);
  phi2=(1/((pSat2/pAmbient)*((0.621964713077499/H2)+1)));
  X2=H2/(1+H2);
  rho2=Medium1.density(Medium1.setState_phX(
    p=port_b_air.p,
    h=port_b_air.h_outflow,
    X=port_b_air.Xi_outflow));
  N2=(1-X2)*0.02896968+X2*0.0180152;
  Hsat2=Medium1.saturationPressure(TWater2)/port_b_air.p;
  //(1/4186.8)*hAir2=(1/4186.8)*hAir1+(mWater1/mAir1)*((TAir2C*(9/5)+32)-(TAir1C*(9/5)+32));
  phi2=1;

//PROPERTIES OF THE EXCHANGED VAPOUR
  Tvap=TvapC+273.15;
  hvap=hfg+Cpv*(TvapC);
  Tvap=TAir2;

//PRESSURE DROP CONSIDERED
  rhoMed=(1/((1/rho1)+(1/rho2)));
  port_a_water.p = port_b_water.p;
  port_a_air.p - port_b_air.p = IncP;
  IncP=(5/3)*(((Kfi*hfi*mMed^2)/(2*rhoMed*Afr^2))+((6.5*mMed^2)/(2*rhoMed*Afr^2)));

//AIR MASS BALANCE
  mMed=(mAir1+mAir2)/2;
  mAir1=mDAir1+mVap1;
  mVap1=mAir1*X1;

  mAir2=mDAir2+mVap2;
  mVap2=mAir2*X2;

  mAir1+mEvap=mAir2;
  mDAir1=mDAir2;

//AIR ENERGY BALANCE
  Qsen=mDAir1*(Cpa+H1*Cpv)*(TAir2C-TAir1C);
  Qlat=mEvap*hvap;
  //Qtot=mAir2*hAir2-mAir1*hAir1;
  Qtot=Qsen+Qlat;

//WATER MASS BALANCE
  mWater1=mWater2+mEvap;

//WATER ENERGY BALANCE
  Qtot=mWater1*hWater1-mWater2*hWater2+Qcol-Qfi;
  sum(port_a.Q_flow) = Qcol;

  if port_a_water.m_flow > 1e-5 then
    T_In=TWater1;
    T_Out=TWater2;
  elseif port_a_water.m_flow < -1e-5 then
    T_In=TWater1;
    T_Out=TWater2;
  else
    T_In=TAir2;
    T_Out=TAir1;
  end if;

  Tinc=((T_In-T_Out)/(nCoil-1));
  port_a[1].T = T_In;
  for i in 2:nCoil loop
    port_a[i].T = ((port_a[1].T) - (i - 1)*(Tinc));
  end for;

//DESIGN PARAMETERS
  C_s=(hsw1-hsw2)/(TWater1C-TWater2C);
  m_ratio=(mAir1/mWater1)*(C_s/Cpw);
  NTU=c*((mAir1/mWater1)^(-(1+n)));
  e_a=(1-exp(-NTU*(1-m_ratio)))/(1-m_ratio*exp(-NTU*(1-m_ratio)));
  //TAir1 in C
  Qtot=(e_a*mAir1*(hsw1-Cpa*(TAir1C)));

  Qfi=C_iner*der(Tfi);
  //mfi=porosity*V_fil*rhofi;
  Tfi=(TWater1+TWater2)/2;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>", info="<html>
<p>This model representes the fill of the closed cooling tower. In the fill heat is exchanged between the air and the sprayed water.</p>
<p>The difference with <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.ClosedHeatToAirPressureDrop\">ClosedHeatToAirPressureDrop</a> is that this model considers the thermal heat absorbed by the filter.</p>
<h4>Assumptions</h4>
<ul>
<li>It is not considered pressure drop neither in the air nor in the water;</li>
<li>The air is saturated at the exit of the cooling tower;</li>
<li>Some sprayed water is evaporated during the cooling process;</li>
<li>All the heat is transferred from the water to the air, heat losses during the water cooling are not considered;</li>
<li>The NTU (Number of Transfer Units) is used to calculate the amount of heat transferred from the water to the air. NTU is given by the n anc c design parameters of the tower;</li>
<li>Some of the heat exchanged between the air and the water is storaged in the filter (thermal inertia). This amount of thermal storaged depends on the C_inertia parameter.</li>
</ul>
<h4>Resolutions</h4>
<p>Mass and energy balance:</p>
<p>(1)Mass conservation of air:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/MBAir_Generation_CoolingTower_OpenHeatExch.png\" alt=\"m_ai+m_e=m_ao\"/></p>
<p>(2)Heat conservation of air:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-SvnlNUE7.png\" alt=\"m_ai*h_ai+Q_tot=m_ao*h_ao\"/></p>
<p>(3)Mass conservation of condenser water:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/MBWater_Generation_CoolingTower_OpenHeatExch.png\" alt=\"m_wi-m_e=m_wo\"/></p>
<p>(4)Heat conservation of condenser water:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-szwgwkSA.png\" alt=\"m_wi*T_wi*C_pw-Q_tot-Q_fi=m_wo*T_wo*C_pw\"/></p>
<p>Heat transferred from water to air:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-VCQwO87j.png\" alt=\"Q_tot=epsilon_a*m_a*(h_swi-h_ai)\"/></p>
<p><br>Efficiency:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/efficiency_Generation_CoolingTower_OpenHeatExch.png\" alt=\"epsilon_a=(1-exp(-NTU*(1-m_ratio)))/(1-m_ratio*exp(-NTU*(1-m_ratio)))\"/></p>
<p>NTU, m* and Cs:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/NTU_Generation_CoolingTower_OpenHeatExch.png\" alt=\"NTU=c*(m_a/m_w)^(-(1+n))\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/m_ratio_Generation_CoolingTower_OpenHeatExch.png\" alt=\"m_ratio=(m_a/m_w)*(C_s/C_pw)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/Cs_Generation_CoolingTower_OpenHeatExch.png\" alt=\"C_s=(h_swi-h_swo)/(T_wi-T_wo)\"/></p>
<p><br>where c and n are characteristic constants which depend on the cooling tower</p>
<p>Thermal inertia of the filter:</p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-gtWj3vhY.png\" alt=\"Q_fi=C_iner*der(T_fi)
\"/></p>
<h4>References</h4>
<ul>
<li>Lu, L. and Cai, W., &QUOT;A Universal Engineering Model For Cooling Towers&QUOT; (2002). International Refrigeration and Air Conditioning, Conference. Paper 625.;</li>
<li>Li, Xiao; Li, Yaoyu; and Seem, John E., &QUOT;Dynamic Modeling of Mechanical Draft Counter-Flow Wet Cooling Tower with Modelica&QUOT;(2010). International Refrigeration and Air Conditioning Conference. Paper 1094.;</li>
<li>http://che.sharif.edu/~heatlab/Lab/Benefit&percnt;20Book&percnt;20&AMP;&percnt;20Journal/Benefit&percnt;20book/Cooling&percnt;20Tower&percnt;20Thermal&percnt;20Design&percnt;20Manual.pdf;</li>
</ul>
</html>"));
end ClosedHeatToAir_inertia;
