within DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.PartialModels;
partial model PartialHTXClosed
  import DCOL;
  extends DCOL.Generation.CoolingTowers.Icons.ClosedHeatExchanger;

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid refrigerant medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 = Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Air medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium2 =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Working fluid medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
    Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coil" annotation (choicesAllMatching = true,Dialog(tab="General", group="Material"));

  outer Modelica.Fluid.System system "System wide properties";

  parameter Boolean allowFlowReversal=false
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);
  parameter Boolean homotopyInitialization=true
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Integer nSeg=10 "Number of sections in which is divided each coil";
  parameter Integer nCoil=10 "Number of coil steps in the fill";
  parameter Integer nParallel=10 "Number of parallel coils in the fill";

  parameter Modelica.SIunits.Length L=5 "Length of the tube" annotation (Dialog(group="Geometric parameters of the cooling tower"));
  parameter Modelica.SIunits.Radius R_ext=0.03 "Extermal radious of the tube" annotation (Dialog(group="Geometric parameters of the cooling tower"));
  parameter Modelica.SIunits.Radius R_int=0.025 "Intermal radious of the tube" annotation (Dialog(group="Geometric parameters of the cooling tower"));

  parameter Real c=2.3 annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Real n=-0.72 annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  //parameter Real NTU=0.74164 "Number of Transfer Units of the tower" annotation (Dialog(group="Characteristic parameters of the cooling tower"));
  parameter Modelica.SIunits.Height roughness=2.5e-5 "Average height of surface asperities (default: smooth steel pipe)" annotation(Dialog(group="Properties of the cooled water pipe"));
  parameter Real a=1000 "Coefficient for quadratic term of the pressure drop" annotation(Dialog(group="Coefficient for the calculation of the pressure drop in the pipe"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coefficient for the calculation of the pressure drop in the pipe"));

  parameter Real Kfi=3.5 "Loss coefficient in the fill" annotation(Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=3 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.388 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.486 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area Afr=wfi*lfi "cross-sectional packing area" annotation(Dialog(group="Geometric properties"));

  Real efficiency "Efficiency of the tower";

//COOLED WATER IN
  Modelica.SIunits.Temperature TCWater1 "Inlet water temperature in K";

//COOLED WATER OUT
  Modelica.SIunits.Temperature TCWater2 "Inlet water temperature in K";

//START VALUES
  parameter Modelica.SIunits.Temperature TWater2_start=20+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=34+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature T_start_coil= 40+273.15 "Start temperature for the average temperature of cylinder" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature TMaterial_start=20+273.15  "start temperature of the material of the coil" annotation(Dialog(tab = "Initialization"));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_water(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Inlet sprayed water fluid connector a (positive design flow direction is from port_a_water to port_b_water)"
    annotation (Placement(transformation(extent={{-60,80},{-40,100}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_water(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Outlet sprayed water fluid connector b (positive design flow direction is from port_a_water to port_b_water)"
    annotation (Placement(transformation(extent={{-60,-100},{-40,-80}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_air(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Inlet air fluid connector a (positive design flow direction is from port_a_air to port_b_air)"
    annotation (Placement(transformation(extent={{40,-100},{60,-80}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_air(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Oulet air fluid connector b (positive design flow direction is from port_a_air to port_b_air)"
    annotation (Placement(transformation(extent={{40,80},{60,100}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Cwater(
    redeclare package Medium = Medium2,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium2.h_default))
    "Inlet cooling water fluid connector a (positive design flow direction is from port_a_Cwater to port_b_Cwater)"
    annotation (Placement(transformation(extent={{92,40},{112,60}}),
        iconTransformation(extent={{92,40},{112,60}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_Cwater(
    redeclare package Medium = Medium2,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium2.h_default))
    "Outlet cooling water fluid connector b (positive design flow direction is from port_a_Cwater to port_b_Cwater)"
    annotation (Placement(transformation(extent={{90,-60},{110,-40}}),
        iconTransformation(extent={{90,-60},{110,-40}})));

  DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.ClosedHeatToAir
    closedHeatToAirPressureDrop(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    allowFlowReversal=allowFlowReversal,
    TWater2_start=TWater2_start,
    TAir2_start=TAir2_start,
    H2_start=H2_start,
    Kfi=Kfi,
    Afr=Afr,
    nCoil=nCoil,
    hfi=hfi,
    wfi=wfi,
    lfi=lfi,
    c=c,
    n=n) annotation (Placement(transformation(extent={{-60,-40},{20,40}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.ThermalVolumes.HollowCylinderBIS coilWall[nCoil](
    each r_int=R_int,
    each r_ext=R_ext,
    each length=L,
    each alpha=2*Modelica.Constants.pi,
    each use_radialDim=true,
    each use_angularDim=false,
    each nRadial=1,
    each nAngular=1,
    each use_longitudinalDim=true,
    each nLongitudinal=nSeg,
    each T_start=TMaterial_start,
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321,
    each nParallel=nParallel) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={50,0})));

  Modelica.Fluid.Pipes.DynamicPipe pipe[nCoil](
    redeclare package Medium = Medium2,
    each allowFlowReversal=allowFlowReversal,
    each use_HeatTransfer=true,
    each diameter=2*R_int,
    each roughness=roughness,
    each nNodes=nSeg,
    each T_start=T_start_coil,
    each length=L,
    each nParallel=nParallel) annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=-90,
        origin={90,30})));

  Modelica.Fluid.Fittings.GenericResistances.VolumeFlowRate volumeFlowRate(
    redeclare package Medium = Medium2,
    allowFlowReversal=allowFlowReversal,
    a=a,
    b=b) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={90,-20})));

equation

  for i in 1:nCoil loop
    for j in 1:nSeg loop
      connect(coilWall[i].port_b_1[1, j], pipe[i].heatPorts[j]) annotation (
          Line(points={{60,0},{80,0},{80,29.9},{85.6,29.9}}, color={127,0,0}));
      connect(closedHeatToAirPressureDrop.port_a[i], coilWall[i].port_a_1[1, j]) annotation (Line(points={{20,0},{40,0}}, color={191,0,0}));
    end for;
  end for;

  for i in 1:nCoil-1 loop
    connect(pipe[i].port_b, pipe[i+1].port_a);
  end for;

  connect(closedHeatToAirPressureDrop.port_a_air, port_a_air) annotation (Line(
        points={{8,-36},{8,-36},{8,-88},{8,-90},{50,-90}}, color={0,127,255}));
  connect(closedHeatToAirPressureDrop.port_b_water, port_b_water) annotation (
      Line(points={{-48,-36},{-48,-36},{-48,-90},{-50,-90}}, color={0,127,255}));
  connect(port_a_water, closedHeatToAirPressureDrop.port_a_water) annotation (
      Line(points={{-50,90},{-50,90},{-48,90},{-48,36}}, color={0,127,255}));
  connect(port_b_air, closedHeatToAirPressureDrop.port_b_air) annotation (Line(
        points={{50,90},{50,90},{8,90},{8,36}}, color={0,127,255}));
  connect(volumeFlowRate.port_b, port_b_Cwater) annotation (Line(points={{90,-30},{90,-50},{100,-50}}, color={0,127,255}));
  connect(port_a_Cwater, pipe[1].port_a) annotation (Line(points={{102,50},{96,
          50},{90,50},{90,40}}, color={0,127,255}));
  connect(pipe[nCoil].port_b, volumeFlowRate.port_a) annotation (Line(points={{90,20},{90,5},{90,-10}}, color={0,127,255}));

          annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
            {100,100}})),       Icon(coordinateSystem(preserveAspectRatio=false,
          extent={{-100,-100},{100,100}})),
    Documentation(info="<html>
<p>This partial model connects the different components forming the heat exchanger of a closed cooling tower.</p>
<p>It is considered closed as the heat transference happens between a chilled water flowing through a closed pipe circuit and the sprayed water and air. The tower is divided in nSeg segments.</p>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end PartialHTXClosed;
