within DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.PartialModels;
partial model PartialHeatTransferOpenCalibrated
  "Partial component with two ports"
  import Modelica.Constants;
  outer Modelica.Fluid.System system "System wide properties";
  extends DCOL.Generation.CoolingTowers.Icons.HeatExchanger;

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 = Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Air medium in the component" annotation (choicesAllMatching = true);

  parameter Boolean allowFlowReversal = system.allowFlowReversal
    "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)"  annotation(Dialog(tab="Assumptions"), Evaluate=true);

protected
  parameter Boolean port_a_exposesState = false
    "= true if WaterIn/AirIn exposes the state of a fluid volume";
  parameter Boolean port_b_exposesState = false
    "= true if WaterOut.p/AirOut.p exposes the state of a fluid volume";
  parameter Boolean showDesignFlowDirection = true
    "= false to hide the arrow in the model icon";

public
  Modelica.Fluid.Interfaces.FluidPort_a port_a_water(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Inlet sprayed water fluid connector a (positive design flow direction is from port_a_water to port_b_water)"
    annotation (Placement(transformation(extent={{-80,80},{-60,100}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_water(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Outlet sprayed water fluid connector b (positive design flow direction is from port_a_water to port_b_water)"
    annotation (Placement(transformation(extent={{-60,-100},{-80,-80}}),
        iconTransformation(extent={{-60,-100},{-80,-80}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_air(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Inlet air fluid connector a (positive design flow direction is from port_a_air to port_b_air)"
    annotation (Placement(transformation(extent={{60,-100},{80,-80}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_air(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Outlet air fluid connector b (positive design flow direction is from port_a_air to port_b_air)"
    annotation (Placement(transformation(extent={{80,80},{60,100}}),
        iconTransformation(extent={{80,80},{60,100}})));

  Modelica.Blocks.Interfaces.RealInput c
    "Empirical constant specific to a particular tower design"
                                         annotation (Placement(transformation(extent={{-130,20},{-90,60}})));

  Modelica.Blocks.Interfaces.RealInput n
    "Empirical constant specific to a particular tower design"
                                         annotation (Placement(transformation(extent={{-130,-60},{-90,-20}})));

   annotation (
    Documentation(info="<html>
<p>This partial model defines an interface with four ports (two for a onw fluid and the other two for the other fluid). The treatment of the design flow direction and of flow reversal are predefined based on the parameter <code>allowFlowReversal</code>. </p>
<p>This is the partial model of a heat exchanger </p>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"),
    Icon(coordinateSystem(
          preserveAspectRatio=true,
          extent={{-100,-100},{100,100}}), graphics={
        Ellipse(
          extent={{-110,26},{-90,-24}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid,
          visible=port_a_exposesState),
        Ellipse(
          extent={{90,25},{110,-25}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid,
          visible=port_b_exposesState)}));
end PartialHeatTransferOpenCalibrated;
