within DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents;
model WaterBasinWall

  extends DCOL.Generation.CoolingTowers.Icons.StorageWall;

  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
      "Material of the storage wall" annotation (choicesAllMatching = true);

  parameter Modelica.SIunits.Temperature T_Wall_start=20+273.15 "Start temperature of the storage walls" annotation(Dialog(tab="Initialization"));

  parameter Modelica.SIunits.Length h "Height of the storage";
  parameter Modelica.SIunits.Length w "Width of the storage";
  parameter Modelica.SIunits.Length l "Length of the storage";
  parameter Modelica.SIunits.Length e "Thicknes of the storages wall";

protected
  parameter Modelica.SIunits.Volume volTop=w*l*e "Volume of the top walls (horizontal)";
  parameter Modelica.SIunits.Volume volFront=h*l*e "Volume of the front walls (horizontal)";
  parameter Modelica.SIunits.Volume volSide=w*h*e "Volume of the side wall (vertical)";

public
  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor sideInertia[2](
    redeclare package Material = Material,
    each V=volSide,
    each T(start=T_Wall_start)) annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-50,50})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor topInertia(
    redeclare package Material = Material,
    each V=volTop,
    each T(start=T_Wall_start)) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-10,54})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D sideCond2[2](
    redeclare package Material = Material,
    each A=h*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-70,60})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D sideCond1[2](
    redeclare package Material = Material,
    each A=h*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-30,30})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D topCond1(
    redeclare package Material = Material,
    each A=l*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={0,34})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D topCond2(
    redeclare package Material = Material,
    each A=l*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={0,74})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b T_water annotation (Placement(transformation(extent={{-10,0},{10,-20}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a ambient
    "Heat exchange in contact with the ambient temperature" annotation (Placement(transformation(extent={{94,82},{114,102}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor frontInertia[2](
    redeclare package Material = Material,
    each V=volFront,
    each T(start=T_Wall_start)) annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={50,30})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D frontCond1[2](
    redeclare package Material = Material,
    each A=h*l,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={30,20})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D frontCond2[2](
    redeclare package Material = Material,
    each A=h*l,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={70,20})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a floor
    "Heat exchange in contact with the ambient temperature" annotation (Placement(transformation(extent={{-10,
            -140},{10,-120}})));

initial equation
  frontInertia[1].T = T_Wall_start;
  frontInertia[2].T = T_Wall_start;
  sideInertia[1].T = T_Wall_start;
  sideInertia[2].T = T_Wall_start;
  topInertia.T = T_Wall_start;

equation

  for i in 1:2 loop
    connect(frontCond1[1].port_b, T_water) annotation (Line(points={{20,20},{14,20},{14,-10},{0,-10}}, color={191,0,0}));
    connect(frontCond1[i].port_a, frontInertia[i].port) annotation (Line(points={{40,20},
            {40,20},{50,20}},                                                                             color={191,0,0}));
    connect(frontInertia[i].port, frontCond2[i].port_b) annotation (Line(points={{50,20},
            {60,20}},                                                                                      color={191,0,0}));
    connect(frontCond2[i].port_a, ambient) annotation (Line(points={{80,20},{90,
            20},{90,92},{104,92}},                                                                     color={191,0,0}));

    connect(sideCond1[i].port_b, T_water) annotation (Line(points={{-20,30},{-18,30},{-16,30},{-16,-10},{0,-10}}, color={191,0,0}));
    connect(sideCond1[i].port_a, sideInertia[i].port) annotation (Line(points={{-40,30},
            {-40,40},{-50,40}},                                                                             color={191,0,0}));
    connect(sideInertia[i].port, sideCond2[i].port_b) annotation (Line(points={{-50,40},
            {-50,40},{-60,40},{-60,60}},                                                                             color={191,0,0}));
    connect(sideCond2[i].port_a, ambient) annotation (Line(points={{-80,60},{
            -88,60},{-88,92},{104,92}},                                                                  color={191,0,0}));
  end for;

  connect(topCond1.port_a, topInertia.port) annotation (Line(points={{0,44},{0,54}},color={191,0,0}));
  connect(topInertia.port, topCond2.port_b) annotation (Line(points={{0,54},{-6.66134e-016,54},{-6.66134e-016,64}},color={191,0,0}));
  connect(topCond1.port_b, T_water) annotation (Line(points={{0,24},{0,-10},{0,-10}}, color={191,0,0}));
  connect(topCond2.port_a, floor) annotation (Line(points={{0,84},{-92,84},{-92,
          -88},{0,-88},{0,-130}}, color={191,0,0}));
   annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents storage walls and the heat exchanged throught the walls to the ambient.</p>
<h4>Assumption</h4>
<ul>
<li>The storage is open in the top;</li>
<li>The storage has rectangular shape;</li>
<li>Thermal storage of the walls is consideted.</li>
</ul>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end WaterBasinWall;
