within DCOL.Generation.CoolingTowers;
model OpenCoolingTowerCalibrated
  import DCOL;
  extends DCOL.Generation.CoolingTowers.Icons.OpenCT;

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 = Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Air medium in the component" annotation (choicesAllMatching = true);
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
      "Material of the storage wall" annotation (choicesAllMatching = true);

  parameter Boolean allowFlowReversal=false
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);
  parameter Boolean homotopyInitialization=true
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Modelica.SIunits.Height hmax=0.377825 "Maximum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Height hmin=0.092075 "Minimum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_char=2*L_basin + 2*w "Characteristic length, length of the plate" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_basin=5.2197/2 "Length of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length w=2.28346 "Width of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Water basin data"));

  parameter Modelica.SIunits.Pressure pAmbient=101325 "Ambient pressure" annotation (Dialog(group="Ambient properties"));
  parameter Real Kfi(unit="1/m")=3.5 "Loss coefficient in the fill" annotation (Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=2.11455 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.28346 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.2197/2 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area Afr=wfi*lfi "cross-sectional packing area" annotation (Dialog(group="Geometric properties"));

  //OPERATION POINT FOR THE CALIBRATION
  parameter Modelica.SIunits.MassFlowRate mWater1_1=100 "Inlet water mass flow for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater1C_1=35 "Inlet water temperature in C for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater2C_1=29 "Outlet water temperature in C for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.MassFlowRate mAir1_1=48 "Inlet air mass flow for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Temp_C TAir1C_1=25 "Inlet air temperature in C for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.MassFraction H1_1=0.0184560958649 "Inlet air absolute humidity for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));
  parameter Modelica.SIunits.Pressure pAmbient_1=101325 "Ambient pressure for the first operation point" annotation (Dialog(tab="Operation Points",group="First Operation Point"));

  parameter Modelica.SIunits.MassFlowRate mWater1_2=80 "Inlet water mass flow for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater1C_2=38 "Inlet water temperature in C for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TWater2C_2=30 "Outlet water temperature in C for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.MassFlowRate mAir1_2=40 "Inlet air mass flow for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Temp_C TAir1C_2=20 "Inlet air temperature in C for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.MassFraction H1_2=0.0184560958649 "Inlet air absolute humidity for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));
  parameter Modelica.SIunits.Pressure pAmbient_2=101325 "Ambient pressure for the second operation point" annotation (Dialog(tab="Operation Points",group="Second Operation Point"));

  //START VALUES
  parameter Modelica.SIunits.Temperature TWater2_start=29+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=34+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFlowRate mAir1_start=20 "Inlet air mass flow" annotation(Dialog(tab = "Initialization"));

  DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents.OpenHTXCalibrated
    openHTXCalibrated(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    allowFlowReversal=allowFlowReversal,
    pAmbient=pAmbient,
    TWater2_start=TWater2_start,
    TAir2_start=TAir2_start,
    H2_start=H2_start,
    Kfi=Kfi,
    Afr=Afr,
    hfi=hfi,
    wfi=wfi,
    lfi=lfi,
    mAir1_start=mAir1_start)
    annotation (Placement(transformation(extent={{-40,12},{40,92}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_air(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Inlet air fluid connector a (positive design flow direction is from port_a_air to port_b_air)"
    annotation (Placement(transformation(extent={{90,-40},{110,-20}}),
        iconTransformation(extent={{90,-40},{110,-20}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_air(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Outlet air fluid connector b (positive design flow direction is from port_a_air to port_b_air)"
    annotation (Placement(transformation(extent={{50,100},{70,120}}),
        iconTransformation(extent={{50,100},{70,120}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_water(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Inlet sprayed water fluid connector a (positive design flow direction is from port_a_water to port_b_water)"
    annotation (Placement(transformation(extent={{-100,80},{-80,100}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_water(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Outlet sprayed water fluid connector b (positive design flow direction is from port_a_water to port_b_water)"
    annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));

  Modelica.Fluid.Vessels.OpenTank waterBasin(
    redeclare package Medium = Medium,
    nPorts=3,
    use_HeatTransfer=true,
    height=hmax,
    crossArea=w*L_basin,
    use_portsData=true,
    heatTransfer(surfaceAreas={w*L_basin+2*(w+L_basin)*waterBasin.level}),
    portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=(
        L_basin*w)/(2*(w + L_basin)), height=hmax),
        Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.1),
        Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.1)}) annotation (Placement(transformation(extent={{-80,-33},
            {-40,7}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Plate.NaturalConvectionVerticalPlateVariableArea naturalConvectionVerticalPlate(L=L_char, Tc(start=TWater2_start))
    annotation (Placement(transformation(extent={{60,0},{80,20}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_floor
    "Heat Losses of the WaterBasin to the floor" annotation (Placement(
        transformation(extent={{-10,-120},{10,-100}}), iconTransformation(
          extent={{-5,-105},{5,-95}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Owater(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Overflow water fluid connector a"
                                       annotation (Placement(transformation(extent={{-100,-64},{-80,-44}})));

  Modelica.Blocks.Sources.RealExpression A(
    y=2*w*waterBasin.level + 2*L_basin*waterBasin.level)
    "Area of the wet walls of the tank" annotation (Placement(transformation(extent={{80,20},
            {60,40}})));

  Modelica.Blocks.Interfaces.RealOutput level=waterBasin.level
    "Level of the water in the waterBasin"                     annotation (Placement(transformation(extent={{90,-90},
            {110,-70}}), iconTransformation(extent={{90,-90},{110,-70}})));

  DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.WaterBasinWall
    storageWall(
    redeclare package Material = Material,
    h=hmax,
    w=w,
    e=e,
    l=L_basin)
    annotation (Placement(transformation(extent={{-46,-84},{-6,-44}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_ambient
    "Heat Losses of the WaterBasin to the ambient" annotation (Placement(
        transformation(extent={{100,0},{120,20}}), iconTransformation(extent={{
            95,15},{105,25}})));

equation
  connect(port_a_water, openHTXCalibrated.port_a_water)
    annotation (Line(points={{-90,90},{-28,90},{-28,88}}, color={0,127,255}));
  connect(openHTXCalibrated.port_a_air, port_a_air)
    annotation (Line(points={{28,16},{28,-30},{100,-30}}, color={0,127,255}));
  connect(port_a_air, port_a_air) annotation (Line(points={{100,-30},{92,-30},{
          100,-30}}, color={0,127,255}));
  connect(openHTXCalibrated.port_b_air, port_b_air)
    annotation (Line(points={{28,88},{28,110},{60,110}}, color={0,127,255}));
  connect(openHTXCalibrated.port_b_water, waterBasin.ports[1]) annotation (Line(
        points={{-28,16},{-28,16},{-91,16},{-93,16},{-93,-36},{-65,-36},{-65,
          -34},{-65.3333,-34},{-65.3333,-33}},
                                          color={0,127,255}));
  connect(waterBasin.ports[2], port_b_water) annotation (Line(points={{-60,-33},
          {-60,-33},{-60,-90},{-90,-90}}, color={0,127,255}));
  connect(waterBasin.ports[3],port_a_Owater)  annotation (Line(points={{
          -54.6667,-33},{-55,-33},{-55,-56},{-90,-56},{-90,-54}},
                                                         color={0,127,255}));
  connect(A.y, naturalConvectionVerticalPlate.A) annotation (Line(points={{59,30},
          {50,30},{50,17},{60,17}},       color={0,0,127}));
  connect(naturalConvectionVerticalPlate.fluid, port_a_ambient)
    annotation (Line(points={{80,10},{110,10}}, color={191,0,0}));
  connect(storageWall.floor, port_a_floor) annotation (Line(points={{-26,-90},{
          -26,-90},{-26,-110},{0,-110}}, color={191,0,0}));
  connect(storageWall.ambient, naturalConvectionVerticalPlate.solid) annotation (Line(points={{-5.2,-45.6},{-5.2,10},{60,10}}, color={191,0,0}));
  connect(waterBasin.heatPort, storageWall.T_water) annotation (Line(points={{-80,
          -13},{-114,-13},{-114,-66},{-26,-66}}, color={191,0,0}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
            -120},{120,120}})), Icon(coordinateSystem(preserveAspectRatio=false,
          extent={{-120,-120},{120,120}})),
    Documentation(info="<html>
<p>This model represents a complete open cooling tower.</p>
<p>Air is blowed through the tower and is used to cool the water sprayed at the top of the tower. The heat transferred is sensible heat (due to the increase of the air temperature) and latent heat (due to the evaporation of part of the water). There is a water basin at the bottom of the tower, where the chilled water is storaged. In this model the NTU is calculated with two operation points.</p>
<h4>Assumptions</h4>
<ul>
<li>Some water is evaporated during the cooling process;</li>
<li>The pressure drop of the air is considered;</li>
<li>All the heat is transferred from the water to the air, heat losses during the water cooling are not considered;</li>
<li>The NTU (Number of Transfer Units) is used to calculate the amount of heat transferred from the water to the air. NTU is given by the n and c which are calculated with two operation points in a calibration component.</li>
</ul>
<h4>Use</h4>
<p>The air fan has been supposed to be located at the exit of the tower, so the mass flow source is recomended to be connected to the por_b_air (otherwise problems during the initialization could appear) . </p>
<p>Both the air and water flow is from port_a to port_b.</p>
<p>Two operation points have to be selected in order to calucualte the NTU parameter of the tower.</p>
<h4>References</h4>
<ul>
<li>Lu, L. and Cai, W., &QUOT;A Universal Engineering Model For Cooling Towers&QUOT; (2002). International Refrigeration and Air Conditioning, Conference. Paper 625.;</li>
<li>Li, Xiao; Li, Yaoyu; and Seem, John E., &QUOT;Dynamic Modeling of Mechanical Draft Counter-Flow Wet Cooling Tower with Modelica&QUOT;(2010). International Refrigeration and Air Conditioning Conference. Paper 1094.;</li>
<li>Baker, Donald. R and Shryock, Howard A., &QUOT;A Compresive Aproach To The Analysis Of Cooling Tower Performance&QUOT; (2013). SPX Corporation. Thermal Science.;</li>
<li>http://che.sharif.edu/~heatlab/Lab/Benefit&percnt;20Book&percnt;20&AMP;&percnt;20Journal/Benefit&percnt;20book/Cooling&percnt;20Tower&percnt;20Thermal&percnt;20Design&percnt;20Manual.pdf;</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end OpenCoolingTowerCalibrated;
