within DCOL.Generation.CoolingTowers;
model OpenCoolingTower_controlled
  import DCOL;
  extends DCOL.Generation.CoolingTowers.Icons.OpenCT;

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 = Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Air medium in the component" annotation (choicesAllMatching = true);

  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
      "Material of the storage wall" annotation (choicesAllMatching = true);

  outer Modelica.Fluid.System system "System wide properties";

  parameter Boolean allowFlowReversal=false
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);
  parameter Boolean homotopyInitialization=true
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Modelica.SIunits.Height hmax=0.377825 "Maximum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Height hmin=0.092075 "Minimum height of water that can the basin have" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_char=2*L_basin + 2*w "Characteristic length, length of the plate" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length L_basin=5.2197/2 "Length of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length w=2.28346 "Width of the basin" annotation(Dialog(group="Water basin data"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Water basin data"));

  parameter Real c=0.69 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));
  parameter Real n=-0.72 "Empirical constant specific to a particular tower design" annotation (Dialog(group="Characteristic parameter of the cooling tower"));

  //parameter Real NTU=0.74164 "Number of Transfer Units of the tower" annotation (Dialog(group="Characteristic parameter of the cooling tower"));

  parameter Real Kfi(unit="1/m")=3.5 "Loss coefficient in the fill" annotation (Dialog(group="Fluid properties"));
  parameter Modelica.SIunits.Length hfi=2.11455 "Height of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length wfi=2.28346 "Width of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length lfi=5.2197/2 "Length of the filter" annotation (Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area Afr=wfi*lfi "cross-sectional packing area" annotation (Dialog(group="Geometric properties"));
  parameter Real C_iner=10 "Constant defining the thermal inertia of the filter" annotation(Dialog(group="Filter properties"));

  parameter Modelica.SIunits.MassFlowRate m_flow_nominal=57.3619  "Nominal mass flow rate of the air, fixed if control_m_flow and not use_m_flow_set" annotation(Dialog(group="Fan properties"));
  parameter Modelica.SIunits.AbsolutePressure p_a_nominal=system.p_ambient-18400 "Nominal inlet pressure for predefined fan characteristics" annotation(Dialog(group="Fan properties"));
  parameter Modelica.SIunits.AbsolutePressure p_b_nominal=system.p_ambient "Nominal outlet pressure, fixed if not control_m_flow and not use_p_set" annotation(Dialog(group="Fan properties"));

  // 116279.36
  // 099502.2

  parameter Modelica.SIunits.Diameter d_a=0.02505 "Diameter at the entrace of the sprayer" annotation(Dialog(group="Sprayer properties"));
  parameter Modelica.SIunits.Diameter d_b=0.025 "Diameter at the exit of the sprayer" annotation(Dialog(group="Sprayer properties"));

  //START VALUES
  parameter Modelica.SIunits.Temperature TWater2_start=29+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.Temperature TAir2_start=34+273.15 "Start value for the outlet water" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFraction H2_start=0.15 "Outlet Air absolute humidity" annotation(Dialog(tab = "Initialization"));
  parameter Modelica.SIunits.MassFlowRate mAir1_start=30 "Inlet air mass flow" annotation(Dialog(tab = "Initialization"));

  DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents.OpenHTX_inertia openHTX(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    allowFlowReversal=allowFlowReversal,
    mAir1_start=mAir1_start,
    TWater2_start=TWater2_start,
    TAir2_start=TAir2_start,
    H2_start=H2_start,
    Kfi=Kfi,
    Afr=Afr,
    hfi=hfi,
    wfi=wfi,
    lfi=lfi,
    C_iner=C_iner,
    c=c,
    n=n)      annotation (Placement(transformation(extent={{-40,-10},{40,70}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_air(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Inlet air fluid connector a (positive design flow direction is from port_a_air to port_b_air)" annotation (Placement(transformation(extent={{90,-40},{110,-20}}),
        iconTransformation(extent={{90,-40},{110,-20}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_air(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Outlet air fluid connector b (positive design flow direction is from port_a_air to port_b_air)" annotation (Placement(transformation(extent={{50,100},{70,120}}),
        iconTransformation(extent={{50,100},{70,120}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_water(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Inlet sprayed water fluid connector a (positive design flow direction is from port_a_water to port_b_water)" annotation (Placement(transformation(extent={{-110,70},{-90,90}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_water(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Outlet sprayed water fluid connector b (positive design flow direction is from port_a_water to port_b_water)" annotation (Placement(transformation(extent={{-110,-110},{-90,-90}})));

  Modelica.Fluid.Vessels.OpenTank waterBasin(
    redeclare package Medium = Medium,
    use_HeatTransfer=true,
    crossArea=w*L_basin,
    height=hmax,
    heatTransfer(surfaceAreas={w*L_basin+2*(w+L_basin)*waterBasin.level}),
    use_portsData=true,
    T_start=TWater2_start,
    portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.5),
        Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.5),
        Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=(L_basin*w)/
        (2*(w + L_basin)), height=hmax)},
    nPorts=3)                             annotation (Placement(transformation(extent={{-80,-42},
            {-40,-2}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Plate.NaturalConvectionVerticalPlateVariableArea naturalConvectionVerticalPlate(L=L_char, Tc(start=TWater2_start))
    annotation (Placement(transformation(extent={{60,0},{80,20}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_floor
    "Heat Losses of the WaterBasin to the floor" annotation (Placement(
        transformation(extent={{-10,-120},{10,-100}}), iconTransformation(
          extent={{-5,-105},{5,-95}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_Owater(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Overflow water fluid connector a" annotation (Placement(transformation(extent={{-110,-62},{-90,-42}})));

  Modelica.Blocks.Sources.RealExpression A(
    y=2*w*waterBasin.level + 2*L_basin*waterBasin.level) "Area of the wet walls of the tank"  annotation (Placement(transformation(extent={{80,20},{60,40}})));

  Modelica.Blocks.Interfaces.RealOutput level=waterBasin.level
    "Level of the water in the waterBasin"                     annotation (Placement(transformation(extent={{90,-90},
            {110,-70}}), iconTransformation(extent={{90,-90},{110,-70}})));

  DCOL.Generation.CoolingTowers.Interfaces.HeatTransferComponents.WaterBasinWall
    storageWall(
    redeclare package Material = Material,
    h=hmax,
    w=w,
    e=e,
    l=L_basin,
    T_Wall_start=TWater2_start)
    annotation (Placement(transformation(extent={{-50,-96},{-10,-56}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_ambient
    "Heat Losses of the WaterBasin to the ambient" annotation (Placement(
        transformation(extent={{100,0},{120,20}}), iconTransformation(extent={{
            95,15},{105,25}})));

  Modelica.Fluid.Sensors.TemperatureTwoPort T_b_water(redeclare package Medium = Medium) annotation (Placement(transformation(extent={{-70,-110},{-90,-90}})));

  Modelica.Blocks.Math.Gain gain1(k=-1) annotation (Placement(transformation(extent={{85,55},{75,65}})));

  Modelica.Blocks.Continuous.LimPID PID(
    controllerType=Modelica.Blocks.Types.SimpleController.PI,
    wp=1,
    Ni=0.1,
    initType=Modelica.Blocks.Types.InitPID.InitialOutput,
    strict=true,
    xi_start=10,
    y_start=10,
    k=1/50,
    Ti=0.1,
    yMax=500,
    yMin=1)     annotation (Placement(transformation(extent={{75,75},{65,85}})));
  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{95,75},{85,85}})));

  Modelica.Fluid.Machines.ControlledPump fan(
    redeclare package Medium = Medium1,
    use_m_flow_set=true,
    p_a_nominal=p_a_nominal,
    p_b_nominal=p_b_nominal,
    p_b_start=p_b_nominal,
    m_flow_nominal=m_flow_nominal,
    nParallel=2,
    p_a_start=p_a_nominal,
    m_flow_start=m_flow_nominal)
                 annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=-90,
        origin={28,90})));

  Modelica.Blocks.Interfaces.RealInput T_reference  annotation (Placement(transformation(extent={{120,70},{100,90}})));

  DCOL.Generation.CoolingTowers.BaseClasses.WaterSpray                       waterSpray(
    redeclare package Medium = Medium,
    d_a=d_a,
    d_b=d_b) annotation (Placement(transformation(extent={{-60,70},{-40,90}})));
  Modelica.Blocks.Sources.RealExpression _T_b_water(y=T_b_water.T) "Area of the wet walls of the tank" annotation (Placement(transformation(extent={{120,50},{100,70}})));
equation
  connect(openHTX.port_a_air, port_a_air) annotation (Line(points={{28,-6},{28,-30},{100,-30}}, color={0,127,255}));
  connect(port_a_air, port_a_air) annotation (Line(points={{100,-30},{90,-30},{
          100,-30}}, color={0,127,255}));
  connect(A.y, naturalConvectionVerticalPlate.A) annotation (Line(points={{59,30},{50,30},{50,17},{60,17}}, color={0,0,127}));
  connect(naturalConvectionVerticalPlate.fluid, port_a_ambient) annotation (Line(points={{80,10},{110,10}}, color={191,0,0}));
  connect(storageWall.floor, port_a_floor) annotation (Line(points={{-30,-102},{
          -30,-110},{0,-110}},           color={191,0,0}));
  connect(storageWall.ambient, naturalConvectionVerticalPlate.solid) annotation (Line(points={{-9.2,-57.6},{-10,-57.6},{-10,-58},{50,-58},{50,10},{60,10}},
                                                                                                                               color={191,0,0}));
  connect(waterBasin.heatPort, storageWall.T_water) annotation (Line(points={{-80,-22},
          {-110,-22},{-110,-78},{-30,-78}},                                                                              color={191,0,0}));

  connect(gain1.y,PID. u_m) annotation (Line(points={{74.5,60},{70,60},{70,74}},     color={0,0,127}));
  connect(gain.y,PID. u_s) annotation (Line(points={{84.5,80},{76,80}},
                     color={0,0,127}));
  connect(gain.u, T_reference) annotation (Line(points={{96,80},{110,80}}, color={0,0,127}));
  connect(fan.m_flow_set, PID.y) annotation (Line(points={{36.2,85},{37.1,85},{37.1,80},{64.5,80}},
                          color={0,0,127}));
  connect(openHTX.port_b_air, fan.port_a)
    annotation (Line(points={{28,66},{28,80}}, color={0,127,255}));
  connect(fan.port_b, port_b_air)
    annotation (Line(points={{28,100},{28,110},{60,110}}, color={0,127,255}));
  connect(port_a_water, waterSpray.port_a)
    annotation (Line(points={{-100,80},{-60,80}},color={0,127,255}));
  connect(waterSpray.port_b, openHTX.port_a_water)
    annotation (Line(points={{-40,80},{-28,80},{-28,66}}, color={0,127,255}));
  connect(port_b_water, T_b_water.port_b) annotation (Line(points={{-100,-100},{-90,-100}}, color={0,127,255}));
  connect(T_b_water.port_a, waterBasin.ports[1]) annotation (Line(points={{-70,-100},{-65.3333,-100},{-65.3333,-42}}, color={0,127,255}));
  connect(port_a_Owater, waterBasin.ports[2]) annotation (Line(points={{-100,-52},{-60,-52},{-60,-42}}, color={0,127,255}));
  connect(openHTX.port_b_water, waterBasin.ports[3]) annotation (Line(points={{-28,-6},{-30,-6},{-30,-42},{-54.6667,-42}}, color={0,127,255}));
  connect(_T_b_water.y, gain1.u) annotation (Line(points={{99,60},{86,60}}, color={0,0,127}));
annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-120,
            -120},{120,120}})), Icon(coordinateSystem(preserveAspectRatio=false,
          extent={{-120,-120},{120,120}})),
    Documentation(info="<html>
<p>This model represents a complete open cooling tower.</p>
<p>Air is blowed through the tower and is used to cool the water sprayed at the top of the tower. The heat transferred is sensible heat (due to the increase of the air temperature) and latent heat (due to the evaporation of part of the water). There is a water basin at the bottom of the tower, where the chilled water is storaged. </p>
<p>The difference with <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.Generation.CoolingTowers.OpenCT2\">OpenCT2</a> is that this model considers the thermal heat absorbed by the filter.</p>
<h4>Assumptions</h4>
<ul>
<li>Some water is evaporated during the cooling process;</li>
<li>The pressure drop of the air is considered;</li>
<li>All the heat is transferred from the water to the air, heat losses during the water cooling are not considered;</li>
<li>The NTU (Number of Transfer Units) is used to calculate the amount of heat transferred from the water to the air. NTU is given by the n anc c design parameters of the tower;</li>
<li>Some of the heat exchanged between the air and the water is storaged in the filter (thermal inertia). This amount of thermal storaged depends on the C_inertia parameter.</li>
</ul>
<h4>Use</h4>
<p>The air fan has been supposed to be located at the exit of the tower, so the mass flow source is recomended to be connected to the por_b_air (otherwise problems during the initialization could appear) . </p>
<p>Both the air and water flow is from port_a to port_b.</p>
<h4>References</h4>
<ul>
<li>Lu, L. and Cai, W., &QUOT;A Universal Engineering Model For Cooling Towers&QUOT; (2002). International Refrigeration and Air Conditioning, Conference. Paper 625.;</li>
<li>Li, Xiao; Li, Yaoyu; and Seem, John E., &QUOT;Dynamic Modeling of Mechanical Draft Counter-Flow Wet Cooling Tower with Modelica&QUOT;(2010). International Refrigeration and Air Conditioning Conference. Paper 1094.;</li>
<li>Baker, Donald. R and Shryock, Howard A., &QUOT;A Compresive Aproach To The Analysis Of Cooling Tower Performance&QUOT; (2013). SPX Corporation. Thermal Science.;</li>
<li>http://che.sharif.edu/~heatlab/Lab/Benefit&percnt;20Book&percnt;20&AMP;&percnt;20Journal/Benefit&percnt;20book/Cooling&percnt;20Tower&percnt;20Thermal&percnt;20Design&percnt;20Manual.pdf;</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16<a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end OpenCoolingTower_controlled;
