within DCOL.Generation.CoolingTowers.Testing.CompleteCoolingTowers;
model CompleteOpenCoolingTower_controlled
  import DCOL;

  parameter Integer nNodes=2 "number of section in which is divided de fill";

  Modelica.SIunits.MassFlowRate m_outflow;

  DCOL.Generation.CoolingTowers.OpenCoolingTower_controlled
    completeOpenCoolingTower(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321,
    hmax=0.377825,
    hmin=0.092075,
    c=0.69)
    annotation (Placement(transformation(extent={{-40,-40},{40,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    m_flow=100,
    use_m_flow_in=true,
    use_T_in=true,
    T=308.15) annotation (Placement(transformation(extent={{-80,60},{-60,80}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary1(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    m_flow=-50,
    use_m_flow_in=true,
    use_T_in=true) annotation (Placement(transformation(extent={{-80,-80},{-60,-60}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Blocks.Sources.Constant
                               const(k=97.259)
               annotation (Placement(transformation(extent={{-120,70},{-100,90}})));

  Modelica.Blocks.Sources.Constant const3(k=35 + 273.15) annotation (Placement(transformation(extent={{-140,40},
            {-120,60}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary4(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    m_flow=10,
    use_m_flow_in=true) annotation (Placement(transformation(extent={{-80,-28},
            {-60,-8}})));

  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{-5,-5},
            {5,5}},
        rotation=-90,
        origin={-96,-44})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature ambientTemperature(T=298.15) annotation (Placement(transformation(extent={{96,-3},
            {76,17}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floorTemperature(T=288.15) annotation (Placement(transformation(extent={{-24,-81},
            {-4,-61}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
    hmin=0.092075,
    hmax=0.377825,
    m_In=2,
    m_Out=-2) annotation (Placement(transformation(extent={{-80,10},{-60,30}})));

  Modelica.Fluid.Sources.FixedBoundary    boundary5(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    nPorts=1)   annotation (Placement(transformation(extent={{60,60},
            {40,80}})));

  Modelica.Fluid.Sources.Boundary_pT   boundary6(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    X={0.003,(1 - 0.003)},
    use_T_in=true,
    nPorts=1,
    p=101325) annotation (Placement(transformation(extent={{80,-60},{60,-40}})));

  Modelica.Blocks.Sources.Constant
                               const2(k=25 + 273.15)
                        annotation (Placement(transformation(extent={{120,-56},
            {100,-36}})));
  Modelica.Blocks.Sources.Constant const1(k=29 + 273.15) annotation (Placement(transformation(extent={{84,30},
            {64,50}})));
equation
  when completeOpenCoolingTower.waterBasin.level > completeOpenCoolingTower.hmax
       - 0.05 then
    m_outflow=-10;
  elsewhen completeOpenCoolingTower.waterBasin.level < completeOpenCoolingTower.hmin then
    m_outflow=10;
  end when;

  connect(boundary.ports[1], completeOpenCoolingTower.port_a_water) annotation (
     Line(points={{-60,70},{-60,70},{-30,70},{-30,30}}, color={0,127,255}));
  connect(boundary1.ports[1], completeOpenCoolingTower.port_b_water)
    annotation (Line(points={{-60,-70},{-30,-70},{-30,-30}}, color={0,127,255}));
  connect(const.y, boundary.m_flow_in) annotation (Line(points={{-99,80},{
          -100,80},{-90,80},{-90,78},{-80,78}},
                                      color={0,0,127}));
  connect(const3.y, boundary.T_in) annotation (Line(points={{-119,50},{-88,
          50},{-88,74},{-82,74}}, color={0,0,127}));
  connect(boundary4.ports[1], completeOpenCoolingTower.port_a_Owater)
    annotation (Line(points={{-60,-18},{-60,-18},{-30,-18}}, color={0,127,255}));
  connect(const3.y, boundary1.T_in) annotation (Line(points={{-119,50},{
          -114,50},{-114,48},{-114,-66},{-82,-66}}, color={0,0,127}));
  connect(const.y, gain.u) annotation (Line(points={{-99,80},{-96,80},{-96,-38}}, color={0,0,127}));
  connect(gain.y, boundary1.m_flow_in) annotation (Line(points={{-96,-49.5},{
          -96.5,-49.5},{-96.5,-62},{-80,-62}}, color={0,0,127}));
  connect(floorTemperature.port, completeOpenCoolingTower.port_a_floor)
    annotation (Line(points={{-4,-71},{0,-71},{0,-33.3333}}, color={191,0,0}));
  connect(ambientTemperature.port, completeOpenCoolingTower.port_a_ambient)
    annotation (Line(points={{76,7},{33.3333,7},{33.3333,6.66667}}, color={191,
          0,0}));
  connect(completeOpenCoolingTower.level, levelControl.level) annotation (Line(
        points={{33.3333,-26.6667},{46,-26.6667},{46,-12},{46,44},{-90,44},{-90,
          30},{-90,20},{-82,20}}, color={0,0,127}));
  connect(levelControl.m_outflow, boundary4.m_flow_in) annotation (Line(points=
          {{-59,20},{-50,20},{-50,10},{-90,10},{-90,-10},{-80,-10}}, color={0,0,
          127}));
  connect(boundary5.ports[1], completeOpenCoolingTower.port_b_air) annotation (
      Line(points={{40,70},{20,70},{20,36.6667}}, color={0,127,255}));
  connect(completeOpenCoolingTower.port_a_air, boundary6.ports[1]) annotation (
      Line(points={{33.3333,-10},{33.3333,-10},{48,-10},{48,-50},{60,-50}},
        color={0,127,255}));
  connect(const2.y, boundary6.T_in) annotation (Line(points={{99,-46},{82,-46}},          color={0,0,127}));
  connect(const1.y, completeOpenCoolingTower.T_reference) annotation (Line(
        points={{63,40},{52,40},{52,26.6667},{36.6667,26.6667}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteOpenCoolingTower_controlled;
