within DCOL.Generation.CoolingTowers.Testing.HeatExchanger;
model OpenHTX
  import DCOL;

  DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents.OpenHTX
    heatExchangerOpen
    annotation (Placement(transformation(extent={{-40,-10},{40,70}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    m_flow=100,
    use_m_flow_in=true,
    use_T_in=true,
    T=308.15) annotation (Placement(transformation(extent={{-60,56},{-40,76}})));

  Modelica.Fluid.Sources.FixedBoundary boundary1(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{-68,-90},{-48,-70}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary2(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=false,
    nPorts=1,
    use_m_flow_in=false,
    m_flow=-11.041)        annotation (Placement(transformation(extent={{60,56},
            {40,76}})));

  Modelica.Fluid.Sources.Boundary_pT   boundary3(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=false,
    X={0.02443096,(1 - 0.02443096)},
    p=101325,
    nPorts=1,
    T=308.15) annotation (Placement(transformation(extent={{60,-40},{40,-20}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Blocks.Sources.Constant const(k=21.7)
                                               annotation (Placement(transformation(extent={{-100,68},
            {-80,88}})));

  Modelica.Blocks.Sources.Constant const2(k=38 + 273.15) annotation (Placement(transformation(extent={{-100,38},
            {-80,58}})));

  Modelica.Blocks.Sources.Sine const3(
    freqHz=0.001,
    offset=10 + 273.15,
    amplitude=0)        annotation (Placement(transformation(extent={{100,-56},
            {80,-36}})));

  Modelica.Fluid.Sensors.Temperature T_waterOut(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
  Modelica.Fluid.Sensors.Temperature T_airOut(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{20,78},{40,98}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air1(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{5,-5},{-5,5}},
        rotation=-90,
        origin={28,-20})));
equation
  connect(boundary.ports[1], heatExchangerOpen.port_a_water) annotation (Line(
        points={{-40,66},{-40,66},{-28,66}},          color={0,127,255}));
  connect(const.y, boundary.m_flow_in) annotation (Line(points={{-79,78},{-80,
          78},{-72,78},{-70,78},{-70,74},{-60,74}},                                         color={0,0,127}));
  connect(boundary.T_in, const2.y) annotation (Line(points={{-62,70},{-70,70},{
          -70,48},{-79,48}},                                                                      color={0,0,127}));
  connect(boundary2.ports[1], heatExchangerOpen.port_b_air)
    annotation (Line(points={{40,66},{28,66}},         color={0,127,255}));
  connect(T_waterOut.port, heatExchangerOpen.port_b_water) annotation (Line(
        points={{-50,-20},{-28,-20},{-28,-6}}, color={0,127,255}));
  connect(T_airOut.port, heatExchangerOpen.port_b_air) annotation (Line(points=
          {{30,78},{36,78},{36,66},{32,66},{28,66}}, color={0,127,255}));
  connect(boundary3.ports[1], massFlow_Air1.port_a)
    annotation (Line(points={{40,-30},{28,-30},{28,-25}}, color={0,127,255}));
  connect(massFlow_Air1.port_b, heatExchangerOpen.port_a_air)
    annotation (Line(points={{28,-15},{28,-10.5},{28,-6}}, color={0,127,255}));
  connect(heatExchangerOpen.port_b_water, boundary1.ports[1]) annotation (Line(
        points={{-28,-6},{-28,-6},{-28,-78},{-28,-80},{-48,-80}}, color={0,127,
          255}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})),
      Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end OpenHTX;
