within DCOL.Generation.CoolingTowers.Testing.HeatExchanger;
model OpenHTX_calibracion
  import DCOL;

  DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents.OpenHTX
    heatExchangerOpen(Kfi=0.00001,
    TWater2_start=33 + 273.15)
    annotation (Placement(transformation(extent={{-40,-10},{40,70}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    m_flow=100,
    use_m_flow_in=true,
    use_T_in=true,
    T=308.15) annotation (Placement(transformation(extent={{-60,60},{-40,80}})));

  Modelica.Fluid.Sources.FixedBoundary boundary1(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{-60,-60},{-40,-40}})));

  Modelica.Fluid.Sources.FixedBoundary    boundary2(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    nPorts=1)              annotation (Placement(transformation(extent={{60,60},
            {40,80}})));

  Modelica.Fluid.Sources.MassFlowSource_T
                                       boundary3(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    nPorts=1,
    use_m_flow_in=true,
    use_T_in=true,
    T=308.15,
    X={0.01722614,(1 - 0.01722614)})
              annotation (Placement(transformation(extent={{60,-40},{40,-20}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Blocks.Sources.Constant mW(k=21.7)
    annotation (Placement(transformation(extent={{-100,70},{-80,90}})));

  Modelica.Blocks.Sources.Constant Tw(k=38 + 273.15)
    annotation (Placement(transformation(extent={{-100,30},{-80,50}})));

  Modelica.Blocks.Sources.Constant ma(k=32.767)
    annotation (Placement(transformation(extent={{90,-20},{70,0}})));

  Modelica.Fluid.Sensors.Temperature T_waterOut(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-60,-20},{-40,0}})));
  Modelica.Fluid.Sensors.Temperature T_airOut(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{18,80},{38,100}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air1(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{5,-5},{-5,5}},
        rotation=-90,
        origin={28,-20})));
  Modelica.Blocks.Sources.Constant Ta(k=35 + 273.15)
    annotation (Placement(transformation(extent={{90,-50},{70,-30}})));
equation
  connect(boundary.ports[1], heatExchangerOpen.port_a_water) annotation (Line(
        points={{-40,70},{-28,70},{-28,66}},          color={0,127,255}));
  connect(mW.y, boundary.m_flow_in) annotation (Line(points={{-79,80},{-80,80},{
          -72,80},{-70,80},{-70,78},{-60,78}},  color={0,0,127}));
  connect(boundary.T_in, Tw.y) annotation (Line(points={{-62,74},{-70,74},{-70,40},
          {-79,40}},     color={0,0,127}));
  connect(boundary2.ports[1], heatExchangerOpen.port_b_air)
    annotation (Line(points={{40,70},{28,70},{28,66}}, color={0,127,255}));
  connect(T_waterOut.port, heatExchangerOpen.port_b_water) annotation (Line(
        points={{-50,-20},{-28,-20},{-28,-6}}, color={0,127,255}));
  connect(T_airOut.port, heatExchangerOpen.port_b_air) annotation (Line(points={{28,80},
          {28,80},{28,66}},                          color={0,127,255}));
  connect(boundary3.ports[1], massFlow_Air1.port_a)
    annotation (Line(points={{40,-30},{28,-30},{28,-25}}, color={0,127,255}));
  connect(massFlow_Air1.port_b, heatExchangerOpen.port_a_air)
    annotation (Line(points={{28,-15},{28,-10.5},{28,-6}}, color={0,127,255}));
  connect(heatExchangerOpen.port_b_water, boundary1.ports[1]) annotation (Line(
        points={{-28,-6},{-28,-6},{-28,-50},{-40,-50}}, color={0,127,255}));
  connect(ma.y, boundary3.m_flow_in) annotation (Line(points={{69,-10},{66,-10},
          {66,-22},{60,-22}},color={0,0,127}));
  connect(Ta.y, boundary3.T_in) annotation (Line(points={{69,-40},{66,-40},{66,-26},
          {62,-26}},      color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})),
      Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end OpenHTX_calibracion;
