within DCOL.Generation.CoolingTowers.Testing.HeatExchanger;
model OpenHTXinertia
  import DCOL;

  DCOL.Generation.CoolingTowers.BaseClasses.HeatTransferComponents.OpenHTX_inertia
    heatExchangerOpen( C_iner=0.01)
    annotation (Placement(transformation(extent={{-40,-30},{40,50}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    m_flow=100,
    use_m_flow_in=true,
    use_T_in=true,
    T=308.15) annotation (Placement(transformation(extent={{-80,60},{-60,80}})));

  Modelica.Fluid.Sources.FixedBoundary boundary1(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{-100,-88},{-80,-68}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary2(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=false,
    nPorts=1,
    use_m_flow_in=false,
    m_flow=-57.3619)       annotation (Placement(transformation(extent={{54,52},
            {34,72}})));

  Modelica.Fluid.Sources.Boundary_pT   boundary3(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    nPorts=1,
    use_T_in=false,
    X={0.017623194,(1 - 0.017623194)},
    p=101325,
    T=299.65) annotation (Placement(transformation(extent={{60,-60},{40,-40}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Blocks.Sources.Constant const(k=97.259)
                                               annotation (Placement(transformation(extent={{-120,68},{-100,88}})));

  Modelica.Blocks.Sources.Constant const2(k=35 + 273.15) annotation (Placement(transformation(extent={{-120,40},{-100,60}})));

  Modelica.Blocks.Sources.Sine const3(
    freqHz=0.001,
    offset=10 + 273.15,
    amplitude=0)        annotation (Placement(transformation(extent={{100,-56},
            {80,-36}})));

equation
  connect(boundary.ports[1], heatExchangerOpen.port_a_water) annotation (Line(
        points={{-60,70},{-44,70},{-28,70},{-28,46}}, color={0,127,255}));
  connect(const.y, boundary.m_flow_in) annotation (Line(points={{-99,78},{-90,78},{-80,78}},color={0,0,127}));
  connect(boundary.T_in, const2.y) annotation (Line(points={{-82,74},{-90,74},{ -90,50},{-99,50}},color={0,0,127}));
  connect(boundary3.ports[1], heatExchangerOpen.port_a_air)
    annotation (Line(points={{40,-50},{28,-50},{28,-26}}, color={0,127,255}));
  connect(boundary2.ports[1], heatExchangerOpen.port_b_air)
    annotation (Line(points={{34,62},{28,62},{28,46}}, color={0,127,255}));
  connect(boundary1.ports[1], heatExchangerOpen.port_b_water) annotation (Line(
        points={{-80,-78},{-54,-78},{-54,-80},{-28,-80},{-28,-26}}, color={0,
          127,255}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})),
      Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end OpenHTXinertia;
