within DCOL.Generation.CoolingTowers.Testing.TestControl;
model CompleteCCT_A_m_flow_inertia
  import DCOL;

  DCOL.Generation.CoolingTowers.ClosedCoolingTower_inertia closedCTPressureDrop(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel,
    R_ext=0.03,
    R_int=0.025,
    nCoil=2,
    nParallel=2,
    H2_start=0.02,
    C_iner=1000,
    redeclare package Material1 = Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel,
    nSeg=10,
    pPumpedWater=135496.772,
    TAir2_start=293.15,
    T_start_coil=308.15)
    annotation (Placement(transformation(extent={{-54,-40},{26,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T airIn(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=true,
    m_flow=48,
    nPorts=1,
    X={0.007713153,(1 - 0.007713153)},
    use_m_flow_in=true,
    T=298.15) annotation (Placement(transformation(extent={{73,-46},{53,-26}})));

  Modelica.Fluid.Sources.FixedBoundary airOut(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    nPorts=1,
    p=101325) annotation (Placement(transformation(extent={{80,60},{60,80}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-70,70},
            {-50,90}})));

  Modelica.Fluid.Sources.MassFlowSource_T cWaterIn(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=13.440411,
    use_m_flow_in=true,
    use_T_in=true,
    nPorts=1,
    T=313.15) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={50,22})));

  Modelica.Fluid.Sources.FixedBoundary cWaterOut(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{10,-10},{-10,10}},
        rotation=0,
        origin={100,-4})));

  Modelica.Fluid.Sensors.Temperature T_airout(
    redeclare package Medium = Modelica.Media.Air.MoistAir) annotation (Placement(transformation(extent={{30,74},{50,94}})));

  Modelica.Fluid.Sensors.Temperature T_CWaterout(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)                        annotation (Placement(transformation(extent={{66,0},{86,20}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_floor(T=298.15) annotation (Placement(transformation(extent={{-40,-70},
            {-20,-50}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature T_ambient annotation (Placement(transformation(extent={{-80,18},
            {-60,38}})));

  Modelica.Fluid.Sources.MassFlowSource_T waterOverFlow(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    use_m_flow_in=true) annotation (Placement(transformation(extent={{-80,-34},{-60,-14}})));

  Modelica.Blocks.Sources.Constant ambient_T(
    k=15.5234973 + 273.15) annotation (Placement(transformation(extent={{80,-80},{60,-60}})));

  Modelica.Blocks.Sources.Constant m_CWater(
    k=13.440411) annotation (Placement(transformation(extent={{100,36},
            {80,56}})));

  Modelica.Blocks.Sources.Constant T_CWater(
    k=40 + 273.15) annotation (Placement(transformation(extent={{120,16},{100,36}})));

  Modelica.Blocks.Sources.TimeTable m_Airin(table=[0.0,0; 5000,0; 5000,25;
        10000,25; 10000,50; 15000,50])                             annotation (Placement(transformation(extent={{120,-38},
            {100,-18}})));

  Modelica.Blocks.Sources.Constant m_Airin1(
    k=45.14) annotation (Placement(transformation(extent={{111,-68},{91,-48}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(m_In=1,
      m_Out=0)
    annotation (Placement(transformation(extent={{0,-100},{-20,-80}})));

equation
  connect(waterOverFlow.ports[1],closedCTPressureDrop.port_a_Owater)  annotation (Line(points={{-60,-24},
          {-50,-24}},                                                                                                color={0,127,255}));
  connect(airIn.ports[1], closedCTPressureDrop.port_a_air) annotation (Line(
        points={{53,-36},{50,-36},{50,-13.6},{29.6,-13.6}}, color={0,127,255}));
  connect(airOut.ports[1], closedCTPressureDrop.port_b_air) annotation (Line(points={{60,70},
          {20,70},{20,46},{6,46},{6,40.8}},            color={0,127,255}));
  connect(T_airout.port, closedCTPressureDrop.port_b_air) annotation (Line(
        points={{40,74},{40,74},{40,70},{20,70},{20,46},{6,46},{6,40.8}},
                                                          color={0,127,255}));
  connect(cWaterIn.ports[1], closedCTPressureDrop.port_a_Cwater) annotation (
      Line(points={{40,22},{34,22},{34,16},{26,16}},         color={0,127,255}));
  connect(closedCTPressureDrop.port_b_Cwater, cWaterOut.ports[1]) annotation (
      Line(points={{26,0},{50,0},{50,-4},{90,-4}}, color={0,127,255}));
  connect(T_CWaterout.port, closedCTPressureDrop.port_b_Cwater) annotation (
      Line(points={{76,0},{76,0},{76,-4},{50,-4},{50,0},{26,0}},         color=
          {0,127,255}));
  connect(T_floor.port, closedCTPressureDrop.port_a_floor) annotation (Line(points={{-20,-60},
          {-14,-60},{-14,-40}},                                                                                     color={191,0,0}));
  connect(ambient_T.y, airIn.T_in) annotation (Line(points={{59,-70},{50,-70},{50,
          -50},{80,-50},{80,-32},{75,-32}},     color={0,0,127}));
  connect(ambient_T.y, T_ambient.T) annotation (Line(points={{59,-70},{59,-70},{
          50,-70},{50,-80},{-90,-80},{-90,28},{-82,28}},
                                                 color={0,0,127}));
  connect(T_ambient.port, closedCTPressureDrop.port_a_ambient) annotation (Line(points={{-60,28},
          {-52,28}},                                                                                        color={191,0,0}));
  connect(m_CWater.y, cWaterIn.m_flow_in) annotation (Line(points={{79,46},{70,
          46},{70,30},{60,30}},   color={0,0,127}));
  connect(T_CWater.y, cWaterIn.T_in) annotation (Line(points={{99,26},{110,26},{62,26}}, color={0,0,127}));
  connect(closedCTPressureDrop.level, levelControl.level) annotation (Line(
        points={{30,-24},{40,-24},{40,-90},{2,-90}}, color={0,0,127}));
  connect(waterOverFlow.m_flow_in, levelControl.m_outflow) annotation (Line(
        points={{-80,-16},{-86,-16},{-86,-90},{-21,-90}}, color={0,0,127}));
  connect(airIn.m_flow_in, m_Airin.y)
    annotation (Line(points={{73,-28},{99,-28}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{120,100}})), Icon(coordinateSystem(extent={{-100,-100},{
            120,100}})),
    experiment(
      StopTime=15000,
      __Dymola_fixedstepsize=0.1,
      __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>Test to show how the variation of the inlet air mass flow affects to the Closed Cooling Tower.</p>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteCCT_A_m_flow_inertia;
