within DCOL.Generation.CoolingTowers.Testing.TestControl;
model CompleteCCT_A_temperature
  import DCOL;

  DCOL.Generation.CoolingTowers.ClosedCoolingTower closedCTPressureDrop(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.StainlessSteel,
    mWaterIn=52.766,
    redeclare package Material1 = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321,
    H2_start=0.015,
    pPumpedWater=135496.772,
    TAir2_start=293.15,
    T_start_coil=307.15)
    annotation (Placement(transformation(extent={{-52,-40},{28,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T airIn(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=true,
    m_flow=48,
    nPorts=1,
    X={0.007713153,(1 - 0.007713153)},
    use_m_flow_in=true,
    T=298.15) annotation (Placement(transformation(extent={{75,-46},{55,-26}})));

  Modelica.Fluid.Sources.FixedBoundary airOut(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    nPorts=1,
    p=101325) annotation (Placement(transformation(extent={{80,60},{60,80}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-70,70},
            {-50,90}})));

  Modelica.Fluid.Sources.MassFlowSource_T cWaterIn(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=13.440411,
    use_m_flow_in=true,
    use_T_in=true,
    T=313.15,
    nPorts=1) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={50,22})));

  Modelica.Fluid.Sources.FixedBoundary cWaterOut(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=101325,
    nPorts=1) annotation (Placement(transformation(extent={{10,-10},{-10,10}},
        rotation=0,
        origin={100,-4})));

  Modelica.Fluid.Sensors.Temperature T_airout(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{30,74},{50,94}})));

  Modelica.Fluid.Sensors.Temperature T_CWaterout(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{66,0},{86,20}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature T_floor(T=288.15) annotation (Placement(transformation(extent={{-40,-70},
            {-20,-50}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature T_ambient annotation (Placement(transformation(extent={{-80,18},
            {-60,38}})));

  Modelica.Fluid.Sources.MassFlowSource_T
                                       waterOverFlow(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    nPorts=1,
    use_m_flow_in=true)
              annotation (Placement(transformation(extent={{-80,-34},{-60,-14}})));

  Modelica.Blocks.Sources.Constant  m_CWater(k=13.440411)
                           annotation (Placement(transformation(extent={{100,36},
            {80,56}})));

  Modelica.Blocks.Sources.Constant T_CWater(k=40 + 273.15)
    annotation (Placement(transformation(extent={{120,16},{100,36}})));

  Modelica.Blocks.Sources.Constant m_Airin(k=25)
    annotation (Placement(transformation(extent={{115,-38},{95,-18}})));
  Modelica.Blocks.Sources.TimeTable ambient_T(table=[0.0,5 + 273.15; 5000,5 +
        273.15; 5000,15 + 273.15; 10000,15 + 273.15; 10000,25 + 273.15; 15000,
        25 + 273.15])
    annotation (Placement(transformation(extent={{80,-80},{60,-60}})));
  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
    m_In=1,
    m_Out=0,
    m_outflow(start=1e-5))
    annotation (Placement(transformation(extent={{0,-100},{-20,-80}})));
equation
  connect(waterOverFlow.ports[1],closedCTPressureDrop.port_a_Owater)  annotation (Line(points={{-60,-24},
          {-60,-24},{-48,-24}},                                                                                      color={0,127,255}));
  connect(airIn.ports[1], closedCTPressureDrop.port_a_air) annotation (Line(
        points={{55,-36},{50,-36},{50,-13},{32,-13},{31.6,-13},{31.6,-13.6}},
                                                            color={0,127,255}));
  connect(airOut.ports[1], closedCTPressureDrop.port_b_air)
    annotation (Line(points={{60,70},{8,70},{8,40.8}}, color={0,127,255}));
  connect(T_airout.port, closedCTPressureDrop.port_b_air) annotation (Line(
        points={{40,74},{40,74},{40,70},{8,70},{8,40.8}}, color={0,127,255}));
  connect(cWaterIn.ports[1], closedCTPressureDrop.port_a_Cwater)
    annotation (Line(points={{40,22},{28,22},{28,16}}, color={0,127,255}));
  connect(closedCTPressureDrop.port_b_Cwater, cWaterOut.ports[1]) annotation (
      Line(points={{28,0},{50,0},{50,-4},{90,-4}}, color={0,127,255}));
  connect(T_CWaterout.port, closedCTPressureDrop.port_b_Cwater)
    annotation (Line(points={{76,0},{50,0},{28,0}}, color={0,127,255}));
  connect(T_floor.port, closedCTPressureDrop.port_a_floor)
    annotation (Line(points={{-20,-60},{-12,-60},{-12,-40}}, color={191,0,0}));
  connect(T_ambient.port, closedCTPressureDrop.port_a_ambient)
    annotation (Line(points={{-60,28},{-50,28}}, color={191,0,0}));
  connect(m_CWater.y, cWaterIn.m_flow_in) annotation (Line(points={{79,46},{
          70,46},{70,30},{62,30},{60,30}},
                                  color={0,0,127}));
  connect(T_CWater.y, cWaterIn.T_in)
    annotation (Line(points={{99,26},{110,26},{62,26}}, color={0,0,127}));
  connect(m_Airin.y, airIn.m_flow_in)
    annotation (Line(points={{94,-28},{94,-28},{75,-28}}, color={0,0,127}));
  connect(ambient_T.y, T_ambient.T) annotation (Line(points={{59,-70},{50,-70},
          {50,-80},{-90,-80},{-90,28},{-82,28}}, color={0,0,127}));
  connect(ambient_T.y, airIn.T_in) annotation (Line(points={{59,-70},{59,-70},{
          50,-70},{50,-50},{90,-50},{90,-32},{77,-32}},  color={0,0,127}));
  connect(closedCTPressureDrop.level, levelControl.level) annotation (Line(
        points={{32,-24},{40,-24},{40,-90},{2,-90}}, color={0,0,127}));
  connect(levelControl.m_outflow, waterOverFlow.m_flow_in) annotation (Line(
        points={{-21,-90},{-86,-90},{-86,-16},{-80,-16}}, color={0,0,127}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{120,100}})), Icon(coordinateSystem(extent={{-100,-100},{
            120,100}})),
    Documentation(info="<html>
<p>Test to show how the variation of the inlet air temperature affects to the Closed Cooling Tower.</p>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"),
    experiment(StopTime=15000, __Dymola_Algorithm="Cvode"));
end CompleteCCT_A_temperature;
