within DCOL.Generation.CoolingTowers.Testing.TestControl;
model CompleteOCT_W_temperature
  import DCOL;

  DCOL.Generation.CoolingTowers.OpenCoolingTower openCT2(
    redeclare package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321,
    hmax=0.377825,
    hmin=0.092075,
    TWater2_start=302.15,
    TAir2_start=300.15)
    annotation (Placement(transformation(extent={{-40,-40},{40,40}})));

  Modelica.Fluid.Sources.MassFlowSource_T inletWater(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=100,
    use_m_flow_in=true,
    use_T_in=true,
    T=308.15,
    nPorts=1) annotation (Placement(transformation(extent={{-60,60},{-40,80}})));

  Modelica.Fluid.Sources.MassFlowSource_T outletWater(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=-50,
    use_m_flow_in=true,
    use_T_in=false,
    nPorts=1) annotation (Placement(transformation(extent={{-60,-78},{-40,-58}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-10,68},{10,88}})));

  Modelica.Blocks.Sources.Constant  inlet_m_flowW(k=97.259)
    annotation (Placement(transformation(extent={{-120,68},{-100,88}})));

  Modelica.Fluid.Sources.MassFlowSource_T overflowWater(
    redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=10,
    use_m_flow_in=true,
    nPorts=1)
    annotation (Placement(transformation(extent={{-60,-28},{-40,-8}})));

  Modelica.Blocks.Math.Gain gain(k=-1) annotation (Placement(transformation(extent={{-5,-5},
            {5,5}},
        rotation=-90,
        origin={-80,-45})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature
    ambientTemperature           annotation (Placement(transformation(extent={{68,-3},
            {48,17}})));

  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature floorTemperature(T=288.15) annotation (Placement(transformation(extent={{24,-80},
            {4,-60}})));

  DCOL.Generation.CoolingTowers.BaseClasses.LevelControl levelControl(
    hmin=0.092075,
    hmax=0.377825,
    m_Out=0,
    m_In=1.683)
    annotation (Placement(transformation(extent={{10,40},{-10,60}})));

  Modelica.Fluid.Sources.MassFlowSource_T outletAir(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=false,
    m_flow=-31.5258,
    use_m_flow_in=true,
    nPorts=1)   annotation (Placement(transformation(extent={{60,52},{40,72}})));

  Modelica.Fluid.Sources.Boundary_pT inletAir(
    redeclare package Medium = Modelica.Media.Air.MoistAir,
    use_T_in=true,
    nPorts=1,
    X={0.017623194,(1 - 0.017623194)},
    p=101325) annotation (Placement(transformation(extent={{80,-60},{60,-40}})));

  Modelica.Blocks.Sources.Constant  ambientT(k=26.5 + 273.15)
    annotation (Placement(transformation(extent={{120,-56},{100,-36}})));
  Modelica.Blocks.Sources.Constant  outlet_m_flowA(k=57.3619)
    annotation (Placement(transformation(extent={{110,60},{90,80}})));
  Modelica.Blocks.Math.Gain gain1(
                                 k=-1) annotation (Placement(transformation(extent={{-5,-5},
            {5,5}},
        rotation=180,
        origin={74,70})));
  Modelica.Fluid.Sensors.Temperature T_waterOut(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-50,-60},{-30,-40}})));
  Modelica.Fluid.Sensors.Temperature T_airOut(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{20,70},{40,90}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Air1(redeclare package Medium =
        Modelica.Media.Air.MoistAir)
    annotation (Placement(transformation(extent={{55,-55},{45,-45}})));
  Modelica.Blocks.Sources.TimeTable inlet_TW(table=[0.0,30 + 273.15; 1000,30 +
        273.15; 1000,35 + 273.15; 2000,35 + 273.15; 2000,45 + 273.15; 3000,45
         + 273.15])
    annotation (Placement(transformation(extent={{-120,38},{-100,58}})));
  Modelica.Fluid.Sensors.MassFlowRate massFlow_Water1(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater) annotation (Placement(
        transformation(
        extent={{5,-5},{-5,5}},
        rotation=90,
        origin={-30,60})));
equation

  connect(inlet_m_flowW.y, inletWater.m_flow_in) annotation (Line(points={{-99,78},
          {-96,78},{-60,78}},              color={0,0,127}));
  connect(inlet_m_flowW.y, gain.u) annotation (Line(points={{-99,78},{-80,78},
          {-80,-39}},                                                                      color={0,0,127}));
  connect(gain.y, outletWater.m_flow_in) annotation (Line(points={{-80,-50.5},{
          -80,-60},{-60,-60}},
                           color={0,0,127}));
  connect(openCT2.level, levelControl.level) annotation (Line(points={{33.3333,
          -26.6667},{42,-26.6667},{42,50},{12,50}},
                                           color={0,0,127}));
  connect(levelControl.m_outflow, overflowWater.m_flow_in) annotation (Line(
        points={{-11,50},{-70,50},{-70,-10},{-60,-10}}, color={0,0,127}));
  connect(openCT2.port_b_water, outletWater.ports[1]) annotation (Line(points={{-30,-30},
          {-30,-68},{-40,-68}},           color={0,127,255}));
  connect(overflowWater.ports[1],openCT2.port_a_Owater)  annotation (Line(
        points={{-40,-18},{-30,-18}},           color={0,127,255}));
  connect(openCT2.port_a_floor, floorTemperature.port) annotation (Line(points={{0,
          -33.3333},{0,-33.3333},{0,-70},{4,-70}},     color={191,0,0}));
  connect(openCT2.port_b_air, outletAir.ports[1]) annotation (Line(points={{20,
          36.6667},{20,36.6667},{20,62},{40,62}}, color={0,127,255}));
  connect(outlet_m_flowA.y, gain1.u) annotation (Line(points={{89,70},{89,70},{
          84,70},{80,70}},                                                              color={0,0,127}));
  connect(gain1.y, outletAir.m_flow_in) annotation (Line(points={{68.5,70},{66,
          70},{64,70},{60,70}},                                                              color={0,0,127}));
  connect(ambientT.y, inletAir.T_in) annotation (Line(points={{99,-46},{82,
          -46}},                                                                            color={0,0,127}));
  connect(ambientT.y, ambientTemperature.T) annotation (Line(points={{99,-46},{
          90,-46},{90,7},{70,7}}, color={0,0,127}));
  connect(ambientTemperature.port, openCT2.port_a_ambient) annotation (Line(
        points={{48,7},{48,7},{48,6.66667},{33.3333,6.66667}}, color={191,0,0}));
  connect(inletAir.ports[1], massFlow_Air1.port_a)
    annotation (Line(points={{60,-50},{55,-50}}, color={0,127,255}));
  connect(massFlow_Air1.port_b, openCT2.port_a_air) annotation (Line(points={{45,-50},
          {38,-50},{38,-10},{33.3333,-10}},         color={0,127,255}));
  connect(T_waterOut.port, openCT2.port_b_water) annotation (Line(points={{-40,
          -60},{-30,-60},{-30,-30}}, color={0,127,255}));
  connect(T_airOut.port, openCT2.port_b_air) annotation (Line(points={{30,70},{
          30,70},{30,62},{20,62},{20,36.6667}}, color={0,127,255}));
  connect(inlet_TW.y, inletWater.T_in) annotation (Line(points={{-99,48},{-90,
          48},{-90,74},{-62,74}}, color={0,0,127}));
  connect(inletWater.ports[1], massFlow_Water1.port_a)
    annotation (Line(points={{-40,70},{-30,70},{-30,65}}, color={0,127,255}));
  connect(massFlow_Water1.port_b, openCT2.port_a_water)
    annotation (Line(points={{-30,55},{-30,30}}, color={0,127,255}));
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), experiment(StopTime=3000, __Dymola_Algorithm=
          "Cvode"),
    Documentation(info="<html>
<p>Test to show how the variation of the inlet water temperature affects to the Open Cooling Tower.</p>
</html>",
    revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end CompleteOCT_W_temperature;
