within DCOL.Generation.SolarThermal.BaseClasses;
model AbsortivityRadiationIncidenceAngleDependent
  "Absortivity of a selective surface depending on radiation incidence angle"

  Modelica.Blocks.Interfaces.RealInput incidenceAngle(unit="rad") annotation (
      Placement(transformation(extent={{-140,-20},{-100,20}}, rotation=0),
        iconTransformation(extent={{-140,-20},{-100,20}})));
  Modelica.Blocks.Interfaces.RealOutput absortivity annotation (Placement(
        transformation(extent={{100,-18},{136,18}}, rotation=0),
        iconTransformation(extent={{100,-10},{120,10}})));

  parameter Real absortivityNormalIncidence;

equation
  if (incidenceAngle - (Modelica.Constants.pi/2)) > 0 then
    absortivity = 0;
  else
    absortivity = absortivityNormalIncidence*(1 + incidenceAngle*(-1.5879E-3 +
      incidenceAngle*(2.7314E-4 + incidenceAngle*(-2.3026E-5 + incidenceAngle*(
      9.0244E-7 + incidenceAngle*(-1.8E-8 + incidenceAngle*(1.7734E-10 - (
      6.9937E-13*incidenceAngle))))))));
  end if;

  annotation (
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
            100,100}}), graphics={Rectangle(
          extent={{-100,100},{100,-100}},
          lineColor={127,0,127},
          fillColor={255,85,170},
          fillPattern=FillPattern.Solid),Text(
          extent={{-24,114},{24,96}},
          lineColor={0,0,0},
          fillPattern=FillPattern.HorizontalCylinder,
          fillColor={255,255,255},
          fontSize=40,
          textString="%name
")}),
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
            100}}), graphics={Rectangle(
          extent={{-100,100},{100,-102}},
          lineColor={127,0,127},
          lineThickness=1,
          fillColor={255,85,170},
          fillPattern=FillPattern.Solid),Text(
          extent={{-40,120},{32,108}},
          lineColor={0,0,255},
          fillPattern=FillPattern.HorizontalCylinder,
          fillColor={255,255,255},
          textString="%name",
          fontSize=40)}),
    Documentation(info="<html>
<p>Block for the calculation of collector solar radiation absorptance depending on radiation incidence angle</p>
<p>-----------------------------------------------------------------------------------------------------</p>
<p>A. Duffie and W. A. Beckman. Solar Energy Thermal Processes (Third Edition). John Wiley and Sons, New Jersey, 2006, p.198</p>
</html>"));
end AbsortivityRadiationIncidenceAngleDependent;
