within DCOL.Generation.SolarThermal.BaseClasses;
function ConvectionCharacteristicLength
  "Convection current length of convective heat exchange between the cover and the surrounding ambient"

  Modelica.Blocks.Interfaces.RealInput fluidDirection(unit="rad");
  Modelica.Blocks.Interfaces.RealInput longSide(unit="m");
  Modelica.Blocks.Interfaces.RealInput shortSide(unit="m");
  Modelica.Blocks.Interfaces.RealOutput L(unit="m");

protected
  Modelica.SIunits.Length L_shortSide;
  Modelica.SIunits.Length L_longSide;
  Modelica.SIunits.Angle limitAngle;

algorithm
  if (fluidDirection > 0 and fluidDirection < Modelica.Constants.pi/2) then
    L_shortSide := longSide/Modelica.Math.sin(fluidDirection);
    L_longSide := shortSide/Modelica.Math.cos(fluidDirection);
    limitAngle := Modelica.Math.atan(L_shortSide/L_longSide);
    if (fluidDirection - limitAngle) >= 0 then
      L := L_shortSide;
    else
      L := L_longSide;
    end if;
  elseif fluidDirection <= 0 then
    L := longSide;
  else
    L := shortSide;
  end if;

  annotation (Documentation(info="<html>
<p>Source: Enari Satroi, Convection coeffcient eqations for forced air flow over flat surfaces, Solar Energy 80 (2006) 1063-1071</p>
</html>"));
end ConvectionCharacteristicLength;
