within DCOL.Generation.SolarThermal.BaseClasses;
function TransmissivityRadiationIncidenceAngleDependent

  parameter Modelica.SIunits.RefractiveIndex n_air=1;
  parameter Modelica.SIunits.RefractiveIndex n_material=1.526;

protected
  Modelica.SIunits.Angle refractionAngle;
  Real paralelUnpolarizedRadiation;
  Real perpendicularUnpolarizedRadiation;
  Modelica.SIunits.TransmissionCoefficient transmissivityReflectionLosses;
  Modelica.SIunits.TransmissionCoefficient transmissivityAbsorptionLosses;

public
  Modelica.Blocks.Interfaces.RealInput incidenceAngle(unit="rad");
  Modelica.Blocks.Interfaces.RealOutput transmissivity;
  Modelica.Blocks.Interfaces.RealInput absorptionCoefficient
    "Absorption coefficient of the material";
  Modelica.Blocks.Interfaces.RealInput e_material "material thickness";

algorithm
  refractionAngle := Modelica.Math.asin(n_air*Modelica.Math.sin(incidenceAngle)
    /n_material);
  paralelUnpolarizedRadiation := ((Modelica.Math.tan(refractionAngle -
    incidenceAngle))^2)/((Modelica.Math.tan(refractionAngle + incidenceAngle))^
    2);
  perpendicularUnpolarizedRadiation := ((Modelica.Math.sin(refractionAngle -
    incidenceAngle))^2)/((Modelica.Math.sin(refractionAngle + incidenceAngle))^
    2);
  transmissivityReflectionLosses := 0.5*(((1 - paralelUnpolarizedRadiation)/(1
     + paralelUnpolarizedRadiation)) + ((1 - perpendicularUnpolarizedRadiation)
    /(1 + perpendicularUnpolarizedRadiation)));
  transmissivityAbsorptionLosses := Modelica.Math.exp(-absorptionCoefficient*
    e_material/Modelica.Math.cos(refractionAngle));

  transmissivity := transmissivityReflectionLosses*
    transmissivityAbsorptionLosses;

  annotation (Documentation(info="<html>
<p>Function for the calculation of a surface solar radiation transissivity depending on radiation incidence angle</p>
<p>-----------------------------------------------------------------------------------------------------</p>
<p>A. Duffie and W. A. Beckman. Solar Energy Thermal Processes (Third Edition). John Wiley and Sons, New Jersey, 2006, p.204-208</p>
</html>"));
end TransmissivityRadiationIncidenceAngleDependent;
