within DCOL.Generation.SolarThermal.BaseClasses;
model TransmissivityRadiationIncidenceAngleDependentBlock

  parameter Real absorptionCoefficient "Absorption coefficient of the material";
  parameter Real e_material "Material thickness";
  parameter Real transmissivityNormalIncidence;

protected
  Real tau;

public
  Modelica.Blocks.Interfaces.RealInput incidenceAngle(unit="rad") annotation (
      Placement(transformation(extent={{-142,-24},{-102,16}}, rotation=0),
        iconTransformation(extent={{-134,-16},{-102,16}})));

  Modelica.Blocks.Interfaces.RealOutput transmissivity
    annotation (Placement(transformation(extent={{100,-10},{120,10}})));
equation
  if incidenceAngle > 0 then
    tau = TransmissivityRadiationIncidenceAngleDependent(
      incidenceAngle,
      absorptionCoefficient,
      e_material);
  else
    tau = transmissivityNormalIncidence;
  end if;
  if (incidenceAngle - (Modelica.Constants.pi/2)) >= 0 then
    transmissivity = 0;
  else
    transmissivity = tau;
  end if;

  annotation (
    Diagram(coordinateSystem(preserveAspectRatio=false,extent={{-100,-100},{100,
            100}}), graphics={Rectangle(
          extent={{-100,100},{100,-100}},
          lineColor={0,0,0},
          fillColor={255,255,0},
          fillPattern=FillPattern.Solid),Text(
          extent={{-24,118},{32,106}},
          lineColor={0,0,255},
          fillPattern=FillPattern.HorizontalCylinder,
          fillColor={255,255,255},
          textString="%name",
          fontSize=40)}),
    Icon(coordinateSystem(preserveAspectRatio=false,extent={{-100,-100},{100,
            100}}), graphics={Rectangle(
          extent={{-100,100},{100,-100}},
          lineColor={0,0,0},
          fillColor={255,255,0},
          fillPattern=FillPattern.Solid),Text(
          extent={{-62,124},{66,102}},
          lineColor={0,0,255},
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid,
          textString="%name",
          fontSize=40)}),
    DymolaStoredErrors,
    Documentation(info="<html>
<p>This block just calls function <a href=\"Ambassador_WP4.ThermoFluidTek.ThermalSources.SolarThermal.BaseClasses.TransmissivityRadiationIncidenceAngleDependent\">TransmissivityRadiationIncidenceAngleDependent</a> to calculate the collector glass cover transmissivity depending on radiation incidence angle.</p>
</html>"));
end TransmissivityRadiationIncidenceAngleDependentBlock;
