within DCOL.Generation.SolarThermal.FMU;
model SolarSystemBasurtoRUG
  parameter Integer n=267 "day of the year";
  parameter Modelica.SIunits.Time e=2
    "Hour change; e=0(h) for no change; e=1(h) if change and winter; e=2(h) if change and summer";
protected
  Interfaces.SolarCollectorInput solarCollectorInput1
    annotation (Placement(transformation(extent={{-40,-6},{-20,14}})));
public
  inner Modelica.Fluid.System system
    annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
  Modelica_IK4_TEKNIKER.Fluid.Sources.FixedBoundary boundary(redeclare package Medium = Modelica.Media.Incompressible.Examples.Glycol47, nPorts=1) annotation (Placement(transformation(extent={{140,-92},{120,-72}})));
  Modelica_IK4_TEKNIKER.Fluid.Sources.MassFlowSource_T boundary1(
    redeclare package Medium = Modelica.Media.Incompressible.Examples.Glycol47,
    nPorts=1,
    m_flow=0.11584*36,
    use_m_flow_in=true,
    use_T_in=true,
    T=343.15) annotation (Placement(transformation(extent={{120,52},{100,72}})));

  Modelica_IK4_TEKNIKER.Meteorological.ClearnessIndex_IncidenceAngle clearnessIndex_IncidenceAngle(
    latitude=0.75502943441275,
    longitude=-0.05155528077466,
    n=n,
    e=e,
    cAzimuth=0.73303828583762,
    cInclination=0.92956235961218) annotation (Placement(transformation(extent={{-102,-2},{-82,18}})));

  ParallelSimplifiedSolarCollector SolarCollectorRow1(
    redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47,
    Nparallel=36,
    n_tubes=1,
    angleModifierData(displayUnit="rad") = 0.87266,
    collectorHarp(T_start=343.15),
    m_flow_max=0.1158411,
    D_tubes=0.0321,
    L_tubes=1.856,
    S_absorber=1.77,
    incidenceAngleModifierData=0.89,
    C=4100,
    F_tau_alfa=0.764,
    c1=4.33,
    c2=0.0069,
    x={2.778e-5,5.556e-5,8.33e-5,1.11e-4},
    y={250,550,900,1300})
    annotation (Placement(transformation(extent={{36,58},{64,84}})));
  ParallelSimplifiedSolarCollector SolarCollectorRow2(
    redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47,
    Nparallel=36,
    n_tubes=1,
    angleModifierData(displayUnit="rad") = 0.87266,
    collectorHarp(T_start=343.15),
    m_flow_max=0.1158411,
    D_tubes=0.0321,
    L_tubes=1.856,
    S_absorber=1.77,
    incidenceAngleModifierData=0.89,
    C=4100,
    F_tau_alfa=0.764,
    c1=4.33,
    c2=0.0069,
    x={2.778e-5,5.556e-5,8.33e-5,1.11e-4},
    y={250,550,900,1300})
    annotation (Placement(transformation(extent={{36,10},{64,36}})));
  ParallelSimplifiedSolarCollector SolarCollectorRow3(
    redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47,
    Nparallel=36,
    n_tubes=1,
    angleModifierData(displayUnit="rad") = 0.87266,
    collectorHarp(T_start=343.15),
    m_flow_max=0.1158411,
    D_tubes=0.0321,
    L_tubes=1.856,
    S_absorber=1.77,
    incidenceAngleModifierData=0.89,
    C=4100,
    F_tau_alfa=0.764,
    c1=4.33,
    c2=0.0069,
    x={2.778e-5,5.556e-5,8.33e-5,1.11e-4},
    y={250,550,900,1300})
    annotation (Placement(transformation(extent={{36,-40},{64,-14}})));
  RealConnectors.RealTemperatureInput ambientTemperature
    "Ambient temperature in K"
    annotation (Placement(transformation(extent={{-180,80},{-140,120}})));
  RealConnectors.RealIrradianceInput   gIhor annotation (Placement(transformation(extent={{-180,40},
            {-140,80}}),                                                                                                      iconTransformation(extent={{-180,40},
            {-140,80}})));
  RealConnectors.RealTimeInput         localTime_h
    "Local time in h with decimals"                          annotation (
      Placement(transformation(extent={{-180,0},{-140,40}}),
        iconTransformation(extent={{-180,0},{-140,40}})));
  RealConnectors.RealIrradianceInput   irradiance annotation (Placement(
        transformation(extent={{-180,-40},{-140,0}}), iconTransformation(extent={{-180,
            -40},{-140,0}})));
  RealConnectors.RealMassFlowInput inlet_massFlow
    annotation (Placement(transformation(extent={{-180,-80},{-140,-40}})));
  RealConnectors.RealTemperatureInput inlet_Temperature
    annotation (Placement(transformation(extent={{-180,-120},{-140,-80}})));
  RealConnectors.RealTemperatureOutput outlet_Temperature
    "Outlet Temprature of the fluid"
    annotation (Placement(transformation(extent={{160,-10},{180,10}})));
  Modelica.Fluid.Sensors.Temperature temperature(redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47)
    annotation (Placement(transformation(extent={{40,-76},{60,-56}})));
equation
  connect(clearnessIndex_IncidenceAngle.incidenceAngle, solarCollectorInput1.IncidenceAngle)
    annotation (Line(points={{-79.9,2.9},{-57.95,2.9},{-57.95,4.05},{-29.95,
          4.05}}, color={0,0,127}), Text(
      string="%second",
      index=1,
      extent={{6,3},{6,3}}));
  connect(boundary1.ports[1], SolarCollectorRow1.inlet) annotation (Line(points={{100,62},
          {100,62.2},{60.2,62.2}},                   color={0,127,255}));
  connect(solarCollectorInput1, SolarCollectorRow1.solarCollectorInput)
    annotation (Line(points={{-30,4},{-26,4},{-26,70},{40.15,70},{40.15,69.1}},
        color={0,0,0}), Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}}));
  connect(solarCollectorInput1, SolarCollectorRow2.solarCollectorInput)
    annotation (Line(points={{-30,4},{2,4},{2,20},{40.15,20},{40.15,21.1}},
                                                                      color={0,
          0,0}), Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}}));
  connect(solarCollectorInput1, SolarCollectorRow3.solarCollectorInput)
    annotation (Line(points={{-30,4},{-30,-30},{40.15,-30},{40.15,-28.9}},
        color={0,0,0}), Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}}));
  connect(SolarCollectorRow1.outlet, SolarCollectorRow2.inlet) annotation (Line(
        points={{38.5,78.2},{12,78.2},{12,54},{106,54},{106,14},{94,14},{94,14.2},
          {60.2,14.2}},color={0,127,255}));
  connect(SolarCollectorRow2.outlet, SolarCollectorRow3.inlet) annotation (Line(
        points={{38.5,30.2},{12,30.2},{12,-12},{120,-12},{120,-35.8},{60.2,-35.8}},
                   color={0,127,255}));
  connect(SolarCollectorRow3.outlet, boundary.ports[1]) annotation (Line(points={{38.5,
          -19.8},{14,-19.8},{14,-82},{120,-82}},       color={0,127,255}));
  connect(ambientTemperature, solarCollectorInput1.AmbientTemperature)
    annotation (Line(points={{-160,100},{-120,100},{-120,70},{-30,70},{-30,42},
          {-29.95,42},{-29.95,4.05}},
                              color={0,0,127}), Text(
      string="%second",
      index=1,
      extent={{6,3},{6,3}}));
  connect(inlet_massFlow, boundary1.m_flow_in) annotation (Line(points={{-160,
          -60},{134,-60},{134,70},{120,70}},
                                        color={0,0,127}));
  connect(inlet_Temperature, boundary1.T_in) annotation (Line(points={{-160,
          -100},{-16,-100},{-16,-48},{130,-48},{130,66},{122,66}},
                                                            color={0,0,127}));
  connect(temperature.T, outlet_Temperature) annotation (Line(points={{57,-66},{
          148,-66},{148,0},{170,0}}, color={0,0,127}));
  connect(temperature.port, SolarCollectorRow3.outlet) annotation (Line(points={
          {50,-76},{50,-82},{14,-82},{14,-19.8},{38.5,-19.8}}, color={0,127,255}));
  connect(gIhor, clearnessIndex_IncidenceAngle.gIhor) annotation (Line(points={{
          -160,60},{-120,60},{-120,12.8},{-104,12.8}}, color={0,0,127}));
  connect(localTime_h, clearnessIndex_IncidenceAngle.localTime_h) annotation (
      Line(points={{-160,20},{-132,20},{-132,4},{-104,4}}, color={0,0,127}));
  connect(irradiance, solarCollectorInput1.Irradiance) annotation (Line(points={{-160,
          -20},{-29.95,-20},{-29.95,4.05}},       color={0,0,127}), Text(
      string="%second",
      index=1,
      extent={{6,3},{6,3}}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-160,
            -120},{160,120}})),                                  Diagram(
        coordinateSystem(preserveAspectRatio=false, extent={{-160,-120},{160,
            120}})));
end SolarSystemBasurtoRUG;
