within DCOL.Generation.SolarThermal.FMU;
model SolarSystemBasurtoSOLTOP
  parameter Integer n=267 "day of the year";
  parameter Modelica.SIunits.Time e=0
    "Hour change; e=0(s) for no change; e=3600(s) if change and winter; e=7200(s) if change and summer";
protected
  Interfaces.SolarCollectorInput solarCollectorInput1
    annotation (Placement(transformation(extent={{-40,-6},{-20,14}})));
public
  inner Modelica.Fluid.System system
    annotation (Placement(transformation(extent={{-100,80},{-80,100}})));
  Modelica_IK4_TEKNIKER.Fluid.Sources.FixedBoundary boundary(redeclare package Medium = Modelica.Media.Incompressible.Examples.Glycol47, nPorts=1) annotation (Placement(transformation(extent={{152,-96},{132,-76}})));
  Modelica_IK4_TEKNIKER.Fluid.Sources.MassFlowSource_T boundary1(
    redeclare package Medium = Modelica.Media.Incompressible.Examples.Glycol47,
    nPorts=1,
    m_flow=0.03*36,
    use_m_flow_in=true,
    use_T_in=true,
    T=343.15) annotation (Placement(transformation(extent={{126,50},{106,70}})));

  Modelica_IK4_TEKNIKER.Meteorological.ClearnessIndex_IncidenceAngle clearnessIndex_IncidenceAngle(
    n=n,
    e=e,
    latitude=0.75502943441275,
    longitude=-0.05155528077466,
    cAzimuth=0.73303828583762,
    cInclination=0.92956235961218) annotation (Placement(transformation(extent={{-84,0},{-64,20}})));

  ParallelSimplifiedSolarCollector SolarCollectorRow1(
    redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47,
    m_flow_max=0.057921,
    n_tubes=1,
    angleModifierData(displayUnit="rad") = 0.87266,
    L_tubes=1.897,
    S_absorber=1.926,
    incidenceAngleModifierData=0.94,
    C=5400,
    F_tau_alfa=0.854,
    c1=4.06,
    c2=0.009,
    x={1.389e-5,2.778e-5,4.167e-5,5.556e-5,6.944e-5,8.33e-5},
    collectorHarp(T_start=343.15),
    Nparallel=35,
    D_tubes=0.0393,
    y={5000,14000,27000,45000,66000,92000})
    annotation (Placement(transformation(extent={{36,40},{64,66}})));
  ParallelSimplifiedSolarCollector SolarCollectorRow2(
    redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47,
    m_flow_max=0.057921,
    n_tubes=1,
    angleModifierData(displayUnit="rad") = 0.87266,
    L_tubes=1.897,
    S_absorber=1.926,
    incidenceAngleModifierData=0.94,
    C=5400,
    F_tau_alfa=0.854,
    c1=4.06,
    c2=0.009,
    x={1.389e-5,2.778e-5,4.167e-5,5.556e-5,6.944e-5,8.33e-5},
    collectorHarp(T_start=343.15),
    Nparallel=35,
    D_tubes=0.0393,
    y={5000,14000,27000,45000,66000,92000})
    annotation (Placement(transformation(extent={{36,0},{64,26}})));
  ParallelSimplifiedSolarCollector SolarCollectorRow3(
    redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47,
    m_flow_max=0.057921,
    n_tubes=1,
    angleModifierData(displayUnit="rad") = 0.87266,
    L_tubes=1.897,
    S_absorber=1.926,
    incidenceAngleModifierData=0.94,
    C=5400,
    F_tau_alfa=0.854,
    c1=4.06,
    c2=0.009,
    x={1.389e-5,2.778e-5,4.167e-5,5.556e-5,6.944e-5,8.33e-5},
    collectorHarp(T_start=343.15),
    Nparallel=35,
    D_tubes=0.0393,
    y={5000,14000,27000,45000,66000,92000})
    annotation (Placement(transformation(extent={{36,-40},{64,-14}})));

  RealConnectors.RealTemperatureInput ambientTemperature
    "Ambient temperature in K"
    annotation (Placement(transformation(extent={{-180,80},{-140,120}})));
  RealConnectors.RealIrradianceInput   Ighor annotation (Placement(
        transformation(extent={{-180,40},{-140,80}}), iconTransformation(extent={{-180,40},
            {-140,80}})));
  RealConnectors.RealTimeInput localTime annotation (
      Placement(transformation(extent={{-180,0},{-140,40}}),
        iconTransformation(extent={{-180,0},{-140,40}})));
  RealConnectors.RealIrradianceInput   irradiance annotation (Placement(
        transformation(extent={{-180,-40},{-140,0}}), iconTransformation(extent={{-180,
            -40},{-140,0}})));
  RealConnectors.RealMassFlowInput inlet_massFlow  annotation (Placement(transformation(extent={{-180,-80},{-140,-40}}),
        iconTransformation(extent={{-180,-80},{-140,-40}})));
  RealConnectors.RealTemperatureInput inlet_Temperature  annotation (Placement(transformation(extent={{-180,-120},{-140,-80}})));
  RealConnectors.RealTemperatureOutput outlet_Temperature "Outlet Temprature of the fluid"  annotation (Placement(transformation(extent={{160,-10},{180,10}})));
  Modelica.Fluid.Sensors.Temperature temperature(redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47) annotation (Placement(transformation(extent={{40,-80},{60,-60}})));
equation
  connect(boundary1.ports[1], SolarCollectorRow1.inlet) annotation (Line(points={{106,60},
          {100,60},{100,44.2},{60.2,44.2}},          color={0,127,255}));
  connect(SolarCollectorRow1.outlet, SolarCollectorRow2.inlet) annotation (Line(
        points={{38.5,60.2},{0,60.2},{0,36},{120,36},{120,4.2},{60.2,4.2}},
        color={0,127,255}));
  connect(SolarCollectorRow2.outlet, SolarCollectorRow3.inlet) annotation (Line(
        points={{38.5,20.2},{0,20.2},{0,-2},{120,-2},{120,-35.8},{60.2,-35.8}},
        color={0,127,255}));
  connect(SolarCollectorRow3.outlet, boundary.ports[1]) annotation (Line(points={{38.5,
          -19.8},{0,-19.8},{0,-86},{132,-86}},       color={0,127,255}));
  connect(solarCollectorInput1, SolarCollectorRow1.solarCollectorInput)
    annotation (Line(points={{-30,4},{-26,4},{-26,52},{40.15,52},{40.15,51.1}},
        color={0,0,0}), Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}}));
  connect(solarCollectorInput1, SolarCollectorRow2.solarCollectorInput)
    annotation (Line(points={{-30,4},{8,4},{8,11.1},{40.15,11.1}},
                                                                 color={0,0,0}),
      Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}}));
  connect(solarCollectorInput1, SolarCollectorRow3.solarCollectorInput)
    annotation (Line(points={{-30,4},{-28,4},{-28,-28},{40.15,-28},{40.15,-28.9}},
        color={0,0,0}), Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}}));
  connect(inlet_massFlow, boundary1.m_flow_in) annotation (Line(points={{-160,-60},
          {136,-60},{136,68},{126,68}},                                   color=
         {0,0,127}));
  connect(inlet_Temperature, boundary1.T_in) annotation (Line(points={{-160,-100},
          {-60,-100},{-60,-54},{140,-54},{140,64},{128,64}},
                                                   color={0,0,127}));
  connect(localTime, clearnessIndex_IncidenceAngle.localTime) annotation (
      Line(points={{-160,20},{-128,20},{-128,6},{-86,6}},  color={0,0,127}));
  connect(Ighor, clearnessIndex_IncidenceAngle.gIhor) annotation (Line(points={{-160,60},
          {-86,60},{-86,14.8}},             color={0,0,127}));
  connect(temperature.port, SolarCollectorRow3.outlet) annotation (Line(points={
          {50,-80},{50,-86},{0,-86},{0,-19.8},{38.5,-19.8}}, color={0,127,255}));
  connect(temperature.T, outlet_Temperature) annotation (Line(points={{57,-70},{
          148,-70},{148,0},{170,0}}, color={0,0,127}));
  connect(irradiance, solarCollectorInput1.Irradiance) annotation (Line(points={
          {-160,-20},{-54,-20},{-54,4.05},{-29.95,4.05}}, color={0,0,127}));
  connect(clearnessIndex_IncidenceAngle.incidenceAngle, solarCollectorInput1.IncidenceAngle)
    annotation (Line(points={{-61.9,4.9},{-55.95,4.9},{-55.95,4.05},{-29.95,
          4.05}},
        color={0,0,127}));
  connect(ambientTemperature, solarCollectorInput1.AmbientTemperature)
    annotation (Line(points={{-160,100},{-120,100},{-120,66},{-50,66},{-50,4.05},
          {-29.95,4.05}}, color={0,0,127}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-160,-120},
            {160,120}})),                                        Diagram(
        coordinateSystem(preserveAspectRatio=false, extent={{-160,-120},{160,120}})));
end SolarSystemBasurtoSOLTOP;
