within DCOL.Generation.SolarThermal;
model SolarCollectorsMedium
  "Solar collector model (detailed or simplified) and other elements (pump, sensors, ambient) involving medium definition"

  parameter Boolean simplifiedModel=true;

  SimplifiedSolarCollector collectorSimplified(redeclare package Medium =
        Medium) if simplifiedModel annotation (Placement(transformation(extent=
            {{0,14},{138,178}},rotation=0)));

  Modelica.Fluid.Sources.FixedBoundary ambient(redeclare package Medium =
        Medium, nPorts=1) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=180,
        origin={-76,136})));
  Modelica.Fluid.Sensors.Temperature outletTemperature(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{-64,134},{-44,154}})));
  Modelica.Fluid.Sources.MassFlowSource_T volumeFlow(
    use_m_flow_in=true,
    use_T_in=true,
    redeclare package Medium = Medium,
    nPorts=1)
    annotation (Placement(transformation(extent={{-86,-160},{-64,-138}})));
  Interfaces.SolarCollectorInput solarCollectorInput annotation (Placement(
        transformation(extent={{-152,0},{-110,46}}), iconTransformation(
        extent={{-21,-23},{21,23}},
        rotation=90,
        origin={-141,-17})));
  replaceable package Medium = Modelica.Media.Interfaces.PartialMedium
    annotation (choicesAllMatching=true);

equation
  connect(ambient.ports[1], outletTemperature.port) annotation (Line(
      points={{-66,136},{-60,136},{-60,134},{-54,134}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(outletTemperature.port, collectorSimplified.outlet) annotation (Line(
      points={{-54,134},{-20,134},{-20,141.415},{12.3214,141.415}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(outletTemperature.port, collectorDetailled.outlet) annotation (Line(
      points={{-54,134},{-50,134},{-50,-34},{16.3214,-34},{16.3214,-36.5846}},
      color={0,127,255},
      smooth=Smooth.None));

  connect(volumeFlow.ports[1], collectorDetailled.inlet) annotation (Line(
      points={{-64,-149},{-60,-149},{-60,-152},{-54,-152},{-54,-174},{148,-174},
          {148,-137.508},{123.271,-137.508}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(volumeFlow.ports[1], collectorSimplified.inlet) annotation (Line(
      points={{-64,-149},{-60,-149},{-60,-152},{-54,-152},{-54,-174},{148,
          -174},{148,40.4923},{119.271,40.4923}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(solarCollectorInput, collectorSimplified.solarCollectorInput)
    annotation (Line(
      points={{-131,23},{-14.5,23},{-14.5,84.0154},{20.4536,84.0154}},
      color={0,0,127},
      smooth=Smooth.None), Text(
      string="%first",
      index=-1,
      extent={{-6,3},{-6,3}}));
  connect(collectorDetailled.solarCollectorInput, solarCollectorInput)
    annotation (Line(
      points={{24.4536,-93.9846},{-46,-93.9846},{-46,22},{-131,22},{-131,23}},
      color={0,0,127},
      smooth=Smooth.None), Text(
      string="%second",
      index=1,
      extent={{6,3},{6,3}}));
  connect(volumeFlow.m_flow_in, solarCollectorInput.MassFlowRate) annotation (
      Line(
      points={{-86,-140.2},{-98,-140.2},{-98,23.115},{-130.895,23.115}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(volumeFlow.T_in, solarCollectorInput.InletTemperature) annotation (
      Line(
      points={{-88.2,-144.6},{-98,-144.6},{-98,23.115},{-130.895,23.115}},
      color={0,0,127},
      smooth=Smooth.None));
  annotation (
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-140,-180},{160,
            180}}), graphics={Bitmap(extent={{-134,180},{160,-178}}, fileName=
              "modelica://Ambassador_WP4/Resources/Images/collector.png")}),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-140,-180},{
            160,180}}), graphics),
    Documentation(info="<html>
<p>This model alllows the user to select the solar collector model between <a href=\"Ambassador_WP4.ThermoFluidTek.ThermalSources.SolarThermal.DetailedSolarCollector\">DetailedSolarCollector</a> and <a href=\"Ambassador_WP4.ThermoFluidTek.ThermalSources.SolarThermal.SimplifiedSolarCollector\">SimplifiedSolarCollector</a>.  Moreover it groups all the elements which need the fluid medium definition in the corresponding experiment in order to make easier the fluid selection by the user. These elements are: </p>
<p><ul>
<li><b>DetailedSolarCollector</b>: solar collector model </li>
<li><b>ambient</b>: fixed boundary conditions for fluid (pressure, density, etc.)</li>
<li><b>outletTemperature</b>: temperature sensor</li>
<li><b>volumeFlow</b>: flow source properties (mass flow, temperature, etc.)</li>
</ul></p>
<p>In this way, only one experiment (<a href=\"Ambassador_WP4.Experiments.ThermalSources.SolarThermal\">SimplifiedSolarCollector</a>) is necessary to evaluate both solar collector models independently. </p>
</html>"));
end SolarCollectorsMedium;
