within DCOL.ThermalStorage.LatentStorages.BaseClasses;
partial model IceStorageExternalMelt_nSeg
  extends DCOL.ThermalStorage.LatentStorages.Icons.IceStorageExternalMelting;

  import Modelica.Constants;
  import DCOL;
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater
  constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water PCM medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
      Modelica_IK4_TEKNIKER.Media.Incompressible.Examples.EthyleneGlycol
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "HTF Medium in the component" annotation (choicesAllMatching = true);

  //Material of the tube
  replaceable package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321 constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coils" annotation (choicesAllMatching = true,Dialog(group="Properties of the coils"));

  parameter Boolean allowFlowReversal = system.allowFlowReversal
    "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)"  annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Integer nSeg=10 "Number of segments of each coil";

  parameter Modelica.SIunits.SpecificEnthalpy hfus=333.55*10^3 "Enthalpy of fusion of the PCM at ambient presure" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMs=2110 "Specific heat capacity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMl=4184 "Specific heat capacity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_solid=917.00 "Density of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_liquid=999.82 "Density of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Temperature T_fus=0+273.15 "fusion temperature of the PCM" annotation(Dialog(group="Properties of the PCM"));

  parameter Modelica.SIunits.Diameter D_tube_in=0.025 "Interior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Length L_coil=10 "Length of each coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Diameter D_crit=0.1 "Critical diameter (vertical/horizontal distance between 2 coils)" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Pressure p_PCM=101325 "Pressure of the PCM" annotation(Dialog(group="Properties of the PCM"));
//   parameter Modelica.SIunits.ThermalConductance G=0.5 "Constant thermal conductance of the material of the tank" annotation(Dialog(group="Thermal properties of the tank"));
  parameter Modelica.SIunits.Diameter D_tube_out=0.03 "Exterior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Real Charge_Percentage=90 "Percentage of ice at the end of the charge [%]" annotation(Dialog(group="Operation properties"));
//   parameter Real Discharge_Percentage=5 "Percentage of ice at the end of the discharge [%]" annotation(Dialog(group="Operation properties"));

  parameter Real a=1000 "Coefficient for quadratic term  of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));

  parameter Modelica.SIunits.Length h=1 "Height of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length w=1 "Width of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Properties of the storage"));

  Boolean Charging(start=Charging_start) "=true during the charging of the storage";
  Boolean Charged(start=Charged_start) "=true when Charge_Percentage is reached";

  Modelica.SIunits.ThermalConductance G_HTFtoTube[nSeg] "Thermal conductance of the tube";
  Modelica.SIunits.ThermalConductance G_TubetoPCM[nSeg] "Thermal conductance of the tube";

protected
  parameter Modelica.SIunits.Mass m_PCM=L_coil*Modelica.Constants.pi*(((D_max/2)^2)-((D_tube_out/2)^2))*rho_liquid "Total mass of the PCM" annotation(Dialog(group="Characteristics of the PCM"));
  parameter Modelica.SIunits.Diameter D_max=sqrt(2)*D_crit "maximun diameter (vertical/horizontal maximun distance between 2 coils)" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Volume vol=L_coil*(Modelica.Constants.pi*(((D_tube_out/2)^2)-(D_tube_in/2)^2)) "Volume of each coil segment" annotation(Dialog(group="Properties of the coils"));
//   parameter Modelica.SIunits.Mass m_PCM_tube=(L_coil/1)*Modelica.Constants.pi*((((sqrt(2)*D_crit)/2)^2)-((D_tube_out/2)^2))*rho_liquid "Mass of PCM around each tube segment" annotation(Dialog(group="Properties of the PCM"));

  //Initial Values
public
  parameter Modelica.SIunits.MassFraction x_liquid_start=1 "Liquid mass fraction at the start" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_PCM_start=10+273.15 "Start temperature of the PCM" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_Tube_start=20 + 273.15 "Start temperature of the tube" annotation(Dialog(tab="Initialization"));
  parameter Boolean Charging_start=true "Initial state of the storage" annotation(Dialog(tab="Initialization"));
  parameter Boolean Charged_start=false "Initial state of the storage" annotation(Dialog(tab="Initialization"));

  DCOL.ThermalStorage.LatentStorages.BaseClasses.ExternalMelt_nSeg externalMelt(
    redeclare package Medium = Medium,
    each hfus=hfus,
    each Cp_PCMs=Cp_PCMs,
    each Cp_PCMl=Cp_PCMl,
    each rho_solid=rho_solid,
    each rho_liquid=rho_liquid,
    each T_fus=T_fus,
    each p_PCM=p_PCM,
    each m_PCM=m_PCM,
    each D_tube_out=D_tube_out,
    each D_crit=D_crit,
    each D_max=D_max,
    each L_coil=L_coil,
    each Charge_Percentage=Charge_Percentage,
    each x_liquid_start=x_liquid_start,
    each T_PCM_start=T_PCM_start,
    each nSeg=nSeg) annotation (Placement(transformation(extent={{-40,30},{40,70}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_water(
    redeclare package Medium = Medium) "Entrace port of the water PCM" annotation (Placement(transformation(extent={{-10,100},{10,120}}),iconTransformation(extent={{-10,100},{10,120}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_water(
    redeclare package Medium = Medium) "Exit port of the water PCM" annotation (Placement(transformation(extent={{-10,-120},{10,-100}}),iconTransformation(extent={{-10,-120},{10,-100}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_Tambient
    "Heat exchanged with the ambient" annotation (Placement(transformation(extent={{100,100},{120,120}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_HTF(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Fluid connector a (positive design flow direction is from port_In to port_Out)" annotation (Placement(transformation(extent={{-160,-10},{-140,10}}),
        iconTransformation(extent={{-160,-10},{-140,10}})));

  Modelica.Fluid.Interfaces.FluidPort_b por_b_HTF(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Fluid connector b (positive design flow direction is from port_In to port_Out)" annotation (Placement(transformation(extent={{140,-10},{160,10}}),
        iconTransformation(extent={{140,-10},{160,10}})));

  Modelica.Fluid.Pipes.DynamicPipe pipe(
    redeclare package Medium = Medium1,
    use_HeatTransfer=true,
    nParallel=1,
    length=L_coil,
    diameter=D_tube_in,
    nNodes=nSeg,
    T_start=T_Tube_start) annotation (Placement(transformation(extent={{-60,-60},{
            -40,-40}})));

  DCOL.ThermalStorage.LatentStorages.Interfaces.HTFtoPCM hTFtoPCM[nSeg](
    redeclare package Material = Material,
    each vol=vol,
    each T_Tube_start=T_Tube_start) annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-50,10})));

  Modelica.Blocks.Sources.RealExpression tubeToPCM[nSeg](
    y=G_TubetoPCM[:]) annotation (Placement(transformation(extent={{-100,8},{-80,28}})));

  Modelica.Blocks.Sources.RealExpression HTFtoTube[nSeg](
    y=G_HTFtoTube[:]) annotation (Placement(transformation(extent={{-100,-8},{-80,12}})));

  Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor[nSeg](
    each G=2) annotation (Placement(transformation(extent={{60,70},{80,90}})));

  DCOL.ThermalStorage.LatentStorages.FMI.RealConectors.RealTemperatureOutput PCM_T "Temperature of the PCM" annotation (Placement(transformation(extent={{160,40},{180,62}})));

equation

  for j in 1:nSeg loop
    connect(tubeToPCM[j].y, hTFtoPCM[j].G_TubetoPCM) annotation (Line(points={{-79,18},
            {-70,18},{-70,15},{-60,15}},                                                                            color={0,0,127}));
    connect(HTFtoTube[j].y, hTFtoPCM[j].G_HTFtoTube) annotation (Line(points={{-79,2},
            {-70,2},{-70,5},{-60,5}},                                                                           color={0,0,127}));
    connect(hTFtoPCM[j].port_b, pipe.heatPorts[j]) annotation (Line(points={{-50,-1},
            {-50,-45.6},{-49.9,-45.6}},                                                         color={191,0,0}));
    connect(port_b_Tambient, thermalConductor[j].port_b) annotation (Line(points={{110,110},{110,80},{80,80}}, color={191,0,0}));
    connect(externalMelt.port_a_heatToHTF[j], hTFtoPCM[j].port_a) annotation (Line(points={{-20,58},{-50,58},{-50,21}}, color={191,0,0}));
    connect(thermalConductor[j].port_a, externalMelt.port_a_heatToAmbient[j]) annotation (Line(points={{60,80},{30,80},{30,66}}, color={191,0,0}));
  end for;

  connect(port_a_HTF, pipe.port_a) annotation (Line(points={{-150,0},{-150,-50},
          {-60,-50}}, color={0,127,255}));
  connect(port_a_water, externalMelt.port_a_water) annotation (Line(points={{0,110},{0,70}}, color={0,127,255}));
  connect(externalMelt.port_b_water, port_b_water) annotation (Line(points={{0,30},{0,-110}}, color={0,127,255}));
  connect(pipe.port_b, por_b_HTF) annotation (Line(points={{-40,-50},{150,-50},{150,0}}, color={0,127,255}));
     annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(
          preserveAspectRatio=false)));
end IceStorageExternalMelt_nSeg;
