within DCOL.ThermalStorage.LatentStorages.BaseClasses;
partial model IceStorageInternalMeltnSegnCoils

  extends DCOL.ThermalStorage.LatentStorages.Icons.IceStorageInternalMelting;

  import Modelica.Constants;
  import DCOL;
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Medium = Modelica.Media.Air.MoistAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "HTF Medium in the component" annotation (choicesAllMatching = true);

  //Material of the tube
  replaceable package Material =
    Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial  "Material of the coils" annotation (choicesAllMatching = true,Dialog(group="Properties of the coils"));

  //Material of the storage wall
  replaceable package Material1 =
    Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial  "Material of the storage wall" annotation (choicesAllMatching = true,Dialog(group="Properties of the storage"));

  parameter Boolean allowFlowReversal = system.allowFlowReversal
    "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)"  annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Integer nSeg=10 "Number of segments of each coil";
  parameter Integer nCoil=10 "Number of Coils for the HTF";

  parameter Modelica.SIunits.SpecificEnthalpy hfus=333.55*10^3 "Enthalpy of fusion of the PCM at ambient presure" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMs=2110 "Specific heat capacity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMl=4184 "Specific heat capacity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_solid=917.00 "Density of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_liquid=999.82 "Density of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Temperature T_fus=0 + 273.15 "fusion temperature of the PCM" annotation(Dialog(group="Properties of the PCM"));

  parameter Modelica.SIunits.Diameter D_tube_in=0.025 "Interior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Length L_coil=10 "Length of each coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Diameter D_crit=0.1 "Critical diameter (vertical/horizontal distance between 2 coils)" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Pressure p_PCM=101325 "Pressure of the PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Mass m_PCM_tube=(L_coil/nSeg)*Modelica.Constants.pi*((((sqrt(2)*D_crit)/2)^2)-((D_tube_out/2)^2))*rho_liquid "Mass of PCM around each tube segment" annotation(Dialog(group="Properties of the PCM"));
//   parameter Modelica.SIunits.ThermalConductance G=0.5 "Constant thermal conductance of the material of the tank" annotation(Dialog(group="Thermal properties of the tank"));
  parameter Modelica.SIunits.Diameter D_tube_out=0.03 "Exterior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Real Charge_Percentage=90 "Percentage of ice at the end of the charge [%]" annotation(Dialog(group="Operation properties"));
//   parameter Real Discharge_Percentage=5 "Percentage of ice at the end of the discharge [%]" annotation(Dialog(group="Operation properties"));

  parameter Modelica.Media.Interfaces.Types.Temperature T_start_pipe=-10+273.15 "Start value of the temperature inside the pipe" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_PCM_start=10 + 273.15 "Start temperature of the PCM" annotation(Dialog(tab="Initialization"));

  parameter Real a=1000 "Coefficient for quadratic term  of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));

  parameter Modelica.SIunits.Volume vol=L_coil*(Modelica.Constants.pi*(((D_tube_out/2)^2)-(D_tube_in/2)^2)) "Volume of each coil segment" annotation(Dialog(group="Properties of the coils"));

  parameter Modelica.SIunits.Length h=1 "Height of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length w=1 "Width of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Properties of the storage"));

  Boolean Charging(start=true) "=true during the charging of the storage";
  Boolean Charged(start=false) "=true when Charge_Percentage is reached";

protected
  Modelica.SIunits.ThermalConductance G_HTFtoTube[nSeg] "Thermal conductance of the tube";
  Modelica.SIunits.ThermalConductance G_TubetoPCM[nSeg] "Thermal conductance of the tube";

public
  Modelica.Fluid.Interfaces.FluidPort_a port_a_HTF(
    redeclare package Medium = Medium,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Fluid connector a (positive design flow direction is from port_In to port_Out)"
    annotation (Placement(transformation(extent={{-160,-10},{-140,10}}),
        iconTransformation(extent={{-160,-10},{-140,10}})));

  Modelica.Fluid.Interfaces.FluidPort_b por_b_HTF(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium.h_default))
    "Fluid connector b (positive design flow direction is from port_In to port_Out)"
    annotation (Placement(transformation(extent={{140,-10},{160,10}}),
        iconTransformation(extent={{140,-10},{160,10}})));

  DCOL.ThermalStorage.LatentStorages.BaseClasses.Ice_WaterRing ice_WaterRing[nCoil,nSeg](
    each hfus=hfus,
    each Cp_PCMs=Cp_PCMs,
    each Cp_PCMl=Cp_PCMl,
    each rho_solid=rho_solid,
    each rho_liquid=rho_liquid,
    each T_fus=T_fus,
    each L_coil=L_coil/nSeg,
    each p_PCM=p_PCM,
    each m_PCM=m_PCM_tube,
    each D_crit=D_crit,
    each D_tube_out=D_tube_out,
    each Charge_Percentage=Charge_Percentage,
    each T_PCM_start=T_PCM_start) annotation (Placement(transformation(extent={{-14,4},{6,24}})));

  DCOL.ThermalStorage.LatentStorages.Interfaces.HTFtoPCM HTFtoPCM[nCoil,nSeg](
    redeclare package Material = Material,
    each vol=vol,
    each T_Tube_start=T_start_pipe) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={0,-40})));

  Modelica.Fluid.Pipes.DynamicPipe pipe(
    redeclare package Medium = Medium,
    use_HeatTransfer=true,
    length=L_coil,
    allowFlowReversal=allowFlowReversal,
    diameter=D_tube_in,
    nNodes=nSeg,
    T_start=T_start_pipe,
    nParallel=nCoil) annotation (Placement(transformation(extent={{-10,-80},{10,-60}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_Tambient
    "Heat exchanged with the ambient"
    annotation (Placement(transformation(extent={{-10,80},{10,100}})));

  Modelica.Fluid.Fittings.GenericResistances.VolumeFlowRate volumeFlowRate(
    redeclare package Medium = Medium,
    a=a,
    b=b) annotation (Placement(transformation(extent={{30,-80},{50,-60}})));

  Modelica.Blocks.Sources.RealExpression tubeToPCM[nSeg](
    y=G_TubetoPCM[:]) annotation (Placement(transformation(extent={{-80,-40},
            {-60,-20}})));

  Modelica.Blocks.Sources.RealExpression HTFtoTube[nSeg](
    y=G_HTFtoTube[:]) annotation (Placement(transformation(extent={{-80,-60},{
            -60,-40}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_Tfloor
    "Heat exchanged with the floor"
    annotation (Placement(transformation(extent={{-100,-100},{-80,-80}})));

  DCOL.ThermalStorage.LatentStorages.Interfaces.StorageWall storageWall(
    redeclare package Material = Material1,
    nCoil=nCoil,
    nSeg=nSeg,
    h=h,
    w=w,
    e=e,
    l=L_coil,
    T_Wall_start=T_PCM_start) annotation (Placement(transformation(extent={{-20,40},{20,80}})));

equation

  for i in 1:nCoil loop
    for j in 1:nSeg loop
      connect(HTFtoPCM[i, j].port_b, pipe.heatPorts[j]) annotation (Line(points=
             {{0,-51},{0,-65.6},{0.1,-65.6}}, color={191,0,0}));
      connect(tubeToPCM[j].y, HTFtoPCM[i,j].G_TubetoPCM) annotation (Line(points={{-59,-30},{-34,-30},{-34,-35},{-10,-35}}, color={0,0,127}));
      connect(HTFtoTube[j].y, HTFtoPCM[i,j].G_HTFtoTube) annotation (Line(points={{-59,-50},{-34,-50},{-34,-45},{-10,-45}}, color={0,0,127}));
      connect(ice_WaterRing[i, j].port_a_heatToHTF,HTFtoPCM[i, j].port_a)
        annotation (Line(points={{0,14},{0,-29}}, color={191,0,0}));
    end for;
  end for;

  connect(port_a_HTF, pipe.port_a) annotation (Line(points={{-150,0},{-150,0},{-150,
          -70},{-10,-70}}, color={0,127,255}));
  connect(pipe.port_b, volumeFlowRate.port_a) annotation (Line(points={{10,-70},
          {30,-70}},                                                                                color={0,127,255}));
  connect(volumeFlowRate.port_b, por_b_HTF) annotation (Line(points={{50,-70},{50,
          -70},{150,-70},{150,0}}, color={0,127,255}));
  connect(ice_WaterRing.port_a_heatToAmbient, storageWall.T_PCM) annotation (
      Line(points={{-5,22},{-5,22},{-5,58},{0,58}}, color={191,0,0}));
  connect(storageWall.port_a_floor, port_b_Tfloor) annotation (Line(points={{0,34},
          {-46,34},{-90,34},{-90,-90}}, color={191,0,0}));
  connect(storageWall.port_a_ambient, port_b_Tambient)
    annotation (Line(points={{20.8,78.4},{20.8,90},{0,90}}, color={191,0,0}));
 annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This partial model represents a latent storage where the Phase Change Material (PCM) is confined in a tank, and the Heat Transfer Fluid (HTF) flows through some pipes submerged in the PCM. Both the solidification and the fusion of the PCM occurs from the inside to the outside.</p>
<p>This partial model is used to build <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.ThermalStorage.LatentStorages.IceStorageInternalMeltnSegnCoils\">DCOL.ThermalStorage.LatentStorages.IceStorageInternalMeltnSegnCoils</a>.</p>
</html>",
      revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end IceStorageInternalMeltnSegnCoils;
