within DCOL.ThermalStorage.LatentStorages.BaseClasses;
model IceWaterVessel2
  import SI = Modelica.SIunits;
  extends DCOL.ThermalStorage.LatentStorages.BaseClasses.PartialSolidLiquidVessel_SM2;
  import Modelica.Media.Interfaces.Choices.IndependentVariables;
  import Modelica.Fluid.Types.Dynamics;
  outer Modelica.Fluid.System system "System wide properties";

//   replaceable package Medium_w =
//       Modelica.Media.Water.ConstantPropertyLiquidWater
//     "Liquid medium in the vessel" annotation (choicesAllMatching=true);

  parameter Integer nSeg = 3;

  parameter Dynamics energyDynamics=Dynamics.SteadyStateInitial
  "Formulation of energy balance"  annotation(Evaluate=true, Dialog(tab = "Assumptions", group="Dynamics"));
  parameter Dynamics massDynamics=Dynamics.SteadyStateInitial
  "Formulation of mass balance" annotation(Evaluate=true, Dialog(tab = "Assumptions", group="Dynamics"));
  final parameter Dynamics substanceDynamics=massDynamics
  "Formulation of mass balance" annotation(Evaluate=true, Dialog(tab = "Assumptions", group="Dynamics"));

  Modelica.Fluid.Interfaces.FluidPort_a port_a(redeclare package Medium = Medium_l)
  "Fluid port. LiBr to Generator"
    annotation (Placement(transformation(extent={{-10,80},{10,100}}),    iconTransformation(extent={{-10,80},
            {10,100}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b(redeclare package Medium = Medium_l)
  "Fluid port. LiBr from Generator"
    annotation (Placement(transformation(extent={{-8,-100},{12,-80}}), iconTransformation(extent={{-8,-100},
            {12,-80}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort[nSeg]
  "Heat port"
    annotation (Placement(transformation(extent={{-100,40},{-80,60}}),
        iconTransformation(extent={{-100,40},{-80,60}})));

//   Medium_w.BaseProperties medium_w(
//     p(start=system.p_ambient),
//     T(start=T_l_start))
//     "Liquid medium";

  SI.AbsolutePressure p
    "Liquid-vapor equilibrium pressure in the vessel";

equation
  Qb_flow = sum(heatPort.Q_flow);

  for i in 1:nSeg loop
    heatPort[i].T = T_s;
  end for;

//   medium_w.T = T_l;
//   medium_w.p = p;

  //Definition of port variables
  port_a.p = p;
  port_b.p = p;
  medium_l.p = p;

  port_a.h_outflow = medium_l.h;
  port_b.h_outflow = medium_l.h;

  port_a.Xi_outflow = medium_l.Xi;
  port_b.Xi_outflow = medium_l.Xi;

  Hb_flow = port_a.m_flow*actualStream(port_a.h_outflow) + port_b.m_flow*actualStream(port_b.h_outflow);
  mb_flow = port_a.m_flow + port_b.m_flow;

initial equation
  // initialization of balances
  // if energyDynamics == Dynamics.FixedInitial then
  //   T = T_start;
  // elseif energyDynamics == Dynamics.SteadyStateInitial then
  //   der(T) = 0;
  // end if;

  if massDynamics == Dynamics.FixedInitial then
    der(m) = mb_flow;
  elseif massDynamics == Dynamics.SteadyStateInitial then
    mb_flow = 0;
//     der(V_l)=0;
  end if;

  if substanceDynamics == Dynamics.FixedInitial then
    medium_l.Xi = X_l_start[1:Medium_l.nXi];
//     medium_v.Xi = X_v_start[1:Medium_v.nXi];
  elseif substanceDynamics == Dynamics.SteadyStateInitial then
    der(medium_l.Xi) = zeros(Medium_l.nXi);
//     der(medium_v.Xi) = zeros(Medium_v.nXi);
  end if;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>Volume of constant size with three fluid ports and two medium models (liquid and vapour) at liquid-vapour equilibrium used to represent <b>the absorber or the generator of an absorption cycle</b>. The flow properties are computed from the upstream quantities, pressures are equal in all nodes. Heat transfer through a thermal port is possible, it equals zero if the port remains unconnected. Ideal heat transfer is assumed per default; the thermal port temperature is equal to the medium temperature. </p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end IceWaterVessel2;
