within DCOL.ThermalStorage.LatentStorages.BaseClasses;
model IceWaterVessel_edu2
  import SI = Modelica.SIunits;
  extends DCOL.ThermalStorage.LatentStorages.BaseClasses.PartialSolidLiquidVessel_SM_edu2;
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Medium_w =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    "Liquid medium in the vessel" annotation (choicesAllMatching=true);

  parameter Integer nSeg = 1;

  Modelica.Fluid.Interfaces.FluidPort_a port_a(redeclare package Medium = Medium_w)
  "Fluid port. LiBr to Generator"
    annotation (Placement(transformation(extent={{-10,80},{10,100}}),    iconTransformation(extent={{-10,80},
            {10,100}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b(redeclare package Medium = Medium_w)
  "Fluid port. LiBr from Generator"
    annotation (Placement(transformation(extent={{-10,-100},{10,-80}}),iconTransformation(extent={{-10,
            -100},{10,-80}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort[nSeg]
  "Heat port"
    annotation (Placement(transformation(extent={{-100,40},{-80,60}}),
        iconTransformation(extent={{-100,40},{-80,60}})));

   Medium_w.BaseProperties medium_w(
     p(start=system.p_ambient),
     T(start=T_l_start))
     "Liquid medium";

   SI.AbsolutePressure p
     "Liquid-vapor equilibrium pressure in the vessel";

equation
   Qb_flow = sum(heatPort.Q_flow);

   for i in 1:nSeg loop
     heatPort[i].T = T_s;
   end for;

   medium_w.T = T_l;
   medium_w.p = system.p_ambient;

   m_w1=port_a.m_flow;
   h_w1=inStream(port_a.h_outflow);

   //Definition of port variables
   port_a.p = p;
   port_b.p = p;

   port_a.h_outflow = medium_w.h;
   port_b.h_outflow = medium_w.h;

   port_a.Xi_outflow = medium_w.Xi;
   port_b.Xi_outflow = medium_w.Xi;

   Hb_flow = port_a.m_flow*actualStream(port_a.h_outflow) + port_b.m_flow*actualStream(port_b.h_outflow);
   mb_flow = port_a.m_flow + port_b.m_flow;

// initial equation
//   mb_flow=0;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>Volume of constant size with three fluid ports and two medium models (liquid and vapour) at liquid-vapour equilibrium used to represent <b>the absorber or the generator of an absorption cycle</b>. The flow properties are computed from the upstream quantities, pressures are equal in all nodes. Heat transfer through a thermal port is possible, it equals zero if the port remains unconnected. Ideal heat transfer is assumed per default; the thermal port temperature is equal to the medium temperature. </p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end IceWaterVessel_edu2;
