within DCOL.ThermalStorage.LatentStorages.BaseClasses;
model Ice_WaterRing

  extends DCOL.ThermalStorage.LatentStorages.Interfaces.PartialIce_WaterRing;
  extends DCOL.ThermalStorage.LatentStorages.Icons.Water_IceRing;

  //Properties of the PCM
  parameter Modelica.SIunits.SpecificEnthalpy hfus=333.55*10^3 "Enthalpy of fusion of the PCM at ambient presure" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMs=2110 "Specific heat capacity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMl=4184 "Specific heat capacity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_solid=917.00 "Density of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_liquid=999.82 "Density of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Temperature T_fus=0+273.15 "fusion temperature of the PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Pressure p_PCM=101325 "Pressure of the PCM" annotation(Dialog(group="Characteristics of the PCM"));
  parameter Modelica.SIunits.Mass m_PCM=L_coil*Modelica.Constants.pi*((((sqrt(2)*D_crit)/2)^2)-((D_tube_out/2)^2))*rho_liquid "Total mass of the PCM" annotation(Dialog(group="Characteristics of the PCM"));
  Modelica.SIunits.Temperature T(start=T_PCM_start) "Temperature of the PCM";
  Modelica.SIunits.MassFraction x_liquid(start=x_liquid_start,min=0,max=1) "Liquid mass fraction";
  Modelica.SIunits.InternalEnergy U "Internal energy of the PCM";
  Modelica.SIunits.Volume V_PCM "Volume ocupied by the PCM";
  Modelica.SIunits.SpecificEnthalpy h_PCM "Specific enthalpy of the PCM";
  Modelica.SIunits.Density rho "Density of the PCM";
  Modelica.SIunits.SpecificEnthalpy h_satS "solid saturation enthalpy";
  Modelica.SIunits.SpecificEnthalpy h_satL "liquid saturation enthalpy";

  parameter Modelica.SIunits.Diameter D_tube_out=0.05 "Exterior diameter of the coil" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Diameter D_crit=0.1 "Critical diameter (vertical/horizontal distance between 2 coils)" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Diameter D_max=sqrt(2)*D_crit "maximun diameter (vertical/horizontal maximun distance between 2 coils)" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Length L_coil=10 "Length of each tube segment" annotation(Dialog(group="Geometric properties"));
  parameter Real Charge_Percentage=90 "Percentage of ice at the end of the charge [%]" annotation(Dialog(group="Operation properties"));
//   parameter Real Discharge_Percentage=5 "Percentage of ice at the end of the discharge [%]" annotation(Dialog(group="Operation properties"));

  parameter Modelica.SIunits.MassFraction x_liquid_start=1 "Liquid mass fraction at the start" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_PCM_start=10+273.15 "Start temperature of the PCM" annotation(Dialog(tab="Initialization"));

  Modelica.SIunits.Mass m_PCMs "Total mass of the solid fraction of the PCM";
  Modelica.SIunits.Temperature T_s(start=0+273.15) "Temperature of the solid fraction of the PCM";
  Modelica.SIunits.Diameter D_s(max=sqrt(2)*D_crit) "External diameter of the formed solid ring";
  Modelica.SIunits.Diameter D_smax "Maximum diameter of the formed solid ring";

  Modelica.SIunits.Mass m_PCMl "Total mass of the liquid fraction of the PCM";
  Modelica.SIunits.Temperature T_l(start=0+273.15) "Temperature of the liquid fraction of the PCM";
  Modelica.SIunits.Diameter D_l "Internal diameter of the formed liquid ring(during Discharge)";
  Modelica.SIunits.Diameter D_l_out "External diameter of the formed liquid ring(during Discharge)";
  Modelica.SIunits.Diameter D_lmax "Maximum diameter of the formed liquid ring";

  input Boolean Charging(start=true) "True during the charging of the storage";

initial equation

  //Initialization of the model
   if T_PCM_start>T_fus then
     h_PCM=Cp_PCMs*(T_fus-273.15) + hfus + Cp_PCMl*(T-T_fus);
   elseif T_PCM_start<T_fus then
     h_PCM=Cp_PCMs*(T-273.15);
   else
     h_PCM=Cp_PCMs*(T-273.15) + hfus*x_liquid;
   end if;

equation

  //Enthalpies of saturation of the PCM
  h_satS=Cp_PCMs*(T_fus-273.15);
  h_satL=Cp_PCMs*(T_fus-273.15)+hfus;

  //Maximum liquid and solid diameter
  if Charge_Percentage<100 then
    (Charge_Percentage/100)*m_PCM=(L_coil*Modelica.Constants.pi*(((D_smax/2)^2)-((D_tube_out/2)^2)))*rho_solid;
    (1-Charge_Percentage/100)*m_PCM=(L_coil*Modelica.Constants.pi*((D_lmax/2)^2-((D_smax/2)^2)))*rho_liquid;
  else
    D_smax=sqrt(2)*D_crit;
    m_PCM=(L_coil*Modelica.Constants.pi*((D_lmax/2)^2-((D_smax/2)^2)))*rho_liquid;
  end if;

  //Calculation of the liquid mass fraction and temperature of the PCM
  m_PCM=(L_coil*Modelica.Constants.pi*(((D_l_out/2)^2)-((D_tube_out/2)^2)))*rho;

  if (h_PCM < h_satS) then
    //All Ice
    x_liquid = 0;
    T = 273.15 + h_PCM/Cp_PCMs;
    T_s=T;
    T_l=0+273.15;
    m_PCMs=(L_coil*Modelica.Constants.pi*(((D_s/2)^2)-((D_tube_out/2)^2)))*rho_solid;
    D_l=0;
    m_PCMl=m_PCM-m_PCMs;
    m_PCMs=(1-x_liquid)*m_PCM;

  elseif (h_PCM > h_satL) then
    //All Water
    x_liquid = 1;
    T = T_fus + (h_PCM - h_satL)/Cp_PCMl;
    T_s=0+273.15;
    T_l=T;
    D_s=D_tube_out;
    m_PCMl=(L_coil*Modelica.Constants.pi*(((D_l/2)^2)-((D_tube_out/2)^2)))*rho_liquid;
    m_PCMl=m_PCM-m_PCMs;
    m_PCMs=(1-x_liquid)*m_PCM;
  else
    //Mix of Water and Ice
    if Charging==true then
      x_liquid = (h_PCM - h_satS)/(h_satL - h_satS);
      T = T_fus;
      T_s=T;
      T_l=T;
      m_PCMs=(L_coil*Modelica.Constants.pi*(((D_s/2)^2)-((D_tube_out/2)^2)))*rho_solid;
      m_PCMl=(L_coil*Modelica.Constants.pi*(((D_l/2)^2)-((D_s/2)^2)))*rho_liquid;
      m_PCMl=m_PCM-m_PCMs;
      m_PCMs=(1-x_liquid)*m_PCM;
    else
      if (1-x_liquid)*100<Charge_Percentage then
        x_liquid = (h_PCM - h_satS)/(h_satL - h_satS);
        T = T_fus;
        T_s=T;
        T_l=T;
        D_s=D_smax;
        // m_PCMs=(L_coil*Modelica.Constants.pi*(((D_s/2)^2)-((D_l/2)^2)))*rho_solid;
        m_PCMl=(L_coil*Modelica.Constants.pi*(((D_lmax/2)^2)-((D_s/2)^2)))*rho_liquid+
                (L_coil*Modelica.Constants.pi*(((D_l/2)^2)-((D_tube_out/2)^2)))*rho_liquid;
        m_PCMl=m_PCM-m_PCMs;
        m_PCMs=(1-x_liquid)*m_PCM;
      else
        x_liquid = (h_PCM - h_satS)/(h_satL - h_satS);
        T = T_fus;
        T_s=T;
        T_l=T;
        D_s=D_smax;
        //m_PCMs=(L_coil*Modelica.Constants.pi*(((D_s/2)^2)-((D_l/2)^2)))*rho_solid;
        m_PCMl=(L_coil*Modelica.Constants.pi*(((D_lmax/2)^2)-((D_s/2)^2)))*rho_liquid+
                (L_coil*Modelica.Constants.pi*(((D_l/2)^2)-((D_tube_out/2)^2)))*rho_liquid;
        m_PCMl=m_PCM-m_PCMs;
        m_PCMs=(1-x_liquid)*m_PCM;
      end if;
    end if;
  end if;

  //Internal energy of the PCM
  U=(m_PCMs+m_PCMl)*h_PCM+p_PCM*V_PCM;

  //Volume and density of the PCM
  V_PCM=(m_PCMs+m_PCMl)/rho;
  rho=(1-x_liquid)*rho_solid+(x_liquid)*rho_liquid;

  //Energy balance of the PCM
  if Charging==true then
    if (1-x_liquid)*100<Charge_Percentage then
      der(U)=port_a_heatToHTF.Q_flow + port_a_heatToAmbient.Q_flow;
    else
      der(U)=0;
    end if;
  else
    //if (1-x_liquid)*100>Discharge_Percentage then
      der(U)=port_a_heatToHTF.Q_flow + port_a_heatToAmbient.Q_flow;
    //else
    //  der(U)=0;
    //end if;
  end if;

  port_a_heatToHTF.T = T;
  port_a_heatToAmbient.T = T;

  annotation (                   Documentation(info="<html>
<p>This model represents the behaviour of th Phase Change Material when heat si introduced/removed from it. A Phase-Change Material (PCM) is a substance with a high heat of fusion which, melting and solidifying at a certain temperature, is capable of storing and releasing large amounts of energy. Heat is absorbed or released when the material changes from solid to liquid and vice versa; thus, PCMs are classified as latent heat storage (LHS) units. This model consider that there are not heat losses to the ambient apart from the heat transfered to the HTF. In this case the model requires the introduction of the values of some of the properties of the PCM.</p>
<h4>Equation</h4>
<p>Calculation of the liquid mass fraction and temperature of the PCM:</p>
<p>If  <img src=\"modelica://DCOL/Resources/Images/equations/equation-FQta5hp4.png\" alt=\"h_PCM<h_satS\"/> then:</p>
<ul>
<li><img src=\"modelica://DCOL/Resources/Images/equations/equation-pQetDyvv.png\" alt=\"x_liquid=0\"/></li>
<li><img src=\"modelica://DCOL/Resources/Images/equations/equation-Yp9mw4ba.png\" alt=\"T=(h_PCM/Cp_PCMS)+273.15\"/></li>
</ul>
<p>If  <img src=\"modelica://DCOL/Resources/Images/equations/equation-tOffQL2L.png\" alt=\"h_PCM>h_satL\"/> then:</p>
<ul>
<li><img src=\"modelica://DCOL/Resources/Images/equations/equation-nIpGuo6c.png\" alt=\"x_liquid=1
\"/></li>
<li><img src=\"modelica://DCOL/Resources/Images/equations/equation-Lc3331eN.png\" alt=\"T=(h_PCM-h_satL)/Cp_PCML+T_fus\"/></li>
</ul>
<p>If  <img src=\"modelica://DCOL/Resources/Images/equations/equation-uiHmz7jl.png\" alt=\"h_satS<h_PCM\"/>  and  <img src=\"modelica://DCOL/Resources/Images/equations/equation-Anhhf8KC.png\" alt=\"h_PCM<h_satL\"/> then:</p>
<ul>
<li><img src=\"modelica://DCOL/Resources/Images/equations/equation-SH0Gut80.png\" alt=\"x_liquid=(h_PCM-h_satS)/(h_sat_L-hsat_S)\"/></li>
<li><img src=\"modelica://DCOL/Resources/Images/equations/equation-QabGlVfT.png\" alt=\"T=T_fus\"/></li>
</ul>
<p>Where:</p>
<ul>
<li>Cp<sub>PCM_S</sub>, Specific heat capacity of the solid PCM;</li>
<li>Cp<sub>PCM_L</sub>, Specific heat capacity of the liquid PCM;</li>
<li>T<sub>fus</sub>, Fusion temperature of the PCM;</li>
<li>x<sub>liquid</sub>, Liquid mass fraction;</li>
<li>h<sub>PCM</sub>, Specific enthalpy of the PCM;</li>
<li>h<sub>sat_S</sub>, Solid saturation enthalpy;</li>
<li>h<sub>sat_L</sub>, Liquid saturation enthalpy.</li>
</ul>
<h4>Assumptions</h4>
<ul>
<li>The PCM starts in solid phase (x<sub>liquid</sub>=0);</li>
</ul>
<h4>References</h4>
<ul>
<li>E. Osterman, K. Hagel, C. Rathgeber, V. Butala, U. Stritih a; &QUOT;Parametrical analysis of latent heat and cold storage for heating and cooling of rooms&QUOT; (2015). ElSevier.</li>
<li>Adeel Waqas, S. Kumar; &QUOT;Thermal performance of latent heat storage for free cooling of buildings in a dry and hot climate: An experimental study&QUOT; (2011). ElSevier.</li>
</ul>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end Ice_WaterRing;
