within DCOL.ThermalStorage.LatentStorages.BaseClasses;
model PartialSolidLiquidVessel_SM_edu
  "Vessel containing solid and liquid PCM with mass and energy balance"
  extends DCOL.ThermalStorage.LatentStorages.BaseClasses.PartialSolidLiquidVessel_edu;

  Modelica_StateGraph2.Step noIce_overH(nIn=2,
    initialStep=((m_s_start<=0) and (m_l_start>0) and (T_l_start>T0)),
    nOut=1)                                                            annotation (Placement(transformation(extent={{-64,-4},{-56,4}})));

  Modelica_StateGraph2.Step noWater_subC(nIn=2,
    initialStep=((m_s_start>0) and (m_l_start<=0) and (T_s_start<T0)),
    nOut=1)                                                            annotation (Placement(transformation(extent={{56,-4},{64,4}})));

  Modelica_StateGraph2.Step IceWater(
    initialStep=((m_s_start>0) and (m_l_start>0) and (T_s_start>=T0) and (T_l_start<=T0)),
    nIn=4,
    nOut=4)                                                                                annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={0,60})));

  Modelica_StateGraph2.Step IceWater_subC(nIn=2, nOut=3,
    initialStep=((m_s_start>0) and (m_l_start>0) and (T_s_start<T0) and (T_l_start<=T0))) annotation (Placement(transformation(extent={{6,-4},{14,4}})));

  Modelica_StateGraph2.Step IceWater_overH(nIn=2, nOut=3,
    initialStep=((m_s_start>0) and (m_l_start>0) and (T_s_start>=T0) and (T_l_start>T0))) annotation (Placement(transformation(extent={{-14,-4},{-6,4}})));

  Modelica_StateGraph2.Step IceWater_subC_overH(nIn=2,nOut=2,
    initialStep=((m_s_start>0) and (m_l_start>0) and (T_s_start<T0) and (T_l_start>T0))) annotation (Placement(transformation(extent={{-4,-48},{4,-40}})));

  Modelica_StateGraph2.Transition T1(
    loopCheck=false,
    condition=T_lN <= 0,
    delayedTransition=true,
    waitTime=0.01) annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=180,
        origin={-80,40})));

  Modelica_StateGraph2.Transition T3(
    waitTime=0.01,
    loopCheck=false,
    delayedTransition=true,
    condition=T_sN >= 0)    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=180,
        origin={80,40})));

  Modelica_StateGraph2.Transition T6(
    loopCheck=false, condition=T_sN < -eps)
                            annotation (Placement(transformation(extent={{6,16},{14,24}})));

  Modelica_StateGraph2.Transition T5(
    loopCheck=false,
    waitTime=0.01,
    delayedTransition=false,
    condition=m_l/m < 0)     annotation (Placement(transformation(extent={{56,16},{64,24}})));
  Modelica_StateGraph2.Transition T7(
    loopCheck=false,
    waitTime=0.01,
    delayedTransition=false,
    condition=T_lN > 0)      annotation (Placement(transformation(extent={{-64,16},{-56,24}})));

  Modelica_StateGraph2.Transition T8(
    loopCheck=false,
    condition=T_lN > eps) annotation (Placement(transformation(extent={{-14,16},{-6,24}})));

  Modelica_StateGraph2.Transition T9(
    loopCheck=false,
    delayedTransition=true,
    waitTime=0.01,
    condition=T_sN < 0)
                   annotation (Placement(transformation(extent={{-14,-24},{-6,-16}})));

  Modelica_StateGraph2.Transition T10(
    loopCheck=false,
    condition=T_lN > 0,
    delayedTransition=true,
    waitTime=0.01)   annotation (Placement(transformation(extent={{6,-24},{14,-16}})));

  Modelica_StateGraph2.Transition T11(
    loopCheck=false,
    condition=T_sN > 0) annotation (Placement(transformation(extent={{-32,-16},{-24,-24}})));

  Modelica_StateGraph2.Transition T12(
    loopCheck=false,
    condition=T_lN <= 0) annotation (Placement(transformation(extent={{24,-16},{32,-24}})));

  Modelica_StateGraph2.Transition T13(
    loopCheck=false,
    waitTime=0.01,
    delayedTransition=false,
    condition=T_lN <= 0) annotation (Placement(transformation(extent={{-34,24},{-26,16}})));

  Modelica_StateGraph2.Transition T14(
    loopCheck=false, condition=T_sN >= 0)
                        annotation (Placement(transformation(extent={{26,24},{34,16}})));

  Modelica_StateGraph2.Transition T17(
    loopCheck=false,
    waitTime=0.0001,
    delayedTransition=false,
    condition=m_s/m <= eps) annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=-90,
        origin={-42,4})));

  Modelica_StateGraph2.Transition T18(
    loopCheck=false,
    waitTime=0.0001,
    delayedTransition=false,
    condition=m_l/m <= eps) annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=90,
        origin={42,4})));

equation
      mb_flow=0;
//    Hb_flow=4184*15;
//    Qb_flow=0;
      Qb_flow=-10000;
      m_w1=0;
      h_w1=20*4184;
//      mb_flow=m_w1-m_w2;
//      Hb_flow=m_w1*h_w1-m_w2*h_w2;

  flag_l = noIce_overH.active;
  flag_l_overHeat = IceWater_overH.active or noIce_overH.active or IceWater_subC_overH.active;
  flag_s = noWater_subC.active;
  flag_s_subCold = IceWater_subC.active or noWater_subC.active or IceWater_subC_overH.active;

  connect(T5.outPort, noWater_subC.inPort[1]) annotation (Line(points={{60,15},{60,4},{59,4}},
                                                                                        color={0,0,0}));
  connect(T6.outPort, IceWater_subC.inPort[1]) annotation (Line(points={{10,15},{10,4},{9,4}},     color={0,0,0}));
  connect(T8.outPort, IceWater_overH.inPort[1]) annotation (Line(points={{-10,15},{-10,4},{-11,4}}, color={0,0,0}));
  connect(IceWater_overH.outPort[1], T9.inPort) annotation (Line(points={{
          -11.3333,-4.6},{-11.3333,-10},{-10,-10},{-10,-16}},                                                       color={0,0,0}));
  connect(IceWater_subC.outPort[1], T10.inPort) annotation (Line(points={{8.66667,-4.6},{8.66667,-10},{10,-10},{10,-16}},
                                                                                                                    color={0,0,0}));
  connect(T10.outPort, IceWater_subC_overH.inPort[1]) annotation (Line(points={{10,-25},{6,-25},{6,-40},{-1,-40}},       color={0,0,0}));
  connect(T9.outPort, IceWater_subC_overH.inPort[2]) annotation (Line(points={{-10,-25},{-6,-25},{-6,-40},{1,-40}},     color={0,0,0}));
  connect(IceWater_subC_overH.outPort[1], T11.inPort) annotation (Line(points={{-1,
          -48.6},{0,-48.6},{0,-50},{-28,-50},{-28,-24}},                                                           color={0,0,0}));
  connect(T11.outPort, IceWater_overH.inPort[2]) annotation (Line(points={{-28,-15},{-28,4},{-9,4}},  color={0,0,0}));
  connect(IceWater_subC_overH.outPort[2], T12.inPort) annotation (Line(points={{1,-48.6},{0,-48.6},
          {0,-50},{28,-50},{28,-24}},                                                                                                  color={0,0,0}));
  connect(T12.outPort, IceWater_subC.inPort[2]) annotation (Line(points={{28,-15},{28,4},{11,4}},    color={0,0,0}));
  connect(IceWater_overH.outPort[2], T13.inPort) annotation (Line(points={{-10,-4.6},{-30,-4.6},{-30,16}}, color={0,0,0}));
  connect(IceWater_subC.outPort[2], T14.inPort) annotation (Line(points={{10,-4.6},{14,-4.6},{
          14,-4},{14,-4},{14,-4},{30,-4},{30,16}},                                                                          color={0,0,0}));
  connect(IceWater_overH.outPort[3], T17.inPort) annotation (Line(points={{-8.66667,-4.6},{-9,
          -4.6},{-9,-6},{-33,-6},{-33,4},{-38,4}},                                                                     color={0,0,0}));
  connect(T17.outPort, noIce_overH.inPort[1]) annotation (Line(points={{-47,4},{
          -61,4}},                                                                       color={0,0,0}));
  connect(IceWater_subC.outPort[3], T18.inPort) annotation (Line(points={{11.3333,
          -4.6},{10,-4.6},{10,-6},{32,-6},{32,4},{38,4}},                                                         color={0,0,0}));
  connect(T18.outPort, noWater_subC.inPort[2]) annotation (Line(points={{47,4},{61,4}}, color={0,0,0}));
  connect(noIce_overH.outPort[1], T1.inPort) annotation (Line(points={{-60,-4.6},{-60,-6},{-80,
          -6},{-80,36}},                                   color={0,0,0}));
  connect(T7.outPort, noIce_overH.inPort[2]) annotation (Line(points={{-60,15},{-60,4},{-59,4}},
                                              color={0,0,0}));
  connect(noWater_subC.outPort[1], T3.inPort)
    annotation (Line(points={{60,-4.6},{60,-6},{80,-6},{80,36}}, color={0,0,0}));
  connect(T13.outPort, IceWater.inPort[1])
    annotation (Line(points={{-30,25},{-30,72},{-1.5,72},{-1.5,64}}, color={0,0,0}));
  connect(T1.outPort, IceWater.inPort[2])
    annotation (Line(points={{-80,45},{-80,80},{-0.5,80},{-0.5,64}}, color={0,0,0}));
  connect(T3.outPort, IceWater.inPort[3])
    annotation (Line(points={{80,45},{80,80},{0,80},{0,64},{0.5,64}}, color={0,0,0}));
  connect(T14.outPort, IceWater.inPort[4]) annotation (Line(points={{30,25},{30,25},{30,72},{1,
          72},{1,64},{1.5,64}}, color={0,0,0}));
  connect(IceWater.outPort[1], T7.inPort)
    annotation (Line(points={{-1.5,55.4},{-60,55.4},{-60,24}}, color={0,0,0}));
  connect(IceWater.outPort[2], T8.inPort) annotation (Line(points={{-0.5,55.4},{-1,55.4},{-1,40},
          {-10,40},{-10,24},{-10,24}}, color={0,0,0}));
  connect(IceWater.outPort[4], T5.inPort)
    annotation (Line(points={{1.5,55.4},{60,55.4},{60,24}}, color={0,0,0}));
  connect(IceWater.outPort[3], T6.inPort) annotation (Line(points={{0.5,55.4},{1,55.4},{1,40},
          {10,40},{10,24}}, color={0,0,0}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
        Text(
          extent={{-100,160},{100,100}},
          lineColor={28,108,200},
          textString="%name"),
        Polygon(
          points={{-28,36},{-28,36}},
          lineColor={28,108,200},
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid)}),                      Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>Base class for an ideal vessel with two mediums at liquid-vapor equilibrium with the ability to store mass and energy. The following boundary terms are part of the energy balance and must be specified in an extending class: </p>
<p><b>Qb_flow</b>, e.g., convective or latent heat flow rate across vessel boundary, and</p>
<p><b>Wb_flow</b>, work term.</p>
<p>Further source terms must be defined by an extending class for fluid flow across the segment boundary: </p>
<p><b>Hb_flow</b>, enthalpy flow,</p>
<p><b>mb_flow</b>, mass flow,</p>
<p><b>mbXi_flow_l</b> &AMP; <b>mbXi_flow_v</b>, substance mass flow for liquid and vapor medium respectively.</p>
<p>Since liquid-vapor equilibrium is assumped, temperatures (and pressures) of the vapor medium and the liquid medium are equal, and named <b>T</b> (<b>p</b>).</p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"),
    experiment(StopTime=40));
end PartialSolidLiquidVessel_SM_edu;
