within DCOL.ThermalStorage.LatentStorages.BaseClasses;
partial model PartialSolidLiquidVessel_edu2
  "Vessel containing solid and liquid PCM with mass and energy balance"
  extends DCOL.ThermalStorage.LatentStorages.Icons.Ice_Water_segments;
  import SI = Modelica.SIunits;

  parameter SI.SpecificEnthalpy hfus=333.55e3;
  parameter SI.SpecificHeatCapacity Cp_l=4184;
  parameter SI.SpecificHeatCapacity Cp_s=2110;
  parameter SI.Density d_s=917.00;
  parameter SI.CoefficientOfHeatTransfer h_l=568.4;
  parameter SI.Diameter d_tube=0.03 annotation(Dialog(group="Geometric properties"));
  parameter SI.Diameter d_crit=0.1 annotation(Dialog(group="Geometric properties"));
  parameter SI.Diameter d_max=sqrt(2)*d_crit annotation(Dialog(group="Geometric properties"));
  parameter SI.Length L_coil=0.066 "Length of each tube segment" annotation(Dialog(group="Geometric properties"));

  // Initialization
  parameter SI.Temperature T_l_start=273.15+20
  "Initial solid temperature"  annotation (Dialog(tab="Initialization"));
  parameter SI.Temperature T_s_start=273.15-0
  "Initial solid temperature" annotation (Dialog(tab="Initialization"));
  parameter SI.Mass m_l_start=d_s*Modelica.Constants.pi*((d_max/2)^2-(d_tube/2)^2)*L_coil
  "Initial mass of liquid medium" annotation (Dialog(tab="Initialization"));
  parameter SI.Mass m_s_start=0
  "Initial mass of solid medium" annotation (Dialog(tab="Initialization"));
  parameter SI.Diameter d_start=2*((m_s_start / (d_s*3.14*1))+((d_tube/2)^2))^0.5
  "Initial mass of solid medium" annotation (Dialog(tab="Initialization"));
  parameter Modelica.SIunits.MassFraction x_l_start=1
  "Liquid mass fraction at the start" annotation(Dialog(tab="Initialization"));
  parameter Boolean charging_start=true
  "Initial state" annotation (Dialog(tab="Initialization"));

  SI.Mass m "Mass in the vessel";
  SI.Mass m_l(start=m_l_start, stateSelect = StateSelect.prefer) "Liquid mass of the vessel";
  SI.Mass m_s(start=m_s_start, stateSelect = StateSelect.prefer) "Solid mass in the vessel";
  SI.MassFlowRate mb_flow;
  SI.MassFlowRate m_w1 "Mass of water entering the storage";
  Modelica.SIunits.MassFraction x_l(each start=x_l_start,each min=0,each max=1) "Liquid mass fraction";
  //   SI.MassFlowRate m_w2 "Mass of water getting out the storage";

  SI.InternalEnergy U
    "Internal energy";
  SI.InternalEnergy U_l
    "Internal energy";
  SI.InternalEnergy U_s
    "Internal energy";
  SI.EnthalpyFlowRate Hb_flow
    "Heat flow across boundaries or energy source/sink";
  SI.HeatFlowRate Qb_flow
    "Heat flow across boundaries or energy source/sink";
  SI.SpecificEnthalpy h_w1
    "Specific enthalpy of the water entering the storage";
//    SI.SpecificEnthalpy h_w2
//      "Specific enthalpy of the water getting out the storage";

  SI.Energy Q_maxs;
  SI.Mass m_max "Maximum solid mass in the vessel";
  SI.Area A;
  SI.Diameter d(start=d_start);
  SI.Time t;
  Real a;

  parameter Real eps = 1e-4;
  parameter SI.Temperature T0=273.15;
  SI.Temperature T_l(start=T_l_start, stateSelect = StateSelect.prefer) "Liquid temperature in the vessel";
  SI.Temperature T_s(start=T_s_start, stateSelect = StateSelect.prefer) "Solid temperature in the vessel";

  SI.TemperatureDifference T_lN = (T_l-T0)/T0;
  SI.TemperatureDifference T_sN = (T_s-T0)/T0;

  Boolean flag_l "when there is liquid";
  Boolean flag_l_overHeat "when there is liquid over fusion temperature";
  Boolean flag_s "when there is solid";
  Boolean flag_s_subCold "when there is solid below fusion temperature";

  Boolean charging(start=charging_start);
  Integer test;
  Integer test1;

initial equation
//   h_w2=20*4184;

equation
  // Total quantities
  m = m_l + m_s;
  m_l = m*x_l;

  U_l = m_l*Cp_l*(T_l-T0);
  U_s = m_s*Cp_s*(T_s-T0);
  U = U_l + U_s;

  der(U) - der(m_s)*hfus= Hb_flow + Qb_flow;

   if abs(Qb_flow)>(m_w1*h_w1) then
     charging = true;
   else
     charging = false;
   end if;

  if charging==true then
    /*Charging process is takig place. No water flow during this proces.
    (Hb_flow=0)*/
     //0 = mb_flow;
     if flag_l and (not flag_s) then
       //Only liquid
       der(U_l) = Qb_flow;
       //    der(T_s) = 0;//*
       der(m_s) = 0;

       // T_s=T_l;
       t=0;
       a=0;
       //der(d)=0;
       der(T_s)=0;
       //  Hb_flow=0;
       //x_l = 1;
       test = 0;
       test1 = 0;
     elseif (not flag_l) and flag_s then
       //Only solid
       //    der(T_l) = 0;//*
       der(U_s) = Qb_flow;
       der(m_s) = 0;

       t=0;
       a=0;
       //der(d)=0;
       der(T_l)=0;
       //x_l = 0;
       test = 10;
       test1=0;
     else
       //Mix of solid and liquid
       if flag_l_overHeat and flag_s_subCold then
         der(U_l) = - A*h_l*(T_l-T_s);
         der(U_s) = Qb_flow + A*h_l*(T_l-T_s);
         //      der(m_s) = 0;//*

         t=0;
         a=0;
         der(d)=0;
         test = 1;
         test1=0;
       elseif flag_l_overHeat and (not flag_s_subCold) then
         der(U_l) = Hb_flow - A*h_l*(T_l-T_s);
         //   der(U_s) = Qb_flow + A*h_l*(T_l-T_s);//*
         der(T_s) = 0;
         t=(Q_maxs)/(-Qb_flow);
         a=(m_max)/t;
         der(m_s)=a;
         test = 2;
         test1=0;
       elseif (not flag_l_overHeat) and flag_s_subCold then
         //   der(U_l) = Hb_flow - A*h_l*(T_l-T_s);//*
         der(U_s) = Qb_flow + A*h_l*(T_l-T_s);
         der(T_l) = 0;
         t=(Q_maxs)/(-Qb_flow);
         a=(m_max)/t;
         der(m_s)=a;
         test = 3;
         test1=0;
       else
         der(T_s) = 0;
         der(T_l) = 0;
         //  T_s = 0;
         //  T_l = 0;
         //- der(m_s)*hfus = Hb_flow + Qb_flow;//*
         t=(Q_maxs)/(-Qb_flow-(m_w1*h_w1));
         a=(m_max)/t;
         der(m_s)=a;
         test = 4;
         test1= 0;
       end if;
     end if;
   else
    /*Disharging process is takig place. No cooling process is taking place.
    (Qb_flow=0)*/
    //der(m) = mb_flow;
    if flag_l and (not flag_s) then
      //Only liquid
      der(U_s) = A*h_l*(T_l-T_s);
      der(m_s) = 0;
      der(U_l) = Hb_flow - A*h_l*(T_l-T_s);
      //    der(T_s) = 0;//*

      // T_s=T_l;
      t=0;
      a=0;
      //der(d)=0;
      //der(T_s)=0;
      //  Hb_flow=0;
      //x_l = 1;
      test = 0;
      test1 = 0;
    elseif (not flag_l) and flag_s then
      //Only solid
      //    der(T_l) = 0;//*
      der(U_s) = A*h_l*(T_l-T_s);
      der(m_s) = 0;
      der(U_l) = Hb_flow - A*h_l*(T_l-T_s);

      t=0;
      a=0;
      //der(d)=0;
      //der(T_l)=0;
      //x_l = 0;
      test = 10;
      test1=0;
    else
      //Mix of solid and liquid
       if flag_l_overHeat and flag_s_subCold then
         der(U_l) = Hb_flow - A*h_l*(T_l-T_s);
         der(U_s) = + A*h_l*(T_l-T_s);
         //      der(m_s) = 0;//*

         t=0;
         a=0;
         der(d)=0;
         test = 1;
         test1= 0;
       elseif flag_l_overHeat and (not flag_s_subCold) then
          der(U_l) = Hb_flow - A*h_l*(T_l-T_s);
          //   der(U_s) = Qb_flow + A*h_l*(T_l-T_s);//*
          der(T_s) = 0;
          t=(Q_maxs)/(-Hb_flow);
          a=(m_max)/t;
          der(m_s)=a;
          test = 2;
          test1=0;
       elseif (not flag_l_overHeat) and flag_s_subCold then
         //   der(U_l) = Hb_flow - A*h_l*(T_l-T_s);//*
          der(U_s) = Qb_flow + A*h_l*(T_l-T_s);
          der(T_l) = 0;
          t=(Q_maxs)/(-Hb_flow);
          a=(m_max)/t;
          der(m_s)=a;
          test = 3;
          test1=0;
       else
         der(T_s) = 0;
         der(T_l) = 0;
         //  T_s = 0;
         //  T_l = 0;
         //  - der(m_s)*hfus = Hb_flow + Qb_flow;//*
         t = (Q_maxs)/(-Hb_flow);
         a = (m_max)/t;
         der(m_s) = a;
         test = 4;
         test1= 0;
      end if;
    end if;
  end if;

  der(m) = mb_flow;
  //0 = mb_flow;

  m_s=d_s*Modelica.Constants.pi*((d/2)^2-(d_tube/2)^2)*L_coil;
//   Q_maxs=m_max*hfus + A*h_l*(T_l-T_s);
  Q_maxs=m_max*hfus;
//   Q_maxs=m_max*hfus;
  m_max=d_s*Modelica.Constants.pi*((d_max/2)^2-(d_tube/2)^2)*L_coil;

  A = Modelica.Constants.pi*d*L_coil;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
        Text(
          extent={{-100,160},{100,100}},
          lineColor={28,108,200},
          textString="%name"),
        Polygon(
          points={{-28,36},{-28,36}},
          lineColor={28,108,200},
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid)}),                      Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>Base class for an ideal vessel with two mediums at liquid-vapor equilibrium with the ability to store mass and energy. The following boundary terms are part of the energy balance and must be specified in an extending class: </p>
<p><b>Qb_flow</b>, e.g., convective or latent heat flow rate across vessel boundary, and</p>
<p><b>Wb_flow</b>, work term.</p>
<p>Further source terms must be defined by an extending class for fluid flow across the segment boundary: </p>
<p><b>Hb_flow</b>, enthalpy flow,</p>
<p><b>mb_flow</b>, mass flow,</p>
<p><b>mbXi_flow_l</b> &AMP; <b>mbXi_flow_v</b>, substance mass flow for liquid and vapor medium respectively.</p>
<p>Since liquid-vapor equilibrium is assumped, temperatures (and pressures) of the vapor medium and the liquid medium are equal, and named <b>T</b> (<b>p</b>).</p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"),
    experiment(StopTime=25));
end PartialSolidLiquidVessel_edu2;
