within DCOL.ThermalStorage.LatentStorages.FMI;
model IceStorageExtMelt_Dym

  replaceable package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater
  constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water PCM medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
      Modelica_IK4_TEKNIKER.Media.Incompressible.Examples.EthyleneGlycol
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "HTF Medium in the component" annotation (choicesAllMatching = true);

  //Material of the tube

  parameter Integer nSeg=10 "Number of segments of each coil";
  parameter Integer nCoilp=10 "number of horizontally parallel coils";

  parameter Modelica.SIunits.SpecificEnthalpy hfus=333.55*10^3 "Enthalpy of fusion of the PCM at ambient presure" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMs=2110 "Specific heat capacity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMl=4184 "Specific heat capacity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_solid=917.00 "Density of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_liquid=999.82 "Density of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Temperature T_fus=0+273.15 "fusion temperature of the PCM" annotation(Dialog(group="Properties of the PCM"));

  parameter Modelica.SIunits.Diameter D_tube_in=0.025 "Interior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Length L_coil=0.66673757545215 "Length of each coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Diameter D_crit=0.1 "Critical diameter (vertical/horizontal distance between 2 coils)" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Pressure p_PCM=101325 "Pressure of the PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Diameter D_tube_out=0.03 "Exterior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Real Charge_Percentage=90 "Percentage of ice at the end of the charge [%]" annotation(Dialog(group="Operation properties"));

  parameter Real a=1000 "Coefficient for quadratic term  of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));

  parameter Modelica.SIunits.Length h=1 "Height of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length w=1 "Width of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Properties of the storage"));

  parameter Modelica.SIunits.ThermalConductivity k_PCMs=2.2 "Thermal conductivity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));

  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_PCMl=568.4 "Convection heat transfer coefficient of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.ThermalConductivity k_PCMl=0.58 "Thermal conductivity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));

  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF=6000 "Convection heat transfer coefficient of the HTF" annotation(Dialog(group="Properties of the HTF"));

  //Initial Values
  parameter Modelica.SIunits.MassFraction x_liquid_start=1 "Liquid mass fraction at the start" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_PCM_start=10+273.15 "Start temperature of the PCM" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_Tube_start=-10 + 273.15 "Start temperature of the tube" annotation(Dialog(tab="Initialization"));
  parameter Boolean Charging_start=true "Initial state of the storage" annotation(Dialog(tab="Initialization"));
  parameter Boolean Charged_start=false "Initial state of the storage" annotation(Dialog(tab="Initialization"));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{60,70},{80,90}})));

  Modelica.Fluid.Sources.FixedBoundary outlet_water(
    redeclare package Medium = Medium,
    nPorts=1) annotation (Placement(transformation(extent={{-60,-90},{-40,-70}})));

  IceStorageExternalMelt_nSegnCoilp iceStorageExternalMelt_nSegnCoilp(
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    redeclare package Material = Material,
    nSeg=nSeg,
    nCoilp=nCoilp,
    hfus=hfus,
    Cp_PCMs=Cp_PCMs,
    Cp_PCMl=Cp_PCMl,
    rho_solid=rho_solid,
    rho_liquid=rho_liquid,
    T_fus=T_fus,
    D_tube_in=D_tube_in,
    L_coil=L_coil,
    D_crit=D_crit,
    p_PCM=p_PCM,
    D_tube_out=D_tube_out,
    k_PCMs=k_PCMs,
    h_PCMl=h_PCMl,
    k_PCMl=k_PCMl,
    Charge_Percentage=Charge_Percentage,
    a=a,
    b=b,
    h=h,
    w=w,
    e=e,
    h_HTF=h_HTF,
    x_liquid_start=x_liquid_start,
    T_PCM_start=T_PCM_start,
    T_Tube_start=T_Tube_start,
    Charging_start=Charging_start,
    Charged_start=Charged_start)
    annotation (Placement(transformation(extent={{-50,-30},{50,30}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_HTF(
    redeclare package Medium = Medium1,
    nPorts=1,
    m_flow=30,
    use_T_in=true,
    use_m_flow_in=true,
    T=263.15) annotation (Placement(transformation(extent={{-80,-30},{-60,-10}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_water(
    redeclare package Medium = Medium,
    m_flow=10,
    use_T_in=true,
    use_m_flow_in=true,
    nPorts=1,
    T=283.15) annotation (Placement(transformation(extent={{-60,50},{-40,70}})));

  Modelica.Fluid.Sources.FixedBoundary outlet_HTF(
    redeclare package Medium = Medium1,
    nPorts=1) annotation (Placement(transformation(extent={{80,-10},{60,10}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature fixedTemperature annotation (Placement(transformation(extent={{0,70},{20,90}})));

  Modelica.Fluid.Sensors.Temperature outlet_water_temperature(
    redeclare package Medium = Medium) annotation (Placement(transformation(extent={{20,-50},{40,-30}})));

  Modelica.Fluid.Sensors.Temperature outlet_HTF_temperature(
    redeclare package Medium = Medium1) annotation (Placement(transformation(extent={{40,40},{60,60}})));

  RealConectors.RealTemperatureInput ambient_T annotation (Placement(transformation(extent={{-140,60},{-100,100}})));

  RealConectors.RealMassFlowInput water_in_m_flow annotation (Placement(transformation(extent={{-140,20},{-100,60}})));

  RealConectors.RealTemperatureInput water_inlet_T annotation (Placement(transformation(extent={{-140,-20},{-100,20}})));

  RealConectors.RealMassFlowInput HTF_m_flow annotation (Placement(transformation(extent={{-140,-60},{-100,-20}})));

  RealConectors.RealTemperatureInput HTF_inlet_T annotation (Placement(transformation(extent={{-140,-100},{-100,-60}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlowRate(
    redeclare package Medium = Medium) annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={0,-70})));

  RealConectors.RealTemperatureOutput HTF_outlet_T annotation (Placement(transformation(extent={{100,50},{120,70}})));

  RealConectors.RealTemperatureOutput PCM_T annotation (Placement(transformation(extent={{100,10},{120,30}})));

  RealConectors.RealTemperatureOutput water_outlet_T annotation (Placement(transformation(extent={{100,-30},{120,-10}})));

  RealConectors.RealMassFlowOutput water_out_m_flow annotation (Placement(transformation(extent={{100,-70},{120,-50}})));

equation
  connect(inlet_HTF.ports[1], iceStorageExternalMelt_nSegnCoilp.port_a_HTF)
    annotation (Line(points={{-60,-20},{-48,-20},{-48,0},{-37.5,0}}, color={0,
          127,255}));
  connect(iceStorageExternalMelt_nSegnCoilp.por_b_HTF, outlet_HTF.ports[1])
    annotation (Line(points={{37.5,0},{60,0}}, color={0,127,255}));
  connect(fixedTemperature.port, iceStorageExternalMelt_nSegnCoilp.port_b_Tambient)
    annotation (Line(points={{20,80},{27.5,80},{27.5,27.5}}, color={191,0,0}));
  connect(outlet_HTF_temperature.port, iceStorageExternalMelt_nSegnCoilp.por_b_HTF)
    annotation (Line(points={{50,40},{50,0},{37.5,0}}, color={0,127,255}));
  connect(inlet_water.ports[1], iceStorageExternalMelt_nSegnCoilp.port_a_water)
    annotation (Line(points={{-40,60},{0,60},{0,27.5}}, color={0,127,255}));
  connect(ambient_T, fixedTemperature.T) annotation (Line(points={{-120,80},{-2,80}}, color={0,0,127}));
  connect(HTF_m_flow, inlet_HTF.m_flow_in) annotation (Line(points={{-120,-40},{
          -94,-40},{-94,-12},{-80,-12}}, color={0,0,127}));
  connect(HTF_inlet_T, inlet_HTF.T_in) annotation (Line(points={{-120,-80},{-88,
          -80},{-88,-16},{-82,-16}}, color={0,0,127}));
  connect(water_in_m_flow, inlet_water.m_flow_in) annotation (Line(points={{-120,
          40},{-80,40},{-80,68},{-60,68}}, color={0,0,127}));
  connect(water_inlet_T, inlet_water.T_in) annotation (Line(points={{-120,0},{-72,
          0},{-72,64},{-62,64}}, color={0,0,127}));
  connect(iceStorageExternalMelt_nSegnCoilp.port_b_water, massFlowRate.port_a)
    annotation (Line(points={{0,-27.5},{0,-60}}, color={0,127,255}));
  connect(massFlowRate.port_b, outlet_water.ports[1]) annotation (Line(points={{0,-80},{-40,-80}}, color={0,127,255}));
  connect(iceStorageExternalMelt_nSegnCoilp.port_b_water,
    outlet_water_temperature.port) annotation (Line(points={{0,-27.5},{0,-50},{
          30,-50}},                         color={0,127,255}));
  connect(massFlowRate.m_flow, water_out_m_flow) annotation (Line(points={{11,-70},
          {56,-70},{56,-60},{110,-60}}, color={0,0,127}));
  connect(iceStorageExternalMelt_nSegnCoilp.PCM_T, PCM_T) annotation (Line(
        points={{42.5,12.75},{42.5,12},{42,12},{42,20},{110,20}},
                                     color={0,0,127}));
  connect(outlet_water_temperature.T, water_outlet_T) annotation (Line(points={{
          37,-40},{70,-40},{70,-20},{110,-20}}, color={0,0,127}));
  connect(outlet_HTF_temperature.T, HTF_outlet_T) annotation (Line(points={{57,50},
          {80,50},{80,60},{110,60}}, color={0,0,127}));
public
  replaceable package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321 constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coils" annotation (choicesAllMatching = true,Dialog(group="Properties of the coils"));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)));
end IceStorageExtMelt_Dym;
