within DCOL.ThermalStorage.LatentStorages.FMI;
model IceStorage_Dym

  replaceable package Medium = Modelica.Media.Air.DryAirNasa
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "HTF Medium in the component" annotation (choicesAllMatching = true);

  //Material of the tube
  replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
     "Material of the coil" annotation (choicesAllMatching = true,Dialog(group="Properties of the coils"));

  //Properties of the PCM
  replaceable package PCM_Prop =
      DCOL.ThermalStorage.LatentStorages.PCMs.Ice_Water constrainedby DCOL.ThermalStorage.LatentStorages.PCMs.BaseClasses.PCM_Properties
     "PCM Medium in the component" annotation (choicesAllMatching = true,Dialog(group="Properties of the PCM"));

  //Material of the storage wall
  replaceable package Material1 =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
      "Material in the component" annotation (choicesAllMatching = true,Dialog(group="Properties of the storage"));

  parameter Integer nSeg=10 "Number of segments of each coil";
  parameter Integer nCoil=10 "Number of coil";

  parameter Modelica.SIunits.Diameter D_tube_in=0.025 "Interior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Length L_coil=10 "Length of each coils segment" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Diameter D_crit=0.1 "Critical diameter (vertical/horizontal distance between 2 coils)" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Pressure p_PCM=101325 "Pressure of the PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Diameter D_tube_out=0.03 "Exterior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Real Charge_Percentage=90 "Percentage of ice at the end of the charge [%]" annotation(Dialog(group="Operation properties"));
  parameter Real a=1000 "Coefficient for quadratic term  of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));

  parameter Modelica.SIunits.Length h=1 "Height of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length w=1 "Width of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Properties of the storage"));

  parameter Modelica.SIunits.ThermalConductivity k_PCMs=2.2 "Thermal conductivity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_PCMl=568.4 "Convection heat transfer coefficient of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.ThermalConductivity k_PCMl=0.58 "Thermal conductivity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF=6000 "Convection heat transfer coefficient of the HTF" annotation(Dialog(group="Properties of the HTF"));

  parameter Modelica.Media.Interfaces.Types.Temperature T_start_pipe=-15+273.15 "Start value of the temperature inside the pipe" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_PCM_start=10 + 273.15 "Start temperature of the PCM" annotation(Dialog(tab="Initialization"));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature ambientTemperature
    annotation (Placement(transformation(extent={{-40,60},{-20,80}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{50,72},
            {70,92}})));

  IceStorageInternalMeltnSegnCoilsRecord iceStorageInternalMelt(
    T_start_pipe=T_start_pipe,
    T_PCM_start=T_PCM_start,
    redeclare package Medium = Medium,
    redeclare package Material = Material,
    redeclare package PCM_Prop = PCM_Prop,
    redeclare package Material1 = Material1,
    nSeg=nSeg,
    nCoil=nCoil,
    D_tube_in=D_tube_in,
    L_coil=L_coil,
    D_crit=D_crit,
    p_PCM=p_PCM,
    D_tube_out=D_tube_out,
    Charge_Percentage=Charge_Percentage,
    a=a,
    b=b,
    h=h,
    w=w,
    e=e,
    k_PCMs=k_PCMs,
    h_PCMl=h_PCMl,
    k_PCMl=k_PCMl,
    h_HTF=h_HTF)
    annotation (Placement(transformation(extent={{-52,-40},{60,40}})));

  Modelica.Fluid.Sources.FixedBoundary outlet_HTF(nPorts=1, redeclare package Medium =
               Medium)
    annotation (Placement(transformation(extent={{88,-10},{68,10}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_HTF(
    m_flow=10,
    nPorts=1,
    use_T_in=true,
    use_m_flow_in=true,
    redeclare package Medium = Medium,
    T=263.15) annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));

  Modelica.Fluid.Sensors.Temperature m_inlet_HTF_T(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{-64,40},{-44,60}})));

  Modelica.Fluid.Sensors.Temperature m_outlet_HTF_T(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{54,-40},{74,-60}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature floorTemperature
    annotation (Placement(transformation(extent={{-60,-80},{-40,-60}})));
  RealConectors.RealTemperatureInput ambient_T "Ambient temperature"
    annotation (Placement(transformation(extent={{-140,70},{-100,110}})));
  RealConectors.RealMassFlowInput HTF_m_flow "Inlet HTF mass flow"
    annotation (Placement(transformation(extent={{-140,10},{-100,50}})));
  RealConectors.RealTemperatureInput HTF_T "Inlet HTF temperature"
    annotation (Placement(transformation(extent={{-140,-50},{-100,-10}})));
  RealConectors.RealTemperatureInput floor_T "Floor temperatura"
    annotation (Placement(transformation(extent={{-140,-110},{-100,-70}})));
  RealConectors.RealTemperatureOutput inletHTF_T "Inlet HTF temperature"
    annotation (Placement(transformation(extent={{100,40},{120,60}})));
  RealConectors.RealTemperatureOutput PCM_T "Temperature of the PCM"
    annotation (Placement(transformation(extent={{100,-10},{120,10}})));
  RealConectors.RealTemperatureOutput outletHTF_T "Outlet HTF temperature"
    annotation (Placement(transformation(extent={{100,-60},{120,-40}})));
equation
  connect(ambientTemperature.port, iceStorageInternalMelt.port_b_Tambient)
    annotation (Line(points={{-20,70},{-20,70},{4,70},{4,36}}, color={191,0,0}));
  connect(inlet_HTF.ports[1], iceStorageInternalMelt.port_a_HTF)
    annotation (Line(points={{-60,0},{-48.5,0}}, color={0,127,255}));
  connect(m_inlet_HTF_T.port, iceStorageInternalMelt.port_a_HTF) annotation (
      Line(points={{-54,40},{-54,40},{-54,0},{-48.5,0}}, color={0,127,255}));
  connect(iceStorageInternalMelt.port_b_HTF, outlet_HTF.ports[1])
    annotation (Line(points={{56.5,0},{56.5,0},{68,0}}, color={0,127,255}));
  connect(m_outlet_HTF_T.port,iceStorageInternalMelt.port_b_HTF)  annotation (
      Line(points={{64,-40},{64,-40},{64,0},{56.5,0}}, color={0,127,255}));

  connect(iceStorageInternalMelt.port_b_Tfloor, floorTemperature.port)
    annotation (Line(points={{-34.5,-36},{-34.5,-36},{-35,-36},{-35,-70},{-40,-70}},
        color={191,0,0}));
  connect(m_inlet_HTF_T.T, inletHTF_T)
    annotation (Line(points={{-47,50},{110,50}}, color={0,0,127}));
  connect(m_outlet_HTF_T.T, outletHTF_T)
    annotation (Line(points={{71,-50},{110,-50}}, color={0,0,127}));
  connect(iceStorageInternalMelt.PCM_T, PCM_T) annotation (Line(points={{63.5,20.4},
          {92,20.4},{92,0},{110,0}}, color={0,0,127}));
  connect(ambient_T, ambientTemperature.T) annotation (Line(points={{-120,90},{-90,
          90},{-90,70},{-42,70}},          color={0,0,127}));
  connect(HTF_m_flow, inlet_HTF.m_flow_in) annotation (Line(points={{-120,30},{-106,
          30},{-90,30},{-90,8},{-80,8}}, color={0,0,127}));
  connect(HTF_T, inlet_HTF.T_in) annotation (Line(points={{-120,-30},{-90,-30},{
          -90,4},{-82,4}}, color={0,0,127}));
  connect(floor_T, floorTemperature.T) annotation (Line(points={{-120,-90},{-92,
          -90},{-92,-70},{-62,-70}}, color={0,0,127}));
  annotation (experiment(StopTime=60000, __Dymola_Algorithm="Cvode"),
      Documentation(revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end IceStorage_Dym;
