within DCOL.ThermalStorage.LatentStorages;
model IceStorageExternalMelt_TOTAL
  extends DCOL.ThermalStorage.LatentStorages.Icons.IceStorageExternalMelting;

  import Modelica.Constants;
  import DCOL;
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater
  constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water PCM medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium1 =
      Modelica_IK4_TEKNIKER.Media.Incompressible.Examples.EthyleneGlycol
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "HTF Medium in the component" annotation (choicesAllMatching = true);

  //Material of the tube
  replaceable package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.Copper
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coils" annotation (choicesAllMatching = true,Dialog(group="Properties of the coils"));

  parameter Boolean allowFlowReversal = system.allowFlowReversal
    "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)"  annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Integer nSeg=3 "Number of segments of each coil";
  parameter Integer nCoilp=10 "number of horizontally parallel coils";
  parameter Integer nCoilv=10 "number of vertically parallel coils";

  parameter Modelica.SIunits.SpecificEnthalpy hfus=333.55*10^3 "Enthalpy of fusion of the PCM at ambient presure" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMs=2110 "Specific heat capacity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.SpecificHeatCapacity Cp_PCMl=4184 "Specific heat capacity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_solid=917.00 "Density of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Density rho_liquid=999.82 "Density of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.Temperature T_fus=0+273.15 "fusion temperature of the PCM" annotation(Dialog(group="Properties of the PCM"));
  //parameter Modelica.SIunits.Mass m_PCM=L_coil*Modelica.Constants.pi*((((sqrt(2)*D_crit)/2)^2)-((D_tube_out/2)^2))*rho_liquid "Total mass of the PCM" annotation(Dialog(group="Characteristics of the PCM"));

  parameter Modelica.SIunits.Diameter D_tube_in=0.025 "Interior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Length L_coil=10 "Length of each coil" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Diameter D_crit=0.1 "Critical diameter (vertical/horizontal distance between 2 coils)" annotation(Dialog(group="Properties of the coils"));
  parameter Modelica.SIunits.Pressure p_PCM=101325 "Pressure of the PCM" annotation(Dialog(group="Properties of the PCM"));
  //parameter Modelica.SIunits.Mass m_PCM_tube=(L_coil/1)*Modelica.Constants.pi*((((sqrt(2)*D_crit)/2)^2)-((D_tube_out/2)^2))*rho_liquid "Mass of PCM around each tube segment" annotation(Dialog(group="Properties of the PCM"));
//   parameter Modelica.SIunits.ThermalConductance G=0.5 "Constant thermal conductance of the material of the tank" annotation(Dialog(group="Thermal properties of the tank"));
  //parameter Modelica.SIunits.Diameter D_max=sqrt(2)*D_crit "maximun diameter (vertical/horizontal maximun distance between 2 coils)" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Diameter D_tube_out=0.03 "Exterior diameter of the coil" annotation(Dialog(group="Properties of the coils"));
  parameter Real Charge_Percentage=90 "Percentage of ice at the end of the charge [%]" annotation(Dialog(group="Operation properties"));
//   parameter Real Discharge_Percentage=5 "Percentage of ice at the end of the discharge [%]" annotation(Dialog(group="Operation properties"));

  parameter Real a=1000 "Coefficient for quadratic term  of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));
  parameter Real b=1000 "Coefficient for linear term of the pressure drop" annotation(Dialog(group="Coeficient for the pressure drop"));

  //parameter Modelica.SIunits.Volume vol=L_coil*(Modelica.Constants.pi*(((D_tube_out/2)^2)-(D_tube_in/2)^2)) "Volume of each coil segment" annotation(Dialog(group="Properties of the coils"));

  parameter Modelica.SIunits.Length h=1 "Height of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length w=1 "Width of the storage" annotation(Dialog(group="Properties of the storage"));
  parameter Modelica.SIunits.Length e=0.2 "Thicknes of the storages wall" annotation(Dialog(group="Properties of the storage"));

  parameter Modelica.SIunits.ThermalConductivity k_PCMs=2.2 "Thermal conductivity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_PCMl=568.4 "Convection heat transfer coefficient of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.ThermalConductivity k_PCMl=0.58 "Thermal conductivity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF=6000 "Convection heat transfer coefficient of the HTF" annotation(Dialog(group="Properties of the HTF"));

  //Initial values
  parameter Modelica.SIunits.MassFraction x_liquid_start=1 "Liquid mass fraction at the start" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_PCM_start=10+273.15 "Start temperature of the PCM" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.Temperature T_Tube_start=20 + 273.15 "Start temperature of the tube" annotation(Dialog(tab="Initialization"));
  parameter Boolean Charging_start=true "Initial state of the storage" annotation(Dialog(tab="Initialization"));
  parameter Boolean Charged_start=false "Initial state of the storage" annotation(Dialog(tab="Initialization"));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_water(
    redeclare package Medium = Medium) "Entrace port of the water PCM" annotation (Placement(transformation(extent={{-10,100},{10,120}}),iconTransformation(extent={{-10,100},{10,120}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b_water(
    redeclare package Medium = Medium) "Exit port of the water PCM" annotation (Placement(transformation(extent={{-10,-120},{10,-100}}),iconTransformation(extent={{-10,-120},{10,-100}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_Tambient
    "Heat exchanged with the ambient" annotation (Placement(transformation(extent={{100,100},{120,120}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_a_HTF(
    redeclare package Medium = Medium1,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Fluid connector a (positive design flow direction is from port_In to port_Out)" annotation (Placement(transformation(extent={{-160,-10},{-140,10}}),
        iconTransformation(extent={{-160,-10},{-140,10}})));

  Modelica.Fluid.Interfaces.FluidPort_b por_b_HTF(
    redeclare package Medium = Medium1,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium1.h_default))
    "Fluid connector b (positive design flow direction is from port_In to port_Out)" annotation (Placement(transformation(extent={{140,-10},{160,10}}),
        iconTransformation(extent={{140,-10},{160,10}})));

  DCOL.ThermalStorage.LatentStorages.IceStorageExternalMelt_nSegnCoilpnCoilv iSEM_T[nCoilv](
    redeclare package Medium = Medium,
    redeclare package Medium1 = Medium1,
    redeclare package Material = Material,
    each nSeg=nSeg,
    each nCoilp=nCoilp,
    each hfus=hfus,
    each Cp_PCMs=Cp_PCMs,
    each Cp_PCMl=Cp_PCMl,
    each rho_solid=rho_solid,
    each rho_liquid=rho_liquid,
    each T_fus=T_fus,
    each D_tube_in=D_tube_in,
    each L_coil=L_coil,
    each D_crit=D_crit,
    each p_PCM=p_PCM,
    each D_tube_out=D_tube_out,
    each Charge_Percentage=Charge_Percentage,
    each a=a,
    each b=b,
    each h=h,
    each w=w,
    each e=e,
    each k_PCMs=k_PCMs,
    each h_PCMl=h_PCMl,
    each k_PCMl=k_PCMl,
    each h_HTF=h_HTF,
    each x_liquid_start=x_liquid_start,
    each T_PCM_start=T_PCM_start,
    each T_Tube_start=T_Tube_start,
    each Charging_start=Charging_start,
    each Charged_start=Charged_start)
    annotation (Placement(transformation(extent={{-60,-36},{60,36}})));

equation

  for i in 1:nCoilv-1 loop
    connect(iSEM_T[i].port_b_water, iSEM_T[i + 1].port_a_water);
  end for;

  for i in 1:nCoilv loop
    connect(iSEM_T[i].port_b_Tambient, port_b_Tambient)
      annotation (Line(points={{33,33},{110,33},{110,110}}, color={191,0,0}));
    connect(port_a_HTF, iSEM_T[i].port_a_HTF)
      annotation (Line(points={{-150,0},{-45,0}}, color={0,127,255}));
    connect(iSEM_T[i].por_b_HTF, por_b_HTF)
      annotation (Line(points={{45,0},{150,0}}, color={0,127,255}));
  end for;

  connect(port_a_water, iSEM_T[1].port_a_water)
    annotation (Line(points={{0,110},{0,110},{0,33}}, color={0,127,255}));
  connect(iSEM_T[nCoilv].port_b_water, port_b_water)
    annotation (Line(points={{0,-33},{0,-110}}, color={0,127,255}));
       annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(
          preserveAspectRatio=false)));
end IceStorageExternalMelt_TOTAL;
