within DCOL.ThermalStorage.LatentStorages;
model IceStorageExternalMelt_nSegnCoilpnCoilv

  extends DCOL.ThermalStorage.LatentStorages.BaseClasses.IceStorageExternalMelt_nSegnCoilpnCoilv_pruebas;

  Modelica.SIunits.ThermalConductivity k_tube[nSeg] "Thermal conductivity of the tube";

  Modelica.SIunits.MassFraction x_liquid_Total(start=x_liquid_start,min=0,max=1) "Total liquid mass fraction";

  Modelica.SIunits.CoefficientOfHeatTransfer U_in[nSeg] "Heat transfer coeficient";
  Modelica.SIunits.CoefficientOfHeatTransfer U_out[nSeg] "Heat transfer coeficient";
  Modelica.SIunits.Area A_in "Heat transfer area";
  Modelica.SIunits.Area A_out "Heat transfer area";

  //Solid PCM
  parameter Modelica.SIunits.ThermalConductivity k_PCMs=2.2 "Thermal conductivity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));

  Modelica.SIunits.Area A_PCMs_out "Area of the exterior of the ice";

  //Liquid PCM
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_PCMl=568.4 "Convection heat transfer coefficient of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.ThermalConductivity k_PCMl=0.58 "Thermal conductivity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));

  Modelica.SIunits.Area A_PCMl_out "Area of the exterior of the liquid PCM";

  //HTF
  Modelica.SIunits.Temperature T_HTFo "Outlet HTF temperature";
  Modelica.SIunits.Temperature T_HTFi "Inlet HTF temperature";
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF=6000 "Convection heat transfer coefficient of the HTF" annotation(Dialog(group="Properties of the HTF"));

  Real f[nSeg] "Correction factor";
  Real AR[nSeg] "Area ratio";

protected
  parameter Modelica.SIunits.Diameter D_tube_mid=D_tube_in-((D_tube_in-D_tube_out)/2) "Interior diameter of the coil" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area A_tube_out=Modelica.Constants.pi*D_tube_out*(L_coil/nSeg) "Area of the exterior of the coil" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area A_tube_in=Modelica.Constants.pi*D_tube_in*(L_coil/nSeg) "Area of the interior of the coil" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area A_tube_mid=Modelica.Constants.pi*D_tube_mid*(L_coil/nSeg) "Area of the middle of the coil" annotation(Dialog(group="Geometric properties"));

equation

  //General equations (for charge and discharge)
  //Properties of the HTF at the entrace
  T_HTFi=Medium1.temperature(Medium1.setState_phX(
      p=port_a_HTF.p,
      h=inStream(port_a_HTF.h_outflow),
      X=inStream(port_a_HTF.Xi_outflow)))
     "Medium1 properties at the entrace";

  //Properties of the HTF at the exit
  T_HTFo=Medium1.temperature(Medium1.setState_phX(
      p=por_b_HTF.p,
      h=por_b_HTF.h_outflow,
      X=por_b_HTF.Xi_outflow))
     "Medium1 properties at the exit";

  x_liquid_Total=externalMelt.x_liquid/1;

  //Calculation of the heat transfer coeficient between the HTF and the PCM
  /*
    It is considered that the storage is charging when the HTF temperature
    at the entrace is higher than the PCM temperature; and discharging 
    when the HTF temperature is higer.
  */
  if (1-x_liquid_Total)*100<Charge_Percentage then
    Charged=false;
  else
    Charged=true;
  end if;

  //if T_HTFi<pruebas_externalMelt.T then
  if T_HTFi < externalMelt.T and Charged==false and port_a_HTF.m_flow>0.0001 then
  //if hTFtoPCM[1].port_b.Q_flow<0 and Charged==false then
    Charging=true;
  else
    Charging=false;
  end if;

  A_in=A_tube_mid;
  externalMelt.Charging = Charging;

//   for i in 1:nCoil loop
//     for j in 1:nSeg loop
//       //Connection of the heat transfer
//       heatSampler[j].Charging=Charging;
//     end for;
//   end for;

  A_PCMs_out=Modelica.Constants.pi*externalMelt.D_s*(L_coil/nSeg);
  A_PCMl_out=Modelica.Constants.pi*externalMelt.D_l*(L_coil/nSeg);

  if Charging==true then
    if externalMelt.T > T_fus then
      A_out=A_tube_out;
    else
      if externalMelt.D_s <= D_crit then
        A_out=A_PCMs_out;
      else
        A_out=A_PCMs_out;
      end if;
    end if;
  else
    if externalMelt.T > T_fus then
      A_out=A_tube_out;
    else
      if externalMelt.D_s > 1.0001*D_crit then
        A_out=A_PCMs_out;
      else
        A_out=A_PCMs_out;
      end if;
    end if;
  end if;

  for i in 1:nSeg loop

    G_TubetoPCM[i]=A_out*U_out[i];
    G_HTFtoTube[i]=A_in*U_in[i];

    U_in[i]=((A_tube_mid/(A_tube_in*h_HTF))+((A_tube_mid*log(D_tube_mid/D_tube_in))/
    (2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg))))^(-1);
    k_tube[i]=Material.thermalConductivity_T(hTFtoPCM[i].TubeInertia.T);

  if Charging==true then
    if externalMelt.T > T_fus then
      /*
        Sensible charging or discharging (There is no solid PCM).
      */
      U_out[i]=(((A_tube_out*log(D_tube_out/D_tube_mid))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
              (1/h_PCMl))^(-1);
      f[i]=0;
      AR[i]=0;
    else
      if externalMelt.D_s <= 1.0001*D_crit then
        /*
          Unconstrained latent charging or discharging (There is a ring of solid 
          PCM which is growing; this phase finishes when two adjacent solid ring 
          touch. During the discharge process the opposite process occurs).
        */
        U_out[i]=(((A_PCMs_out*log(D_tube_out/D_tube_mid))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg))) +
                   ((A_PCMs_out*log(externalMelt.D_s/D_tube_out))/(2*Modelica.Constants.pi*k_PCMs*(L_coil/nSeg))) +
                     (1/h_PCMl))^(-1);
        f[i]=0;
        AR[i]=0;
      else
        /*
          Constrained latent charging or discharging (this phase starts when 
          adjacent solid rings touch and ends when there is no water in the 
          spaces between the ice rings. During the discharge process the opposite 
          process ocurs).
        */
        U_out[i]=(((A_PCMs_out*log(D_tube_out/D_tube_mid))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                   ((A_PCMs_out*log(D_crit/D_tube_out))/(2*Modelica.Constants.pi*k_PCMs*(L_coil/nSeg)*f[i]))+
                     (1/h_PCMl))^(-1);
        f[i]=-1.441*AR[i]+2.455*sqrt(AR[i])+(D_tube_out/D_crit)*(3.116*AR[i]-3.158*sqrt(AR[i]));
        AR[i]=1 - ((4/Modelica.Constants.pi)*acos(D_crit/(externalMelt.D_s)));
      end if;
    end if;
  else
    /*
      When the storage is nor charging it is asumed the no heat goes throuth the
      tubes to the HTF as there is no HTF.
    */
    U_out[i]=0;
    f[i]=0;
    AR[i]=0;
  end if;

  end for;

  when Charged==true then
    assert(port_a_HTF.m_flow==0.0,"Storage CHARGED; no HTF should flow",
             AssertionLevel.error);
  end when;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-200,-120},{200,120}})),
                                                                 Diagram(coordinateSystem(
          preserveAspectRatio=false, extent={{-200,-120},{200,120}})));
end IceStorageExternalMelt_nSegnCoilpnCoilv;
