within DCOL.ThermalStorage.LatentStorages;
model IceStorageInternalMeltnSegnCoils

  extends DCOL.ThermalStorage.LatentStorages.BaseClasses.IceStorageInternalMeltnSegnCoils;

  parameter Modelica.SIunits.Diameter D_tube_mid=D_tube_in-((D_tube_in-D_tube_out)/2) "Interior diameter of the coil" annotation(Dialog(group="Geometric properties"));
  Modelica.SIunits.Mass m_PCM "Total mass of the PCM";
  Modelica.SIunits.MassFraction x_liquid_Total(start=1,min=0,max=1) "Total liquid mass fraction";

protected
  parameter Modelica.SIunits.Area A_tube_out=Modelica.Constants.pi*D_tube_out*(L_coil/nSeg) "Area of the exterior of the coil" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area A_tube_in=Modelica.Constants.pi*D_tube_in*(L_coil/nSeg) "Area of the interior of the coil" annotation(Dialog(group="Geometric properties"));
  parameter Modelica.SIunits.Area A_tube_mid=Modelica.Constants.pi*D_tube_mid*(L_coil/nSeg) "Area of the middle of the coil" annotation(Dialog(group="Geometric properties"));
  Modelica.SIunits.ThermalConductivity k_tube[nSeg] "Thermal conductivity of the tube"
                                                                                      annotation(Dialog(group="Properties of the coil"));

  Modelica.SIunits.CoefficientOfHeatTransfer U_tot[nSeg] "Heat transfer coeficient";
  Modelica.SIunits.CoefficientOfHeatTransfer U_in[nSeg] "Heat transfer coeficient";
  Modelica.SIunits.CoefficientOfHeatTransfer U_out[nSeg] "Heat transfer coeficient";
  Modelica.SIunits.Area A[nSeg] "Heat transfer area";
  Modelica.SIunits.Area A_in "Heat transfer area";
  Modelica.SIunits.Area A_out[nSeg] "Heat transfer area";
  Modelica.SIunits.ThermalConductance G_total[nSeg] "Thermal conductance of the tube";

  //Solid PCM
public
  parameter Modelica.SIunits.ThermalConductivity k_PCMs=2.2 "Thermal conductivity of the solid PCM" annotation(Dialog(group="Properties of the PCM"));

  Modelica.SIunits.Area A_PCMs_out[nSeg] "Area of the exterior of the ice";
  Modelica.SIunits.Area A_PCMs_total "Total solid PCM area";

  //Liquid PCM
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_PCMl=568.4 "Convection heat transfer coefficient of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));
  parameter Modelica.SIunits.ThermalConductivity k_PCMl=0.58 "Thermal conductivity of the liquid PCM" annotation(Dialog(group="Properties of the PCM"));

  Modelica.SIunits.Area A_PCMl_out[nSeg] "Area of the exterior of the liquid PCM";
  Modelica.SIunits.Area A_PCMl_total "Total liquid PCM area";

  //HTF
  Modelica.SIunits.Temperature T_HTFo "Outlet HTF temperature";
  Modelica.SIunits.Temperature T_HTFi "Inlet HTF temperature";
  //parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF=2.43234 "Convection heat transfer coefficient of the HTF" annotation(Dialog(group="Properties of the HTF"));
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF=6000 "Convection heat transfer coefficient of the HTF" annotation(Dialog(group="Properties of the HTF"));

  Real f[nSeg] "Correction factor";
  Real AR[nSeg] "Area ratio";

equation

  //General equations (for charge and discharge)
  //Properties of the HTF at the entrace
  T_HTFi=Medium.temperature(Medium.setState_phX(
      p=port_a_HTF.p,
      h=inStream(port_a_HTF.h_outflow),
      X=inStream(port_a_HTF.Xi_outflow)))
     "Medium properties at the entrace";

  //Properties of the HTF at the exit
  T_HTFo=Medium.temperature(Medium.setState_phX(
      p=por_b_HTF.p,
      h=por_b_HTF.h_outflow,
      X=por_b_HTF.Xi_outflow))
     "Medium properties at the exit";
  A_PCMs_total=sum(A_PCMs_out);
  A_PCMl_total=sum(A_PCMl_out);
  m_PCM=m_PCM_tube*nCoil;
  x_liquid_Total=sum(ice_WaterRing.x_liquid)/(nCoil*nSeg);

  //Calculation of the heat transfer coeficient between the HTF and the PCM
  /*
    It is considered that the storage is charging when the HTF temperature
    at the entrace is higher than the PCM temperature; and discharging 
    when the HTF temperature is higer.
    */
  if (1-x_liquid_Total)*100<=Charge_Percentage then
    Charged=false;
  else
    Charged=true;
  end if;

  if T_HTFi<ice_WaterRing[1,1].T then
    Charging=true;
  else
    Charging=false;
  end if;

  for i in 1:nCoil loop
    for j in 1:nSeg loop
      ice_WaterRing[i,j].Charging=Charging;
    end for;
  end for;

  A_in=A_tube_mid;

  for i in 1:nSeg loop
    G_total[i] = A[i]*U_tot[i];
    G_TubetoPCM[i]=A_out[i]*U_out[i];
    G_HTFtoTube[i]=A_in*U_in[i];

    U_in[i]=((A_tube_mid/(A_tube_in*h_HTF))+((A_tube_mid*log(D_tube_mid/D_tube_in))/
    (2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg))))^(-1);
    k_tube[i]=Material.thermalConductivity_T(HTFtoPCM[1,i].TubeInertia.T);

    /*
      Areas of the solid PCM and liquid PCM rings (the fist one is used during 
      the charging process as the PCM is getting solid from the part in contact 
      with the tube to the exterior; the area of the liquid ring is used in the 
      opposite procces, when the PCM is melting from the inside to the outside). 
    */
    A_PCMs_out[i]=Modelica.Constants.pi*ice_WaterRing[1,i].D_s*(L_coil/nSeg);
    A_PCMl_out[i]=Modelica.Constants.pi*ice_WaterRing[1,i].D_l*(L_coil/nSeg);

    /*
      The value of the overall conductance between the HTF and the PCM varies 
      depending on if the storage is in the charging or discharging process; 
      and depending on with phase of this proces it is.
    */
    if Charging==true then
      if ice_WaterRing[1,i].T>T_fus then
        /*
          Sensible charging (No solid PCM is formed, the heat is taken from the liquid
          PCM).
        */
        U_tot[i]=((A_tube_out/(A_tube_in*h_HTF))+
                   ((A_tube_out*log(D_tube_out/D_tube_in))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                     (1/h_PCMl))^(-1);
        U_out[i]=(((A_tube_out*log(D_tube_out/D_tube_mid))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                   (1/h_PCMl))^(-1);
        A[i]=A_tube_out;
        A_out[i]=A_tube_out;
        f[i]=0;
        AR[i]=0;
      else
        if ice_WaterRing[1,i].D_s<D_crit then
          /*
            Unconstrained latent charging (There is a ring of solid PCM which is 
            growing; this phase finishes when two adjacent solid ring touch).
          */
          U_tot[i]=((A_PCMs_out[i]/(A_tube_in*h_HTF))+
                     ((A_PCMs_out[i]*log(D_tube_out/D_tube_in))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                       ((A_PCMs_out[i]*log(ice_WaterRing[1,i].D_s/D_tube_out))/(2*Modelica.Constants.pi*k_PCMs*(L_coil/nSeg)))+
                         (1/h_PCMl))^(-1);
          U_out[i]=(((A_PCMs_out[i]*log(D_tube_out/D_tube_mid))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                     ((A_PCMs_out[i]*log(ice_WaterRing[1,i].D_s/D_tube_out))/(2*Modelica.Constants.pi*k_PCMs*(L_coil/nSeg)))+
                       (1/h_PCMl))^(-1);
          A[i]=A_PCMs_out[i];
          A_out[i]=A_PCMs_out[i];
          f[i]=0;
          AR[i]=0;
        else
          /*
            Constrained latent charging (this phase starts when adjacent solid rings 
            touch and ends when there is no water in the spaces between the ice rings).
          */
          U_tot[i]=((A_PCMs_out[i]/(A_tube_in*h_HTF))+
                     ((A_PCMs_out[i]*log(D_tube_out/D_tube_in))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                       ((A_PCMs_out[i]*log(D_crit/D_tube_out))/(2*Modelica.Constants.pi*k_PCMs*(L_coil/nSeg)*f[i]))+
                         (1/h_PCMl))^(-1);
          U_out[i]=(((A_PCMs_out[i]*log(D_tube_out/D_tube_mid))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                     ((A_PCMs_out[i]*log(D_crit/D_tube_out))/(2*Modelica.Constants.pi*k_PCMs*(L_coil/nSeg)*f[i]))+
                       (1/h_PCMl))^(-1);
          A[i]=A_PCMs_out[i];
          A_out[i]=A_PCMs_out[i];
          f[i]=-1.441*AR[i]+2.455*sqrt(AR[i])+(D_tube_out/D_crit)*(3.116*AR[i]-3.158*sqrt(AR[i]));
          AR[i]=1-((4/Modelica.Constants.pi)*acos(D_crit/(ice_WaterRing[1,i].D_s)));
        end if;
      end if;
    else
      if ice_WaterRing[1,i].D_l<D_crit then
        /*
          Unconstrained latent discharging (Growth of the liquid ring as the PCM 
          melts; this phase goes from the formation of the liqid ring until adjacent
          rings touch).
        */
        U_tot[i]=((A_PCMl_out[i]/(A_tube_in*h_HTF))+
                   ((A_PCMl_out[i]*log(D_tube_out/D_tube_in))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                     ((A_PCMl_out[i]*log(ice_WaterRing[1,i].D_l/D_tube_out))/(2*Modelica.Constants.pi*k_PCMl*(L_coil/nSeg))))^(-1);
        U_out[i]=((A_PCMl_out[i]/(A_tube_in*h_HTF))+
                   ((A_PCMl_out[i]*log(D_tube_out/D_tube_in))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                     ((A_PCMl_out[i]*log(ice_WaterRing[1,i].D_l/D_tube_out))/(2*Modelica.Constants.pi*k_PCMl*(L_coil/nSeg))))^(-1);
        A[i]=A_PCMl_out[i];
        A_out[i]=A_PCMl_out[i];
        f[i]=0;
        AR[i]=0;
      else
        /*
          Constrained latent and sensible discharging(This phase goes since the liquid
          rings touch until the storage is discharged).
        */
        U_tot[i]=((A_PCMl_out[i]/(A_tube_in*h_HTF))+
                   ((A_PCMl_out[i]*log(D_tube_out/D_tube_in))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                     (A_PCMl_out[i]/(A_tube_out*h_PCMl)))^(-1);
        U_out[i]=(((A_PCMl_out[i]*log(D_tube_out/D_tube_mid))/(2*Modelica.Constants.pi*k_tube[i]*(L_coil/nSeg)))+
                   (A_PCMl_out[i]/(A_tube_out*h_PCMl)))^(-1);
        A[i]=A_PCMl_out[i];
        A_out[i]=A_PCMl_out[i];
        f[i]=0;
        AR[i]=0;
      end if;
    end if;
  end for;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents a latent storage where the Phase Change Material (PCM) is confined in a tank, and the Heat Transfer Fluid (HTF) flows through some pipes submerged in the PCM. During the charging process (considering the storage as a cold energy storaging system) the HTF cools the PCM, making the PCM changing its phase to solid (the process of solidification appears from the innermost part to the coil, forming a ring). During the discharge, the opposite process happens (the PCM melts starting from the closest part to the coil), the PCM is used to cool the HTF. This model considers ther are only heat losses from the PCM to the ambient as the Coils inside the storage are not in contact with the ambient.</p>
<p><code>Ice_WaterRing</code> model is used to represent the PCM.</p>
<p>This model allows to select the number of coils (<code>nCoils</code>).This model considers the coils are divided in <code>nSeg</code> segments each.</p>
<p>This model version of a latent storage operates correctly when the storage is charged completelly (until the established <code>Charge_Percentage</code> is reached) before the discharge starts, or it is completelly discharged before the charge. </p>
<h4>Equations</h4>
<p>As the amount of solid PCM changes the thermal conductance between the HTf and the PCM also changes depending on the diameter of ice. The theraml conductance has been divide in two: <code>G_HTFtoTube </code>(constant during all processes) and <code>G_TubetoPCM </code>(varie depending on the amount of solid PCM)<code>:</code></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-zNHQkv3W.png\" alt=\"G_HTFtoTube=A_in*U_in\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-x2lWyYrD.png\" alt=\"A_In=A_tubeMid
\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-R3cLk8CB.png\" alt=\"U_in=((A_tubeMid/(A_tubeIn*h_HTF))+((A_tubeMid*log(D_tubeMid/D_tubeIn))/(2*pi*k_tube*(L_coil/nSeg))))^(-1)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-PfXolRJn.png\" alt=\"A_tubeIn=pi*D_tubeIn*(L_coil/nSeg)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-BIvrXmNA.png\" alt=\"A_tubeMid=pi*D_tubeMid*(L_coil/nSeg)\"/></p>
<p><br><br><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-JhuJEIyE.png\" alt=\"G_TubetoPCM=A_out*U_out
\"/></p>
<ul>
<li>Sensible&nbsp;charging&nbsp;(No&nbsp;solid&nbsp;PCM&nbsp;is&nbsp;formed,&nbsp;the&nbsp;heat&nbsp;is&nbsp;taken&nbsp;from&nbsp;the&nbsp;liquid&nbsp;PCM).</li>
</ul>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-WbIKtPDi.png\" alt=\"U_out=(((A_tubeOut*log(D_tubeOut/D_tubeMid))/(2*pi*k_tube*(L_coil/nSeg)))+(1/h_PCMl))^(-1)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-6MmmN1AK.png\" alt=\"A_out=A_tubeOut\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-xbJxmeRR.png\" alt=\"A_tubeOut=pi*D_tubeOut*(L_coil/nSeg)
\"/></p>
<ul>
<li>Unconstrained&nbsp;latent&nbsp;charging&nbsp;(There&nbsp;is&nbsp;a&nbsp;ring&nbsp;of&nbsp;solid&nbsp;PCM&nbsp;which&nbsp;is&nbsp;growing;&nbsp;this&nbsp;phase&nbsp;finishes&nbsp;when&nbsp;two&nbsp;adjacent&nbsp;solid&nbsp;ring&nbsp;touch).</li>
</ul>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-4hgcOodR.png\" alt=\"U_out=(((A_PCMsOut*log(D_tubeOut/D_tubeMid))/(2*pi*k_tube*(L_coil/nSeg)))+((A_PCMsOut*log(D_s/D_tubeOut))/(2*pi*k_PCMs*(L_coil/nSeg)))+(1/h_PCMl))^(-1)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-6OrnV2ap.png\" alt=\"A_out=A_PCMsOut\"/></p>
<p><br><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-uk2rAzcT.png\" alt=\"A_PCMsOut=pi*D_s*(L_coil/nSeg)\"/></p>
<ul>
<li>Constrained&nbsp;latent&nbsp;charging&nbsp;(this&nbsp;phase&nbsp;starts&nbsp;when&nbsp;adjacent&nbsp;solid&nbsp;rings touch &nbsp;and &nbsp;ends &nbsp;when &nbsp;there &nbsp;is &nbsp;no &nbsp;water &nbsp;in &nbsp;the spaces between the ice rings).</li>
</ul>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-xTVBpR6R.png\" alt=\"U_out=(((A_PCMsOut*log(D_tubeOut/D_tubeMid))/(2*pi*k_tube*(L_coil/nSeg)))+((A_PCMsOut*log(D_crit/D_tubeOut))/(2*pi*k_PCMs*(L_coil/nSeg)*f))+(1/h_PCMl))^(-1)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-OHHnf1TJ.png\" alt=\"A_out=A_PCMsOut
\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-8KpY9m8q.png\" alt=\"A_PCMsOut=pi*D_s*(L_coil/nSeg)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-OGNaOgzN.png\" alt=\"f=-1.441*AR+2.455*sqrt(AR)+(D_tubeOut/D_crit)*(3.116*AR-3.158*sqrt(AR))\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-7iTqEmT3.png\" alt=\"AR=1-((4/pi)*acos(D_crit/D_s))\"/></p>
<ul>
<li>Unconstrained latent discharging (Growth of the liquid ring as the PCM melts; this phase goes from the formation of the liqid ring until adjacent rings touch).</li>
</ul>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-PwZnwzTD.png\" alt=\" U_out=((A_PCMlOut/(A_tubeIn*h_HTF))+ ((A_PCMlOut*log(D_tubeOut/D_tubeIn))/(2*pi*k_tube*(L_coil/nSeg)))+((A_PCMlOut*log(D_l/D_tubeOut))/(2*k_PCMl*(L_coil/nSeg))))^(-1)\"/></p>
<p><br><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-IxxboBTd.png\" alt=\"A_out=A_PCMlOut\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-Ty02Fy3B.png\" alt=\"A_PCMlOut=pi*Dl*(L_coil/nSeg)\"/></p>
<ul>
<li>Constrained&nbsp;latent&nbsp;and&nbsp;sensible&nbsp;discharging(This&nbsp;phase&nbsp;goes&nbsp;since&nbsp;the&nbsp;liquid rings&nbsp;touch&nbsp;until&nbsp;the&nbsp;storage&nbsp;is&nbsp;discharged).</li>
</ul>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-bf138pfW.png\" alt=\"U_out=(((A_PCMlOut*log(D_tubeOut/D_tubeMid))/(2*pi*k_tube*(L_coil/nSeg)))+(A_PCMlOut/(AtubeOut*h_PCMl)))^(-1)\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-tTlBC2DD.png\" alt=\"A_out=A_PCMlOut\"/></p>
<p><img src=\"modelica://Modelica_IK4_TEKNIKER/DCOL/Resources/Images/equations/equation-PGQU6A2C.png\" alt=\"A_PCMlOut=pi*D_l*(L_coil/nSeg)
\"/></p>
<p><br>Where:</p>
<ul>
<li>nSeg, Number of segments of each coil;</li>
<li>k<sub>tube</sub>, Thermal conductivity of the tube;</li>
<li>k<sub>PCM</sub>, Thermal conductivity of the liquid PCM;</li>
<li>k<sub>PCMs</sub>, Thermal conductivity of the solid PCM;</li>
<li>L<sub>coil</sub>, Length of each coil;</li>
<li>A<sub>in</sub>, Area heat transfer area from the HTF to the tube;</li>
<li>A<sub>out</sub>, Area of heat transfer from the tube to the liquid PCM;</li>
<li>A<sub>tubeIn</sub>, Area of the interior of the coil;</li>
<li>A<sub>tubeOut</sub> , Area of the exterior of the coil;</li>
<li>A<sub>tubeMid</sub>, Area of the middle of the coil;</li>
<li>A<sub>PCMsOut</sub>, Area of the exterior of the ice;</li>
<li>A<sub>PCMlout</sub>, Area of the exterior of the liquid PCM;</li>
<li>D<sub>tubeOut</sub>, Exterior diameter of the coil;</li>
<li>D<sub>tubeIn</sub>, Interior diameter of the coil;</li>
<li>D<sub>tubeMid</sub>, Diameter of the centre of the coil;</li>
<li>G<sub>HTFtoTube</sub>, Thermal conductance from the HTF to the tube;</li>
<li>G<sub>TubetoPCM</sub>, Thermal conductance from the tube to the liquid PCM; </li>
<li>U<sub>in</sub>, Heat transfer coeficient from the HTF to the tube;</li>
<li>U<sub>out</sub>, Heat transfer coeficient from the tube to the liquid PCM;</li>
<li>h_<sub>PCMl</sub>, Convection heat transfer coefficient of the liquid PCM.</li>
</ul>
<h4>Assuptions</h4>
<ul>
<li>The PCM considered is water;</li>
<li>The heat losses to the ambient are just from the PCMModel to the ambient; this heat losses are calculated as <code>Q=G_toAmbient2&middot;dT</code> where <code>G_toAmbient2</code> is the constant thermal conductance of the material in contact with the PCM, and dT is the difference between the ambient temperature and the PCM temperature;</li>
<li>The pressure drop of the HTF is not considered; </li>
<li>The mass flow of the HTF at the entrace and at the exit is the same;</li>
<li>The mass flow of the PCM remains the same;</li>
<li>The tubes are spaced on a square grid (horizontal and vertical distance between the different coils is the same).</li>
</ul>
<h4>References</h4>
<ul>
<li>K. Nithyanandam, R. Pitchumani; &QUOT;Numerical Analysis of Latent thermal energy storage system with embedded thermosyphons&QUOT; (July 23-26, 2012, San Diego, CA, USA); Proceedings of the ASME 2012 6th International Conference on Energy Sustainability, ES2012;</li>
<li>T.B. Jekel; &QUOT;Modeling of Ice-Storage systems&QUOT; (1991); A thesis submitted in partial fulfilnent of the requirements for the degree of MASTER OF -SCIENCE (Mechanical Engineering) at the UNIVERSITY OF WISCONSIN -- MADISON</li>
</ul>
</html>",
        revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end IceStorageInternalMeltnSegnCoils;
