within DCOL.ThermalStorage.LatentStorages.Interfaces;
model HTFtoPCM_nCoilpnCoinv

  extends DCOL.ThermalStorage.LatentStorages.Icons.HTFtoPCM;

  replaceable package Material =
    Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial  "Material in the component" annotation (choicesAllMatching = true);

  parameter Modelica.SIunits.Volume vol "Volume of element";
  parameter Integer nCoilp=10 "number of horizontally parallel coils";
  parameter Integer nCoilv=10 "number of horizontally parallel coils";

  parameter Modelica.SIunits.Temperature T_Tube_start=20+273.15 "Start temperature of the tube" annotation(Dialog(tab="Initialization"));

  PartialModels.ThermalConductorVariableThermalConductance HTFtoTube annotation (Placement(transformation(extent={{-60,-10},{-40,10}})));

  PartialModels.ThermalConductorVariableThermalConductance TubetoPCM annotation (Placement(transformation(extent={{40,-10},{60,10}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor TubeInertia(
    redeclare package Material = Material,
    T(start=T_Tube_start),
    V=vol) annotation (Placement(transformation(extent={{-10,0},{10,20}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation (
      Placement(transformation(extent={{-120,-10},{-100,10}}),
        iconTransformation(extent={{-120,-10},{-100,10}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a annotation (Placement(transformation(extent={{100,-10},
            {120,10}}), iconTransformation(extent={{100,-10},{120,10}})));

  Modelica.Blocks.Interfaces.RealInput G_HTFtoTube annotation (Placement(
        transformation(
        extent={{-20,-20},{20,20}},
        rotation=-90,
        origin={-50,100})));

  Modelica.Blocks.Interfaces.RealInput G_TubetoPCM annotation (Placement(
        transformation(
        extent={{-20,-20},{20,20}},
        rotation=-90,
        origin={50,100})));

equation
  G_TubetoPCM*nCoilp/nCoilv=TubetoPCM.G;
  G_HTFtoTube*nCoilp/nCoilv=HTFtoTube.G;

  connect(port_b, HTFtoTube.port_a) annotation (Line(points={{-110,0},{-110,0},{-60,0}}, color={191,0,0}));
  connect(HTFtoTube.port_b, TubeInertia.port) annotation (Line(points={{-40,0},{-20,0},{0,0}}, color={191,0,0}));
  connect(TubeInertia.port, TubetoPCM.port_a) annotation (Line(points={{0,0},{20,0},{40,0}}, color={191,0,0}));
  connect(TubetoPCM.port_b,port_a)  annotation (Line(points={{60,0},{110,0}},        color={191,0,0}));
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents the heat exchange between the Heat Transfer Fluid and the liquid Phase Change Material (PCM).</p>
<p>
<h4>Assumptions</h4>
</p>
<ul>
<li>A thermal capacitance is located at the center of the metallic coil;</li>
<li>The thermal conductance between the HTF and the centre of the tube is constant;</li>
<li>The thermal conductance between the centre of the tube and the liquid PCM varies as the diameter of ice changes during the charging or discharging processes.</li>
</ul>
</html>",
      revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end HTFtoPCM_nCoilpnCoinv;
