within DCOL.ThermalStorage.LatentStorages.Testing;
model OneDimSemiInf

  DCOL.ThermalStorage.LatentStorages.BaseClasses.IceLiquidVessel23 iceLiquidVessel(n_seg=n_seg) annotation (Placement(transformation(extent={{-30,-14},{30,16}})));
  Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow[n_seg]
    annotation (Placement(transformation(extent={{-68,-10},{-48,10}})));
  Modelica.Blocks.Sources.Trapezoid Qb_flow_trap[n_seg](
    each rising(displayUnit="min") = 300,
    each width(displayUnit="min") = 4200,
    each falling(displayUnit="min") = 300,
    each period(displayUnit="min") = 14400,
    each amplitude=-50e3/n_seg)
    annotation (Placement(transformation(extent={{-100,-10},{-80,10}})));
  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater,
    T=283.15) annotation (Placement(transformation(extent={{-40,40},{-20,60}})));
  Modelica.Blocks.Sources.Trapezoid m_flow_trap(
    period(displayUnit="min") = 14400,
    rising(displayUnit="min") = 300,
    width(displayUnit="min") = 4200,
    falling(displayUnit="min") = 300,
    startTime(displayUnit="min") = 6000,
    amplitude=10) annotation (Placement(transformation(extent={{-100,48},{-80,68}})));
  Modelica.Fluid.Sources.MassFlowSource_T boundary2(
    redeclare package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    T=283.15,
    nPorts=1) annotation (Placement(transformation(extent={{40,-40},{20,-20}})));
  Modelica.Blocks.Sources.Trapezoid m_flow_trap_b(
    amplitude=-m_flow_trap.amplitude,
    rising(displayUnit="min") = m_flow_trap.rising,
    width(displayUnit="min") = m_flow_trap.width,
    falling(displayUnit="min") = m_flow_trap.falling,
    period(displayUnit="min") = m_flow_trap.period,
    startTime(displayUnit="min") = m_flow_trap.startTime) annotation (Placement(transformation(extent={{94,-32},{74,-12}})));
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor(G=50)
    annotation (Placement(transformation(extent={{60,20},{40,40}})));
  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature fixedTemperature(T=293.15)
    annotation (Placement(transformation(extent={{90,20},{70,40}})));
  parameter Integer n_seg=10 "Number of segments forming each coil";
equation

  for i in 1:iceLiquidVessel.n_seg loop
  end for;

  connect(boundary.ports[1], iceLiquidVessel.port_l_a) annotation (Line(points={{-20,50},{0,50},
          {0,14.5}},                                                                                    color={0,127,255}));
  connect(m_flow_trap.y, boundary.m_flow_in) annotation (Line(points={{-79,58},{-40,58}}, color={0,0,127}));
  connect(iceLiquidVessel.port_l_b, boundary2.ports[1]) annotation (Line(points={{0,-12.5},{0,
          -30},{20,-30}},                                                                                   color={0,127,255}));
  connect(m_flow_trap_b.y, boundary2.m_flow_in) annotation (Line(points={{73,-22},{40,-22}}, color={0,0,127}));
  connect(thermalConductor.port_b, iceLiquidVessel.heatPort_amb) annotation (Line(points={{40,30},{19.5,30},{19.5,14.5}}, color={191,0,0}));
  connect(fixedTemperature.port, thermalConductor.port_a) annotation (Line(points={{70,30},{60,30}}, color={191,0,0}));

  connect(Qb_flow_trap.y, prescribedHeatFlow.Q_flow)
    annotation (Line(points={{-79,0},{-68,0}}, color={0,0,127}));
  connect(prescribedHeatFlow.port, iceLiquidVessel.heatPort)
    annotation (Line(points={{-48,0},{-32,0},{-32,7},{-15.3,7}}, color={191,0,0}));
end OneDimSemiInf;
