﻿within DCOL.ThermalStorage.LatentStoragesNEW.BaseClasses;
model IceLiquidVessel
  import SI = Modelica.SIunits;

  extends DCOL.ThermalStorage.LatentStoragesNEW.Icons.Ice_Water_segments;
  extends DCOL.ThermalStorage.LatentStoragesNEW.BaseClasses.PartialIceLiquidVessel(
    final d_l=Medium_l.d_const,
    final k_l=Medium_l.lambda_const,
    final cp_l=Medium_l.cp_const);
    replaceable package Medium_l =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid medium in the vessel" annotation (choicesAllMatching=true);

  Medium_l.BaseProperties medium_l;

  SI.InternalEnergy U_t "Storaged energy (this energy is referenced to the 
  temperatur of the water at the entrace";
  SI.InternalEnergy U_max "Storaged energy (this energy is referenced to the 
  temperatur of the water at the entrace";

  input SI.Temperature T_HTF "Temperature of the HTF at the entrace";
  input SI.Temperature T_w "Temperature of the water at the entrace";
  Real Energy_percentage "Percentage of energy storaged";

  Modelica.Fluid.Interfaces.FluidPort_a port_l_a(redeclare package Medium = Medium_l, m_flow(min=0))
  "Fluid port. LiBr to Generator"
    annotation (Placement(transformation(extent={{-10,80},{10,100}}),    iconTransformation(extent={{-10,80},
            {10,100}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_l_b(redeclare package Medium = Medium_l, m_flow(max=0))
  "Fluid port. LiBr from Generator"
    annotation (Placement(transformation(extent={{-10,-100},{10,-80}}),iconTransformation(extent={{-10,
            -100},{10,-80}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort[n_seg]
  "Heat port to the coil"
    annotation (Placement(transformation(extent={{-112,30},{-92,50}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort_amb
  "Heat port to the ambient"
    annotation (Placement(transformation(extent={{120,80},{140,100}})));

equation
  //Q_amb=1000;
  Q_flow_p = sum(heatPort.Q_flow);

  for i in 1:n_seg loop
    heatPort[i].T = T_ext;
  end for;

  Q_amb = heatPort_amb.Q_flow;
  heatPort_amb.T = T_l;

  medium_l.T = T_l;
  medium_l.p = 101325;

  //Definition of port variables
  port_l_a.p = medium_l.p;
  port_l_b.p = medium_l.p;

  port_l_a.h_outflow = medium_l.h;
  port_l_b.h_outflow = medium_l.h;

  port_l_a.Xi_outflow = medium_l.Xi;
  port_l_b.Xi_outflow = medium_l.Xi;

  Hb_flow = port_l_a.m_flow*actualStream(port_l_a.h_outflow) + port_l_b.m_flow*actualStream(port_l_b.h_outflow);
  m_flow_a = port_l_a.m_flow;
  m_flow_b = port_l_b.m_flow;
  port_l_a.m_flow*actualStream(port_l_a.Xi_outflow) = -port_l_b.m_flow*actualStream(port_l_b.Xi_outflow);

  //U_max and U_t calulation
  /*U_max is the maximum amount of enery storaged, considering that the maximum amount 
  of ice has been formed and the rest of liquid water is at 0ºC*/
  /*U_t is the amount of energy storaged at any moment (referenced to the temperature
  of the discharging water at the entrace*/
  U_max=m_s_max*cp_s*(Tfus-(T_HTF+Tfus)/2)+m_s_max*hfus+(m_l_m+m_s_max)*cp_l*(T_w-Tfus);
  U_t=m_s*cp_s*(Tfus-T_s)+m_s*hfus+(m_l+m_s)*cp_l*(T_w-T_l);
  Energy_percentage=U_t/U_max*100;

  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>Volume of constant size with three fluid ports and two medium models (liquid and vapour) at liquid-vapour equilibrium used to represent <b>the absorber or the generator of an absorption cycle</b>. The flow properties are computed from the upstream quantities, pressures are equal in all nodes. Heat transfer through a thermal port is possible, it equals zero if the port remains unconnected. Ideal heat transfer is assumed per default; the thermal port temperature is equal to the medium temperature. </p>
</html>", revisions="<html>
<p>2016-05-31 <a href=\"mailto:jesus.febres@tekniker.es\">Jes&uacute;s Febres</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end IceLiquidVessel;
