within DCOL.ThermalStorage.LatentStoragesNEW.FMI;
model ExternalLS_Dym

  import Modelica.Constants;
  import Modelica.Constants.pi;
  import SI = Modelica.SIunits;
  import DCOL;

  replaceable package Medium_r =
      Modelica.Media.Incompressible.Examples.Glycol47
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "HTF Medium in the component" annotation (choicesAllMatching = true);

  //Material of the tube
  replaceable package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.Copper constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coils" annotation (choicesAllMatching = true,Dialog(group="Properties of the coils"));

  parameter SI.ThermalConductivity k_s=2.16 "Thermal conductivity of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.ThermalConductivity k_l=0.556 "Thermal conductivity of the liquid water" annotation(Dialog(group="PCM properties"));
  parameter SI.Density d_s=916.7 "Density of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.Density d_l=999.8 "Density of the liquid water" annotation(Dialog(group="PCM properties"));
  parameter SI.SpecificHeatCapacity cp_s=2110 "Specific heat capacity of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.SpecificHeatCapacity cp_l=4184 "Specific heat capacity of the liquid water" annotation(Dialog(group="PCM properties"));
  parameter SI.DynamicViscosity mu = 1.79e-3 "Dynamic viscosity of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.Temperature Tfus=0.0+273.15 "Fusion temperature of the water" annotation(Dialog(group="PCM properties"));
  parameter SI.Temperature T0=273.15 "Reference temperature" annotation(Dialog(group="PCM properties"));
  parameter SI.SpecificEnthalpy hfus=333.55e3 "Phase change enthalpy" annotation(Dialog(group="PCM properties"));
  parameter SI.CoefficientOfHeatTransfer h_l=568.4 "Convection heat transfer coefficient of liquid water when static" annotation(Dialog(group="PCM properties"));

  parameter SI.Radius r_int=0.00535 "Inner radius of cylinder";
  parameter SI.Radius r_ext=0.00635 "Outer radius of cylinder";
  //parameter SI.Radius r0 = 0.02 "Radius of each coil" annotation(Dialog(group="Geometric properties"));
  parameter SI.Length L = 6 "Length of each colis" annotation(Dialog(group="Geometric properties"));
  //parameter SI.Area A_unit = 1;
  parameter SI.Area A0 = L*pi*r_ext^2 "External area of ecah coil" annotation(Dialog(group="Geometric properties"));
  parameter SI.Length S_T = 0.02 "Vertical separation between colis" annotation(Dialog(group="Geometric properties"));
  parameter SI.Length S_L = 0.03 "Horizontal separation between coils" annotation(Dialog(group="Geometric properties"));
  parameter Integer n_seg = 10 "Number of segments forming each coil" annotation(Dialog(group="Geometric properties"));
  parameter Integer n_step = 45 "Vertical number of coils" annotation(Dialog(group="Geometric properties"));
  parameter Integer n_L = 10 "Horizontal number of coils" annotation(Dialog(group="Geometric properties"));
  parameter Boolean in_line=true "Configutation of the tubes in the storage (true if In-line; flase if Staggered)" annotation(Dialog(group="Geometric properties"));

  parameter Real eps = 1e-10 annotation(Dialog(group="Adjust value"));

  //Initialization
   parameter SI.Temperature T_l_start = Tfus "Initial liquid water temperature" annotation (Dialog(tab="Initialization")); //0.0 + T0;
   parameter SI.Temperature T_s_start = 0.0 + T0 "Initial solid water temperature" annotation (Dialog(tab="Initialization"));
   parameter SI.MassFlowRate m_flow_start = 5 "Initial mass flow" annotation (Dialog(tab="Initialization"));
   parameter SI.Mass m_l_start = n_step*n_L*((S_T*S_L)-(pi*r_ext^2))*L*d_l "Initial mass of liquid water" annotation (Dialog(tab="Initialization"));
   parameter SI.Mass m_s_start = eps "Initial mass of solid water" annotation (Dialog(tab="Initialization"));

//   parameter SI.Temperature T_l_start = 0.0+273.15 "Initial liquid water temperature" annotation (Dialog(tab="Initialization")); //0.0 + T0;
//   parameter SI.Temperature T_s_start = 273.15 "Initial solid water temperature" annotation (Dialog(tab="Initialization"));
//   parameter SI.MassFlowRate m_flow_start = 5 "Initial mass flow" annotation (Dialog(tab="Initialization"));
//   parameter SI.Mass m_l_start = 1443.8025 "Initial mass of liquid water" annotation (Dialog(tab="Initialization"));
//   parameter SI.Mass m_s_start = 1e-10 "Initial mass of solid water" annotation (Dialog(tab="Initialization"));

  IceVessel iceLiquidVessel(
    redeclare package Medium_r = Medium_r,
    redeclare package Material = Material,
    k_s=k_s,
    k_l=k_l,
    d_s=d_s,
    d_l=d_l,
    cp_s=cp_s,
    cp_l=cp_l,
    mu=mu,
    Tfus=Tfus,
    T0=T0,
    hfus=hfus,
    h_l=h_l,
    r_int=r_int,
    r_ext=r_ext,
    L=L,
    A0=A0,
    S_T=S_T,
    S_L=S_L,
    n_seg=n_seg,
    n_L=n_L,
    in_line=in_line,
    eps=eps,
    T_l_start=T_l_start,
    T_s_start=T_s_start,
    m_flow_start=m_flow_start,
    m_l_start=m_l_start,
    m_s_start=m_s_start,
    n_step=n_step)
             annotation (Placement(transformation(extent={{-32,-20},
            {32,22}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_T_in=true,
    T=283.15) annotation (Placement(transformation(extent={{-40,30},{-20,50}})));
  Modelica.Fluid.Sources.MassFlowSource_T boundary2(
    redeclare package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    T=283.15,
    nPorts=1) annotation (Placement(transformation(extent={{30,-50},{10,-30}})));
  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature
    annotation (Placement(transformation(extent={{60,60},{40,80}})));

  Modelica.Fluid.Sources.MassFlowSource_T inlet_HTF(
    redeclare package Medium = Medium_r,
    nPorts=1,
    m_flow=30,
    use_T_in=true,
    use_m_flow_in=true,
    T=263.15)
    annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
  Modelica.Fluid.Sensors.Temperature inlet_HTF_temperature(
    redeclare package Medium = Medium_r)
    annotation (Placement(transformation(extent={{-52,8},{-32,28}})));
  Modelica.Fluid.Sensors.Temperature outlet_HTF_temperature(
    redeclare package Medium = Medium_r)
    annotation (Placement(transformation(extent={{28,18},{48,38}})));
  Modelica.Fluid.Sources.FixedBoundary outlet_HTF(
    redeclare package Medium = Medium_r,
     nPorts=1)
    annotation (Placement(transformation(extent={{60,-10},{40,10}})));
  Modelica.Fluid.Sensors.Temperature outlet_water_temperature(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-30,-40},{-10,-20}})));
  Modelica.Fluid.Sensors.Temperature inlet_water_temperature(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-20,40},{0,60}})));
  RealConectors.RealMassFlowInput water_m_flow_a
    annotation (Placement(transformation(extent={{-110,70},{-90,90}})));
  RealConectors.RealTemperatureInput water_T
    annotation (Placement(transformation(extent={{-110,30},{-90,50}})));
  RealConectors.RealMassFlowInput HTF_m_flow_a
    annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));
  RealConectors.RealTemperatureInput HTF_T
    annotation (Placement(transformation(extent={{-110,-50},{-90,-30}})));
  RealConectors.RealTemperatureInput Ambient_T
    annotation (Placement(transformation(extent={{-110,-90},{-90,-70}})));
  RealConectors.RealTemperatureOutput HTF_outlet_T
    annotation (Placement(transformation(extent={{100,70},{120,90}})));
  RealConectors.RealTemperatureOutput water_outlet_T
    annotation (Placement(transformation(extent={{100,30},{120,50}})));
  RealConectors.RealMassFractionOutput charge_percentage
    annotation (Placement(transformation(extent={{100,-10},{120,10}})));
  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-8,70},{12,90}})));
  DCOL.ThermalStorage.LatentStoragesNEW.FMI.RealConectors.RealInternalEnergy storaged_energy
    annotation (Placement(transformation(extent={{100,-50},{120,-30}})));
  DCOL.ThermalStorage.LatentStoragesNEW.FMI.RealConectors.RealMassFractionOutput energy_percentage
    annotation (Placement(transformation(extent={{100,-90},{120,-70}})));
  Modelica.Blocks.Math.Gain gain(k=-1)
    annotation (Placement(transformation(extent={{-60,-40},{-50,-30}})));
equation

  charge_percentage=iceLiquidVessel.Charge_percentage;
  storaged_energy=iceLiquidVessel.U_t;
  energy_percentage=iceLiquidVessel.Energy_percentage;

  for i in 1:iceLiquidVessel.n_seg loop
  end for;

  connect(boundary.ports[1], iceLiquidVessel.port_l_a) annotation (Line(points={{-20,40},{0,40},{0,13.25}},
                                                                                                        color={0,127,255}));
  connect(iceLiquidVessel.port_l_b, boundary2.ports[1]) annotation (Line(points={{0,-14.75},{0,-40},{10,-40}},
                                                                                                            color={0,127,255}));

  connect(iceLiquidVessel.port_b_Tambient, prescribedTemperature.port)
    annotation (Line(points={{22,13.25},{22,70},{40,70}}, color={191,0,0}));
  connect(iceLiquidVessel.por_HTF_b, outlet_HTF_temperature.port) annotation (
      Line(points={{30,-0.75},{37.125,-0.75},{37.125,18},{38,18}}, color={0,127,
          255}));
  connect(iceLiquidVessel.por_HTF_b, outlet_HTF.ports[1]) annotation (Line(
        points={{30,-0.75},{41.125,-0.75},{41.125,0},{40,0}}, color={0,127,255}));
  connect(inlet_HTF.ports[1], iceLiquidVessel.port_HTF_a) annotation (Line(
        points={{-50,0},{-48,-0.75},{-30,-0.75}},         color={0,127,255}));
  connect(iceLiquidVessel.port_HTF_a, inlet_HTF_temperature.port) annotation (
      Line(points={{-30,-0.75},{-42,-0.75},{-42,8}},                   color={0,
          127,255}));

  connect(outlet_water_temperature.port, iceLiquidVessel.port_l_b) annotation (
      Line(points={{-20,-40},{0,-40},{0,-14.75}}, color={0,127,255}));
  connect(inlet_water_temperature.port, iceLiquidVessel.port_l_a)
    annotation (Line(points={{-10,40},{0,40},{0,13.25}},color={0,127,255}));
  connect(water_m_flow_a, boundary.m_flow_in)
    annotation (Line(points={{-100,80},{-70,80},{-70,48},{-40,48}}, color={0,0,127}));
  connect(water_T, boundary.T_in)
    annotation (Line(points={{-100,40},{-72,40},{-72,44},{-42,44}}, color={0,0,127}));
  connect(HTF_m_flow_a, inlet_HTF.m_flow_in)
    annotation (Line(points={{-100,0},{-86,0},{-86,8},{-70,8}},   color={0,0,127}));
  connect(HTF_T, inlet_HTF.T_in)
    annotation (Line(points={{-100,-40},{-88,-40},{-88,4},{-72,4}}, color={0,0,127}));
  connect(Ambient_T, prescribedTemperature.T)
    annotation (Line(points={{-100,-80},{70,-80},{70,70},{62,70}}, color={0,0,127}));
  connect(outlet_HTF_temperature.T, HTF_outlet_T)
    annotation (Line(points={{45,28},{80,28},{80,80},{110,80}}, color={0,0,127}));
  connect(outlet_water_temperature.T, water_outlet_T) annotation (Line(points={{-13,-30},{6,-30},{6,-20},{90,
          -20},{90,40},{110,40}}, color={0,0,127}));
  connect(water_m_flow_a, gain.u) annotation (Line(points={{-100,80},{-80,80},{
          -80,-35},{-61,-35}}, color={0,0,127}));
  connect(gain.y, boundary2.m_flow_in) annotation (Line(points={{-49.5,-35},{
          -40,-35},{-40,-60},{40,-60},{40,-32},{30,-32}}, color={0,0,127}));
  annotation (experiment(
      StopTime=17000,
      Tolerance=1e-006,
      __Dymola_Algorithm="Cvode"));
end ExternalLS_Dym;
