within DCOL.ThermalStorage.LatentStoragesNEW;
model IceVessel
  import Modelica_IK4_TEKNIKER;
  extends Modelica_IK4_TEKNIKER.DCOL.ThermalStorage.LatentStoragesNEW.Icons.IceStorageExternalMelting;

  import Modelica.Constants;
  import Modelica.Constants.pi;
  import SI = Modelica.SIunits;
  import DCOL;
  outer Modelica.Fluid.System system "System wide properties";

  replaceable package Medium_l =
      Modelica.Media.Water.ConstantPropertyLiquidWater
  constrainedby Modelica.Media.Interfaces.PartialMedium
    "Water PCM medium in the component" annotation (choicesAllMatching = true);

  replaceable package Medium_r =
      Modelica.Media.Incompressible.Examples.Glycol47
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "HTF Medium in the component" annotation (choicesAllMatching = true);

  //Material of the tube
  replaceable package Material = Modelica_IK4_TEKNIKER.Thermal.Materials.Copper
    constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
    "Material of the coils" annotation (choicesAllMatching = true,Dialog(group="Properties of the coils"));

  parameter Boolean allowFlowReversal = system.allowFlowReversal
    "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)"  annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter SI.ThermalConductivity k_s=2.16 "Thermal conductivity of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.ThermalConductivity k_l=0.556 "Thermal conductivity of the liquid water" annotation(Dialog(group="PCM properties"));
  parameter SI.Density d_s=916.7 "Density of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.Density d_l=999.8 "Density of the liquid water" annotation(Dialog(group="PCM properties"));
  parameter SI.SpecificHeatCapacity cp_s=2110 "Specific heat capacity of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.SpecificHeatCapacity cp_l=4184 "Specific heat capacity of the liquid water" annotation(Dialog(group="PCM properties"));
  parameter SI.DynamicViscosity mu = 1.79e-3 "Dynamic viscosity of the solid water" annotation(Dialog(group="PCM properties"));
  parameter SI.Temperature Tfus=0.0+273.15 "Fusion temperature of the water" annotation(Dialog(group="PCM properties"));
  parameter SI.Temperature T0=273.15 "Reference temperature" annotation(Dialog(group="PCM properties"));
  parameter SI.SpecificEnthalpy hfus=333.55e3 "Phase change enthalpy" annotation(Dialog(group="PCM properties"));
  parameter SI.CoefficientOfHeatTransfer h_l=568.4 "Convection heat transfer coefficient of liquid water when static" annotation(Dialog(group="PCM properties"));

  parameter SI.Radius r_int=0.00535 "Inner radius of cylinder";
  parameter SI.Radius r_ext=0.00635 "Outer radius of cylinder";
  //parameter SI.Radius r0 = 0.02 "Radius of each coil" annotation(Dialog(group="Geometric properties"));
  parameter SI.Length L = 6 "Length of each colis" annotation(Dialog(group="Geometric properties"));
  //parameter SI.Area A_unit = 1;
  parameter SI.Area A0 = L*pi*r_ext^2 "External area of ecah coil" annotation(Dialog(group="Geometric properties"));
  parameter SI.Length S_T = 0.02 "Vertical separation between colis" annotation(Dialog(group="Geometric properties"));
  parameter SI.Length S_L = 0.03 "Horizontal separation between coils" annotation(Dialog(group="Geometric properties"));
  parameter Integer n_seg = 10 "Number of segments forming each coil" annotation(Dialog(group="Geometric properties"));
  parameter Integer n_step = 45 "Number of stepsof the refrigerant coils" annotation(Dialog(group="Geometric properties"));
  parameter Integer n_L = 10 "Horizontal number of coils" annotation(Dialog(group="Geometric properties"));
  parameter Boolean in_line=true "Configutation of the tubes in the storage (true if In-line; flase if Staggered)" annotation(Dialog(group="Geometric properties"));

protected
  parameter Integer n_T = n_step "Vertical number of coils" annotation(Dialog(group="Geometric properties"));

public
  parameter Real eps = 1e-10 annotation(Dialog(group="Adjust value"));

  //Initialization
  parameter SI.Temperature T_l_start = Tfus "Initial liquid water temperature" annotation (Dialog(tab="Initialization")); //0.0 + T0;
  parameter SI.Temperature T_s_start = 0.0 + T0 "Initial solid water temperature" annotation (Dialog(tab="Initialization"));
  parameter SI.MassFlowRate m_flow_start = 5 "Initial mass flow" annotation (Dialog(tab="Initialization"));
  parameter SI.Mass m_l_start = n_T*n_L*((S_T*S_L)-(pi*r_ext^2))*L*d_l "Initial mass of liquid water" annotation (Dialog(tab="Initialization"));
  parameter SI.Mass m_s_start = eps "Initial mass of solid water" annotation (Dialog(tab="Initialization"));

  Real Charge_percentage=iceLiquidVessel.Charge_percentage "Percentage of charge in the storage";
  SI.InternalEnergy U_t=iceLiquidVessel.U_t "Storaged energy (this energy is referenced to the temperatur of the water at the entrace";
  Real Energy_percentage=iceLiquidVessel.Energy_percentage "Percentage of energy storaged";

  Modelica.Fluid.Interfaces.FluidPort_a port_l_a(redeclare package Medium = Medium_l)
    "Entrace port of the water PCM" annotation (Placement(transformation(extent={{-10,60},{10,80}}),
        iconTransformation(extent={{-10,60},{10,80}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_l_b(redeclare package Medium = Medium_l)
    "Exit port of the water PCM" annotation (Placement(transformation(extent={{-10,-100},{10,-80}}),
        iconTransformation(extent={{-10,-100},{10,-80}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b_Tambient
    "Heat exchanged with the ambient" annotation (Placement(transformation(extent={{100,60},
            {120,80}})));

  Modelica.Fluid.Interfaces.FluidPort_a port_HTF_a(
    redeclare package Medium = Medium_r,
    m_flow(min=if allowFlowReversal then -Constants.inf else 0),
    h_outflow(start=Medium_r.h_default))
    "Fluid connector a (positive design flow direction is from port_In to port_Out)" annotation (Placement(transformation(extent={{-160,
            -20},{-140,0}}),
        iconTransformation(extent={{-160,-20},{-140,0}})));

  Modelica.Fluid.Interfaces.FluidPort_b por_HTF_b(
    redeclare package Medium = Medium_r,
    m_flow(max=if allowFlowReversal then +Constants.inf else 0),
    h_outflow(start=Medium_r.h_default))
    "Fluid connector b (positive design flow direction is from port_In to port_Out)" annotation (Placement(transformation(extent={{140,-20},
            {160,0}}),
        iconTransformation(extent={{140,-20},{160,0}})));

  Modelica.Fluid.Pipes.DynamicPipe pipe(
    redeclare package Medium = Medium_r,
    use_HeatTransfer=true,
    nNodes=n_seg,
    diameter=2*r_int,
    modelStructure=Modelica.Fluid.Types.ModelStructure.a_v_b,
    T_start=T_l_start,
    redeclare model FlowModel =
        Modelica.Fluid.Pipes.BaseClasses.FlowModels.NominalLaminarFlow (
          dp_nominal=100000, m_flow_nominal=3000),
    nParallel=n_L,
    length=L*n_step,
    redeclare model HeatTransfer =
        Modelica.Fluid.Pipes.BaseClasses.HeatTransfer.LocalPipeFlowHeatTransfer) annotation (Placement(transformation(extent={{-60,-60},{
            -40,-40}})));

  DCOL.ThermalStorage.LatentStoragesNEW.BaseClasses.IceLiquidVessel
    iceLiquidVessel(
    redeclare package Medium_l = Medium_l,
    T_HTF=inlet_HTF_temperature.T,
    T_w=inlet_water_temperature.T,
    k_s=k_s,
    d_s=d_s,
    cp_s=cp_s,
    mu=mu,
    Tfus=Tfus,
    T0=T0,
    hfus=hfus,
    h_l=h_l,
    L=L,
    A0=A0,
    S_T=S_T,
    S_L=S_L,
    n_seg=n_seg,
    n_T=n_T,
    n_L=n_L,
    in_line=in_line,
    T_l_start=T_l_start,
    T_s_start=T_s_start,
    m_flow_start=m_flow_start,
    m_l_start=m_l_start,
    m_s_start=m_s_start,
    eps=eps,
    r0=r_ext,
    r_int=r_int,
    r_ext=r_ext)
              annotation (Placement(transformation(extent={{-40,0},{40,40}})));

  DCOL.Distribution.Thermal_temp.HollowCylinder hollowCylinder(
    use_longitudinalDim=false,
    use_angularDim=false,
    redeclare package Material = Material,
    r_int=r_int,
    r_ext=r_ext,
    nLongitudinal=n_seg,
    nAngular=1,
    alpha=2*Modelica.Constants.pi,
    T_start=T_l_start,
    nRadial=2,
    modelStructure_radial=Modelica.Fluid.Types.ModelStructure.av_vb,
    modelStructure_angular=Modelica.Fluid.Types.ModelStructure.a_v_b,
    modelStructure_longitudinal=Modelica.Fluid.Types.ModelStructure.a_v_b,
    nParallel=n_L,
    length=L*n_step)                                                       annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={-50,-10})));

  Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor(G=100)
    annotation (Placement(transformation(extent={{60,40},{80,60}})));
  Modelica.Fluid.Sensors.Temperature inlet_water_temperature(redeclare package Medium =
        Medium_l)
    annotation (Placement(transformation(extent={{-40,60},{-20,80}})));
  Modelica.Fluid.Sensors.Temperature inlet_HTF_temperature(redeclare package Medium =
        Medium_r)
    annotation (Placement(transformation(extent={{-120,-40},{-100,-20}})));
equation

  for i in 1:n_seg loop
  end for;

  connect(port_HTF_a, pipe.port_a) annotation (Line(points={{-150,-10},{-150,
          -50},{-60,-50}},
                      color={0,127,255}));
  connect(pipe.port_b,por_HTF_b)  annotation (Line(points={{-40,-50},{150,-50},
          {150,-10}},                                                                    color={0,127,255}));
  connect(port_l_a, iceLiquidVessel.port_l_a) annotation (Line(points={{0,70},{0,38}}, color={0,127,255}));
  connect(iceLiquidVessel.port_l_b, port_l_b) annotation (Line(points={{0,2},{0,-90}}, color={0,127,255}));

  connect(iceLiquidVessel.heatPort_amb, thermalConductor.port_a)
    annotation (Line(points={{26,38},{26,50},{60,50}}, color={191,0,0}));
  connect(thermalConductor.port_b, port_b_Tambient)
    annotation (Line(points={{80,50},{110,50},{110,70}}, color={191,0,0}));
  connect(hollowCylinder.port_a_radial[1, :], iceLiquidVessel.heatPort)
    annotation (Line(points={{-50,0},{-50,28},{-20.4,28}}, color={191,0,0}));
  connect(hollowCylinder.port_b_radial[1, :], pipe.heatPorts) annotation (Line(
        points={{-50,-20},{-50,-32},{-50,-45.6},{-49.9,-45.6}}, color={191,0,0}));
  connect(inlet_HTF_temperature.port, port_HTF_a) annotation (Line(points={{-110,-40},{
          -110,-50},{-150,-50},{-150,-10}}, color={0,127,255}));
  connect(inlet_water_temperature.port, port_l_a)
    annotation (Line(points={{-30,60},{-30,54},{0,54},{0,70}},
                                                             color={0,127,255}));
       annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(coordinateSystem(
          preserveAspectRatio=false)));
end IceVessel;
