within DCOL.ThermalStorage.LatentStoragesNEW.Interfaces;
model StorageWall_external

  extends DCOL.ThermalStorage.LatentStoragesNEW.Icons.StorageWall;

  replaceable package Material =
    Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
      "Material of the storage wall" annotation (choicesAllMatching = true);

  parameter Integer nCoilv=10 "Number of vartically parallel Coils for the HTF";
  parameter Integer nCoilh=10 "Number of horizontally parallel Coils for the HTF";
  parameter Integer nSeg=10 "Number of segments of each coil";

  parameter Modelica.SIunits.Temperature T_Wall_start=20+273.15 "Start temperature of the storage walls" annotation(Dialog(tab="Initialization"));

  parameter Modelica.SIunits.Length h "Height of the storage";
  parameter Modelica.SIunits.Length w "Width of the storage";
  parameter Modelica.SIunits.Length l "Length of the storage";
  parameter Modelica.SIunits.Length e "Thicknes of the storages wall";

protected
  parameter Modelica.SIunits.Volume volTop=w*l*e "Volume of the top walls (horizontal)";
  parameter Modelica.SIunits.Volume volFront=h*l*e "Volume of the front walls (horizontal)";
  parameter Modelica.SIunits.Volume volSide=w*h*e "Volume of the side wall (vertical)";

public
  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor sideInertia[2](
    redeclare package Material = Material,
    each V=volSide,
    each T(start=T_Wall_start)) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-50,50})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor topInertia[2](
    redeclare package Material = Material,
    each V=volTop,
    each T(start=T_Wall_start)) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-10,54})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D sideCond2[2](
    redeclare package Material = Material,
    each A=h*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-70,60})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D sideCond1[2](
    redeclare package Material = Material,
    each A=h*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-30,30})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D topCond1[2](
    redeclare package Material = Material,
    each A=l*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={0,34})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D topCond2[2](
    redeclare package Material = Material,
    each A=l*w,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={0,74})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b T_PCM[nCoilv,nCoilh,nSeg]
    annotation (Placement(transformation(extent={{-10,0},{10,-20}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_ambient
    "Heat exchange in contact with the ambient temperature"
    annotation (Placement(transformation(extent={{94,82},{114,102}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.HeatCapacitors.HeatCapacitor frontInertia[2](
    redeclare package Material = Material,
    each V=volFront,
    each T(start=T_Wall_start)) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={50,30})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D frontCond1[2](
    redeclare package Material = Material,
    each A=h*l,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={30,20})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D frontCond2[2](
    redeclare package Material = Material,
    each A=h*l,
    each L=e/2) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=0,
        origin={70,20})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_floor
    "Heat exchange in contact with the ambient temperature"
    annotation (Placement(transformation(extent={{-10,-140},{10,-120}})));
equation

  for i in 1:2 loop
    connect(midTemperature.port_b, topCond1[i].port_b) annotation (Line(points={{0,19.8},
            {0,24}},                                                                                       color={191,0,0}));
    connect(topCond1[i].port_a, topInertia[i].port) annotation (Line(points={{0,44},{
            0,54}},                                                                          color={191,0,0}));
    connect(topInertia[i].port, topCond2[i].port_b) annotation (Line(points={{0,54},{
            -6.66134e-016,54},{-6.66134e-016,64}},                                                                          color={191,0,0}));

    connect(midTemperature.port_b, frontCond1[i].port_b) annotation (Line(points={{0,19.8},
            {0,19.8},{0,20},{20,20}},                                                                                                          color={191,0,0}));
    connect(frontCond1[i].port_a, frontInertia[i].port) annotation (Line(points={{40,20},
            {40,20},{50,20}},                                                                             color={191,0,0}));
    connect(frontInertia[i].port, frontCond2[i].port_b) annotation (Line(points={{50,20},
            {60,20}},                                                                                      color={191,0,0}));
    connect(frontCond2[i].port_a, port_a_ambient) annotation (Line(points={{80,
            20},{90,20},{90,92},{104,92}}, color={191,0,0}));

    connect(midTemperature.port_b, sideCond1[i].port_b) annotation (Line(points={{0,19.8},
            {0,19.8},{0,20},{-16,20},{-16,30},{-20,30}},                                                                             color={191,0,0}));
    connect(sideCond1[i].port_a, sideInertia[i].port) annotation (Line(points={{-40,30},
            {-40,40},{-50,40}},                                                                             color={191,0,0}));
    connect(sideInertia[i].port, sideCond2[i].port_b) annotation (Line(points={{-50,40},
            {-50,40},{-60,40},{-60,60}},                                                                             color={191,0,0}));
    connect(sideCond2[i].port_a, port_a_ambient) annotation (Line(points={{-80,
            60},{-88,60},{-88,92},{104,92}}, color={191,0,0}));
  end for;

  for i in 1:nCoilv loop
    for j in 1:nCoilh loop
      for k in 1:nSeg loop
        connect(midTemperature.port_a[i,j,k], T_PCM[i,j,k]) annotation (Line(points={{0,0.2},
              {0,-10}},                                                                           color={191,0,0}));
      end for;
    end for;
  end for;

  connect(topCond2[1].port_a, port_a_ambient)
    annotation (Line(points={{0,84},{0,92},{104,92}}, color={191,0,0}));
  connect(topCond2[2].port_a, port_a_floor) annotation (Line(points={{
          4.44089e-016,84},{0,84},{0,88},{-92,88},{-92,-40},{0,-40},{0,-130}},
        color={191,0,0}));

   annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(info="<html>
<p>This model represents storage walls (hollow box) and the heat exchanged between a fluid inside and the ambient.</p>
<p>Assumption</p>
<ul>
<li>The storage is closed (top wall is also considered);</li>
<li>The storage has rectangular shape;</li>
<li>Thermal storage of the walls is consideted.</li>
</ul>
</html>",
      revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end StorageWall_external;
