within DCOL.ThermalStorage.LatentStoragesNEW.Testing;
model Test_ExternalLS

  IceVessel iceLiquidVessel(
    n_seg=n_seg,
    r_ext(displayUnit="mm"),
    redeclare package Medium_r =
        Modelica.Media.Incompressible.Examples.Glycol47,
    r_int(displayUnit="mm"))
            annotation (Placement(transformation(extent={{-32,-20},
            {32,22}})));

  Modelica.Fluid.Sources.MassFlowSource_T boundary(
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    T=283.15) annotation (Placement(transformation(extent={{-40,40},{-20,60}})));
  Modelica.Blocks.Sources.Trapezoid m_flow_trap(
    period(displayUnit="min") = 14400,
    rising(displayUnit="min") = 300,
    width(displayUnit="min") = 4200,
    falling(displayUnit="min") = 300,
    amplitude=10,
    startTime(displayUnit="min") = 7800)
                  annotation (Placement(transformation(extent={{-100,70},{-80,
            90}})));
  Modelica.Fluid.Sources.MassFlowSource_T boundary2(
    redeclare package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater,
    use_m_flow_in=true,
    T=283.15,
    nPorts=1) annotation (Placement(transformation(extent={{38,-54},{18,-34}})));
  Modelica.Blocks.Sources.Trapezoid m_flow_trap_b(
    amplitude=-m_flow_trap.amplitude,
    rising(displayUnit="min") = m_flow_trap.rising,
    width(displayUnit="min") = m_flow_trap.width,
    falling(displayUnit="min") = m_flow_trap.falling,
    period(displayUnit="min") = m_flow_trap.period,
    startTime(displayUnit="min") = m_flow_trap.startTime) annotation (Placement(transformation(extent={{84,-46},
            {64,-26}})));
  Modelica.Thermal.HeatTransfer.Sources.FixedTemperature fixedTemperature(T=293.15)
    annotation (Placement(transformation(extent={{82,64},{62,84}})));
  parameter Integer n_seg=3 "Number of segments forming each coil";
  Modelica.Blocks.Sources.TimeTable timeTable(table=[0.0,-3 + 273.15; 100000,-3 + 273.15])
    annotation (Placement(transformation(extent={{-120,-28},{-100,-8}})));
  Modelica.Fluid.Sources.MassFlowSource_T inlet_HTF(
    nPorts=1,
    m_flow=30,
    use_T_in=true,
    use_m_flow_in=true,
    T=263.15,
    redeclare package Medium = Modelica.Media.Incompressible.Examples.Glycol47)
    annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
  Modelica.Fluid.Sensors.Temperature inlet_HTF_temperature(redeclare package Medium =
               Modelica.Media.Incompressible.Examples.Glycol47)
    annotation (Placement(transformation(extent={{-62,20},{-42,40}})));
  Modelica.Fluid.Sensors.Temperature outlet_HTF_temperature(redeclare package Medium =
               Modelica.Media.Incompressible.Examples.Glycol47)
    annotation (Placement(transformation(extent={{40,20},{60,40}})));
  Modelica.Fluid.Sources.FixedBoundary outlet_HTF(
                                     nPorts=1, redeclare package Medium =
        Modelica.Media.Incompressible.Examples.Glycol47)
    annotation (Placement(transformation(extent={{80,-10},{60,10}})));
  Modelica.Blocks.Sources.Trapezoid Qb_flow_trap(
    each rising(displayUnit="min") = 300,
    each falling(displayUnit="min") = 300,
    each period(displayUnit="min") = 14400,
    each width(displayUnit="min") = 6000,
    each amplitude=300)
    annotation (Placement(transformation(extent={{-120,10},{-100,30}})));
  Modelica.Fluid.Sensors.Temperature outlet_water_temperature(redeclare package Medium =
               Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-30,-40},{-10,-20}})));
  Modelica.Fluid.Sensors.Temperature inlet_water_temperature(redeclare package Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{2,40},{22,60}})));
equation

  for i in 1:iceLiquidVessel.n_seg loop
  end for;

  connect(boundary.ports[1], iceLiquidVessel.port_l_a) annotation (Line(points={{-20,50},
          {0,50},{0,13.25}},                                                                            color={0,127,255}));
  connect(m_flow_trap.y, boundary.m_flow_in) annotation (Line(points={{-79,80},
          {-60,80},{-60,58},{-40,58}},                                                    color={0,0,127}));
  connect(iceLiquidVessel.port_l_b, boundary2.ports[1]) annotation (Line(points={{0,
          -14.75},{0,-44},{18,-44}},                                                                        color={0,127,255}));
  connect(m_flow_trap_b.y, boundary2.m_flow_in) annotation (Line(points={{63,-36},
          {38,-36}},                                                                         color={0,0,127}));

  connect(iceLiquidVessel.port_b_Tambient, fixedTemperature.port)
    annotation (Line(points={{22,13.25},{22,74},{62,74}}, color={191,0,0}));
  connect(timeTable.y,inlet_HTF. T_in) annotation (Line(points={{-99,-18},{-90,
          -18},{-90,4},{-72,4}},color={0,0,127}));
  connect(iceLiquidVessel.por_HTF_b, outlet_HTF_temperature.port) annotation (
      Line(points={{30,-0.75},{37.125,-0.75},{37.125,20},{50,20}}, color={0,127,
          255}));
  connect(iceLiquidVessel.por_HTF_b, outlet_HTF.ports[1]) annotation (Line(
        points={{30,-0.75},{41.125,-0.75},{41.125,0},{60,0}}, color={0,127,255}));
  connect(inlet_HTF.ports[1], iceLiquidVessel.port_HTF_a) annotation (Line(
        points={{-50,0},{-48,-0.75},{-30,-0.75}},         color={0,127,255}));
  connect(iceLiquidVessel.port_HTF_a, inlet_HTF_temperature.port) annotation (
      Line(points={{-30,-0.75},{-36.125,-0.75},{-36.125,20},{-52,20}}, color={0,
          127,255}));

  connect(Qb_flow_trap.y, inlet_HTF.m_flow_in) annotation (Line(points={{-99,20},
          {-90,20},{-90,8},{-70,8}}, color={0,0,127}));
  connect(outlet_water_temperature.port, iceLiquidVessel.port_l_b) annotation (
      Line(points={{-20,-40},{0,-40},{0,-14.75}}, color={0,127,255}));
  connect(inlet_water_temperature.port, iceLiquidVessel.port_l_a)
    annotation (Line(points={{12,40},{0,40},{0,13.25}}, color={0,127,255}));
  annotation (experiment(
      StopTime=17000,
      Tolerance=1e-006,
      __Dymola_Algorithm="Cvode"));
end Test_ExternalLS;
