within DCOL.ThermalStorage.SensibleStorages.BaseClasses;
model Buoyancy
  "Model to add buoyancy if there is a temperature inversion in the tank"

  import DCOL;
  extends DCOL.ThermalStorage.SensibleStorages.Interfaces.Buoyancy;

equation
  for i in 1:nSeg-1 loop
    dT[i] =port_a_heat[i + 1].T - port_a_heat[i].T;
    Q_flow[i] = k*noEvent(smooth(1, if dT[i]>0 then dT[i]^2 else 0));
  end for;

  port_a_heat[1].Q_flow = -Q_flow[1];
  for i in 2:nSeg-1 loop
    port_a_heat[i].Q_flow = -Q_flow[i] + Q_flow[i - 1];
  end for;
  port_a_heat[nSeg].Q_flow = Q_flow[nSeg - 1];
  annotation (Documentation(info="<html>
<p>This model is the same as the <a href=\"modelica://Buildings.Fluid.Storage.BaseClasses.Buoyancy\">Buildings.Fluid.Storage.BaseClasses.Buoyancy</a> model from the Building Library. </p>
<p>This model outputs a heat flow rate that can be added to fluid volumes in order to emulate buoyancy during a temperature inversion. For simplicity, this model does not compute a buoyancy induced mass flow rate, but rather a heat flow that has the same magnitude as the enthalpy flow associated with the buoyancy induced mass flow rate. </p>
<h4>Copyright and license</h4>
<ul><li style=\"list-style-type:none\">
Licensed by The Regents of the University of California, through Lawrence Berkeley National Laboratory under the Modelica License 2 Copyright (c) 2009-2015, The Regents of the University of California, through Lawrence Berkeley National Laboratory.
</li>
<li style=\"list-style-type:none\"><i>
This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica license 2, see the license conditions (including the disclaimer of warranty) here or at <a href=\"http://www.modelica.org/modelica-legal-documents/ModelicaLicense2.html\">http://www.modelica.org/modelica-legal-documents/ModelicaLicense2.html</a>.
</i></li></ul>
</html>", revisions="<html>
<ul>
<li>
December 14, 2012 by Michael Wetter:<br/>
Renamed protected parameters for consistency with naming convention.
</li>
<li>
October 8, 2011 by Michael Wetter:<br/>
Added <code>noEvent(...)</code> to
<code>Q_flow[i] = k*smooth(1, if dT[i]>0 then dT[i]^2 else 0);</code>
since the equation returns the same value to the left and right of
<code>dT[i]>0</code>.
</li>
<li>
September 16, 2011 by Michael Wetter:<br/>
Changed the implementation from <code>Q_flow[i] = k*max(heatPort[i+1].T-heatPort[i].T, 0);</code> to
<code>Q_flow[i] = k*smooth(1, if dT[i]>0 then dT[i]^2 else 0);</code>.
The previous implementation was not differentiable. In modeling a solar system, this
change reduced the computing time by a factor of 20 during the time when the pumps
were almost switched off and colder temperature was fed from the collector to the tank.
</li>
<li>
October 28, 2008 by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),
Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
end Buoyancy;
