within DCOL.ThermalStorage.SensibleStorages.BaseClasses;
model ClosedCylindricalConstantVolume
  "Volume of fixed size, closed to the ambient, with inlet/outlet ports"
  import Modelica.Constants.pi;
  extends DCOL.ThermalStorage.SensibleStorages.Icons.CylindricalVolume;

  // Mass and energy balance, ports
  extends Modelica.Fluid.Vessels.BaseClasses.PartialLumpedVessel(
    final fluidVolume=V,
    final fluidLevel=h,
    final fluidLevel_max=h_max,
    vesselArea=pi*(d^2)/4,
    heatTransfer(surfaceAreas={pi*d*h + pi*(d^2)/4}));

  parameter Modelica.SIunits.Volume V=pi*d^2*h/4 "Volume" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Diameter d "diameter of the cylindrical tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h "Height of the cylindrical tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_max=10 "Maximun height occupied by the water" annotation(Dialog(group="Geometric data"));

equation
  Wb_flow = 0;
  for i in 1:nPorts loop
    vessel_ps_static[i] = medium.p;
  end for;

  annotation (defaultComponentName="volume",
    Icon(coordinateSystem(preserveAspectRatio=true,  extent={{-100,-100},{
          100,100}})),
  Documentation(info="<html>
<p>Ideally mixed volume of constant sized with nPort number of ports and one medium model. This model is based in the <a href=\"modelica://Modelica.Fluid.Vessels.ClosedVolume\">Modelica.Fluid.Vessels.ClosedVolume</a> model from the modelica Standard Library with the only difference that in this case the volume is cylindrical, V=pi*d^2*h/4; and heat tranfer area A=pi*d*h+pi*(d^2)/4.</p>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end ClosedCylindricalConstantVolume;
