within DCOL.ThermalStorage.SensibleStorages.BaseClasses;
model ClosedRectangularConstantVolume
  "Volume of fixed size, closed to the ambient, with inlet/outlet ports"
  import Modelica.Constants.pi;
  extends DCOL.ThermalStorage.SensibleStorages.Icons.RectangularVolume;

  // Mass and energy balance, ports
  extends Modelica.Fluid.Vessels.BaseClasses.PartialLumpedVessel(
    final fluidVolume=V,
    final fluidLevel=h,
    final fluidLevel_max=h_max,
    vesselArea=l*w,
    heatTransfer(surfaceAreas={2*l*h + 2*w*h + l*w}));

  parameter Modelica.SIunits.Volume V=l*h*w "Volume" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Length l "Length of the rectangular tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h "Height of the rectangular tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Length w "Width of the rectangular tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_max=10 "Maximun height occupied by the water" annotation(Dialog(group="Geometric data"));

equation
  Wb_flow = 0;
  for i in 1:nPorts loop
    vessel_ps_static[i] = medium.p;
  end for;

  annotation (defaultComponentName="volume",
    Icon(coordinateSystem(preserveAspectRatio=true,  extent={{-100,-100},{
          100,100}})),
  Documentation(info="<html>
<p>Ideally mixed volume of constant sized with nPort number of ports and one medium model. This model is the same as the <a href=\"modelica://Modelica.Fluid.Vessels.ClosedVolume\">Modelica.Fluid.Vessels.ClosedVolume</a> model from the modelica Standard Library with the only difference that in this case the volume is rectangular, V=l*h*w; and heat tranfer area A=2*l*h+2*w*h+l*w.</p>
</html>", revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end ClosedRectangularConstantVolume;
