within DCOL.ThermalStorage.SensibleStorages.FMI;
model Buffer_Dym
  replaceable package Medium =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Medium in the component" annotation (choicesAllMatching = true);

   replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
     constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
     "Material of the storage walls" annotation (choicesAllMatching=true);

  replaceable package Medium1 = Modelica.Media.Air.SimpleAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Medium arround the storage" annotation (choicesAllMatching = true);

  parameter Integer nSeg=4 "number of segments the volume is divided";
  //3 is the minimun number of segments in which the middle volume can be divided;
  parameter Modelica.SIunits.Diameter d=1.128379167 "diameter of the cylindrical tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_max=10 "Maximun height occupied by the water" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h=5 "height of the cylindrical tank" annotation(Dialog(group="Geometric data"));

  parameter Modelica.SIunits.Length eTank=0.03 "Thickness of insulation" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_portIn=7.5 "Height of the inlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Height h_portOut=0.5 "Height of the outlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Diameter d_Inlet=0.05 "Diameter of the inlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Diameter d_Outlet=0.05 "Diameter of the outlet port" annotation(Dialog(group="Ports data"));

  parameter Modelica.SIunits.Height h_heater=7.5 "Height of the heater" annotation(Dialog(tab="Assumptions", group="Heaters data",enable=useHeater));

  parameter Modelica.SIunits.Temperature T_start=283.15 "Default start value for temperatures" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.AbsolutePressure p_start=system.p_ambient "Default start value for pressures" annotation(Dialog(tab="Initialization"));

  parameter Modelica.SIunits.Time tau=1 "Time constant for mixing" annotation(Dialog(group="Bouyancy data"));

  ClosedCylindricalTank_NatConv closedCylindricalTank(
    redeclare package Medium = Medium,
    redeclare package Material = Material,
    redeclare package Medium1 = Medium1,
    faceUpBottom=true,
    nSeg=nSeg,
    d=d,
    h_max=h_max,
    h=h,
    eTank=eTank,
    h_portIn=h_portIn,
    h_portOut=h_portOut,
    d_Inlet=d_Inlet,
    d_Outlet=d_Outlet,
    T_start=T_start,
    p_start=p_start,
    tau=tau) annotation (Placement(transformation(extent={{24,-30},{84,30}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-40,60},{-20,80}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature ambientTemperature annotation (Placement(transformation(extent={{34,-90},{54,-70}})));

  Modelica.Fluid.Sources.Boundary_pT Retorno(
    redeclare package Medium = Medium,
    nPorts=1,
    use_p_in=false,
    use_T_in=true) annotation (Placement(transformation(extent={{-36,-40},{-16,-20}})));

  Modelica.Fluid.Sources.MassFlowSource_T Impulsion(
    redeclare package Medium = Medium,
    nPorts=1,
    use_m_flow_in=true,
    use_T_in=true) annotation (Placement(transformation(extent={{-16,20},{4,40}})));

  Modelica.Fluid.Sensors.Temperature T_Impulsion(
    redeclare package Medium = Medium) annotation (Placement(transformation(extent={{20,40},
            {40,60}})));

  Modelica.Fluid.Sensors.Temperature T_Retorno(
    redeclare package Medium = Medium) annotation (Placement(transformation(extent={{20,-60},
            {40,-40}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlowRate(
    redeclare package Medium = Medium) annotation (Placement(transformation(extent={{9,-35},{-1,-25}})));

  Modelica.Blocks.Discrete.TriggeredSampler triggeredSampler(
    y_start=7 + 273.15) annotation (Placement(transformation(extent={{-70,15},{-60,25}})));

  Modelica.Blocks.Discrete.TriggeredSampler triggeredSampler1(
    y_start=7 + 273.15) annotation (Placement(transformation(extent={{-70,-15},{-60,-25}})));

  Modelica.Blocks.Logical.Not not1 annotation (Placement(transformation(extent={{-46,-9},{-56,1}})));

  Modelica.Blocks.Sources.BooleanExpression booleanExpression(
    y=if massFlow < 0 then false else true) annotation (Placement(transformation(extent={{-16,-6},{-36,14}})));

  RealConectors.RealMassFlowInput massFlow "Inlet fluid mass flow" annotation (Placement(transformation(extent={{-140,60},{-100,100}})));

  RealConectors.RealTemperatureInput impulsion_T
    "Temperature of the fluid to the \"Impulsion\"" annotation (Placement(transformation(extent={{-140,10},{-100,50}})));

  RealConectors.RealTemperatureInput return_T
    "Temperature of the fluid to the \"Return\"" annotation (Placement(transformation(extent={{-140,-50},{-100,-10}})));

  RealConectors.RealTemperatureInput ambient_T "Ambient temperautre" annotation (Placement(transformation(extent={{-140,-100},{-100,-60}})));

  RealConectors.RealTemperatureOutput m_impulsion_T
    "Temperature of the fluid to the \"Impulsion\"" annotation (Placement(transformation(extent={{100,40},{120,60}})));

  RealConectors.RealTemperatureOutput m_return_T
    "Temperature of the fluid to the \"Return\"" annotation (Placement(transformation(extent={{100,-60},{120,-40}})));

  RealConectors.RealHeatFlowOutput heatLosses "Heat losses of the storage" annotation (Placement(transformation(extent={{100,-10},{120,10}})));

equation

  connect(closedCylindricalTank.port_a_Tambient, ambientTemperature.port) annotation (Line(points={{75.9231,
          0},{88,0},{88,-80},{54,-80}},                                                                                                   color={191,
          0,0}));
  connect(Impulsion.ports[1],closedCylindricalTank.port_a)  annotation (Line(
        points={{4,30},{14,30},{14,21},{28.6154,21}}, color={0,127,255}));
  connect(T_Retorno.port, closedCylindricalTank.port_b) annotation (Line(points={{30,-60},
          {14,-60},{14,-21},{28.6154,-21}},          color={0,127,255}));
  connect(T_Impulsion.port,closedCylindricalTank.port_a)  annotation (Line(
        points={{30,40},{14,40},{14,21},{28.6154,21}},color={0,127,255}));
  connect(closedCylindricalTank.port_b, massFlowRate.port_a) annotation (Line(
        points={{28.6154,-21},{28.6154,-21},{10,-21},{10,-30},{9,-30}}, color={
          0,127,255}));
  connect(massFlowRate.port_b, Retorno.ports[1]) annotation (Line(points={{-1,-30},
          {-1,-30},{-16,-30}},  color={0,127,255}));
  connect(triggeredSampler.y, Impulsion.T_in) annotation (Line(points={{-59.5,20},
          {-30,20},{-30,34},{-18,34}}, color={0,0,127}));
  connect(booleanExpression.y, triggeredSampler.trigger) annotation (Line(
        points={{-37,4},{-65,4},{-65,14.1}},    color={255,0,255}));
  connect(booleanExpression.y, not1.u) annotation (Line(points={{-37,4},{-40,4},
          {-40,-4},{-45,-4}},   color={255,0,255}));
  connect(not1.y, triggeredSampler1.trigger) annotation (Line(points={{-56.5,-4},
          {-65,-4},{-65,-14.1}},    color={255,0,255}));
  connect(triggeredSampler1.y, Retorno.T_in) annotation (Line(points={{-59.5,-20},
          {-50,-20},{-50,-26},{-38,-26}}, color={0,0,127}));
  connect(massFlow, Impulsion.m_flow_in) annotation (Line(points={{-120,80},{-68,
          80},{-68,38},{-16,38}}, color={0,0,127}));
  connect(impulsion_T, triggeredSampler.u) annotation (Line(points={{-120,30},{-96,
          30},{-96,20},{-71,20}}, color={0,0,127}));
  connect(return_T, triggeredSampler1.u) annotation (Line(points={{-120,-30},{-96,
          -30},{-96,-20},{-71,-20}}, color={0,0,127}));
  connect(ambient_T, ambientTemperature.T) annotation (Line(points={{-120,-80},{
          32,-80}},                                                                                color={0,0,127}));
  connect(T_Impulsion.T, m_impulsion_T) annotation (Line(points={{37,50},{37,50},
          {110,50}},         color={0,0,127}));
  connect(closedCylindricalTank.Ql_flow, heatLosses) annotation (Line(points={{77.5385,
          -12},{92,-12},{92,0},{110,0}}, color={0,0,127}));
  connect(T_Retorno.T, m_return_T) annotation (Line(points={{37,-50},{110,-50}}, color={0,0,127}));

   annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    experiment(StopTime=60000, __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>This model is used to test the model when the mass flow entering the storage is variable (temperature can also be variable).</p>
</html>",
      revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end Buffer_Dym;
