within DCOL.ThermalStorage.SensibleStorages.FMI;
model Buffer_Dym_temperature

  replaceable package Medium =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Medium in the component" annotation (choicesAllMatching = true);

   replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
     constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
     "Material of the storage walls" annotation (choicesAllMatching=true);

  replaceable package Medium1 = Modelica.Media.Air.SimpleAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Medium arround the storage" annotation (choicesAllMatching = true);

  parameter Integer nSeg=4 "number of segments the volume is divided";
  //3 is the minimun number of segments in which the middle volume can be divided;
  parameter Modelica.SIunits.Diameter d=1.128379167 "diameter of the cylindrical tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_max=10 "Maximun height occupied by the water" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h=5 "height of the cylindrical tank" annotation(Dialog(group="Geometric data"));

  parameter Modelica.SIunits.Length eTank=0.03 "Thickness of insulation" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_portIn=7.5 "Height of the inlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Height h_portOut=0.5 "Height of the outlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Diameter d_Inlet=0.05 "Diameter of the inlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Diameter d_Outlet=0.05 "Diameter of the outlet port" annotation(Dialog(group="Ports data"));

  parameter Modelica.SIunits.Height h_heater=7.5 "Height of the heater" annotation(Dialog(tab="Assumptions", group="Heaters data",enable=useHeater));

  parameter Modelica.SIunits.Temperature T_start=283.15 "Default start value for temperatures" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.AbsolutePressure p_start=system.p_ambient "Default start value for pressures" annotation(Dialog(tab="Initialization"));

  parameter Modelica.SIunits.Time tau=1 "Time constant for mixing" annotation(Dialog(group="Bouyancy data"));

  ClosedCylindricalTank_NatConv closedCylindricalTank(
    redeclare package Medium = Medium,
    redeclare package Material = Material,
    redeclare package Medium1 = Medium1,
    nSeg=nSeg,
    d=d,
    h_max=h_max,
    h=h,
    eTank=eTank,
    h_portIn=h_portIn,
    h_portOut=h_portOut,
    d_Inlet=d_Inlet,
    d_Outlet=d_Outlet,
    T_start=T_start,
    p_start=p_start,
    tau=tau,
    faceUpBottom=false)
    annotation (Placement(transformation(extent={{24,-30},{84,30}})));

  inner Modelica.Fluid.System system annotation (Placement(transformation(extent={{-40,60},{-20,80}})));

  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature ambientTemperature annotation (Placement(transformation(extent={{34,-90},{54,-70}})));

  Modelica.Fluid.Sources.FixedBoundary
                                     Retorno(
    nPorts=1, redeclare package Medium = Medium)
                   annotation (Placement(transformation(extent={{-36,-40},{-16,-20}})));

  Modelica.Fluid.Sources.MassFlowSource_T Impulsion(
    nPorts=1,
    use_m_flow_in=true,
    use_T_in=true,
    redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{-16,20},{4,40}})));
  Modelica.Fluid.Sensors.Temperature T_Impulsion(redeclare package Medium =
        Medium)                                                                  annotation (Placement(transformation(extent={{4,46},{24,66}})));

  Modelica.Fluid.Sensors.Temperature T_Retorno(redeclare package Medium =
        Medium)                                                                  annotation (Placement(transformation(extent={{14,-60},{34,-40}})));

  Modelica.Fluid.Sensors.MassFlowRate massFlowRate(redeclare package Medium =
        Medium)                                                                  annotation (Placement(transformation(extent={{9,-35},{-1,-25}})));

  RealConectors.RealMassFlowInput massFlow "Inlet fluid mass flow"
                                           annotation (Placement(transformation(extent={{-140,60},{-100,100}})));

  RealConectors.RealTemperatureInput impulsion_T
    "Temperature of the fluid to \"Impulsion\""  annotation (Placement(transformation(extent={{-140,10},{-100,50}})));

  RealConectors.RealTemperatureInput ambient_T "Ambient temperature"
                                               annotation (Placement(transformation(extent={{-140,-100},{-100,-60}})));

  RealConectors.RealTemperatureOutput m_impulsion_T annotation (Placement(transformation(extent={{100,40},{120,60}})));

  RealConectors.RealTemperatureOutput m_retorno_T annotation (Placement(transformation(extent={{100,-60},{120,-40}})));

  RealConectors.RealHeatFlowOutput heatLosses annotation (Placement(transformation(extent={{100,-10},{120,10}})));
equation

  connect(closedCylindricalTank.port_a_Tambient, ambientTemperature.port)
    annotation (Line(points={{75.9231,0},{88,0},{88,-80},{54,-80}}, color={191,
          0,0}));
  connect(Impulsion.ports[1],closedCylindricalTank.port_a)  annotation (Line(
        points={{4,30},{14,30},{14,21},{28.6154,21}}, color={0,127,255}));
  connect(T_Retorno.port, closedCylindricalTank.port_b) annotation (Line(points={{24,-60},
          {14,-60},{14,-21},{28.6154,-21}},          color={0,127,255}));
  connect(T_Impulsion.port,closedCylindricalTank.port_a)  annotation (Line(
        points={{14,46},{14,46},{14,21},{28.6154,21}},color={0,127,255}));
  connect(closedCylindricalTank.port_b, massFlowRate.port_a) annotation (Line(
        points={{28.6154,-21},{28.6154,-21},{10,-21},{10,-30},{9,-30}}, color={
          0,127,255}));
  connect(massFlowRate.port_b, Retorno.ports[1]) annotation (Line(points={{-1,-30},
          {-1,-30},{-16,-30}},  color={0,127,255}));
  connect(massFlow, Impulsion.m_flow_in) annotation (Line(points={{-120,80},{
          -70,80},{-70,38},{-16,38}},
                                  color={0,0,127}));
  connect(ambient_T, ambientTemperature.T) annotation (Line(points={{-120,-80},
          {32,-80}},                                                                               color={0,0,127}));
  connect(T_Impulsion.T, m_impulsion_T) annotation (Line(points={{21,56},{64,56},
          {64,50},{110,50}}, color={0,0,127}));
  connect(closedCylindricalTank.Ql_flow, heatLosses) annotation (Line(points={{77.5385,
          -12},{92,-12},{92,0},{110,0}}, color={0,0,127}));
  connect(T_Retorno.T, m_retorno_T) annotation (Line(points={{31,-50},{110,-50}},           color={0,0,127}));
  connect(impulsion_T, Impulsion.T_in) annotation (Line(points={{-120,30},{-70,
          30},{-70,34},{-18,34}}, color={0,0,127}));
   annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    experiment(StopTime=60000, __Dymola_Algorithm="Cvode"),
    Documentation(info="<html>
<p>In this case the fluid always flow from port_a to port_b, it cam be variable, but not negative. </p>
</html>",
      revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end Buffer_Dym_temperature;
