within DCOL.ThermalStorage.SensibleStorages.Interfaces;
partial model Buoyancy
  "Model to add buoyancy if there is a temperature inversion in the tank"

  import DCOL;
  extends DCOL.ThermalStorage.SensibleStorages.Icons.Buoyancy;

  replaceable package Medium =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialSimpleMedium
    "Water Medium in the component" annotation (choicesAllMatching = true,
      Documentation(info="<html>
<p>Copyright and license</p>
<p>Copyright (c) 2012-2015, The Regents of the University of California, Department of Energy contract-operators of the Lawrence Berkeley National Laboratory. All rights reserved.</p>
<p>1. Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:</p>
<p>(1) Redistributions of source code must retain the copyright notice, this list of conditions and the following disclaimer.</p>
<p>(2) Redistributions in binary form must reproduce the copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.</p>
<p>(3) Neither the name of the University of California, Lawrence Berkeley National Laboratory, U.S. Dept. of Energy nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.</p>
<p>2. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &ldquo;AS IS&rdquo; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.</p>
<p>3. You are under no obligation whatsoever to provide any bug fixes, patches, or upgrades to the features, functionality or performance of the source code (&ldquo;Enhancements&rdquo;) to anyone; however, if you choose to make your Enhancements available either publicly, or directly to Lawrence Berkeley National Laboratory, without imposing a separate written license agreement for such Enhancements, then you hereby grant the following license: a non-exclusive, royalty-free perpetual license to install, use, modify, prepare derivative works, incorporate into other computer software, distribute, and sublicense such enhancements or derivative works thereof, in binary and source code form.</p>
<p>NOTE: This license corresponds to the &ldquo;revised BSD&rdquo; or &ldquo;3-clause BSD&rdquo; license and includes the following modification: Paragraph 3. has been added by the University of California.</p>
</html>"));

  parameter Modelica.SIunits.Volume V "Volume";
  parameter Integer nSeg(min=2) = 2 "Number of volume segments";
  parameter Modelica.SIunits.Time tau(min=0) "Time constant for mixing";

  parameter Medium.ThermodynamicState sta_default = Medium.setState_pTX(T=Medium.T_default,
        p=Medium.p_default, X=Medium.X_default[1:Medium.nXi]) "Medium state at default properties";
  parameter Modelica.SIunits.Density rho_default=Medium.density(sta_default) "Density, used to compute fluid mass";
  parameter Modelica.SIunits.SpecificHeatCapacity cp_default=Medium.specificHeatCapacityCp(sta_default) "Specific heat capacity";
  parameter Real k(unit="W/K") = V*rho_default*cp_default/tau/nSeg "Proportionality constant, since we use dT instead of dH";

  Modelica.SIunits.TemperatureDifference dT[nSeg-1] "Temperature difference between adjoining volumes";

  Modelica.SIunits.HeatFlowRate[nSeg-1] Q_flow "Heat flow rate from segment i+1 to i";

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a[nSeg] port_a_heat
    "Heat input into the volumes"
    annotation (Placement(transformation(extent={{90,-10},{110,10}})));

annotation (Documentation(info="<html>
<p>Partial model with the interfaces of the Boyancy model.</p>
<h4>Copyright and license</h4>
<ul><li style=\"list-style-type:none\">
Licensed by The Regents of the University of California, through Lawrence Berkeley National Laboratory under the Modelica License 2 Copyright (c) 2009-2015, The Regents of the University of California, through Lawrence Berkeley National Laboratory.
</li>
<li style=\"list-style-type:none\"><i>
This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica license 2, see the license conditions (including the disclaimer of warranty) here or at <a href=\"http://www.modelica.org/modelica-legal-documents/ModelicaLicense2.html\">http://www.modelica.org/modelica-legal-documents/ModelicaLicense2.html</a>.
</i></li></ul>
</html>", revisions="<html>
<ul>
<li>
December 14, 2012 by Michael Wetter:<br/>
Renamed protected parameters for consistency with naming convention.
</li>
<li>
October 8, 2011 by Michael Wetter:<br/>
Added <code>noEvent(...)</code> to
<code>Q_flow[i] = k*smooth(1, if dT[i]>0 then dT[i]^2 else 0);</code>
since the equation returns the same value to the left and right of
<code>dT[i]>0</code>.
</li>
<li>
September 16, 2011 by Michael Wetter:<br/>
Changed the implementation from <code>Q_flow[i] = k*max(heatPort[i+1].T-heatPort[i].T, 0);</code> to
<code>Q_flow[i] = k*smooth(1, if dT[i]>0 then dT[i]^2 else 0);</code>.
The previous implementation was not differentiable. In modeling a solar system, this
change reduced the computing time by a factor of 20 during the time when the pumps
were almost switched off and colder temperature was fed from the collector to the tank.
</li>
<li>
October 28, 2008 by Michael Wetter:<br/>
First implementation.
</li>
</ul>
</html>"),
Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}})));
end Buoyancy;
