within DCOL.ThermalStorage.SensibleStorages.Interfaces;
partial model PartialClosedCylindricalTank_NatConv
  import DCOL;
  extends DCOL.ThermalStorage.SensibleStorages.Icons.ClosedCylindricalTank;

  replaceable package Medium =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Medium in the component" annotation (choicesAllMatching = true);

   replaceable package Material =
      Modelica_IK4_TEKNIKER.Thermal.Materials.AISI321
     constrainedby Modelica_IK4_TEKNIKER.Thermal.Materials.BaseClases.PartialMaterial
     "Material of the storage walls" annotation (choicesAllMatching=true);

  replaceable package Medium1 = Modelica.Media.Air.SimpleAir
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Medium arround the storage" annotation (choicesAllMatching = true);

  outer Modelica.Fluid.System system(p_start=p_start, T_start=T_start);

  parameter Boolean allowFlowReversal=true
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);
  parameter Boolean homotopyInitialization=true
    "true for allowing the reversal flow" annotation(Dialog(tab="Assumptions"), Evaluate=true);

  parameter Boolean useHeater = false "Inlet port at the top of the tank" annotation (Dialog(tab="Assumptions", group="Heaters data"));

  parameter Integer nSeg=4 "number of segments the volume is divided";
  //3 is the minimun number of segments in which the middle volume can be divided;
  parameter Modelica.SIunits.Diameter d=1.128379167 "diameter of the cylindrical tank" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_max=10 "Maximun height occupied by the water" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h=5 "height of the cylindrical tank" annotation(Dialog(group="Geometric data"));

protected
  Modelica.SIunits.Height h_seg "height of each cylindrical tank segment";
  Modelica.SIunits.Volume Vinstant[nSeg] "Instant volume on each secment";
  Modelica.SIunits.Volume VIn[nSeg] "Inlet volume rate on each secment";
  Modelica.SIunits.Volume VOut[nSeg] "Outlet volume rate on each secment";

public
  parameter Modelica.SIunits.Length eTank=0.03 "Thickness of insulation" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Height h_portIn=7.5 "Height of the inlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Height h_portOut=0.5 "Height of the outlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Diameter d_Inlet=0.05 "Diameter of the inlet port" annotation(Dialog(group="Ports data"));
  parameter Modelica.SIunits.Diameter d_Outlet=0.05 "Diameter of the outlet port" annotation(Dialog(group="Ports data"));

  parameter Modelica.SIunits.Height h_heater=7.5 "Height of the heater" annotation(Dialog(tab="Assumptions", group="Heaters data",enable=useHeater));

protected
  Medium.ThermodynamicState sta_defaultIn[nSeg] "Medium state at default properties";
  Modelica.SIunits.Density rhoIn[nSeg] "Density, used to compute fluid mass";
  Medium.ThermodynamicState sta_defaultOut[nSeg] "Medium state at default properties";
  Modelica.SIunits.Density rhoOut[nSeg] "Density, used to compute fluid mass";

  Modelica.SIunits.ThermalConductance GFluid[nSeg-1] "Constant thermal conductance of material";

public
  parameter Modelica.SIunits.Temperature T_start=283.15 "Default start value for temperatures" annotation(Dialog(tab="Initialization"));
  parameter Modelica.SIunits.AbsolutePressure p_start=system.p_ambient "Default start value for pressures" annotation(Dialog(tab="Initialization"));

  parameter Modelica.SIunits.Time tau=1 "Time constant for mixing" annotation(Dialog(group="Bouyancy data"));

  parameter Boolean faceUpTop=true "True when the top of the storage is facing up" annotation(Dialog(group="Heat Transfer through convection"));
  parameter Boolean faceUpBottom=false "True when the bottom of the storage is facing up" annotation(Dialog(group="Heat Transfer through convection"));
  parameter Modelica.SIunits.Length D=d "External diameter of the clinder" annotation(Dialog(group="Heat Transfer through convection"));

protected
  parameter Modelica.SIunits.Volume initialV=(h*Modelica.Constants.pi*(d/2)^2) "Initial total volume" annotation(Dialog(tab="Initialization"));

  parameter Modelica.SIunits.Volume V=(h*Modelica.Constants.pi*(d/2)^2) "Total volume" annotation(Dialog(group="Geometric data"));
  parameter Modelica.SIunits.Volume V_seg=(Modelica.Constants.pi*d^2*h/4)/nSeg "Volume of each segment" annotation(Dialog(group="Geometric data"));

  parameter Modelica.SIunits.Area A=(Modelica.Constants.pi*(d/2)^2) "Convection area of the top and bottom surfaces of the tank" annotation(Dialog(group="Convection data"));
  parameter Modelica.SIunits.Area AMiddle=(Modelica.Constants.pi*d*h/nSeg)  "Convection area of the middle surfaces of the tank" annotation(Dialog(group="Convection data"));
  parameter Modelica.SIunits.Length B=Modelica.Constants.pi*d "Perimeter of the top and bottom walls" annotation(Dialog(group="Convection data"));
  parameter Modelica.SIunits.Length L=d/4 "Characteristic length, surface of the plate/perimeter" annotation(Dialog(group="Convection data"));
  parameter Modelica.SIunits.Length H=h/nSeg "Height of the cylinder" annotation(Dialog(group="Convection data"));

  parameter Integer InletPortConnect=integer(h_portIn/(h/nSeg));
  parameter Integer OutletPortConnect=integer(h_portOut/(h/nSeg));
  parameter Integer HeaterConnect=integer(h_heater/(h/nSeg));

public
  Modelica.Fluid.Interfaces.FluidPort_a port_a(
  redeclare package Medium = Medium,
  m_flow(min=if allowFlowReversal then -Modelica.Constants.inf else 0),
  h_outflow(start=Medium.h_default)) "Entrace port of the fluid"
                                     annotation (Placement(transformation(
        extent={{-110,60},{-90,80}}), iconTransformation(extent={{-110,60},{-90,
          80}})));

  Modelica.Fluid.Interfaces.FluidPort_b port_b(
    redeclare package Medium = Medium,
    m_flow(max=if allowFlowReversal then +Modelica.Constants.inf else 0),
    h_outflow(start=Medium.h_default)) "Exit port of the fluid"
    annotation (Placement(transformation(extent={{-90,-80},{-110,-60}})));

  DCOL.ThermalStorage.SensibleStorages.BaseClasses.ClosedCylindricalConstantVolume volumeTop(
    redeclare package Medium = Medium,
    use_HeatTransfer=true,
    use_portsData=false,
    d=d,
    V=V_seg,
    h=h/nSeg,
    nPorts=3,
    portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d_Inlet, height=h/nSeg),Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d_Outlet, height=h/nSeg),Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(
        diameter=d)},
    p_start=p_start,
    T_start=T_start,
    h_max=h_max/nSeg) annotation (Placement(transformation(extent={{-28,60},{-8,80}})));

  DCOL.ThermalStorage.SensibleStorages.BaseClasses.ClosedCylindricalConstantVolume volumeMiddle[nSeg - 2](
    redeclare package Medium = Medium,
    each use_HeatTransfer=true,
    each use_portsData=false,
    each nPorts=4,
    each d=d,
    each V=V_seg,
    each h=h/nSeg,
    each portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d_Inlet, height=h_portIn - InletPortConnect*h/nSeg),Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d, height=h/nSeg),
        Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d),Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d_Outlet, height=h_portOut - OutletPortConnect*h/nSeg)},
    each p_start=p_start,
    each T_start=T_start,
    each h_max=h_max/nSeg) annotation (Placement(transformation(extent={{-28,-10},{-8,10}})));

  DCOL.ThermalStorage.SensibleStorages.BaseClasses.ClosedCylindricalConstantVolume volumeBottom(
    redeclare package Medium = Medium,
    use_HeatTransfer=true,
    use_portsData=false,
    d=d,
    V=V_seg,
    h=h/nSeg,
    nPorts=3,
    portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d_Inlet),Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d_Outlet),Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=d, height=h/nSeg)},
    p_start=p_start,
    T_start=T_start,
    h_max=h_max/nSeg) annotation (Placement(transformation(extent={{-28,-80},{-8,-60}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D topCond(
    redeclare package Material = Material,
    A=(Modelica.Constants.pi*(d/2)^2),
    L=eTank) annotation (Placement(transformation(extent={{14,64},{26,76}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D middleCond[nSeg](
    redeclare package Material = Material,
    each A=(Modelica.Constants.pi*d*(h/nSeg)),
    each L=eTank) annotation (Placement(transformation(extent={{14,-6},{26,6}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Conduction.PlaneWall_1D bottomCond(
    redeclare package Material = Material,
    A=(Modelica.Constants.pi*(d/2)^2),
    L=eTank) annotation (Placement(transformation(extent={{14,-76},{26,-64}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Plate.NaturalConvectionHorizontalPlate topConv(
    redeclare package Medium = Medium1,
    A=A,
    faceUp=faceUpTop,
    B=B,
    P=system.p_ambient) annotation (Placement(transformation(extent={{44,64},{56,76}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Cylinder.NaturalConvectionVerticalCylinder middleConv[nSeg](
    each H=H,
    each A=AMiddle,
    each D=D) annotation (Placement(transformation(extent={{44,-6},{56,6}})));

  Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Plate.NaturalConvectionVerticalPlate bottomConv(A=A, L=L) annotation (Placement(transformation(extent={{44,-76},{56,-64}})));

  DCOL.ThermalStorage.SensibleStorages.BaseClasses.ThermalConductorVariableConductance                                                      condFluid[nSeg - 1](
    G=GFluid) annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=180,
        origin={-80,-30})));

  Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowTop "Heat flow at top of tank (outside insulation)" annotation (Placement(transformation(extent={{74,64},
            {86,76}})));

  Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowMiddle[nSeg] "Heat flow at top of tank (outside insulation)" annotation (Placement(transformation(extent={{74,-6},
            {86,6}})));

  Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowBottom "Heat flow at top of tank (outside insulation)" annotation (Placement(transformation(extent={{74,-76},
            {86,-64}})));

  Modelica.Blocks.Interfaces.RealOutput Ql_flow "Heat loss of tank (positive if heat flows from tank to ambient)" annotation (Placement(transformation(extent={{102,-50},
            {122,-30}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_Tambient
    "Heat exchanged with the ambient"
    annotation (Placement(transformation(extent={{95,-10},{115,10}})));

  DCOL.ThermalStorage.SensibleStorages.BaseClasses.Buoyancy buoyancy(
    redeclare package Medium = Medium,
    V=V,
    nSeg=nSeg,
    tau=tau) annotation (Placement(transformation(extent={{-90,30},{-70,50}})));

  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_a_heater if
                                                                useHeater
    "Heat exchanged through a heater (can be activated or desactivated)"
    annotation (Placement(transformation(extent={{95,30},{115,50}})));

protected
  Modelica.Blocks.Routing.Multiplex3 mul(
    n1=1,
    n3=1,
    n2=nSeg) "Multiplex to collect heat flow rates" annotation (Placement(transformation(extent={{44,-45},
            {52,-35}})));

  Modelica.Blocks.Math.Sum sum(nin=nSeg + 2) annotation (Placement(transformation(extent={{68,-47},{80,-33}})));

equation

  //Connection of the inlet port
  if InletPortConnect>nSeg-2 then
    connect(port_a, volumeTop.ports[1]) annotation (Line(points={{-100,70},{-60,
            70},{-60,60},{-20.6667,60}},                                                                    color={0,127,255}));
  elseif InletPortConnect<1 then
    connect(port_a, volumeBottom.ports[1]) annotation (Line(points={{-100,70},{
            -60,70},{-60,-80},{-20.6667,-80}},                                                                   color={0,127,255}));
  else
    connect(port_a, volumeMiddle[InletPortConnect].ports[1]) annotation (Line(points={{-100,70},{-60,70},{-60,-10},{-21,-10}}, color={0,127,255}));
  end if;

  //Connection of the outlet port
  if OutletPortConnect<=1 then
    connect(port_b, volumeBottom.ports[2]) annotation (Line(points={{-100,-70},
            {-60,-70},{-60,-80},{-18,-80}}, color={0,127,255}));
  elseif OutletPortConnect>nSeg-2 then
    connect(port_b, volumeTop.ports[2]) annotation (Line(points={{-100,-70},{-60,
            -70},{-60,60},{-18,60}}, color={0,127,255}));
  else
    connect(port_b, volumeMiddle[OutletPortConnect].ports[4]) annotation (Line(
          points={{-100,-70},{-100,-70},{-60,-70},{-60,-10},{-15,-10}}, color={
            0,127,255}));
  end if;

  //Connection between the ports of the middle volumes
  for i in 2:nSeg-2 loop
    connect(volumeMiddle[i].ports[3],volumeMiddle[i-1].ports[2]);
  end for;

  //Heat conections
  for i in 1:nSeg loop
    connect(middleCond[i].port_b, middleConv[i].solid) annotation (Line(points={{26,0},{
            26,0},{44,0}},                                                                                color={191,0,0}));
    connect(middleConv[i].fluid, heatFlowMiddle[i].port_a) annotation (Line(points={{56,0},{
            56,0},{74,0}},                                                                                    color={191,0,0}));
    connect(heatFlowMiddle[i].Q_flow, mul.u2[i]) annotation (Line(points={{80,-6},
            {80,-6},{80,-12},{2,-12},{2,-40},{43.2,-40}},
                               color={0,0,127}));
    connect(heatFlowMiddle[i].port_b, port_a_Tambient)
      annotation (Line(points={{86,0},{86,0},{105,0}}, color={191,0,0}));
  end for;

  //Connection of the heater
  if HeaterConnect>nSeg-2 then
    connect(port_a_heater, volumeTop.heatPort) annotation (Line(points={{105,40},
            {-50,40},{-50,70},{-28,70}}, color={191,0,0}));
  elseif HeaterConnect<1 then
    connect(port_a_heater, volumeBottom.heatPort) annotation (Line(points={{105,
            40},{-40,40},{-40,-70},{-28,-70}}, color={191,0,0}));
  else
    connect(port_a_heater, volumeMiddle[HeaterConnect].heatPort) annotation (
        Line(points={{105,40},{-45,40},{-45,0},{-28,0}}, color={191,0,0}));
  end if;

  for i in 1:nSeg-2 loop
    connect(volumeMiddle[i].heatPort, condFluid[i+1].port_a) annotation (Line(points={{-28,0},
            {-28,0},{-100,0},{-100,-30},{-90,-30}},                                                                                   color={191,0,0}));
    connect(volumeMiddle[i].heatPort, condFluid[i].port_b) annotation (Line(points={{-28,0},
            {-45,0},{-45,-30},{-70,-30}},                                                                                 color={191,0,0}));
    connect(volumeMiddle[i].heatPort, buoyancy.port_a_heat[i + 1]) annotation (
        Line(points={{-28,0},{-45,0},{-45,40},{-70,40}}, color={191,0,0}));
    connect(volumeMiddle[i].heatPort, middleCond[i+1].port_a) annotation (Line(points={{-28,0},{-34,0},{-34,26},{10,26},{10,0},{14,0}}, color={191,0,0}));
  end for;

  connect(topCond.port_b, topConv.solid) annotation (Line(points={{26,70},{26,70},
          {44,70}},                                                                         color={191,0,0}));
  connect(bottomCond.port_b, bottomConv.solid) annotation (Line(points={{26,-70},
          {26,-70},{44,-70}},                                                                        color={191,0,0}));
  connect(topConv.fluid, heatFlowTop.port_a) annotation (Line(points={{56,70},{56,
          70},{74,70}},                                                                         color={191,0,0}));
  connect(bottomConv.fluid, heatFlowBottom.port_a) annotation (Line(points={{56,-70},
          {56,-70},{74,-70}},                                                                   color={191,0,0}));
  connect(sum.y, Ql_flow) annotation (Line(points={{80.6,-40},{88,-40},{96,-40},
          {112,-40}}, color={0,0,127}));
  connect(mul.y, sum.u) annotation (Line(points={{52.4,-40},{52.4,-40},{66.8,-40}},
        color={0,0,127}));
  connect(heatFlowTop.Q_flow, mul.u1[1]) annotation (Line(points={{80,64},{80,50},
          {0,50},{0,-36.5},{43.2,-36.5}},
                                    color={0,0,127}));
  connect(heatFlowBottom.Q_flow, mul.u3[1]) annotation (Line(points={{80,-76},{80,
          -80},{2,-80},{2,-70},{2,-43.5},{43.2,-43.5}},
                                          color={0,0,127}));
  connect(heatFlowTop.port_b, port_a_Tambient) annotation (Line(points={{86,70},
          {92,70},{92,0},{105,0}}, color={191,0,0}));
  connect(heatFlowBottom.port_b, port_a_Tambient) annotation (Line(points={{86,
          -70},{92,-70},{92,0},{105,0}}, color={191,0,0}));
  connect(volumeTop.ports[3], volumeMiddle[nSeg-2].ports[2]) annotation (Line(points={{
          -15.3333,60},{-4,60},{-4,-10},{-19,-10}},
                                             color={0,127,255}));
  connect(volumeBottom.ports[3], volumeMiddle[1].ports[3]) annotation (Line(points={{
          -15.3333,-80},{-4,-80},{-4,-10},{-17,-10}},
                                                    color={0,127,255}));
  connect(volumeTop.heatPort, topCond.port_a) annotation (Line(points={{-28,70},
          {-50,70},{-50,90},{10,90},{10,70},{14,70}}, color={191,0,0}));
  connect(volumeTop.heatPort, middleCond[nSeg].port_a) annotation (Line(points={{-28,
          70},{-40,70},{-50,70},{-50,40},{10,40},{10,0},{14,0}}, color={191,0,0}));
  connect(volumeTop.heatPort, buoyancy.port_a_heat[nSeg]) annotation (Line(
        points={{-28,70},{-50,70},{-50,40},{-70,40}}, color={191,0,0}));
  connect(volumeTop.heatPort, condFluid[nSeg-1].port_b) annotation (Line(points={{-28,70},
          {-50,70},{-50,-30},{-70,-30}},               color={191,0,0}));
  connect(volumeBottom.heatPort, condFluid[1].port_a) annotation (Line(points={{
          -28,-70},{-40,-70},{-40,-52},{-100,-52},{-100,-30},{-90,-30}}, color={
          191,0,0}));
  connect(volumeBottom.heatPort, buoyancy.port_a_heat[1]) annotation (Line(
        points={{-28,-70},{-40,-70},{-40,40},{-70,40}}, color={191,0,0}));
  connect(volumeBottom.heatPort, middleCond[1].port_a) annotation (Line(points={
          {-28,-70},{-40,-70},{-40,-28},{10,-28},{10,0},{14,0}}, color={191,0,0}));
  connect(volumeBottom.heatPort, bottomCond.port_a) annotation (Line(points={{-28,
          -70},{-40,-70},{-40,-90},{10,-90},{10,-70},{14,-70}}, color={191,0,0}));
 annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
            -100},{100,100}})), Documentation(info="<html>
<p>This partial model represents a closed tank with cylindrical shape for the accumulation of water. Is used for the modeling of <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.ThermalStorage.SensibleStorages.ClosedCylindricalTank_NatConv\">ClosedRectangularTank_NatConv</a>.</p>
<p>The difference with the <a href=\"modelica://Modelica_IK4_TEKNIKER.DCOL.ThermalStorage.SensibleStorages.Interfaces.PartialClosedCylindricalTank\">PartialClosedCylindricalTank</a> is the convection components used, in this case <a href=\"modelica://Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Plate.NaturalConvectionHorizontalPlate\">NaturalConvectionHorizontalPlate</a> and <a href=\"modelica://Modelica_IK4_TEKNIKER.Thermal.NewHeatTransfer.Components.Convection.NaturalConvection.Cylinder.NaturalConvectionVerticalCylinder\">NaturalConvectionVerticalCylinder</a>. In these components the coefficient of heat transfer depend on the geometrical properties of the tanka, and on the properties of the air around the tank.</p>
</html>",
        revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end PartialClosedCylindricalTank_NatConv;
