within DCOL.ThermalStorage.LatentStorages.FMI;
model IceStorage_FMU
// Model automatically generated by Dymola from FMI model description
public
  type Modelica_Blocks_Interfaces_RealInput = Real;
  type Modelica_Blocks_Interfaces_RealOutput = Real;
  type Modelica_IK4_TEKNIKER_DCOL_Generation_LatentStorages_FMI_RealConectors_RealMassFlowInput = Real (unit = "kg/s", quantity = "MassFlowRate");
  type Modelica_IK4_TEKNIKER_DCOL_Generation_LatentStorages_FMI_RealConectors_RealTemperatureInput = Real (unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0);
  type Modelica_IK4_TEKNIKER_DCOL_Generation_LatentStorages_FMI_RealConectors_RealTemperatureOutput = Real (unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0);
protected
  record 'system_rec'
    constant Modelica.SIunits.AbsolutePressure p_ambient = 101325
                                                                 "Default ambient pressure";
    parameter Modelica.SIunits.Temperature T_ambient = 293.15
                                                             "Default ambient temperature";
    parameter Modelica.SIunits.Acceleration g = 9.80665
                                                       "Constant gravity acceleration";
    constant Boolean allowFlowReversal = true
                                             "= false to restrict to design flow direction (port_a -> port_b)";
    constant Modelica.Fluid.Types.Dynamics energyDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                            "Default formulation of energy balances";
    constant Modelica.Fluid.Types.Dynamics massDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                          "Default formulation of mass balances";
    constant Modelica.Fluid.Types.Dynamics substanceDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                               "Default formulation of substance balances";
    constant Modelica.Fluid.Types.Dynamics traceDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                           "Default formulation of trace substance balances";
    constant Modelica.Fluid.Types.Dynamics momentumDynamics = Modelica.Fluid.Types.Dynamics.SteadyState
                                                                                                       "Default formulation of momentum balances, if options available";
    constant Modelica.SIunits.MassFlowRate m_flow_start = 0
                                                           "Default start value for mass flow rates";
    constant Modelica.SIunits.AbsolutePressure p_start = 101325.0
                                                                 "Default start value for pressures";
    parameter Modelica.SIunits.Temperature T_start(fixed=false)
                                                               "Default start value for temperatures";
    constant Boolean use_eps_Re = false
                                       "= true to determine turbulent region automatically using Reynolds number";
    parameter Modelica.SIunits.MassFlowRate m_flow_nominal(fixed=false)
                                                                       "Default nominal mass flow rate";
    parameter Real eps_m_flow(unit = "1", min = 0.0) = 0.0001
                                                             "Regularization of zero flow for |m_flow| < eps_m_flow*m_flow_nominal";
    parameter Modelica.SIunits.AbsolutePressure dp_small = 1
                                                            "Default small pressure drop for regularization of laminar and zero flow";
    parameter Modelica.SIunits.MassFlowRate m_flow_small(min = 0.0) = 0.01
                                                                          "Default small mass flow rate for regularization of laminar and zero flow";
  end 'system_rec';
public
  'system_rec' 'system' annotation(Dialog);
  constant Integer nSeg = 10
                            "Number of segments of each coil";
  constant Integer nCoil = 10
                             "Number of coil";
  parameter Modelica.SIunits.Diameter D_tube_in = 0.025
                                                       "Interior diameter of the coil";
  constant Modelica.SIunits.Length L_coil = 10
                                              "Length of each coils segment";
  constant Modelica.SIunits.Diameter D_crit = 0.1
                                                 "Critical diameter (vertical/horizontal distance between 2 coils)";
  parameter Modelica.SIunits.Pressure p_PCM = 101325
                                                    "Pressure of the PCM";
  parameter Modelica.SIunits.Diameter D_tube_out = 0.03
                                                       "Exterior diameter of the coil";
  constant Real Charge_Percentage = 90
                                      "Percentage of ice at the end of the charge [%]";
  parameter Real a(unit = "(Pa.s2)/m6") = 1000
                                              "Coefficient for quadratic term  of the pressure drop";
  parameter Real b(unit = "(Pa.s)/m3") = 1000
                                             "Coefficient for linear term of the pressure drop";
  parameter Modelica.SIunits.Length h = 1
                                         "Height of the storage";
  parameter Modelica.SIunits.Length w = 1
                                         "Width of the storage";
  parameter Modelica.SIunits.Length e = 0.2
                                           "Thicknes of the storages wall";
  parameter Modelica.SIunits.ThermalConductivity k_PCMs = 2.2
                                                             "Thermal conductivity of the solid PCM";
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_PCMl = 568.4
                                                                     "Convection heat transfer coefficient of the liquid PCM";
  parameter Modelica.SIunits.ThermalConductivity k_PCMl = 0.58
                                                              "Thermal conductivity of the liquid PCM";
  parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF = 6000
                                                                   "Convection heat transfer coefficient of the HTF";
  constant Modelica.Media.Interfaces.Types.Temperature T_start_pipe = 258.15
                                                                            "Start value of the temperature inside the pipe";
  constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                            "Start temperature of the PCM";
protected
  record ambientTemperature_rec
  protected
    record port_rec
      Modelica.SIunits.Temperature T
                                    "Port temperature";
      Modelica.SIunits.HeatFlowRate Q_flow
                                          "Heat flow rate (positive if flowing from outside into the component)";
    end port_rec;
  public
    port_rec port;
    Modelica_Blocks_Interfaces_RealInput T(unit = "K");
  end ambientTemperature_rec;
public
  ambientTemperature_rec ambientTemperature;
protected
  record iceStorageInternalMelt_rec
    constant Boolean allowFlowReversal = true
                                             "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)";
    constant Integer nSeg = 10
                              "Number of segments of each coil";
    constant Integer nCoil = 10
                               "Number of coil";
    parameter Modelica.SIunits.Diameter D_tube_in(fixed=false)
                                                              "Interior diameter of the coil";
    constant Modelica.SIunits.Length L_coil = 10.0
                                                  "Length of each coils segment";
    constant Modelica.SIunits.Diameter D_crit = 0.1
                                                   "Critical diameter (vertical/horizontal distance between 2 coils)";
    parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                          "Pressure of the PCM";
    parameter Modelica.SIunits.Mass m_PCM_tube(fixed=false)
                                                           "Mass of PCM around each tube segment";
    parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                               "Exterior diameter of the coil";
    constant Real Charge_Percentage = 90
                                        "Percentage of ice at the end of the charge [%]";
    constant Modelica.Media.Interfaces.Types.Temperature T_start_pipe = 258.15
                                                                              "Start value of the temperature inside the pipe";
    constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                              "Start temperature of the PCM";
    parameter Real a(unit = "(Pa.s2)/m6", fixed=false)
                                                      "Coefficient for quadratic term  of the pressure drop";
    parameter Real b(unit = "(Pa.s)/m3", fixed=false)
                                                     "Coefficient for linear term of the pressure drop";
    parameter Modelica.SIunits.Volume vol(fixed=false)
                                                      "Volume of each coil segment";
    parameter Modelica.SIunits.Length h(fixed=false)
                                                    "Height of the storage";
    parameter Modelica.SIunits.Length w(fixed=false)
                                                    "Width of the storage";
    parameter Modelica.SIunits.Length e(fixed=false)
                                                    "Thicknes of the storages wall";
    Boolean Charging
                    "=true during the charging of the storage";
    Boolean Charged
                   "=true when Charge_Percentage is reached";
  protected
    record port_a_HTF_rec
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                               "Mass flow rate from the connection point into the component";
      Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                             "Thermodynamic pressure in the connection point";
      Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0)
                                                                                    "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
      Real h_outflow_der(unit = "m2/s3")
                                        "der(Specific thermodynamic enthalpy close to the connection point if m_flow < 0)";
    end port_a_HTF_rec;
  public
    port_a_HTF_rec port_a_HTF;
  protected
    record port_b_HTF_rec
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", max = 1E+060)
                                                                                                              "Mass flow rate from the connection point into the component";
      Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                             "Thermodynamic pressure in the connection point";
      Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0)
                                                                                    "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
      Real h_outflow_der(unit = "m2/s3")
                                        "der(Specific thermodynamic enthalpy close to the connection point if m_flow < 0)";
    end port_b_HTF_rec;
  public
    port_b_HTF_rec port_b_HTF;
  protected
    record 'ice_WaterRing[1, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 1]_rec';
  public
    'ice_WaterRing[1, 1]_rec' 'ice_WaterRing[1, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 2]_rec';
  public
    'ice_WaterRing[1, 2]_rec' 'ice_WaterRing[1, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 3]_rec';
  public
    'ice_WaterRing[1, 3]_rec' 'ice_WaterRing[1, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 4]_rec';
  public
    'ice_WaterRing[1, 4]_rec' 'ice_WaterRing[1, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 5]_rec';
  public
    'ice_WaterRing[1, 5]_rec' 'ice_WaterRing[1, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 6]_rec';
  public
    'ice_WaterRing[1, 6]_rec' 'ice_WaterRing[1, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 7]_rec';
  public
    'ice_WaterRing[1, 7]_rec' 'ice_WaterRing[1, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 8]_rec';
  public
    'ice_WaterRing[1, 8]_rec' 'ice_WaterRing[1, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 9]_rec';
  public
    'ice_WaterRing[1, 9]_rec' 'ice_WaterRing[1, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[1, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[1, 10]_rec';
  public
    'ice_WaterRing[1, 10]_rec' 'ice_WaterRing[1, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 1]_rec';
  public
    'ice_WaterRing[2, 1]_rec' 'ice_WaterRing[2, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 2]_rec';
  public
    'ice_WaterRing[2, 2]_rec' 'ice_WaterRing[2, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 3]_rec';
  public
    'ice_WaterRing[2, 3]_rec' 'ice_WaterRing[2, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 4]_rec';
  public
    'ice_WaterRing[2, 4]_rec' 'ice_WaterRing[2, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 5]_rec';
  public
    'ice_WaterRing[2, 5]_rec' 'ice_WaterRing[2, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 6]_rec';
  public
    'ice_WaterRing[2, 6]_rec' 'ice_WaterRing[2, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 7]_rec';
  public
    'ice_WaterRing[2, 7]_rec' 'ice_WaterRing[2, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 8]_rec';
  public
    'ice_WaterRing[2, 8]_rec' 'ice_WaterRing[2, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 9]_rec';
  public
    'ice_WaterRing[2, 9]_rec' 'ice_WaterRing[2, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[2, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[2, 10]_rec';
  public
    'ice_WaterRing[2, 10]_rec' 'ice_WaterRing[2, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 1]_rec';
  public
    'ice_WaterRing[3, 1]_rec' 'ice_WaterRing[3, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 2]_rec';
  public
    'ice_WaterRing[3, 2]_rec' 'ice_WaterRing[3, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 3]_rec';
  public
    'ice_WaterRing[3, 3]_rec' 'ice_WaterRing[3, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 4]_rec';
  public
    'ice_WaterRing[3, 4]_rec' 'ice_WaterRing[3, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 5]_rec';
  public
    'ice_WaterRing[3, 5]_rec' 'ice_WaterRing[3, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 6]_rec';
  public
    'ice_WaterRing[3, 6]_rec' 'ice_WaterRing[3, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 7]_rec';
  public
    'ice_WaterRing[3, 7]_rec' 'ice_WaterRing[3, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 8]_rec';
  public
    'ice_WaterRing[3, 8]_rec' 'ice_WaterRing[3, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 9]_rec';
  public
    'ice_WaterRing[3, 9]_rec' 'ice_WaterRing[3, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[3, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[3, 10]_rec';
  public
    'ice_WaterRing[3, 10]_rec' 'ice_WaterRing[3, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 1]_rec';
  public
    'ice_WaterRing[4, 1]_rec' 'ice_WaterRing[4, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 2]_rec';
  public
    'ice_WaterRing[4, 2]_rec' 'ice_WaterRing[4, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 3]_rec';
  public
    'ice_WaterRing[4, 3]_rec' 'ice_WaterRing[4, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 4]_rec';
  public
    'ice_WaterRing[4, 4]_rec' 'ice_WaterRing[4, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 5]_rec';
  public
    'ice_WaterRing[4, 5]_rec' 'ice_WaterRing[4, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 6]_rec';
  public
    'ice_WaterRing[4, 6]_rec' 'ice_WaterRing[4, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 7]_rec';
  public
    'ice_WaterRing[4, 7]_rec' 'ice_WaterRing[4, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 8]_rec';
  public
    'ice_WaterRing[4, 8]_rec' 'ice_WaterRing[4, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 9]_rec';
  public
    'ice_WaterRing[4, 9]_rec' 'ice_WaterRing[4, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[4, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[4, 10]_rec';
  public
    'ice_WaterRing[4, 10]_rec' 'ice_WaterRing[4, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 1]_rec';
  public
    'ice_WaterRing[5, 1]_rec' 'ice_WaterRing[5, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 2]_rec';
  public
    'ice_WaterRing[5, 2]_rec' 'ice_WaterRing[5, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 3]_rec';
  public
    'ice_WaterRing[5, 3]_rec' 'ice_WaterRing[5, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 4]_rec';
  public
    'ice_WaterRing[5, 4]_rec' 'ice_WaterRing[5, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 5]_rec';
  public
    'ice_WaterRing[5, 5]_rec' 'ice_WaterRing[5, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 6]_rec';
  public
    'ice_WaterRing[5, 6]_rec' 'ice_WaterRing[5, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 7]_rec';
  public
    'ice_WaterRing[5, 7]_rec' 'ice_WaterRing[5, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 8]_rec';
  public
    'ice_WaterRing[5, 8]_rec' 'ice_WaterRing[5, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 9]_rec';
  public
    'ice_WaterRing[5, 9]_rec' 'ice_WaterRing[5, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[5, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[5, 10]_rec';
  public
    'ice_WaterRing[5, 10]_rec' 'ice_WaterRing[5, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 1]_rec';
  public
    'ice_WaterRing[6, 1]_rec' 'ice_WaterRing[6, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 2]_rec';
  public
    'ice_WaterRing[6, 2]_rec' 'ice_WaterRing[6, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 3]_rec';
  public
    'ice_WaterRing[6, 3]_rec' 'ice_WaterRing[6, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 4]_rec';
  public
    'ice_WaterRing[6, 4]_rec' 'ice_WaterRing[6, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 5]_rec';
  public
    'ice_WaterRing[6, 5]_rec' 'ice_WaterRing[6, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 6]_rec';
  public
    'ice_WaterRing[6, 6]_rec' 'ice_WaterRing[6, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 7]_rec';
  public
    'ice_WaterRing[6, 7]_rec' 'ice_WaterRing[6, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 8]_rec';
  public
    'ice_WaterRing[6, 8]_rec' 'ice_WaterRing[6, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 9]_rec';
  public
    'ice_WaterRing[6, 9]_rec' 'ice_WaterRing[6, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[6, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[6, 10]_rec';
  public
    'ice_WaterRing[6, 10]_rec' 'ice_WaterRing[6, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 1]_rec';
  public
    'ice_WaterRing[7, 1]_rec' 'ice_WaterRing[7, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 2]_rec';
  public
    'ice_WaterRing[7, 2]_rec' 'ice_WaterRing[7, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 3]_rec';
  public
    'ice_WaterRing[7, 3]_rec' 'ice_WaterRing[7, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 4]_rec';
  public
    'ice_WaterRing[7, 4]_rec' 'ice_WaterRing[7, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 5]_rec';
  public
    'ice_WaterRing[7, 5]_rec' 'ice_WaterRing[7, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 6]_rec';
  public
    'ice_WaterRing[7, 6]_rec' 'ice_WaterRing[7, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 7]_rec';
  public
    'ice_WaterRing[7, 7]_rec' 'ice_WaterRing[7, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 8]_rec';
  public
    'ice_WaterRing[7, 8]_rec' 'ice_WaterRing[7, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 9]_rec';
  public
    'ice_WaterRing[7, 9]_rec' 'ice_WaterRing[7, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[7, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[7, 10]_rec';
  public
    'ice_WaterRing[7, 10]_rec' 'ice_WaterRing[7, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 1]_rec';
  public
    'ice_WaterRing[8, 1]_rec' 'ice_WaterRing[8, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 2]_rec';
  public
    'ice_WaterRing[8, 2]_rec' 'ice_WaterRing[8, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 3]_rec';
  public
    'ice_WaterRing[8, 3]_rec' 'ice_WaterRing[8, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 4]_rec';
  public
    'ice_WaterRing[8, 4]_rec' 'ice_WaterRing[8, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 5]_rec';
  public
    'ice_WaterRing[8, 5]_rec' 'ice_WaterRing[8, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 6]_rec';
  public
    'ice_WaterRing[8, 6]_rec' 'ice_WaterRing[8, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 7]_rec';
  public
    'ice_WaterRing[8, 7]_rec' 'ice_WaterRing[8, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 8]_rec';
  public
    'ice_WaterRing[8, 8]_rec' 'ice_WaterRing[8, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 9]_rec';
  public
    'ice_WaterRing[8, 9]_rec' 'ice_WaterRing[8, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[8, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[8, 10]_rec';
  public
    'ice_WaterRing[8, 10]_rec' 'ice_WaterRing[8, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 1]_rec';
  public
    'ice_WaterRing[9, 1]_rec' 'ice_WaterRing[9, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 2]_rec';
  public
    'ice_WaterRing[9, 2]_rec' 'ice_WaterRing[9, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 3]_rec';
  public
    'ice_WaterRing[9, 3]_rec' 'ice_WaterRing[9, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 4]_rec';
  public
    'ice_WaterRing[9, 4]_rec' 'ice_WaterRing[9, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 5]_rec';
  public
    'ice_WaterRing[9, 5]_rec' 'ice_WaterRing[9, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 6]_rec';
  public
    'ice_WaterRing[9, 6]_rec' 'ice_WaterRing[9, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 7]_rec';
  public
    'ice_WaterRing[9, 7]_rec' 'ice_WaterRing[9, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 8]_rec';
  public
    'ice_WaterRing[9, 8]_rec' 'ice_WaterRing[9, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 9]_rec';
  public
    'ice_WaterRing[9, 9]_rec' 'ice_WaterRing[9, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[9, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[9, 10]_rec';
  public
    'ice_WaterRing[9, 10]_rec' 'ice_WaterRing[9, 10]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 1]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 1]_rec';
  public
    'ice_WaterRing[10, 1]_rec' 'ice_WaterRing[10, 1]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 2]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 2]_rec';
  public
    'ice_WaterRing[10, 2]_rec' 'ice_WaterRing[10, 2]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 3]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 3]_rec';
  public
    'ice_WaterRing[10, 3]_rec' 'ice_WaterRing[10, 3]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 4]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 4]_rec';
  public
    'ice_WaterRing[10, 4]_rec' 'ice_WaterRing[10, 4]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 5]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 5]_rec';
  public
    'ice_WaterRing[10, 5]_rec' 'ice_WaterRing[10, 5]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 6]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 6]_rec';
  public
    'ice_WaterRing[10, 6]_rec' 'ice_WaterRing[10, 6]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 7]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 7]_rec';
  public
    'ice_WaterRing[10, 7]_rec' 'ice_WaterRing[10, 7]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 8]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 8]_rec';
  public
    'ice_WaterRing[10, 8]_rec' 'ice_WaterRing[10, 8]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 9]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 9]_rec';
  public
    'ice_WaterRing[10, 9]_rec' 'ice_WaterRing[10, 9]' annotation(Dialog);
  protected
    record 'ice_WaterRing[10, 10]_rec'
    protected
      record port_a_heatToAmbient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToAmbient_rec;
    public
      port_a_heatToAmbient_rec port_a_heatToAmbient;
    protected
      record port_a_heatToHTF_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_heatToHTF_rec;
    public
      port_a_heatToHTF_rec port_a_heatToHTF;
      parameter Modelica.SIunits.Pressure p_PCM(fixed=false)
                                                            "Pressure of the PCM";
      parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                        "Total mass of the PCM";
      Modelica.SIunits.Temperature T
                                    "Temperature of the PCM";
      Modelica.SIunits.MassFraction x_liquid
                                            "Liquid mass fraction";
      Modelica.SIunits.InternalEnergy U
                                       "Internal energy of the PCM";
      Real U_der(unit = "W")
                            "der(Internal energy of the PCM)";
      Modelica.SIunits.Volume V_PCM
                                   "Volume ocupied by the PCM";
      Modelica.SIunits.SpecificEnthalpy h_PCM
                                             "Specific enthalpy of the PCM";
      Modelica.SIunits.Density rho
                                  "Density of the PCM";
      constant Modelica.SIunits.SpecificEnthalpy h_satS = 0.0
                                                             "solid saturation enthalpy";
      constant Modelica.SIunits.SpecificEnthalpy h_satL = 333550.0
                                                                  "liquid saturation enthalpy";
      parameter Modelica.SIunits.Diameter D_tube_out(fixed=false)
                                                                 "Exterior diameter of the coil";
      constant Modelica.SIunits.Diameter D_crit = 0.1
                                                     "Critical diameter (vertical/horizontal distance between 2 coils)";
      constant Modelica.SIunits.Diameter D_max = 0.14142135623730953
                                                                    "maximun diameter (vertical/horizontal maximun distance between 2 coils)";
      constant Modelica.SIunits.Length L_coil = 1.0
                                                   "Length of each tube segment";
      constant Real Charge_Percentage = 90
                                          "Percentage of ice at the end of the charge [%]";
      parameter Modelica.SIunits.MassFraction x_liquid_start = 1
                                                                "Liquid mass fraction at the start";
      constant Modelica.SIunits.Temperature T_PCM_start = 283.15
                                                                "Start temperature of the PCM";
      Modelica.SIunits.Mass m_PCMs
                                  "Total mass of the solid fraction of the PCM";
      Modelica.SIunits.Temperature T_s
                                      "Temperature of the solid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_s_start = 0.0;
      Modelica.SIunits.Diameter D_s(max = 0.14142135623730953,start = _D_s_start, fixed=false)
                                                                                              "External diameter of the formed solid ring";
      parameter Modelica.SIunits.Diameter D_smax(fixed=false)
                                                             "Maximum diameter of the formed solid ring";
      Modelica.SIunits.Mass m_PCMl
                                  "Total mass of the liquid fraction of the PCM";
      Modelica.SIunits.Temperature T_l
                                      "Temperature of the liquid fraction of the PCM";
      parameter Modelica.SIunits.Diameter _D_l_start = 0.0;
      Modelica.SIunits.Diameter D_l(start = _D_l_start, fixed=false)
                                                                    "Internal diameter of the formed liquid ring(during Discharge)";
      Modelica.SIunits.Diameter D_l_out
                                       "External diameter of the formed liquid ring(during Discharge)";
      parameter Modelica.SIunits.Diameter D_lmax(fixed=false)
                                                             "Maximum diameter of the formed liquid ring";
      Boolean Charging
                      "True during the charging of the storage";
    end 'ice_WaterRing[10, 10]_rec';
  public
    'ice_WaterRing[10, 10]_rec' 'ice_WaterRing[10, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 1]_rec';
  public
    'HTFtoPCM[1, 1]_rec' 'HTFtoPCM[1, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 2]_rec';
  public
    'HTFtoPCM[1, 2]_rec' 'HTFtoPCM[1, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 3]_rec';
  public
    'HTFtoPCM[1, 3]_rec' 'HTFtoPCM[1, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 4]_rec';
  public
    'HTFtoPCM[1, 4]_rec' 'HTFtoPCM[1, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 5]_rec';
  public
    'HTFtoPCM[1, 5]_rec' 'HTFtoPCM[1, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 6]_rec';
  public
    'HTFtoPCM[1, 6]_rec' 'HTFtoPCM[1, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 7]_rec';
  public
    'HTFtoPCM[1, 7]_rec' 'HTFtoPCM[1, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 8]_rec';
  public
    'HTFtoPCM[1, 8]_rec' 'HTFtoPCM[1, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 9]_rec';
  public
    'HTFtoPCM[1, 9]_rec' 'HTFtoPCM[1, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[1, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[1, 10]_rec';
  public
    'HTFtoPCM[1, 10]_rec' 'HTFtoPCM[1, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 1]_rec';
  public
    'HTFtoPCM[2, 1]_rec' 'HTFtoPCM[2, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 2]_rec';
  public
    'HTFtoPCM[2, 2]_rec' 'HTFtoPCM[2, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 3]_rec';
  public
    'HTFtoPCM[2, 3]_rec' 'HTFtoPCM[2, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 4]_rec';
  public
    'HTFtoPCM[2, 4]_rec' 'HTFtoPCM[2, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 5]_rec';
  public
    'HTFtoPCM[2, 5]_rec' 'HTFtoPCM[2, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 6]_rec';
  public
    'HTFtoPCM[2, 6]_rec' 'HTFtoPCM[2, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 7]_rec';
  public
    'HTFtoPCM[2, 7]_rec' 'HTFtoPCM[2, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 8]_rec';
  public
    'HTFtoPCM[2, 8]_rec' 'HTFtoPCM[2, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 9]_rec';
  public
    'HTFtoPCM[2, 9]_rec' 'HTFtoPCM[2, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[2, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[2, 10]_rec';
  public
    'HTFtoPCM[2, 10]_rec' 'HTFtoPCM[2, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 1]_rec';
  public
    'HTFtoPCM[3, 1]_rec' 'HTFtoPCM[3, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 2]_rec';
  public
    'HTFtoPCM[3, 2]_rec' 'HTFtoPCM[3, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 3]_rec';
  public
    'HTFtoPCM[3, 3]_rec' 'HTFtoPCM[3, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 4]_rec';
  public
    'HTFtoPCM[3, 4]_rec' 'HTFtoPCM[3, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 5]_rec';
  public
    'HTFtoPCM[3, 5]_rec' 'HTFtoPCM[3, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 6]_rec';
  public
    'HTFtoPCM[3, 6]_rec' 'HTFtoPCM[3, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 7]_rec';
  public
    'HTFtoPCM[3, 7]_rec' 'HTFtoPCM[3, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 8]_rec';
  public
    'HTFtoPCM[3, 8]_rec' 'HTFtoPCM[3, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 9]_rec';
  public
    'HTFtoPCM[3, 9]_rec' 'HTFtoPCM[3, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[3, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[3, 10]_rec';
  public
    'HTFtoPCM[3, 10]_rec' 'HTFtoPCM[3, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 1]_rec';
  public
    'HTFtoPCM[4, 1]_rec' 'HTFtoPCM[4, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 2]_rec';
  public
    'HTFtoPCM[4, 2]_rec' 'HTFtoPCM[4, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 3]_rec';
  public
    'HTFtoPCM[4, 3]_rec' 'HTFtoPCM[4, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 4]_rec';
  public
    'HTFtoPCM[4, 4]_rec' 'HTFtoPCM[4, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 5]_rec';
  public
    'HTFtoPCM[4, 5]_rec' 'HTFtoPCM[4, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 6]_rec';
  public
    'HTFtoPCM[4, 6]_rec' 'HTFtoPCM[4, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 7]_rec';
  public
    'HTFtoPCM[4, 7]_rec' 'HTFtoPCM[4, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 8]_rec';
  public
    'HTFtoPCM[4, 8]_rec' 'HTFtoPCM[4, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 9]_rec';
  public
    'HTFtoPCM[4, 9]_rec' 'HTFtoPCM[4, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[4, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[4, 10]_rec';
  public
    'HTFtoPCM[4, 10]_rec' 'HTFtoPCM[4, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 1]_rec';
  public
    'HTFtoPCM[5, 1]_rec' 'HTFtoPCM[5, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 2]_rec';
  public
    'HTFtoPCM[5, 2]_rec' 'HTFtoPCM[5, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 3]_rec';
  public
    'HTFtoPCM[5, 3]_rec' 'HTFtoPCM[5, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 4]_rec';
  public
    'HTFtoPCM[5, 4]_rec' 'HTFtoPCM[5, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 5]_rec';
  public
    'HTFtoPCM[5, 5]_rec' 'HTFtoPCM[5, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 6]_rec';
  public
    'HTFtoPCM[5, 6]_rec' 'HTFtoPCM[5, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 7]_rec';
  public
    'HTFtoPCM[5, 7]_rec' 'HTFtoPCM[5, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 8]_rec';
  public
    'HTFtoPCM[5, 8]_rec' 'HTFtoPCM[5, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 9]_rec';
  public
    'HTFtoPCM[5, 9]_rec' 'HTFtoPCM[5, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[5, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[5, 10]_rec';
  public
    'HTFtoPCM[5, 10]_rec' 'HTFtoPCM[5, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 1]_rec';
  public
    'HTFtoPCM[6, 1]_rec' 'HTFtoPCM[6, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 2]_rec';
  public
    'HTFtoPCM[6, 2]_rec' 'HTFtoPCM[6, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 3]_rec';
  public
    'HTFtoPCM[6, 3]_rec' 'HTFtoPCM[6, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 4]_rec';
  public
    'HTFtoPCM[6, 4]_rec' 'HTFtoPCM[6, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 5]_rec';
  public
    'HTFtoPCM[6, 5]_rec' 'HTFtoPCM[6, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 6]_rec';
  public
    'HTFtoPCM[6, 6]_rec' 'HTFtoPCM[6, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 7]_rec';
  public
    'HTFtoPCM[6, 7]_rec' 'HTFtoPCM[6, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 8]_rec';
  public
    'HTFtoPCM[6, 8]_rec' 'HTFtoPCM[6, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 9]_rec';
  public
    'HTFtoPCM[6, 9]_rec' 'HTFtoPCM[6, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[6, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[6, 10]_rec';
  public
    'HTFtoPCM[6, 10]_rec' 'HTFtoPCM[6, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 1]_rec';
  public
    'HTFtoPCM[7, 1]_rec' 'HTFtoPCM[7, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 2]_rec';
  public
    'HTFtoPCM[7, 2]_rec' 'HTFtoPCM[7, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 3]_rec';
  public
    'HTFtoPCM[7, 3]_rec' 'HTFtoPCM[7, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 4]_rec';
  public
    'HTFtoPCM[7, 4]_rec' 'HTFtoPCM[7, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 5]_rec';
  public
    'HTFtoPCM[7, 5]_rec' 'HTFtoPCM[7, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 6]_rec';
  public
    'HTFtoPCM[7, 6]_rec' 'HTFtoPCM[7, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 7]_rec';
  public
    'HTFtoPCM[7, 7]_rec' 'HTFtoPCM[7, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 8]_rec';
  public
    'HTFtoPCM[7, 8]_rec' 'HTFtoPCM[7, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 9]_rec';
  public
    'HTFtoPCM[7, 9]_rec' 'HTFtoPCM[7, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[7, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[7, 10]_rec';
  public
    'HTFtoPCM[7, 10]_rec' 'HTFtoPCM[7, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 1]_rec';
  public
    'HTFtoPCM[8, 1]_rec' 'HTFtoPCM[8, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 2]_rec';
  public
    'HTFtoPCM[8, 2]_rec' 'HTFtoPCM[8, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 3]_rec';
  public
    'HTFtoPCM[8, 3]_rec' 'HTFtoPCM[8, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 4]_rec';
  public
    'HTFtoPCM[8, 4]_rec' 'HTFtoPCM[8, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 5]_rec';
  public
    'HTFtoPCM[8, 5]_rec' 'HTFtoPCM[8, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 6]_rec';
  public
    'HTFtoPCM[8, 6]_rec' 'HTFtoPCM[8, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 7]_rec';
  public
    'HTFtoPCM[8, 7]_rec' 'HTFtoPCM[8, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 8]_rec';
  public
    'HTFtoPCM[8, 8]_rec' 'HTFtoPCM[8, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 9]_rec';
  public
    'HTFtoPCM[8, 9]_rec' 'HTFtoPCM[8, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[8, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[8, 10]_rec';
  public
    'HTFtoPCM[8, 10]_rec' 'HTFtoPCM[8, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 1]_rec';
  public
    'HTFtoPCM[9, 1]_rec' 'HTFtoPCM[9, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 2]_rec';
  public
    'HTFtoPCM[9, 2]_rec' 'HTFtoPCM[9, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 3]_rec';
  public
    'HTFtoPCM[9, 3]_rec' 'HTFtoPCM[9, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 4]_rec';
  public
    'HTFtoPCM[9, 4]_rec' 'HTFtoPCM[9, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 5]_rec';
  public
    'HTFtoPCM[9, 5]_rec' 'HTFtoPCM[9, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 6]_rec';
  public
    'HTFtoPCM[9, 6]_rec' 'HTFtoPCM[9, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 7]_rec';
  public
    'HTFtoPCM[9, 7]_rec' 'HTFtoPCM[9, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 8]_rec';
  public
    'HTFtoPCM[9, 8]_rec' 'HTFtoPCM[9, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 9]_rec';
  public
    'HTFtoPCM[9, 9]_rec' 'HTFtoPCM[9, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[9, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[9, 10]_rec';
  public
    'HTFtoPCM[9, 10]_rec' 'HTFtoPCM[9, 10]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 1]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 1]_rec';
  public
    'HTFtoPCM[10, 1]_rec' 'HTFtoPCM[10, 1]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 2]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 2]_rec';
  public
    'HTFtoPCM[10, 2]_rec' 'HTFtoPCM[10, 2]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 3]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 3]_rec';
  public
    'HTFtoPCM[10, 3]_rec' 'HTFtoPCM[10, 3]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 4]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 4]_rec';
  public
    'HTFtoPCM[10, 4]_rec' 'HTFtoPCM[10, 4]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 5]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 5]_rec';
  public
    'HTFtoPCM[10, 5]_rec' 'HTFtoPCM[10, 5]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 6]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 6]_rec';
  public
    'HTFtoPCM[10, 6]_rec' 'HTFtoPCM[10, 6]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 7]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 7]_rec';
  public
    'HTFtoPCM[10, 7]_rec' 'HTFtoPCM[10, 7]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 8]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 8]_rec';
  public
    'HTFtoPCM[10, 8]_rec' 'HTFtoPCM[10, 8]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 9]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 9]_rec';
  public
    'HTFtoPCM[10, 9]_rec' 'HTFtoPCM[10, 9]' annotation(Dialog);
  protected
    record 'HTFtoPCM[10, 10]_rec'
      parameter Modelica.SIunits.Volume vol(fixed=false)
                                                        "Volume of element";
      constant Modelica.SIunits.Temperature T_Tube_start = 258.15
                                                                 "Start temperature of the tube";
    protected
      record HTFtoTube_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end HTFtoTube_rec;
    public
      HTFtoTube_rec HTFtoTube;
    protected
      record TubetoPCM_rec
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica_Blocks_Interfaces_RealInput G(unit = "W/K")
                                                            "Constant thermal conductance of material";
      end TubetoPCM_rec;
    public
      TubetoPCM_rec TubetoPCM;
    protected
      record TubeInertia_rec
        parameter Modelica.SIunits.Temperature _T_start = 258.15;
        Modelica.SIunits.Temperature T(start = _T_start)
                                                        "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end TubeInertia_rec;
    public
      TubeInertia_rec TubeInertia annotation(Dialog);
    protected
      record port_a_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_b_rec;
    public
      port_b_rec port_b;
      Modelica_Blocks_Interfaces_RealInput G_HTFtoTube(unit = "W/K");
      Modelica_Blocks_Interfaces_RealInput G_TubetoPCM(unit = "W/K");
    end 'HTFtoPCM[10, 10]_rec';
  public
    'HTFtoPCM[10, 10]_rec' 'HTFtoPCM[10, 10]' annotation(Dialog);
  protected
    record pipe_rec
      constant Boolean allowFlowReversal = true
                                               "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)";
    protected
      record port_a_rec
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                 "Mass flow rate from the connection point into the component";
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Thermodynamic pressure in the connection point";
        Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0)
                                                                                      "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", max = 1E+060)
                                                                                                                "Mass flow rate from the connection point into the component";
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Thermodynamic pressure in the connection point";
        Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0)
                                                                                      "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
      end port_b_rec;
    public
      port_b_rec port_b;
      constant Real nParallel(unit = "1", min = 1.0) = 10
                                                         "Number of identical parallel pipes";
      constant Modelica.SIunits.Length length = 10.0
                                                    "Length";
      constant Boolean isCircular = true
                                        "= true if cross sectional area is circular";
      parameter Modelica.SIunits.Diameter diameter(fixed=false)
                                                               "Diameter of circular pipe";
      parameter Modelica.SIunits.Area crossArea(fixed=false)
                                                            "Inner cross section area";
      parameter Modelica.SIunits.Length perimeter(fixed=false)
                                                              "Inner perimeter";
      parameter Modelica.SIunits.Height roughness = 2.5E-005
                                                            "Average height of surface asperities (default: smooth steel pipe)";
      parameter Modelica.SIunits.Volume V(fixed=false)
                                                      "volume size";
      constant Modelica.SIunits.Length height_ab = 0
                                                    "Height(port_b) - Height(port_a)";
      constant Integer n = 10
                             "Number of discrete volumes";
      parameter Modelica.SIunits.Volume 'fluidVolumes[1]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[2]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[3]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[4]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[5]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[6]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[7]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[8]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[9]'(fixed=false)
                                                                      "Discretized volume, determine in inheriting class";
      parameter Modelica.SIunits.Volume 'fluidVolumes[10]'(fixed=false)
                                                                       "Discretized volume, determine in inheriting class";
      constant Modelica.Fluid.Types.Dynamics energyDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                              "Formulation of energy balances";
      constant Modelica.Fluid.Types.Dynamics massDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                            "Formulation of mass balances";
      constant Modelica.Fluid.Types.Dynamics substanceDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                                 "Formulation of substance balances";
      constant Modelica.Fluid.Types.Dynamics traceDynamics = Modelica.Fluid.Types.Dynamics.DynamicFreeInitial
                                                                                                             "Formulation of trace substance balances";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure p_a_start(nominal = 1000000.0) = 101325.0
                                                                                                         "Start value of pressure at port a";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure p_b_start(nominal = 1000000.0) = 101325.0
                                                                                                         "Start value of pressure at port b";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[1]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[2]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[3]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[4]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[5]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[6]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[7]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[8]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[9]'(nominal = 1000000.0) = 101325.0
                                                                                                             "Start value of pressure";
      constant Modelica.Media.Interfaces.Types.AbsolutePressure 'ps_start[10]'(nominal = 1000000.0) = 101325.0
                                                                                                              "Start value of pressure";
      constant Boolean use_T_start = true
                                         "Use T_start if true, otherwise h_start";
      constant Modelica.Media.Interfaces.Types.Temperature T_start(nominal = 500.0, min = 200.0, max = 6000.0) = 258.15
                                                                                                                       "Start value of temperature";
      parameter Modelica.Media.Interfaces.Types.SpecificEnthalpy h_start(nominal = 100000.0, fixed=false)
                                                                                                         "Start value of specific enthalpy";
      constant Modelica.Media.Interfaces.Types.MassFraction 'X_start[1]' = 1.0
                                                                              "Start value of mass fractions m_i/m";
      Modelica.SIunits.Energy 'Us[1]'
                                     "Internal energy of fluid";
      Real 'Us[1]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[2]'
                                     "Internal energy of fluid";
      Real 'Us[2]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[3]'
                                     "Internal energy of fluid";
      Real 'Us[3]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[4]'
                                     "Internal energy of fluid";
      Real 'Us[4]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[5]'
                                     "Internal energy of fluid";
      Real 'Us[5]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[6]'
                                     "Internal energy of fluid";
      Real 'Us[6]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[7]'
                                     "Internal energy of fluid";
      Real 'Us[7]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[8]'
                                     "Internal energy of fluid";
      Real 'Us[8]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[9]'
                                     "Internal energy of fluid";
      Real 'Us[9]_der'(unit = "W")
                                  "der(Internal energy of fluid)";
      Modelica.SIunits.Energy 'Us[10]'
                                      "Internal energy of fluid";
      Real 'Us[10]_der'(unit = "W")
                                   "der(Internal energy of fluid)";
      Modelica.SIunits.Mass 'ms[1]'
                                   "Fluid mass";
      Real 'ms[1]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[2]'
                                   "Fluid mass";
      Real 'ms[2]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[3]'
                                   "Fluid mass";
      Real 'ms[3]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[4]'
                                   "Fluid mass";
      Real 'ms[4]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[5]'
                                   "Fluid mass";
      Real 'ms[5]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[6]'
                                   "Fluid mass";
      Real 'ms[6]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[7]'
                                   "Fluid mass";
      Real 'ms[7]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[8]'
                                   "Fluid mass";
      Real 'ms[8]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[9]'
                                   "Fluid mass";
      Real 'ms[9]_der'(unit = "kg/s")
                                     "der(Fluid mass)";
      Modelica.SIunits.Mass 'ms[10]'
                                    "Fluid mass";
      Real 'ms[10]_der'(unit = "kg/s")
                                      "der(Fluid mass)";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[1]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[2]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[3]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[4]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[5]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[6]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[7]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[8]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[9]'(quantity = "MassFlowRate.Air")
                                                                                                       "Mass flow rate, source or sink";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'mb_flows[10]'(quantity = "MassFlowRate.Air")
                                                                                                        "Mass flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[1]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[2]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[3]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[4]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[5]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[6]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[7]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[8]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[9]'
                                                     "Enthalpy flow rate, source or sink";
      Modelica.SIunits.EnthalpyFlowRate 'Hb_flows[10]'
                                                      "Enthalpy flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[1]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[2]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[3]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[4]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[5]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[6]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[7]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[8]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[9]'
                                                 "Heat flow rate, source or sink";
      Modelica.SIunits.HeatFlowRate 'Qb_flows[10]'
                                                  "Heat flow rate, source or sink";
      Modelica.SIunits.Power 'Wb_flows[1]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[2]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[3]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[4]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[5]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[6]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[7]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[8]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[9]'
                                          "Mechanical power, p*der(V) etc.";
      Modelica.SIunits.Power 'Wb_flows[10]'
                                           "Mechanical power, p*der(V) etc.";
      constant Modelica.SIunits.Length 'lengths[1]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[2]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[3]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[4]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[5]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[6]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[7]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[8]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[9]' = 1.0
                                                         "lengths of flow segments";
      constant Modelica.SIunits.Length 'lengths[10]' = 1.0
                                                          "lengths of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[1]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[2]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[3]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[4]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[5]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[6]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[7]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[8]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[9]'(fixed=false)
                                                                  "cross flow areas of flow segments";
      parameter Modelica.SIunits.Area 'crossAreas[10]'(fixed=false)
                                                                   "cross flow areas of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[1]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[2]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[3]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[4]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[5]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[6]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[7]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[8]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[9]'(fixed=false)
                                                                    "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Length 'dimensions[10]'(fixed=false)
                                                                     "hydraulic diameters of flow segments";
      parameter Modelica.SIunits.Height 'roughnesses[1]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[2]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[3]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[4]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[5]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[6]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[7]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[8]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[9]'(fixed=false)
                                                                     "Average heights of surface asperities";
      parameter Modelica.SIunits.Height 'roughnesses[10]'(fixed=false)
                                                                      "Average heights of surface asperities";
      constant Modelica.SIunits.Length 'dheights[1]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[2]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[3]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[4]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[5]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[6]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[7]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[8]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[9]' = 0.0
                                                          "Differences in heights of flow segments";
      constant Modelica.SIunits.Length 'dheights[10]' = 0.0
                                                           "Differences in heights of flow segments";
      constant Modelica.Fluid.Types.Dynamics momentumDynamics = Modelica.Fluid.Types.Dynamics.SteadyState
                                                                                                         "Formulation of momentum balances";
      constant Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow_start(quantity = "MassFlowRate.Air") = 0.0
                                                                                                                     "Start value for mass flow rate";
      constant Integer nNodes(min = 1) = 10
                                           "Number of discrete flow volumes";
      constant Modelica.Fluid.Types.ModelStructure modelStructure = Modelica.Fluid.Types.ModelStructure.av_vb
                                                                                                             "Determines whether flow or volume models are present at the ports";
      constant Boolean useLumpedPressure = false
                                                "=true to lump pressure states together";
      constant Integer nFM = 9
                              "number of flow models in flowModel";
      constant Integer nFMDistributed = 9;
      constant Integer nFMLumped = 1;
      constant Integer iLumped = 6
                                  "Index of control volume with representative state if useLumpedPressure";
      constant Boolean useInnerPortProperties = false
                                                     "=true to take port properties for flow models from internal control volumes";
    protected
      record state_a_rec
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end state_a_rec;
    public
      state_a_rec state_a;
    protected
      record state_b_rec
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end state_b_rec;
    public
      state_b_rec state_b;
    protected
      record 'statesFM[1]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[1]_rec';
    public
      'statesFM[1]_rec' 'statesFM[1]';
    protected
      record 'statesFM[2]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[2]_rec';
    public
      'statesFM[2]_rec' 'statesFM[2]';
    protected
      record 'statesFM[3]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[3]_rec';
    public
      'statesFM[3]_rec' 'statesFM[3]';
    protected
      record 'statesFM[4]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[4]_rec';
    public
      'statesFM[4]_rec' 'statesFM[4]';
    protected
      record 'statesFM[5]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[5]_rec';
    public
      'statesFM[5]_rec' 'statesFM[5]';
    protected
      record 'statesFM[6]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[6]_rec';
    public
      'statesFM[6]_rec' 'statesFM[6]';
    protected
      record 'statesFM[7]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[7]_rec';
    public
      'statesFM[7]_rec' 'statesFM[7]';
    protected
      record 'statesFM[8]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[8]_rec';
    public
      'statesFM[8]_rec' 'statesFM[8]';
    protected
      record 'statesFM[9]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[9]_rec';
    public
      'statesFM[9]_rec' 'statesFM[9]';
    protected
      record 'statesFM[10]_rec'
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end 'statesFM[10]_rec';
    public
      'statesFM[10]_rec' 'statesFM[10]';
    protected
      record flowModel_rec
        constant Boolean from_dp = true
                                       "= true, use m_flow = f(dp), otherwise dp = f(m_flow)";
        constant Integer n = 10
                               "Number of discrete flow volumes";
      protected
        record 'states[1]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[1]_rec';
      public
        'states[1]_rec' 'states[1]';
      protected
        record 'states[2]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[2]_rec';
      public
        'states[2]_rec' 'states[2]';
      protected
        record 'states[3]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[3]_rec';
      public
        'states[3]_rec' 'states[3]';
      protected
        record 'states[4]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[4]_rec';
      public
        'states[4]_rec' 'states[4]';
      protected
        record 'states[5]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[5]_rec';
      public
        'states[5]_rec' 'states[5]';
      protected
        record 'states[6]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[6]_rec';
      public
        'states[6]_rec' 'states[6]';
      protected
        record 'states[7]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[7]_rec';
      public
        'states[7]_rec' 'states[7]';
      protected
        record 'states[8]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[8]_rec';
      public
        'states[8]_rec' 'states[8]';
      protected
        record 'states[9]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[9]_rec';
      public
        'states[9]_rec' 'states[9]';
      protected
        record 'states[10]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[10]_rec';
      public
        'states[10]_rec' 'states[10]';
        Modelica.SIunits.Velocity 'vs[1]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[2]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[3]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[4]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[5]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[6]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[7]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[8]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[9]'
                                         "Mean velocities of fluid flow";
        Modelica.SIunits.Velocity 'vs[10]'
                                          "Mean velocities of fluid flow";
        constant Real nParallel(unit = "1") = 10.0
                                                  "number of identical parallel flow devices";
        Modelica.SIunits.Area 'crossAreas[1]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[2]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[3]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[4]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[5]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[6]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[7]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[8]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[9]'
                                             "Cross flow areas at segment boundaries";
        Modelica.SIunits.Area 'crossAreas[10]'
                                              "Cross flow areas at segment boundaries";
        Modelica.SIunits.Length 'dimensions[1]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[2]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[3]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[4]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[5]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[6]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[7]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[8]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[9]'
                                               "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Length 'dimensions[10]'
                                                "Characteristic dimensions for fluid flow (diameters for pipe flow)";
        Modelica.SIunits.Height 'roughnesses[1]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[2]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[3]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[4]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[5]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[6]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[7]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[8]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[9]'
                                                "Average height of surface asperities";
        Modelica.SIunits.Height 'roughnesses[10]'
                                                 "Average height of surface asperities";
        constant Modelica.SIunits.Length 'dheights[1]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[2]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[3]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[4]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[5]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[6]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[7]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[8]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        constant Modelica.SIunits.Length 'dheights[9]' = 0.0
                                                            "Height(states[2:n]) - Height(states[1:n-1])";
        parameter Modelica.SIunits.Acceleration g(fixed=false)
                                                              "Constant gravity acceleration";
        constant Boolean allowFlowReversal = true
                                                 "= true to allow flow reversal, false restricts to design direction (states[1] -> states[n+1])";
        constant Modelica.Fluid.Types.Dynamics momentumDynamics = Modelica.Fluid.Types.Dynamics.SteadyState
                                                                                                           "Formulation of momentum balance";
        constant Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow_start(quantity = "MassFlowRate.Air") = 0.0
                                                                                                                       "Start value of mass flow rates";
        constant Modelica.Media.Interfaces.Types.AbsolutePressure p_a_start(nominal = 1000000.0) = 101325.0
                                                                                                           "Start value for p[1] at design inflow";
        constant Modelica.Media.Interfaces.Types.AbsolutePressure p_b_start(nominal = 1000000.0) = 101325.0
                                                                                                           "Start value for p[n+1] at design outflow";
        constant Integer m = 9
                              "Number of flow segments";
        constant Modelica.SIunits.Length 'pathLengths[1]' = 1.5
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[2]' = 1.0
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[3]' = 1.0
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[4]' = 1.0
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[5]' = 1.0
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[6]' = 1.0
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[7]' = 1.0
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[8]' = 1.0
                                                               "Lengths along flow path";
        constant Modelica.SIunits.Length 'pathLengths[9]' = 1.5
                                                               "Lengths along flow path";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[1]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[2]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[3]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[4]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[5]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[6]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[7]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[8]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[9]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                       "mass flow rates between states";
        Modelica.SIunits.Momentum 'Is[1]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[2]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[3]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[4]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[5]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[6]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[7]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[8]'
                                         "Momenta of flow segments";
        Modelica.SIunits.Momentum 'Is[9]'
                                         "Momenta of flow segments";
        constant Modelica.SIunits.Force 'Ib_flows[1]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[2]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[3]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[4]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[5]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[6]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[7]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[8]' = 0.0
                                                           "Flow of momentum across boundaries";
        constant Modelica.SIunits.Force 'Ib_flows[9]' = 0.0
                                                           "Flow of momentum across boundaries";
        Modelica.SIunits.Force 'Fs_p[1]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[2]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[3]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[4]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[5]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[6]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[7]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[8]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_p[9]'
                                        "Pressure forces";
        Modelica.SIunits.Force 'Fs_fg[1]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[2]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[3]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[4]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[5]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[6]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[7]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[8]'
                                         "Friction and gravity forces";
        Modelica.SIunits.Force 'Fs_fg[9]'
                                         "Friction and gravity forces";
        constant Boolean useUpstreamScheme = true
                                                 "= false to average upstream and downstream properties across flow segments";
        constant Boolean use_Ib_flows = false
                                             "= true to consider differences in flow of momentum through boundaries";
        Modelica.Media.Interfaces.Types.Density 'rhos[1]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[2]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[3]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[4]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[5]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[6]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[7]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[8]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[9]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos[10]'(nominal = 10.0);
        Modelica.Media.Interfaces.Types.Density 'rhos_act[1]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[2]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[3]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[4]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[5]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[6]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[7]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[8]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.Density 'rhos_act[9]'(nominal = 10.0)
                                                                             "Actual density per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[1]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[2]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[3]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[4]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[5]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[6]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[7]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[8]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[9]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus[10]';
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[1]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[2]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[3]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[4]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[5]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[6]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[7]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[8]'
                                                                     "Actual viscosity per segment";
        Modelica.Media.Interfaces.Types.DynamicViscosity 'mus_act[9]'
                                                                     "Actual viscosity per segment";
        Modelica.SIunits.Pressure 'dps_fg[1]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[2]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[3]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[4]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[5]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[6]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[7]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[8]'
                                             "pressure drop between states";
        Modelica.SIunits.Pressure 'dps_fg[9]'
                                             "pressure drop between states";
        constant Modelica.SIunits.ReynoldsNumber Re_turbulent = 4000
                                                                    "Start of turbulent regime, depending on type of flow device";
        constant Boolean show_Res = false
                                         "= true, if Reynolds numbers are included for plotting";
        constant Modelica.SIunits.Length 'pathLengths_internal[1]' = 1.5
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[2]' = 1.0
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[3]' = 1.0
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[4]' = 1.0
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[5]' = 1.0
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[6]' = 1.0
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[7]' = 1.0
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[8]' = 1.0
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.Length 'pathLengths_internal[9]' = 1.5
                                                                        "pathLengths used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[1]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[2]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[3]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[4]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[5]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[6]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[7]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[8]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        constant Modelica.SIunits.ReynoldsNumber 'Res_turbulent_internal[9]' = 4000
                                                                                   "Re_turbulent used internally; to be defined by extending class";
        parameter Modelica.SIunits.AbsolutePressure dp_nominal(fixed=false)
                                                                           "Nominal pressure loss (only for nominal models)";
        parameter Modelica.SIunits.MassFlowRate m_flow_nominal(fixed=false)
                                                                           "Nominal mass flow rate";
        parameter Modelica.SIunits.MassFlowRate m_flow_small(fixed=false)
                                                                         "Within regularization if |m_flows| < m_flow_small (may be wider for large discontinuities in static head)";
      end flowModel_rec;
    public
      flowModel_rec flowModel;
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[1]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[2]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[3]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[4]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[5]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[6]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[7]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[8]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[9]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                     "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[10]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                      "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate 'm_flows[11]'(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                      "Mass flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[1]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[2]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[3]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[4]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[5]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[6]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[7]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[8]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[9]'
                                                                   "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[10]'
                                                                    "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.Media.Interfaces.Types.EnthalpyFlowRate 'H_flows[11]'
                                                                    "Enthalpy flow rates of fluid across segment boundaries";
      Modelica.SIunits.Velocity 'vs[1]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[2]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[3]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[4]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[5]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[6]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[7]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[8]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[9]'
                                       "mean velocities in flow segments";
      Modelica.SIunits.Velocity 'vs[10]'
                                        "mean velocities in flow segments";
      constant Boolean use_HeatTransfer = true
                                              "= true to use the HeatTransfer model";
    protected
      record 'heatPorts[1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[1]_rec';
    public
      'heatPorts[1]_rec' 'heatPorts[1]';
    protected
      record 'heatPorts[2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[2]_rec';
    public
      'heatPorts[2]_rec' 'heatPorts[2]';
    protected
      record 'heatPorts[3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[3]_rec';
    public
      'heatPorts[3]_rec' 'heatPorts[3]';
    protected
      record 'heatPorts[4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[4]_rec';
    public
      'heatPorts[4]_rec' 'heatPorts[4]';
    protected
      record 'heatPorts[5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[5]_rec';
    public
      'heatPorts[5]_rec' 'heatPorts[5]';
    protected
      record 'heatPorts[6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[6]_rec';
    public
      'heatPorts[6]_rec' 'heatPorts[6]';
    protected
      record 'heatPorts[7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[7]_rec';
    public
      'heatPorts[7]_rec' 'heatPorts[7]';
    protected
      record 'heatPorts[8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[8]_rec';
    public
      'heatPorts[8]_rec' 'heatPorts[8]';
    protected
      record 'heatPorts[9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[9]_rec';
    public
      'heatPorts[9]_rec' 'heatPorts[9]';
    protected
      record 'heatPorts[10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'heatPorts[10]_rec';
    public
      'heatPorts[10]_rec' 'heatPorts[10]';
    protected
      record heatTransfer_rec
        constant Integer n = 10
                               "Number of heat transfer segments";
      protected
        record 'states[1]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[1]_rec';
      public
        'states[1]_rec' 'states[1]';
      protected
        record 'states[2]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[2]_rec';
      public
        'states[2]_rec' 'states[2]';
      protected
        record 'states[3]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[3]_rec';
      public
        'states[3]_rec' 'states[3]';
      protected
        record 'states[4]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[4]_rec';
      public
        'states[4]_rec' 'states[4]';
      protected
        record 'states[5]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[5]_rec';
      public
        'states[5]_rec' 'states[5]';
      protected
        record 'states[6]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[6]_rec';
      public
        'states[6]_rec' 'states[6]';
      protected
        record 'states[7]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[7]_rec';
      public
        'states[7]_rec' 'states[7]';
      protected
        record 'states[8]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[8]_rec';
      public
        'states[8]_rec' 'states[8]';
      protected
        record 'states[9]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[9]_rec';
      public
        'states[9]_rec' 'states[9]';
      protected
        record 'states[10]_rec'
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end 'states[10]_rec';
      public
        'states[10]_rec' 'states[10]';
        Modelica.SIunits.Area 'surfaceAreas[1]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[2]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[3]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[4]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[5]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[6]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[7]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[8]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[9]'
                                               "Heat transfer areas";
        Modelica.SIunits.Area 'surfaceAreas[10]'
                                                "Heat transfer areas";
        Modelica.SIunits.HeatFlowRate 'Q_flows[1]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[2]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[3]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[4]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[5]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[6]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[7]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[8]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[9]'
                                                  "Heat flow rates";
        Modelica.SIunits.HeatFlowRate 'Q_flows[10]'
                                                   "Heat flow rates";
        constant Boolean use_k = true
                                     "= true to use k value for thermal isolation";
        constant Modelica.SIunits.CoefficientOfHeatTransfer k = 0
                                                                 "Heat transfer coefficient to ambient";
        parameter Modelica.SIunits.Temperature T_ambient(fixed=false)
                                                                     "Ambient temperature";
      protected
        record 'heatPorts[1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[1]_rec';
      public
        'heatPorts[1]_rec' 'heatPorts[1]';
      protected
        record 'heatPorts[2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[2]_rec';
      public
        'heatPorts[2]_rec' 'heatPorts[2]';
      protected
        record 'heatPorts[3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[3]_rec';
      public
        'heatPorts[3]_rec' 'heatPorts[3]';
      protected
        record 'heatPorts[4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[4]_rec';
      public
        'heatPorts[4]_rec' 'heatPorts[4]';
      protected
        record 'heatPorts[5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[5]_rec';
      public
        'heatPorts[5]_rec' 'heatPorts[5]';
      protected
        record 'heatPorts[6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[6]_rec';
      public
        'heatPorts[6]_rec' 'heatPorts[6]';
      protected
        record 'heatPorts[7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[7]_rec';
      public
        'heatPorts[7]_rec' 'heatPorts[7]';
      protected
        record 'heatPorts[8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[8]_rec';
      public
        'heatPorts[8]_rec' 'heatPorts[8]';
      protected
        record 'heatPorts[9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[9]_rec';
      public
        'heatPorts[9]_rec' 'heatPorts[9]';
      protected
        record 'heatPorts[10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'heatPorts[10]_rec';
      public
        'heatPorts[10]_rec' 'heatPorts[10]';
        Modelica.SIunits.Temperature 'Ts[1]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[2]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[3]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[4]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[5]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[6]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[7]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[8]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[9]'
                                            "Temperatures defined by fluid states";
        Modelica.SIunits.Temperature 'Ts[10]'
                                             "Temperatures defined by fluid states";
        Modelica.SIunits.Velocity 'vs[1]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[2]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[3]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[4]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[5]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[6]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[7]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[8]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[9]'
                                         "Mean velocities of fluid flow in segments";
        Modelica.SIunits.Velocity 'vs[10]'
                                          "Mean velocities of fluid flow in segments";
        constant Real nParallel(unit = "1") = 10.0
                                                  "number of identical parallel flow devices";
        constant Modelica.SIunits.Length 'lengths[1]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[2]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[3]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[4]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[5]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[6]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[7]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[8]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[9]' = 1.0
                                                           "Lengths along flow path";
        constant Modelica.SIunits.Length 'lengths[10]' = 1.0
                                                            "Lengths along flow path";
        Modelica.SIunits.Length 'dimensions[1]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[2]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[3]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[4]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[5]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[6]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[7]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[8]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[9]'
                                               "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Length 'dimensions[10]'
                                                "Characteristic dimensions for fluid flow (diameter for pipe flow)";
        Modelica.SIunits.Height 'roughnesses[1]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[2]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[3]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[4]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[5]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[6]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[7]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[8]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[9]'
                                                "Average heights of surface asperities";
        Modelica.SIunits.Height 'roughnesses[10]'
                                                 "Average heights of surface asperities";
      end heatTransfer_rec;
    public
      heatTransfer_rec heatTransfer;
      constant Real 'dxs[1]'(unit = "1") = 0.1;
      constant Real 'dxs[2]'(unit = "1") = 0.1;
      constant Real 'dxs[3]'(unit = "1") = 0.1;
      constant Real 'dxs[4]'(unit = "1") = 0.1;
      constant Real 'dxs[5]'(unit = "1") = 0.1;
      constant Real 'dxs[6]'(unit = "1") = 0.1;
      constant Real 'dxs[7]'(unit = "1") = 0.1;
      constant Real 'dxs[8]'(unit = "1") = 0.1;
      constant Real 'dxs[9]'(unit = "1") = 0.1;
      constant Real 'dxs[10]'(unit = "1") = 0.1;
    protected
      record 'mediums[1]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[1]_rec';
    public
      'mediums[1]_rec' 'mediums[1]' annotation(Dialog);
    protected
      record 'mediums[2]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[2]_rec';
    public
      'mediums[2]_rec' 'mediums[2]' annotation(Dialog);
    protected
      record 'mediums[3]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[3]_rec';
    public
      'mediums[3]_rec' 'mediums[3]' annotation(Dialog);
    protected
      record 'mediums[4]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[4]_rec';
    public
      'mediums[4]_rec' 'mediums[4]' annotation(Dialog);
    protected
      record 'mediums[5]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[5]_rec';
    public
      'mediums[5]_rec' 'mediums[5]' annotation(Dialog);
    protected
      record 'mediums[6]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[6]_rec';
    public
      'mediums[6]_rec' 'mediums[6]' annotation(Dialog);
    protected
      record 'mediums[7]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[7]_rec';
    public
      'mediums[7]_rec' 'mediums[7]' annotation(Dialog);
    protected
      record 'mediums[8]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[8]_rec';
    public
      'mediums[8]_rec' 'mediums[8]' annotation(Dialog);
    protected
      record 'mediums[9]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Real h_der(unit = "m2/s3")
                                  "der(Specific enthalpy of medium)";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[9]_rec';
    public
      'mediums[9]_rec' 'mediums[9]' annotation(Dialog);
    protected
      record 'mediums[10]_rec'
        Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0, max = 100000000.0)
                                                                                                                         "Absolute pressure of medium";
        Real p_der(unit = "Pa/s")
                                 "der(Absolute pressure of medium)";
        Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                          "Specific enthalpy of medium";
        Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                                 "Density of medium";
        Real d_der(unit = "Pa.m-2.s")
                                     "der(Density of medium)";
        parameter Modelica.Media.Interfaces.Types.Temperature _T_start = 258.15;
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0,start = _T_start)
                                                                                                                  "Temperature of medium";
        Real T_der(unit = "K/s")
                                "der(Temperature of medium)";
        constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                          "Mass fractions (= (component mass)/total mass  m_i/m)";
        Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                                "Specific internal energy of medium";
        Real u_der(unit = "m2/s3")
                                  "der(Specific internal energy of medium)";
        constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                           "Gas constant (of mixture if applicable)";
        constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                            "Molar mass (of mixture or single fluid)";
      protected
        record state_rec
          Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                                 "Absolute pressure of medium";
          Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                   "Temperature of medium";
        end state_rec;
      public
        state_rec state;
        constant Boolean preferredMediumStates = true
                                                     "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
        constant Boolean standardOrderComponents = true
                                                       "If true, and reducedX = true, the last element of X will be computed from the other ones";
        Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                       "Temperature of medium in [degC]";
        Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                  "Absolute pressure of medium in [bar]";
      end 'mediums[10]_rec';
    public
      'mediums[10]_rec' 'mediums[10]' annotation(Dialog);
    end pipe_rec;
  public
    pipe_rec pipe annotation(Dialog);
  protected
    record port_b_Tambient_rec
      Modelica.SIunits.Temperature T
                                    "Port temperature";
      Modelica.SIunits.HeatFlowRate Q_flow
                                          "Heat flow rate (positive if flowing from outside into the component)";
    end port_b_Tambient_rec;
  public
    port_b_Tambient_rec port_b_Tambient;
  protected
    record volumeFlowRate_rec
      constant Boolean allowFlowReversal = true
                                               "= true to allow flow reversal, false restricts to design direction (port_a -> port_b)";
    protected
      record port_a_rec
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                                 "Mass flow rate from the connection point into the component";
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Thermodynamic pressure in the connection point";
        Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0)
                                                                                      "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
      end port_a_rec;
    public
      port_a_rec port_a;
    protected
      record port_b_rec
        Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", max = 1E+060)
                                                                                                                "Mass flow rate from the connection point into the component";
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Thermodynamic pressure in the connection point";
        Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0)
                                                                                      "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
      end port_b_rec;
    public
      port_b_rec port_b;
      constant Modelica.Media.Interfaces.Types.AbsolutePressure dp_start(nominal = 1000000.0, min = -1E+060) = 1013.25
                                                                                                                      "Guess value of dp = port_a.p - port_b.p";
      constant Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow_start(quantity = "MassFlowRate.Air") = 0.0
                                                                                                                     "Guess value of m_flow = port_a.m_flow";
      parameter Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow_small(quantity = "MassFlowRate.Air", fixed=false)
                                                                                                                             "Small mass flow rate for regularization of zero flow";
      constant Boolean show_T = true
                                    "= true, if temperatures at port_a and port_b are computed";
      constant Boolean show_V_flow = true
                                         "= true, if volume flow rate at inflowing port is computed";
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = -1E+060)
                                                                                                               "Mass flow rate in design flow direction";
      Modelica.SIunits.Pressure dp
                                  "Pressure difference between port_a and port_b (= port_a.p - port_b.p)";
      Modelica.SIunits.VolumeFlowRate V_flow
                                            "Volume flow rate at inflowing port (positive when flow from port_a to port_b)";
      Modelica.Media.Interfaces.Types.Temperature port_a_T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                      "Temperature close to port_a, if show_T = true";
      Modelica.Media.Interfaces.Types.Temperature port_b_T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                      "Temperature close to port_b, if show_T = true";
      parameter Real a(unit = "(Pa.s2)/m6", fixed=false)
                                                        "Coefficient for quadratic term";
      parameter Real b(unit = "(Pa.s)/m3", fixed=false)
                                                       "Coefficient for linear term";
    end volumeFlowRate_rec;
  public
    volumeFlowRate_rec volumeFlowRate;
  protected
    record 'tubeToPCM[1]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[1]_rec';
  public
    'tubeToPCM[1]_rec' 'tubeToPCM[1]';
  protected
    record 'tubeToPCM[2]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[2]_rec';
  public
    'tubeToPCM[2]_rec' 'tubeToPCM[2]';
  protected
    record 'tubeToPCM[3]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[3]_rec';
  public
    'tubeToPCM[3]_rec' 'tubeToPCM[3]';
  protected
    record 'tubeToPCM[4]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[4]_rec';
  public
    'tubeToPCM[4]_rec' 'tubeToPCM[4]';
  protected
    record 'tubeToPCM[5]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[5]_rec';
  public
    'tubeToPCM[5]_rec' 'tubeToPCM[5]';
  protected
    record 'tubeToPCM[6]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[6]_rec';
  public
    'tubeToPCM[6]_rec' 'tubeToPCM[6]';
  protected
    record 'tubeToPCM[7]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[7]_rec';
  public
    'tubeToPCM[7]_rec' 'tubeToPCM[7]';
  protected
    record 'tubeToPCM[8]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[8]_rec';
  public
    'tubeToPCM[8]_rec' 'tubeToPCM[8]';
  protected
    record 'tubeToPCM[9]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[9]_rec';
  public
    'tubeToPCM[9]_rec' 'tubeToPCM[9]';
  protected
    record 'tubeToPCM[10]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'tubeToPCM[10]_rec';
  public
    'tubeToPCM[10]_rec' 'tubeToPCM[10]';
  protected
    record 'HTFtoTube[1]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[1]_rec';
  public
    'HTFtoTube[1]_rec' 'HTFtoTube[1]';
  protected
    record 'HTFtoTube[2]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[2]_rec';
  public
    'HTFtoTube[2]_rec' 'HTFtoTube[2]';
  protected
    record 'HTFtoTube[3]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[3]_rec';
  public
    'HTFtoTube[3]_rec' 'HTFtoTube[3]';
  protected
    record 'HTFtoTube[4]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[4]_rec';
  public
    'HTFtoTube[4]_rec' 'HTFtoTube[4]';
  protected
    record 'HTFtoTube[5]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[5]_rec';
  public
    'HTFtoTube[5]_rec' 'HTFtoTube[5]';
  protected
    record 'HTFtoTube[6]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[6]_rec';
  public
    'HTFtoTube[6]_rec' 'HTFtoTube[6]';
  protected
    record 'HTFtoTube[7]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[7]_rec';
  public
    'HTFtoTube[7]_rec' 'HTFtoTube[7]';
  protected
    record 'HTFtoTube[8]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[8]_rec';
  public
    'HTFtoTube[8]_rec' 'HTFtoTube[8]';
  protected
    record 'HTFtoTube[9]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[9]_rec';
  public
    'HTFtoTube[9]_rec' 'HTFtoTube[9]';
  protected
    record 'HTFtoTube[10]_rec'
      Modelica_Blocks_Interfaces_RealOutput y(unit = "W/K")
                                                           "Value of Real output";
    end 'HTFtoTube[10]_rec';
  public
    'HTFtoTube[10]_rec' 'HTFtoTube[10]';
  protected
    record port_b_Tfloor_rec
      Modelica.SIunits.Temperature T
                                    "Port temperature";
      Modelica.SIunits.HeatFlowRate Q_flow
                                          "Heat flow rate (positive if flowing from outside into the component)";
    end port_b_Tfloor_rec;
  public
    port_b_Tfloor_rec port_b_Tfloor;
  protected
    record storageWall_rec
      constant Integer nCoil = 10
                                 "Number of coils";
      constant Integer nSeg = 10
                                "Number of segments of each coil";
      parameter Modelica.SIunits.Temperature T_Wall_start(fixed=false)
                                                                      "Start temperature of the storage walls";
      parameter Modelica.SIunits.Length h(fixed=false)
                                                      "Height of the storage";
      parameter Modelica.SIunits.Length w(fixed=false)
                                                      "Width of the storage";
      constant Modelica.SIunits.Length l = 10.0
                                               "Length of the storage";
      parameter Modelica.SIunits.Length e(fixed=false)
                                                      "Thicknes of the storages wall";
    protected
      record 'sideInertia[1]_rec'
        Modelica.SIunits.Temperature T
                                      "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end 'sideInertia[1]_rec';
    public
      'sideInertia[1]_rec' 'sideInertia[1]' annotation(Dialog);
    protected
      record 'sideInertia[2]_rec'
        Modelica.SIunits.Temperature T
                                      "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end 'sideInertia[2]_rec';
    public
      'sideInertia[2]_rec' 'sideInertia[2]' annotation(Dialog);
    protected
      record 'topInertia[1]_rec'
        Modelica.SIunits.Temperature T
                                      "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end 'topInertia[1]_rec';
    public
      'topInertia[1]_rec' 'topInertia[1]' annotation(Dialog);
    protected
      record 'topInertia[2]_rec'
        Modelica.SIunits.Temperature T
                                      "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end 'topInertia[2]_rec';
    public
      'topInertia[2]_rec' 'topInertia[2]' annotation(Dialog);
    protected
      record 'sideCond2[1]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'sideCond2[1]_rec';
    public
      'sideCond2[1]_rec' 'sideCond2[1]' annotation(Dialog);
    protected
      record 'sideCond2[2]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'sideCond2[2]_rec';
    public
      'sideCond2[2]_rec' 'sideCond2[2]' annotation(Dialog);
    protected
      record 'sideCond1[1]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'sideCond1[1]_rec';
    public
      'sideCond1[1]_rec' 'sideCond1[1]' annotation(Dialog);
    protected
      record 'sideCond1[2]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'sideCond1[2]_rec';
    public
      'sideCond1[2]_rec' 'sideCond1[2]' annotation(Dialog);
    protected
      record 'topCond1[1]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'topCond1[1]_rec';
    public
      'topCond1[1]_rec' 'topCond1[1]' annotation(Dialog);
    protected
      record 'topCond1[2]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'topCond1[2]_rec';
    public
      'topCond1[2]_rec' 'topCond1[2]' annotation(Dialog);
    protected
      record 'topCond2[1]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'topCond2[1]_rec';
    public
      'topCond2[1]_rec' 'topCond2[1]' annotation(Dialog);
    protected
      record 'topCond2[2]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'topCond2[2]_rec';
    public
      'topCond2[2]_rec' 'topCond2[2]' annotation(Dialog);
    protected
      record 'T_PCM[1, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 1]_rec';
    public
      'T_PCM[1, 1]_rec' 'T_PCM[1, 1]';
    protected
      record 'T_PCM[1, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 2]_rec';
    public
      'T_PCM[1, 2]_rec' 'T_PCM[1, 2]';
    protected
      record 'T_PCM[1, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 3]_rec';
    public
      'T_PCM[1, 3]_rec' 'T_PCM[1, 3]';
    protected
      record 'T_PCM[1, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 4]_rec';
    public
      'T_PCM[1, 4]_rec' 'T_PCM[1, 4]';
    protected
      record 'T_PCM[1, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 5]_rec';
    public
      'T_PCM[1, 5]_rec' 'T_PCM[1, 5]';
    protected
      record 'T_PCM[1, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 6]_rec';
    public
      'T_PCM[1, 6]_rec' 'T_PCM[1, 6]';
    protected
      record 'T_PCM[1, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 7]_rec';
    public
      'T_PCM[1, 7]_rec' 'T_PCM[1, 7]';
    protected
      record 'T_PCM[1, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 8]_rec';
    public
      'T_PCM[1, 8]_rec' 'T_PCM[1, 8]';
    protected
      record 'T_PCM[1, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 9]_rec';
    public
      'T_PCM[1, 9]_rec' 'T_PCM[1, 9]';
    protected
      record 'T_PCM[1, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[1, 10]_rec';
    public
      'T_PCM[1, 10]_rec' 'T_PCM[1, 10]';
    protected
      record 'T_PCM[2, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 1]_rec';
    public
      'T_PCM[2, 1]_rec' 'T_PCM[2, 1]';
    protected
      record 'T_PCM[2, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 2]_rec';
    public
      'T_PCM[2, 2]_rec' 'T_PCM[2, 2]';
    protected
      record 'T_PCM[2, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 3]_rec';
    public
      'T_PCM[2, 3]_rec' 'T_PCM[2, 3]';
    protected
      record 'T_PCM[2, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 4]_rec';
    public
      'T_PCM[2, 4]_rec' 'T_PCM[2, 4]';
    protected
      record 'T_PCM[2, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 5]_rec';
    public
      'T_PCM[2, 5]_rec' 'T_PCM[2, 5]';
    protected
      record 'T_PCM[2, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 6]_rec';
    public
      'T_PCM[2, 6]_rec' 'T_PCM[2, 6]';
    protected
      record 'T_PCM[2, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 7]_rec';
    public
      'T_PCM[2, 7]_rec' 'T_PCM[2, 7]';
    protected
      record 'T_PCM[2, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 8]_rec';
    public
      'T_PCM[2, 8]_rec' 'T_PCM[2, 8]';
    protected
      record 'T_PCM[2, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 9]_rec';
    public
      'T_PCM[2, 9]_rec' 'T_PCM[2, 9]';
    protected
      record 'T_PCM[2, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[2, 10]_rec';
    public
      'T_PCM[2, 10]_rec' 'T_PCM[2, 10]';
    protected
      record 'T_PCM[3, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 1]_rec';
    public
      'T_PCM[3, 1]_rec' 'T_PCM[3, 1]';
    protected
      record 'T_PCM[3, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 2]_rec';
    public
      'T_PCM[3, 2]_rec' 'T_PCM[3, 2]';
    protected
      record 'T_PCM[3, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 3]_rec';
    public
      'T_PCM[3, 3]_rec' 'T_PCM[3, 3]';
    protected
      record 'T_PCM[3, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 4]_rec';
    public
      'T_PCM[3, 4]_rec' 'T_PCM[3, 4]';
    protected
      record 'T_PCM[3, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 5]_rec';
    public
      'T_PCM[3, 5]_rec' 'T_PCM[3, 5]';
    protected
      record 'T_PCM[3, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 6]_rec';
    public
      'T_PCM[3, 6]_rec' 'T_PCM[3, 6]';
    protected
      record 'T_PCM[3, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 7]_rec';
    public
      'T_PCM[3, 7]_rec' 'T_PCM[3, 7]';
    protected
      record 'T_PCM[3, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 8]_rec';
    public
      'T_PCM[3, 8]_rec' 'T_PCM[3, 8]';
    protected
      record 'T_PCM[3, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 9]_rec';
    public
      'T_PCM[3, 9]_rec' 'T_PCM[3, 9]';
    protected
      record 'T_PCM[3, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[3, 10]_rec';
    public
      'T_PCM[3, 10]_rec' 'T_PCM[3, 10]';
    protected
      record 'T_PCM[4, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 1]_rec';
    public
      'T_PCM[4, 1]_rec' 'T_PCM[4, 1]';
    protected
      record 'T_PCM[4, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 2]_rec';
    public
      'T_PCM[4, 2]_rec' 'T_PCM[4, 2]';
    protected
      record 'T_PCM[4, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 3]_rec';
    public
      'T_PCM[4, 3]_rec' 'T_PCM[4, 3]';
    protected
      record 'T_PCM[4, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 4]_rec';
    public
      'T_PCM[4, 4]_rec' 'T_PCM[4, 4]';
    protected
      record 'T_PCM[4, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 5]_rec';
    public
      'T_PCM[4, 5]_rec' 'T_PCM[4, 5]';
    protected
      record 'T_PCM[4, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 6]_rec';
    public
      'T_PCM[4, 6]_rec' 'T_PCM[4, 6]';
    protected
      record 'T_PCM[4, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 7]_rec';
    public
      'T_PCM[4, 7]_rec' 'T_PCM[4, 7]';
    protected
      record 'T_PCM[4, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 8]_rec';
    public
      'T_PCM[4, 8]_rec' 'T_PCM[4, 8]';
    protected
      record 'T_PCM[4, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 9]_rec';
    public
      'T_PCM[4, 9]_rec' 'T_PCM[4, 9]';
    protected
      record 'T_PCM[4, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[4, 10]_rec';
    public
      'T_PCM[4, 10]_rec' 'T_PCM[4, 10]';
    protected
      record 'T_PCM[5, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 1]_rec';
    public
      'T_PCM[5, 1]_rec' 'T_PCM[5, 1]';
    protected
      record 'T_PCM[5, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 2]_rec';
    public
      'T_PCM[5, 2]_rec' 'T_PCM[5, 2]';
    protected
      record 'T_PCM[5, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 3]_rec';
    public
      'T_PCM[5, 3]_rec' 'T_PCM[5, 3]';
    protected
      record 'T_PCM[5, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 4]_rec';
    public
      'T_PCM[5, 4]_rec' 'T_PCM[5, 4]';
    protected
      record 'T_PCM[5, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 5]_rec';
    public
      'T_PCM[5, 5]_rec' 'T_PCM[5, 5]';
    protected
      record 'T_PCM[5, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 6]_rec';
    public
      'T_PCM[5, 6]_rec' 'T_PCM[5, 6]';
    protected
      record 'T_PCM[5, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 7]_rec';
    public
      'T_PCM[5, 7]_rec' 'T_PCM[5, 7]';
    protected
      record 'T_PCM[5, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 8]_rec';
    public
      'T_PCM[5, 8]_rec' 'T_PCM[5, 8]';
    protected
      record 'T_PCM[5, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 9]_rec';
    public
      'T_PCM[5, 9]_rec' 'T_PCM[5, 9]';
    protected
      record 'T_PCM[5, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[5, 10]_rec';
    public
      'T_PCM[5, 10]_rec' 'T_PCM[5, 10]';
    protected
      record 'T_PCM[6, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 1]_rec';
    public
      'T_PCM[6, 1]_rec' 'T_PCM[6, 1]';
    protected
      record 'T_PCM[6, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 2]_rec';
    public
      'T_PCM[6, 2]_rec' 'T_PCM[6, 2]';
    protected
      record 'T_PCM[6, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 3]_rec';
    public
      'T_PCM[6, 3]_rec' 'T_PCM[6, 3]';
    protected
      record 'T_PCM[6, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 4]_rec';
    public
      'T_PCM[6, 4]_rec' 'T_PCM[6, 4]';
    protected
      record 'T_PCM[6, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 5]_rec';
    public
      'T_PCM[6, 5]_rec' 'T_PCM[6, 5]';
    protected
      record 'T_PCM[6, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 6]_rec';
    public
      'T_PCM[6, 6]_rec' 'T_PCM[6, 6]';
    protected
      record 'T_PCM[6, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 7]_rec';
    public
      'T_PCM[6, 7]_rec' 'T_PCM[6, 7]';
    protected
      record 'T_PCM[6, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 8]_rec';
    public
      'T_PCM[6, 8]_rec' 'T_PCM[6, 8]';
    protected
      record 'T_PCM[6, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 9]_rec';
    public
      'T_PCM[6, 9]_rec' 'T_PCM[6, 9]';
    protected
      record 'T_PCM[6, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[6, 10]_rec';
    public
      'T_PCM[6, 10]_rec' 'T_PCM[6, 10]';
    protected
      record 'T_PCM[7, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 1]_rec';
    public
      'T_PCM[7, 1]_rec' 'T_PCM[7, 1]';
    protected
      record 'T_PCM[7, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 2]_rec';
    public
      'T_PCM[7, 2]_rec' 'T_PCM[7, 2]';
    protected
      record 'T_PCM[7, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 3]_rec';
    public
      'T_PCM[7, 3]_rec' 'T_PCM[7, 3]';
    protected
      record 'T_PCM[7, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 4]_rec';
    public
      'T_PCM[7, 4]_rec' 'T_PCM[7, 4]';
    protected
      record 'T_PCM[7, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 5]_rec';
    public
      'T_PCM[7, 5]_rec' 'T_PCM[7, 5]';
    protected
      record 'T_PCM[7, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 6]_rec';
    public
      'T_PCM[7, 6]_rec' 'T_PCM[7, 6]';
    protected
      record 'T_PCM[7, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 7]_rec';
    public
      'T_PCM[7, 7]_rec' 'T_PCM[7, 7]';
    protected
      record 'T_PCM[7, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 8]_rec';
    public
      'T_PCM[7, 8]_rec' 'T_PCM[7, 8]';
    protected
      record 'T_PCM[7, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 9]_rec';
    public
      'T_PCM[7, 9]_rec' 'T_PCM[7, 9]';
    protected
      record 'T_PCM[7, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[7, 10]_rec';
    public
      'T_PCM[7, 10]_rec' 'T_PCM[7, 10]';
    protected
      record 'T_PCM[8, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 1]_rec';
    public
      'T_PCM[8, 1]_rec' 'T_PCM[8, 1]';
    protected
      record 'T_PCM[8, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 2]_rec';
    public
      'T_PCM[8, 2]_rec' 'T_PCM[8, 2]';
    protected
      record 'T_PCM[8, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 3]_rec';
    public
      'T_PCM[8, 3]_rec' 'T_PCM[8, 3]';
    protected
      record 'T_PCM[8, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 4]_rec';
    public
      'T_PCM[8, 4]_rec' 'T_PCM[8, 4]';
    protected
      record 'T_PCM[8, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 5]_rec';
    public
      'T_PCM[8, 5]_rec' 'T_PCM[8, 5]';
    protected
      record 'T_PCM[8, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 6]_rec';
    public
      'T_PCM[8, 6]_rec' 'T_PCM[8, 6]';
    protected
      record 'T_PCM[8, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 7]_rec';
    public
      'T_PCM[8, 7]_rec' 'T_PCM[8, 7]';
    protected
      record 'T_PCM[8, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 8]_rec';
    public
      'T_PCM[8, 8]_rec' 'T_PCM[8, 8]';
    protected
      record 'T_PCM[8, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 9]_rec';
    public
      'T_PCM[8, 9]_rec' 'T_PCM[8, 9]';
    protected
      record 'T_PCM[8, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[8, 10]_rec';
    public
      'T_PCM[8, 10]_rec' 'T_PCM[8, 10]';
    protected
      record 'T_PCM[9, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 1]_rec';
    public
      'T_PCM[9, 1]_rec' 'T_PCM[9, 1]';
    protected
      record 'T_PCM[9, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 2]_rec';
    public
      'T_PCM[9, 2]_rec' 'T_PCM[9, 2]';
    protected
      record 'T_PCM[9, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 3]_rec';
    public
      'T_PCM[9, 3]_rec' 'T_PCM[9, 3]';
    protected
      record 'T_PCM[9, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 4]_rec';
    public
      'T_PCM[9, 4]_rec' 'T_PCM[9, 4]';
    protected
      record 'T_PCM[9, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 5]_rec';
    public
      'T_PCM[9, 5]_rec' 'T_PCM[9, 5]';
    protected
      record 'T_PCM[9, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 6]_rec';
    public
      'T_PCM[9, 6]_rec' 'T_PCM[9, 6]';
    protected
      record 'T_PCM[9, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 7]_rec';
    public
      'T_PCM[9, 7]_rec' 'T_PCM[9, 7]';
    protected
      record 'T_PCM[9, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 8]_rec';
    public
      'T_PCM[9, 8]_rec' 'T_PCM[9, 8]';
    protected
      record 'T_PCM[9, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 9]_rec';
    public
      'T_PCM[9, 9]_rec' 'T_PCM[9, 9]';
    protected
      record 'T_PCM[9, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[9, 10]_rec';
    public
      'T_PCM[9, 10]_rec' 'T_PCM[9, 10]';
    protected
      record 'T_PCM[10, 1]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 1]_rec';
    public
      'T_PCM[10, 1]_rec' 'T_PCM[10, 1]';
    protected
      record 'T_PCM[10, 2]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 2]_rec';
    public
      'T_PCM[10, 2]_rec' 'T_PCM[10, 2]';
    protected
      record 'T_PCM[10, 3]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 3]_rec';
    public
      'T_PCM[10, 3]_rec' 'T_PCM[10, 3]';
    protected
      record 'T_PCM[10, 4]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 4]_rec';
    public
      'T_PCM[10, 4]_rec' 'T_PCM[10, 4]';
    protected
      record 'T_PCM[10, 5]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 5]_rec';
    public
      'T_PCM[10, 5]_rec' 'T_PCM[10, 5]';
    protected
      record 'T_PCM[10, 6]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 6]_rec';
    public
      'T_PCM[10, 6]_rec' 'T_PCM[10, 6]';
    protected
      record 'T_PCM[10, 7]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 7]_rec';
    public
      'T_PCM[10, 7]_rec' 'T_PCM[10, 7]';
    protected
      record 'T_PCM[10, 8]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 8]_rec';
    public
      'T_PCM[10, 8]_rec' 'T_PCM[10, 8]';
    protected
      record 'T_PCM[10, 9]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 9]_rec';
    public
      'T_PCM[10, 9]_rec' 'T_PCM[10, 9]';
    protected
      record 'T_PCM[10, 10]_rec'
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end 'T_PCM[10, 10]_rec';
    public
      'T_PCM[10, 10]_rec' 'T_PCM[10, 10]';
    protected
      record port_a_ambient_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_ambient_rec;
    public
      port_a_ambient_rec port_a_ambient;
    protected
      record 'frontInertia[1]_rec'
        Modelica.SIunits.Temperature T
                                      "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end 'frontInertia[1]_rec';
    public
      'frontInertia[1]_rec' 'frontInertia[1]' annotation(Dialog);
    protected
      record 'frontInertia[2]_rec'
        Modelica.SIunits.Temperature T
                                      "Temperature of element";
        Real T_der(unit = "K/s")
                                "der(Temperature of element)";
        Modelica.SIunits.HeatFlowRate Q_flow;
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of ellement";
      protected
        record port_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_rec;
      public
        port_rec port;
        parameter Modelica.SIunits.Volume V(fixed=false)
                                                        "Volume of element";
        parameter Modelica.SIunits.Mass m(fixed=false)
                                                      "Mass of element";
        Modelica.SIunits.TemperatureSlope der_T
                                               "Time derivative of temperature (= der(T))";
        Modelica.SIunits.HeatCapacity C
                                       "Heat capacity of element (= cp*m)";
        parameter Modelica.SIunits.TemperatureSlope der_T_start = 0
                                                                   "Start value ofime derivative of temperature (= der(T))";
      end 'frontInertia[2]_rec';
    public
      'frontInertia[2]_rec' 'frontInertia[2]' annotation(Dialog);
    protected
      record 'frontCond1[1]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'frontCond1[1]_rec';
    public
      'frontCond1[1]_rec' 'frontCond1[1]' annotation(Dialog);
    protected
      record 'frontCond1[2]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'frontCond1[2]_rec';
    public
      'frontCond1[2]_rec' 'frontCond1[2]' annotation(Dialog);
    protected
      record 'frontCond2[1]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'frontCond2[1]_rec';
    public
      'frontCond2[1]_rec' 'frontCond2[1]' annotation(Dialog);
    protected
      record 'frontCond2[2]_rec'
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate from port_a -> port_b";
        Modelica.SIunits.TemperatureDifference dT
                                                 "port_a.T - port_b.T";
      protected
        record port_a_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_a_rec;
      public
        port_a_rec port_a;
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
        Modelica.SIunits.Temperature T
                                      "Average temperature of element";
        parameter Modelica.SIunits.Temperature T_start = 293.15
                                                               "Start temperature for the average temperature of element";
        Modelica.SIunits.ThermalConductance G
                                             "Thermal conductance of material";
        Modelica.SIunits.ThermalConductivity k
                                              "Thermal conductivity";
        parameter Modelica.SIunits.Length L(fixed=false)
                                                        "length of conduction";
        parameter Modelica.SIunits.Area A(fixed=false)
                                                      "Heat transfer area";
      end 'frontCond2[2]_rec';
    public
      'frontCond2[2]_rec' 'frontCond2[2]' annotation(Dialog);
    protected
      record midTemperature_rec
        constant Integer m(min = 1) = 10
                                        "Number of collected heat flows";
        constant Integer n(min = 1) = 10
                                        "Number of collected heat flows";
      protected
        record 'port_a[1, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 1]_rec';
      public
        'port_a[1, 1]_rec' 'port_a[1, 1]';
      protected
        record 'port_a[1, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 2]_rec';
      public
        'port_a[1, 2]_rec' 'port_a[1, 2]';
      protected
        record 'port_a[1, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 3]_rec';
      public
        'port_a[1, 3]_rec' 'port_a[1, 3]';
      protected
        record 'port_a[1, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 4]_rec';
      public
        'port_a[1, 4]_rec' 'port_a[1, 4]';
      protected
        record 'port_a[1, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 5]_rec';
      public
        'port_a[1, 5]_rec' 'port_a[1, 5]';
      protected
        record 'port_a[1, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 6]_rec';
      public
        'port_a[1, 6]_rec' 'port_a[1, 6]';
      protected
        record 'port_a[1, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 7]_rec';
      public
        'port_a[1, 7]_rec' 'port_a[1, 7]';
      protected
        record 'port_a[1, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 8]_rec';
      public
        'port_a[1, 8]_rec' 'port_a[1, 8]';
      protected
        record 'port_a[1, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 9]_rec';
      public
        'port_a[1, 9]_rec' 'port_a[1, 9]';
      protected
        record 'port_a[1, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[1, 10]_rec';
      public
        'port_a[1, 10]_rec' 'port_a[1, 10]';
      protected
        record 'port_a[2, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 1]_rec';
      public
        'port_a[2, 1]_rec' 'port_a[2, 1]';
      protected
        record 'port_a[2, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 2]_rec';
      public
        'port_a[2, 2]_rec' 'port_a[2, 2]';
      protected
        record 'port_a[2, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 3]_rec';
      public
        'port_a[2, 3]_rec' 'port_a[2, 3]';
      protected
        record 'port_a[2, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 4]_rec';
      public
        'port_a[2, 4]_rec' 'port_a[2, 4]';
      protected
        record 'port_a[2, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 5]_rec';
      public
        'port_a[2, 5]_rec' 'port_a[2, 5]';
      protected
        record 'port_a[2, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 6]_rec';
      public
        'port_a[2, 6]_rec' 'port_a[2, 6]';
      protected
        record 'port_a[2, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 7]_rec';
      public
        'port_a[2, 7]_rec' 'port_a[2, 7]';
      protected
        record 'port_a[2, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 8]_rec';
      public
        'port_a[2, 8]_rec' 'port_a[2, 8]';
      protected
        record 'port_a[2, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 9]_rec';
      public
        'port_a[2, 9]_rec' 'port_a[2, 9]';
      protected
        record 'port_a[2, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[2, 10]_rec';
      public
        'port_a[2, 10]_rec' 'port_a[2, 10]';
      protected
        record 'port_a[3, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 1]_rec';
      public
        'port_a[3, 1]_rec' 'port_a[3, 1]';
      protected
        record 'port_a[3, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 2]_rec';
      public
        'port_a[3, 2]_rec' 'port_a[3, 2]';
      protected
        record 'port_a[3, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 3]_rec';
      public
        'port_a[3, 3]_rec' 'port_a[3, 3]';
      protected
        record 'port_a[3, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 4]_rec';
      public
        'port_a[3, 4]_rec' 'port_a[3, 4]';
      protected
        record 'port_a[3, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 5]_rec';
      public
        'port_a[3, 5]_rec' 'port_a[3, 5]';
      protected
        record 'port_a[3, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 6]_rec';
      public
        'port_a[3, 6]_rec' 'port_a[3, 6]';
      protected
        record 'port_a[3, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 7]_rec';
      public
        'port_a[3, 7]_rec' 'port_a[3, 7]';
      protected
        record 'port_a[3, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 8]_rec';
      public
        'port_a[3, 8]_rec' 'port_a[3, 8]';
      protected
        record 'port_a[3, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 9]_rec';
      public
        'port_a[3, 9]_rec' 'port_a[3, 9]';
      protected
        record 'port_a[3, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[3, 10]_rec';
      public
        'port_a[3, 10]_rec' 'port_a[3, 10]';
      protected
        record 'port_a[4, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 1]_rec';
      public
        'port_a[4, 1]_rec' 'port_a[4, 1]';
      protected
        record 'port_a[4, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 2]_rec';
      public
        'port_a[4, 2]_rec' 'port_a[4, 2]';
      protected
        record 'port_a[4, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 3]_rec';
      public
        'port_a[4, 3]_rec' 'port_a[4, 3]';
      protected
        record 'port_a[4, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 4]_rec';
      public
        'port_a[4, 4]_rec' 'port_a[4, 4]';
      protected
        record 'port_a[4, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 5]_rec';
      public
        'port_a[4, 5]_rec' 'port_a[4, 5]';
      protected
        record 'port_a[4, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 6]_rec';
      public
        'port_a[4, 6]_rec' 'port_a[4, 6]';
      protected
        record 'port_a[4, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 7]_rec';
      public
        'port_a[4, 7]_rec' 'port_a[4, 7]';
      protected
        record 'port_a[4, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 8]_rec';
      public
        'port_a[4, 8]_rec' 'port_a[4, 8]';
      protected
        record 'port_a[4, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 9]_rec';
      public
        'port_a[4, 9]_rec' 'port_a[4, 9]';
      protected
        record 'port_a[4, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[4, 10]_rec';
      public
        'port_a[4, 10]_rec' 'port_a[4, 10]';
      protected
        record 'port_a[5, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 1]_rec';
      public
        'port_a[5, 1]_rec' 'port_a[5, 1]';
      protected
        record 'port_a[5, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 2]_rec';
      public
        'port_a[5, 2]_rec' 'port_a[5, 2]';
      protected
        record 'port_a[5, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 3]_rec';
      public
        'port_a[5, 3]_rec' 'port_a[5, 3]';
      protected
        record 'port_a[5, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 4]_rec';
      public
        'port_a[5, 4]_rec' 'port_a[5, 4]';
      protected
        record 'port_a[5, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 5]_rec';
      public
        'port_a[5, 5]_rec' 'port_a[5, 5]';
      protected
        record 'port_a[5, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 6]_rec';
      public
        'port_a[5, 6]_rec' 'port_a[5, 6]';
      protected
        record 'port_a[5, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 7]_rec';
      public
        'port_a[5, 7]_rec' 'port_a[5, 7]';
      protected
        record 'port_a[5, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 8]_rec';
      public
        'port_a[5, 8]_rec' 'port_a[5, 8]';
      protected
        record 'port_a[5, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 9]_rec';
      public
        'port_a[5, 9]_rec' 'port_a[5, 9]';
      protected
        record 'port_a[5, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[5, 10]_rec';
      public
        'port_a[5, 10]_rec' 'port_a[5, 10]';
      protected
        record 'port_a[6, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 1]_rec';
      public
        'port_a[6, 1]_rec' 'port_a[6, 1]';
      protected
        record 'port_a[6, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 2]_rec';
      public
        'port_a[6, 2]_rec' 'port_a[6, 2]';
      protected
        record 'port_a[6, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 3]_rec';
      public
        'port_a[6, 3]_rec' 'port_a[6, 3]';
      protected
        record 'port_a[6, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 4]_rec';
      public
        'port_a[6, 4]_rec' 'port_a[6, 4]';
      protected
        record 'port_a[6, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 5]_rec';
      public
        'port_a[6, 5]_rec' 'port_a[6, 5]';
      protected
        record 'port_a[6, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 6]_rec';
      public
        'port_a[6, 6]_rec' 'port_a[6, 6]';
      protected
        record 'port_a[6, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 7]_rec';
      public
        'port_a[6, 7]_rec' 'port_a[6, 7]';
      protected
        record 'port_a[6, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 8]_rec';
      public
        'port_a[6, 8]_rec' 'port_a[6, 8]';
      protected
        record 'port_a[6, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 9]_rec';
      public
        'port_a[6, 9]_rec' 'port_a[6, 9]';
      protected
        record 'port_a[6, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[6, 10]_rec';
      public
        'port_a[6, 10]_rec' 'port_a[6, 10]';
      protected
        record 'port_a[7, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 1]_rec';
      public
        'port_a[7, 1]_rec' 'port_a[7, 1]';
      protected
        record 'port_a[7, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 2]_rec';
      public
        'port_a[7, 2]_rec' 'port_a[7, 2]';
      protected
        record 'port_a[7, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 3]_rec';
      public
        'port_a[7, 3]_rec' 'port_a[7, 3]';
      protected
        record 'port_a[7, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 4]_rec';
      public
        'port_a[7, 4]_rec' 'port_a[7, 4]';
      protected
        record 'port_a[7, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 5]_rec';
      public
        'port_a[7, 5]_rec' 'port_a[7, 5]';
      protected
        record 'port_a[7, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 6]_rec';
      public
        'port_a[7, 6]_rec' 'port_a[7, 6]';
      protected
        record 'port_a[7, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 7]_rec';
      public
        'port_a[7, 7]_rec' 'port_a[7, 7]';
      protected
        record 'port_a[7, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 8]_rec';
      public
        'port_a[7, 8]_rec' 'port_a[7, 8]';
      protected
        record 'port_a[7, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 9]_rec';
      public
        'port_a[7, 9]_rec' 'port_a[7, 9]';
      protected
        record 'port_a[7, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[7, 10]_rec';
      public
        'port_a[7, 10]_rec' 'port_a[7, 10]';
      protected
        record 'port_a[8, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 1]_rec';
      public
        'port_a[8, 1]_rec' 'port_a[8, 1]';
      protected
        record 'port_a[8, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 2]_rec';
      public
        'port_a[8, 2]_rec' 'port_a[8, 2]';
      protected
        record 'port_a[8, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 3]_rec';
      public
        'port_a[8, 3]_rec' 'port_a[8, 3]';
      protected
        record 'port_a[8, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 4]_rec';
      public
        'port_a[8, 4]_rec' 'port_a[8, 4]';
      protected
        record 'port_a[8, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 5]_rec';
      public
        'port_a[8, 5]_rec' 'port_a[8, 5]';
      protected
        record 'port_a[8, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 6]_rec';
      public
        'port_a[8, 6]_rec' 'port_a[8, 6]';
      protected
        record 'port_a[8, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 7]_rec';
      public
        'port_a[8, 7]_rec' 'port_a[8, 7]';
      protected
        record 'port_a[8, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 8]_rec';
      public
        'port_a[8, 8]_rec' 'port_a[8, 8]';
      protected
        record 'port_a[8, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 9]_rec';
      public
        'port_a[8, 9]_rec' 'port_a[8, 9]';
      protected
        record 'port_a[8, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[8, 10]_rec';
      public
        'port_a[8, 10]_rec' 'port_a[8, 10]';
      protected
        record 'port_a[9, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 1]_rec';
      public
        'port_a[9, 1]_rec' 'port_a[9, 1]';
      protected
        record 'port_a[9, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 2]_rec';
      public
        'port_a[9, 2]_rec' 'port_a[9, 2]';
      protected
        record 'port_a[9, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 3]_rec';
      public
        'port_a[9, 3]_rec' 'port_a[9, 3]';
      protected
        record 'port_a[9, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 4]_rec';
      public
        'port_a[9, 4]_rec' 'port_a[9, 4]';
      protected
        record 'port_a[9, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 5]_rec';
      public
        'port_a[9, 5]_rec' 'port_a[9, 5]';
      protected
        record 'port_a[9, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 6]_rec';
      public
        'port_a[9, 6]_rec' 'port_a[9, 6]';
      protected
        record 'port_a[9, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 7]_rec';
      public
        'port_a[9, 7]_rec' 'port_a[9, 7]';
      protected
        record 'port_a[9, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 8]_rec';
      public
        'port_a[9, 8]_rec' 'port_a[9, 8]';
      protected
        record 'port_a[9, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 9]_rec';
      public
        'port_a[9, 9]_rec' 'port_a[9, 9]';
      protected
        record 'port_a[9, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[9, 10]_rec';
      public
        'port_a[9, 10]_rec' 'port_a[9, 10]';
      protected
        record 'port_a[10, 1]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 1]_rec';
      public
        'port_a[10, 1]_rec' 'port_a[10, 1]';
      protected
        record 'port_a[10, 2]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 2]_rec';
      public
        'port_a[10, 2]_rec' 'port_a[10, 2]';
      protected
        record 'port_a[10, 3]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 3]_rec';
      public
        'port_a[10, 3]_rec' 'port_a[10, 3]';
      protected
        record 'port_a[10, 4]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 4]_rec';
      public
        'port_a[10, 4]_rec' 'port_a[10, 4]';
      protected
        record 'port_a[10, 5]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 5]_rec';
      public
        'port_a[10, 5]_rec' 'port_a[10, 5]';
      protected
        record 'port_a[10, 6]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 6]_rec';
      public
        'port_a[10, 6]_rec' 'port_a[10, 6]';
      protected
        record 'port_a[10, 7]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 7]_rec';
      public
        'port_a[10, 7]_rec' 'port_a[10, 7]';
      protected
        record 'port_a[10, 8]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 8]_rec';
      public
        'port_a[10, 8]_rec' 'port_a[10, 8]';
      protected
        record 'port_a[10, 9]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 9]_rec';
      public
        'port_a[10, 9]_rec' 'port_a[10, 9]';
      protected
        record 'port_a[10, 10]_rec'
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end 'port_a[10, 10]_rec';
      public
        'port_a[10, 10]_rec' 'port_a[10, 10]';
      protected
        record port_b_rec
          Modelica.SIunits.Temperature T
                                        "Port temperature";
          Modelica.SIunits.HeatFlowRate Q_flow
                                              "Heat flow rate (positive if flowing from outside into the component)";
        end port_b_rec;
      public
        port_b_rec port_b;
      end midTemperature_rec;
    public
      midTemperature_rec midTemperature;
    protected
      record port_a_floor_rec
        Modelica.SIunits.Temperature T
                                      "Port temperature";
        Modelica.SIunits.HeatFlowRate Q_flow
                                            "Heat flow rate (positive if flowing from outside into the component)";
      end port_a_floor_rec;
    public
      port_a_floor_rec port_a_floor;
    end storageWall_rec;
  public
    storageWall_rec storageWall annotation(Dialog);
    Modelica_IK4_TEKNIKER_DCOL_Generation_LatentStorages_FMI_RealConectors_RealTemperatureOutput PCM_T
                                                                                                      "Temperature of the PCM";
    parameter Modelica.SIunits.Diameter D_tube_mid(fixed=false)
                                                               "Interior diameter of the coil";
    parameter Modelica.SIunits.Mass m_PCM(fixed=false)
                                                      "Total mass of the PCM";
    Modelica.SIunits.MassFraction x_liquid_Total
                                                "Total liquid mass fraction";
    parameter Modelica.SIunits.ThermalConductivity k_PCMs(fixed=false)
                                                                      "Thermal conductivity of the solid PCM";
    Modelica.SIunits.Area 'A_PCMs_out[1]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[2]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[3]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[4]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[5]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[6]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[7]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[8]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[9]'
                                         "Area of the exterior of the ice";
    Modelica.SIunits.Area 'A_PCMs_out[10]'
                                          "Area of the exterior of the ice";
    Modelica.SIunits.Area A_PCMs_total
                                      "Total solid PCM area";
    parameter Modelica.SIunits.CoefficientOfHeatTransfer h_PCMl(fixed=false)
                                                                            "Convection heat transfer coefficient of the liquid PCM";
    parameter Modelica.SIunits.ThermalConductivity k_PCMl(fixed=false)
                                                                      "Thermal conductivity of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[1]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[2]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[3]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[4]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[5]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[6]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[7]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[8]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[9]'
                                         "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area 'A_PCMl_out[10]'
                                          "Area of the exterior of the liquid PCM";
    Modelica.SIunits.Area A_PCMl_total
                                      "Total liquid PCM area";
    Modelica.SIunits.Temperature T_HTFo
                                       "Outlet HTF temperature";
    Modelica.SIunits.Temperature T_HTFi
                                       "Inlet HTF temperature";
    parameter Modelica.SIunits.CoefficientOfHeatTransfer h_HTF(fixed=false)
                                                                           "Convection heat transfer coefficient of the HTF";
    Real 'f[1]'
               "Correction factor";
    Real 'f[2]'
               "Correction factor";
    Real 'f[3]'
               "Correction factor";
    Real 'f[4]'
               "Correction factor";
    Real 'f[5]'
               "Correction factor";
    Real 'f[6]'
               "Correction factor";
    Real 'f[7]'
               "Correction factor";
    Real 'f[8]'
               "Correction factor";
    Real 'f[9]'
               "Correction factor";
    Real 'f[10]'
                "Correction factor";
    Real 'AR[1]'
                "Area ratio";
    Real 'AR[2]'
                "Area ratio";
    Real 'AR[3]'
                "Area ratio";
    Real 'AR[4]'
                "Area ratio";
    Real 'AR[5]'
                "Area ratio";
    Real 'AR[6]'
                "Area ratio";
    Real 'AR[7]'
                "Area ratio";
    Real 'AR[8]'
                "Area ratio";
    Real 'AR[9]'
                "Area ratio";
    Real 'AR[10]'
                 "Area ratio";
  end iceStorageInternalMelt_rec;
public
  iceStorageInternalMelt_rec iceStorageInternalMelt annotation(Dialog);
protected
  record outlet_HTF_rec
    constant Integer nPorts = 1
                               "Number of ports";
  protected
    record medium_rec
      Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0)
                                                                                                    "Absolute pressure of medium";
      Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                        "Specific enthalpy of medium";
      parameter Modelica.Media.Interfaces.Types.Density d(nominal = 10.0, fixed=false)
                                                                                      "Density of medium";
      Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                               "Temperature of medium";
      constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                        "Mass fractions (= (component mass)/total mass  m_i/m)";
      parameter Modelica.Media.Interfaces.Types.SpecificInternalEnergy u(fixed=false)
                                                                                     "Specific internal energy of medium";
      constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                         "Gas constant (of mixture if applicable)";
      constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                          "Molar mass (of mixture or single fluid)";
    protected
      record state_rec
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end state_rec;
    public
      state_rec state;
      constant Boolean preferredMediumStates = false
                                                    "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
      constant Boolean standardOrderComponents = true
                                                     "If true, and reducedX = true, the last element of X will be computed from the other ones";
      parameter Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC(fixed=false)
                                                                                            "Temperature of medium in [degC]";
      parameter Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar(fixed=false)
                                                                                       "Absolute pressure of medium in [bar]";
    end medium_rec;
  public
    medium_rec medium;
  protected
    record 'ports[1]_rec'
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = -1E+060, max = 1E+060)
                                                                                                                             "Mass flow rate from the connection point into the component";
      Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                             "Thermodynamic pressure in the connection point";
      parameter Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0, fixed=false)
                                                                                                           "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
    end 'ports[1]_rec';
  public
    'ports[1]_rec' 'ports[1]';
    constant Boolean use_p = true
                                 "select p or d";
    parameter Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0) = 101325
                                                                                              "Boundary pressure";
    parameter Modelica.Media.Interfaces.Types.Density d(nominal = 10.0, fixed=false)
                                                                                    "Boundary density";
    constant Boolean use_T = true
                                 "select T or h";
    parameter Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0) = 293.15
                                                                                                                "Boundary temperature";
    parameter Modelica.Media.Interfaces.Types.SpecificEnthalpy h(nominal = 100000.0, fixed=false)
                                                                                                 "Boundary specific enthalpy";
    parameter Modelica.Media.Interfaces.Types.MassFraction 'X[1]'(quantity = "Air") = 1.0
                                                                                         "Boundary mass fractions m_i/m";
  end outlet_HTF_rec;
public
  outlet_HTF_rec outlet_HTF annotation(Dialog);
protected
  record inlet_HTF_rec
    constant Integer nPorts = 1
                               "Number of ports";
  protected
    record medium_rec
      Real p(unit = "Pa", displayUnit = "bar", nominal = 100000.0, quantity = "Pressure", min = 0.0)
                                                                                                    "Absolute pressure of medium";
      Real h(unit = "J/kg", quantity = "SpecificEnergy")
                                                        "Specific enthalpy of medium";
      Modelica.Media.Interfaces.Types.Density d(nominal = 10.0)
                                                               "Density of medium";
      Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                               "Temperature of medium";
      constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                        "Mass fractions (= (component mass)/total mass  m_i/m)";
      Modelica.Media.Interfaces.Types.SpecificInternalEnergy u
                                                              "Specific internal energy of medium";
      constant Modelica.Media.Interfaces.Types.SpecificHeatCapacity R = 287.0512249529787
                                                                                         "Gas constant (of mixture if applicable)";
      constant Modelica.Media.Interfaces.Types.MolarMass MM = 0.0289651159
                                                                          "Molar mass (of mixture or single fluid)";
    protected
      record state_rec
        Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                               "Absolute pressure of medium";
        Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0)
                                                                                                 "Temperature of medium";
      end state_rec;
    public
      state_rec state;
      constant Boolean preferredMediumStates = false
                                                    "= true if StateSelect.prefer shall be used for the independent property variables of the medium";
      constant Boolean standardOrderComponents = true
                                                     "If true, and reducedX = true, the last element of X will be computed from the other ones";
      Modelica.SIunits.Conversions.NonSIunits.Temperature_degC T_degC
                                                                     "Temperature of medium in [degC]";
      Modelica.SIunits.Conversions.NonSIunits.Pressure_bar p_bar
                                                                "Absolute pressure of medium in [bar]";
    end medium_rec;
  public
    medium_rec medium;
  protected
    record 'ports[1]_rec'
      Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = -1E+060, max = 1E+060)
                                                                                                                             "Mass flow rate from the connection point into the component";
      Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                             "Thermodynamic pressure in the connection point";
      Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0)
                                                                                    "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
    end 'ports[1]_rec';
  public
    'ports[1]_rec' 'ports[1]';
    constant Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air") = 10
                                                                                                            "Fixed mass flow rate going out of the fluid port";
    constant Modelica.Media.Interfaces.Types.Temperature T(nominal = 500.0, min = 200.0, max = 6000.0) = 263.15
                                                                                                               "Fixed value of temperature";
    constant Modelica.Media.Interfaces.Types.MassFraction 'X[1]' = 1.0
                                                                      "Fixed value of composition";
    Modelica_Blocks_Interfaces_RealInput m_flow_in(unit = "kg/s")
                                                                 "Prescribed mass flow rate";
    Modelica_Blocks_Interfaces_RealInput T_in(unit = "K")
                                                         "Prescribed fluid temperature";
  end inlet_HTF_rec;
public
  inlet_HTF_rec inlet_HTF;
protected
  record m_inlet_HTF_T_rec
  protected
    record port_rec
      constant Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = 0.0) = 0
                                                                                                                        "Mass flow rate from the connection point into the component";
      Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                             "Thermodynamic pressure in the connection point";
      parameter Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0, fixed=false)
                                                                                                           "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
    end port_rec;
  public
    port_rec port;
    Modelica_Blocks_Interfaces_RealOutput T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0)
                                                                                                                                                "Temperature in port medium";
  end m_inlet_HTF_T_rec;
public
  m_inlet_HTF_T_rec m_inlet_HTF_T;
protected
  record m_outlet_HTF_T_rec
  protected
    record port_rec
      constant Modelica.Media.Interfaces.PartialMedium.MassFlowRate m_flow(quantity = "MassFlowRate.Air", min = 0.0) = 0
                                                                                                                        "Mass flow rate from the connection point into the component";
      Modelica.Media.Interfaces.Types.AbsolutePressure p(nominal = 1000000.0)
                                                                             "Thermodynamic pressure in the connection point";
      parameter Modelica.Media.Interfaces.Types.SpecificEnthalpy h_outflow(nominal = 100000.0, fixed=false)
                                                                                                           "Specific thermodynamic enthalpy close to the connection point if m_flow < 0";
    end port_rec;
  public
    port_rec port;
    Modelica_Blocks_Interfaces_RealOutput T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0)
                                                                                                                                                "Temperature in port medium";
  end m_outlet_HTF_T_rec;
public
  m_outlet_HTF_T_rec m_outlet_HTF_T;
protected
  record floorTemperature_rec
  protected
    record port_rec
      Modelica.SIunits.Temperature T
                                    "Port temperature";
      Modelica.SIunits.HeatFlowRate Q_flow
                                          "Heat flow rate (positive if flowing from outside into the component)";
    end port_rec;
  public
    port_rec port;
    Modelica_Blocks_Interfaces_RealInput T(unit = "K");
  end floorTemperature_rec;
public
  floorTemperature_rec floorTemperature;
  parameter Real _ambient_T_start = 288.15
  annotation (Dialog(tab="Input Start Values", group="Input Start Value before call to fmiInitialize"));
protected
  Real _ambient_T_old;
public
  Modelica.Blocks.Interfaces.RealInput ambient_T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0, start = 288.15)
                                                                                                                                                                     "Ambient temperature"
  annotation (Placement(transformation(extent={{-124,40},{-84,80}})));
  parameter Real _HTF_m_flow_start = 0.0
  annotation (Dialog(tab="Input Start Values", group="Input Start Value before call to fmiInitialize"));
protected
  Real _HTF_m_flow_old;
public
  Modelica.Blocks.Interfaces.RealInput HTF_m_flow(unit = "kg/s", quantity = "MassFlowRate", min = -1E+060, max = 100000.0, start = 0.0)
                                                                                                                                       "Inlet HTF mass flow"
  annotation (Placement(transformation(extent={{-124,0},{-84,40}})));
  parameter Real _HTF_T_start = 288.15
  annotation (Dialog(tab="Input Start Values", group="Input Start Value before call to fmiInitialize"));
protected
  Real _HTF_T_old;
public
  Modelica.Blocks.Interfaces.RealInput HTF_T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 200.0, max = 6000.0, start = 288.15)
                                                                                                                                                                                 "Inlet HTF temperature"
  annotation (Placement(transformation(extent={{-124,-40},{-84,0}})));
  parameter Real _floor_T_start = 288.15
  annotation (Dialog(tab="Input Start Values", group="Input Start Value before call to fmiInitialize"));
protected
  Real _floor_T_old;
public
  Modelica.Blocks.Interfaces.RealInput floor_T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0, start = 288.15)
                                                                                                                                                                   "Floor temperatura"
  annotation (Placement(transformation(extent={{-124,-80},{-84,-40}})));
  Modelica.Blocks.Interfaces.RealOutput inletHTF_T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0)
                                                                                                                                                       "Inlet HTF temperature"
  annotation (Placement(transformation(extent={{100,30},{140,70}})));
  Modelica.Blocks.Interfaces.RealOutput PCM_T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0)
                                                                                                                                                  "Temperature of the PCM"
  annotation (Placement(transformation(extent={{100,-20},{140,20}})));
  Modelica.Blocks.Interfaces.RealOutput outletHTF_T(unit = "K", displayUnit = "degC", nominal = 300.0, quantity = "ThermodynamicTemperature", min = 0.0)
                                                                                                                                                        "Outlet HTF temperature"
  annotation (Placement(transformation(extent={{100,-70},{140,-30}})));
public
  parameter String fmi_instanceName="IceStorage_FMU_fmu"
  annotation (Dialog(tab="FMI", group="Instance name"));
  parameter Boolean fmi_loggingOn=false
  annotation (Dialog(tab="FMI", group="Enable logging"));
  parameter Boolean fmi_pullInputsForInitialization=true
  "Set to false when using the FMU in feedback connections"
  annotation (Dialog(tab="FMI", group="Inputs for initialization"));
  parameter Boolean fmi_InputTime=false
  "Time point of input used when calling doStep."
  annotation (Evaluate=true,Dialog(tab="FMI", group="Input Handling"),choices(choice= false "StepEnd", choice= true "StepStart"));
  parameter Boolean fmi_UsePreOnInputSignals=true
  annotation (Evaluate=true,Dialog(tab="FMI", group="Input Handling"));
  parameter Real fmi_StartTime = 0.0
  annotation (Dialog(tab="FMI", group="Step time"));
  parameter Real fmi_StopTime = 60000.0
  annotation (Dialog(tab="FMI", group="Step time"));
  parameter Real fmi_NumberOfSteps = 500
  annotation (Dialog(tab="FMI", group="Step time"));
  parameter Real fmi_CommunicationStepSize=(fmi_StopTime-fmi_StartTime)/fmi_NumberOfSteps
  annotation (Dialog(tab="FMI", group="Step time"));
  parameter Integer stepSizeScaleFactor = 1 "Number of doSteps called between two CommunicationStepSize"
  annotation (Dialog(tab="FMI", group="Step time"));
  parameter Boolean fmi_forceShutDownAtStopTime=false
  annotation (Dialog(tab="FMI", group="Step time"));
  parameter String fmi_fmuLocation="file:///"+ModelicaServices.ExternalReferences.loadResource("modelica://IceStorage_FMU_fmu/Resources/Library/FMU/IceStorage_FMU")
  annotation (Dialog(tab="FMI", group="Instantiation"));
protected
fmi_Functions.fmiModel fmi;
Boolean fmi_StepOK;
parameter Real fmi_Initialized(fixed=false);
parameter Real fmi_AParamsAndStart(fixed=false);
parameter Real fmi_initInput0(start=0,fixed=false);
parameter Real fmi_initInput1(start=0,fixed=false);
parameter Real fmi_initInput2(start=0,fixed=false);
parameter Real fmi_initInput3(start=0,fixed=false);
Real RealVariables1[100];
Real RealVariables2[100];
Real RealVariables3[100];
Real RealVariables4[100];
Real RealVariables5[100];
Real RealVariables6[100];
Real RealVariables7[100];
Real RealVariables8[100];
Real RealVariables9[100];
Real RealVariables10[100];
Real RealVariables11[100];
Real RealVariables12[100];
Real RealVariables13[100];
Real RealVariables14[100];
Real RealVariables15[100];
Real RealVariables16[100];
Real RealVariables17[100];
Real RealVariables18[100];
Real RealVariables19[100];
Real RealVariables20[100];
Real RealVariables21[100];
Real RealVariables22[100];
Real RealVariables23[100];
Real RealVariables24[100];
Real RealVariables25[100];
Real RealVariables26[100];
Real RealVariables27[100];
Real RealVariables28[100];
Real RealVariables29[100];
Real RealVariables30[100];
Real RealVariables31[100];
Real RealVariables32[100];
Real RealVariables33[100];
Real RealVariables34[100];
Real RealVariables35[100];
Real RealVariables36[100];
Real RealVariables37[100];
Real RealVariables38[100];
Real RealVariables39[100];
Real RealVariables40[100];
Real RealVariables41[100];
Real RealVariables42[100];
Real RealVariables43[100];
Real RealVariables44[100];
Real RealVariables45[100];
Real RealVariables46[100];
Real RealVariables47[100];
Real RealVariables48[100];
Real RealVariables49[100];
Real RealVariables50[100];
Real RealVariables51[100];
Real RealVariables52[100];
Real RealVariables53[100];
Real RealVariables54[100];
Real RealVariables55[100];
Real RealVariables56[100];
Real RealVariables57[100];
Real RealVariables58[19];
Real RealDependentParameters1[100];
Real RealDependentParameters2[100];
Real RealDependentParameters3[100];
Real RealDependentParameters4[100];
Real RealDependentParameters5[100];
Real RealDependentParameters6[100];
Real RealDependentParameters7[100];
Real RealDependentParameters8[100];
Real RealDependentParameters9[100];
Real RealDependentParameters10[20];
Boolean BooleanVariables1[100];
Boolean BooleanVariables2[2];
package fmi_Functions
  class fmiModel
  extends ExternalObject;
    function constructor "Initialize FMI model"
      extends Modelica.Icons.Function;
      input String instanceName;
      input Boolean loggingOn;
        input String fmuLocation;
      output fmiModel fmi;
      external"C" fmi = Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiInstantiateModel2(instanceName, loggingOn, fmuLocation)
      annotation(Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_Instantiate_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_Instantiate_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_MYSTRCMP_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_MYSTRCMP_C 1
int Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dymmystrcmp(const void *_a, const void *_b) {
  char *a = _a;
  char *const *b = _b;
  return strcmp(a, *b);
}
#endif
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0DymLogger(fmiComponent c, fmiString instanceName, fmiStatus status,
         fmiString category, fmiString message, ...) {
  char msg[4096];
  char buf[4096];
  int len;
  va_list ap;
  va_start(ap,message);
#if defined(_MSC_VER) && _MSC_VER>=1200
  len = _snprintf(msg, sizeof(msg)/sizeof(*msg), \"%s: %s\", instanceName, message);
  if (len < 0) goto fail;
  len = _vsnprintf(buf, sizeof(buf)/sizeof(*buf) - 2, msg, ap);
  if (len < 0) goto fail;
#else
  len = snprintf(msg, sizeof(msg)/sizeof(*msg), \"%s: %s\", instanceName, message);
  if (len < 0) goto fail;
  len = vsnprintf(buf, sizeof(buf)/sizeof(*buf) - 2, msg, ap);
  if (len < 0) goto fail;
#endif
  if( len>0 && len <4096 && buf[len - 1]!='\\n'){
    buf[len] = '\\n';
    buf[len + 1] = 0;
  }
  va_end(ap);
  switch (status) {
    case fmiFatal:
      ModelicaMessage(\"[fmiFatal]: \");
      break;
    case fmiError:
      ModelicaMessage(\"[fmiError]: \");
      break;
    case fmiDiscard:
      ModelicaMessage(\"[fmiDiscard]: \");
      break;
    case fmiWarning:
      ModelicaMessage(\"[fmiWarning]: \");
      break;
    case fmiOK:
      ModelicaMessage(\"[fmiOK]: \");
      break;
  }
  ModelicaMessage(buf);
  return;
fail:
  ModelicaMessage(\"Logger failed, message too long?\");
}
void * Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiInstantiateModel2(const char*instanceName, fmiBoolean loggingOn, const char* fmuLocation) {
  static fmiCoSimCallbackFunctions funcs = {&Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0DymLogger, &calloc, &free, NULL};
  struct dy_Extended* res;

  res = calloc(1, sizeof(struct dy_Extended));
  if (res!=0) {
    if (!(res->hInst=LoadLibraryW(L\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym.dll\"))) {
      ModelicaError(\"Loading of FMU dynamic link library (Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym.dll) failed!\");
      return 0;
    }
    if(!(res->dyFmiInstantiateSlave=(fmiInstantiateSlaveFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiInstantiateSlave\"))){
      ModelicaError(\"GetProcAddress failed for fmiInstantiateSlave!\\n The model was imported as a Co-Simulation FMU but could not load the CS specific function fmiInstantiateSlave\\n Verify that the FMU supports Co-Simulation\");
      return 0;
    }
    if(!(res->dyFmiFreeSlaveInstance=(fmiFreeSlaveInstanceFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiFreeSlaveInstance\"))){
      ModelicaError(\"GetProcAddress failed for fmiFreeSlaveInstance!\\n The model was imported as a Co-Simulation FMU but could not load the CS specific function fmiFreeSlaveInstance\\n Verify that the FMU supports Co-Simulation\");
      return 0;
    }
    if(!(res->dyFmiInitializeSlave=(fmiInitializeSlaveFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiInitializeSlave\"))){
      ModelicaError(\"GetProcAddress failed for fmiInitializeSlave!\\n The model was imported as a Co-Simulation FMU but could not load the CS specific function fmiInitializeSlave\\n Verify that the FMU supports Co-Simulation\");
      return 0;
    }
    if(!(res->dyFmiResetSlave=(fmiResetSlaveFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiResetSlave\"))){
      ModelicaError(\"GetProcAddress failed for fmiResetSlave!\\n The model was imported as a Co-Simulation FMU but could not load the CS specific function fmiResetSlave\\n Verify that the FMU supports Co-Simulation\");
      return 0;
    }
    if(!(res->dyFmiDoStep=(fmiDoStepFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiDoStep\"))){
      ModelicaError(\"GetProcAddress failed for fmiDoStep!\\n The model was imported as a Co-Simulation FMU but could not load the CS specific function fmiDoStep\\n Verify that the FMU supports Co-Simulation\");
      return 0;
    }
    if(!(res->dyFmiTerminateSlave=(fmiTerminateSlaveFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiTerminateSlave\"))){
      ModelicaError(\"GetProcAddress failed for fmiTerminateSlave!\\n The model was imported as a Co-Simulation FMU but could not load the CS specific function fmiTerminateSlave\\n Verify that the FMU supports Co-Simulation\");
      return 0;
    }
    if (!(res->dyFmiSetReal=(fmiSetRealFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetReal\"))) {
      ModelicaError(\"GetProcAddress failed for fmiSetReal!\");
      return 0;
    }
    if (!(res->dyFmiGetReal=(fmiGetRealFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetReal\"))) {
      ModelicaError(\"GetProcAddress failed for fmiGetReal!\");
      return 0;
    }
    if (!(res->dyFmiSetInteger=(fmiSetIntegerFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetInteger\"))) {
      ModelicaError(\"GetProcAddress failed for fmiSetInteger!\");
      return 0;
    }
    if (!(res->dyFmiGetInteger=(fmiGetIntegerFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetInteger\"))) {
      ModelicaError(\"GetProcAddress failed for fmiGetInteger!\");
      return 0;
    }
    if (!(res->dyFmiSetBoolean=(fmiSetBooleanFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetBoolean\"))) {
      ModelicaError(\"GetProcAddress failed for fmiSetBoolean!\");
      return 0;
    }
    if (!(res->dyFmiGetBoolean=(fmiGetBooleanFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetBoolean\"))) {
      ModelicaError(\"GetProcAddress failed for fmiGetBoolean!\");
      return 0;
    }
    if (!(res->dyFmiSetString=(fmiSetStringFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetString\"))) {
      ModelicaError(\"GetProcAddress failed for fmiSetString!\");
      return 0;
    }
    if (!(res->dyFmiGetString=(fmiGetStringFunc)GetProcAddress(res->hInst,\"Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetString\"))) {
      ModelicaError(\"GetProcAddress failed for fmiGetString!\");
      return 0;
    }
    res->m=res->dyFmiInstantiateSlave(instanceName, \"{cd0d3ccd-2df1-4a0f-90ca-9cc49c1aae7d}\", fmuLocation, \"application/x-dymolakernel\", 0, fmiFalse, fmiFalse, funcs, loggingOn);
    if (0==res->m) {free(res);res=0;ModelicaError(\"InstantiateSlave failed\");}
    else {res->dyTriggered=0;res->dyTime=res->dyLastTime=-1e37;}
  }
  return res;
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end constructor;

    function destructor "Release storage of FMI model"
      extends Modelica.Icons.Function;
      input fmiModel fmi;
      external"C"
                 Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiFreeModelInstance2(fmi);
      annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_Free_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_Free_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiFreeModelInstance2(void*m) {
  struct dy_Extended*a=m;
  if (a) {
    a->dyFmiTerminateSlave(a->m);
    a->dyFmiFreeSlaveInstance(a->m);
    FreeLibrary(a->hInst);
    free(a);
  }
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end destructor;
  end fmiModel;

    function fmiInitializeSlave
      input fmiModel fmi;
      input Real tStart;
      input Boolean forceShutDownAtTStop;
       input Real tStop;
      input Real preAvailable;
      output Real postAvailable=preAvailable;
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiInitializeSlave2(fmi, tStart, forceShutDownAtTStop, tStop);
      annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_InitializeSlave_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_InitializeSlave_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
double Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiInitializeSlave2(void*m, fmiReal tStart, fmiBoolean forceShutDownAtTStop, fmiReal tStop) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if (a) {
    status=a->dyFmiInitializeSlave(a->m, tStart, forceShutDownAtTStop, tStop);
    a->dyTriggered=0;
    a->dyLastTime=a->dyTime;
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"InitializeSlave failed\");
  return 1e37;
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end fmiInitializeSlave;

    function fmiDoStep
     input fmiModel fmi;
     input Real currentTime;
     input Real stepSize;
     output Boolean stepOK;
     external"C" stepOK= Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiDoStep2(fmi, currentTime, stepSize);
     annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_DoStep_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_DoStep_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
double Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiDoStep2(void*m, double currentTime, double stepSize) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if (a) {
    status=a->dyFmiDoStep(a->m, currentTime, stepSize, fmiTrue);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"DoStep failed\");
  return 1.0;
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end fmiDoStep;

    function fmiResetSlave
      input fmiModel fmi;
      output Boolean resetOK;
      external"C" resetOK = Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiResetSlave2(fmi);
      annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_ResetSlave_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_ResetSlave_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
double Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiResetSlave2(void*m) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if (a) {
    status=a->dyFmiResetSlave(a->m);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"resetSlave failed\");
    return 1.0;
  }
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end fmiResetSlave;

    function fmiSetReal
      input fmiModel fmi;
      input Integer refs[:];
      input Real vals[size(refs, 1)];
      output Real dummy= 1;
      external"C"
                 Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetReal2(
        fmi,
        refs,
        size(refs, 1),
        vals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetReal_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetReal_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetReal2(void*m, const int*refs, size_t nrefs, const double*vals) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if(!nrefs){return;}
  if (a) {
    status=a->dyFmiSetReal(a->m, refs, nrefs, vals);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetReal failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetReal;

    function fmiSetRealParam
      input fmiModel fmi;
      input Integer refs[:];
      input Real vals[size(refs, 1)];
    protected
      Real oldVals[size(refs, 1)];
      external"C"
                 Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetRealParam2(
        fmi,
        refs,
        size(refs, 1),
        vals,
        oldVals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetRealParam_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetRealParam_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetRealParam2(void*m, const int*refs, size_t nrefs, const double*vals, double*oldVals) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  int i = 0;
  if(!nrefs){return;}
  if (a) {
    if(a->currentMode == dyInstantiationMode){
                status=a->dyFmiSetReal(a->m, refs, nrefs, vals);
    }else{
      status=a->dyFmiGetReal(a->m, refs, nrefs, oldVals);
      for(i=0; i<nrefs;++i){
        if( abs(vals[i]-oldVals[i])> 5e-16){
          ModelicaError(\"SetRealParameter: new parameters with diferent values are being set after initialization, this is not allowed\");
        }
      }
    }
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetReal failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetRealParam;

    function fmiGetRealScalar
      input fmiModel fmi;
      input Integer ref;
      input Real dummy;
      output Real val;
    algorithm
        val := scalar(fmiGetReal(fmi, {ref}, dummy));
    end fmiGetRealScalar;

    function fmiGetReal
      input fmiModel fmi;
      input Integer refs[:];
      output Real vals[size(refs, 1)];
      input Real preAvailable;
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetReal2(
        fmi,
        refs,
        size(refs, 1),
        vals);
      annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetReal_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetReal_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetReal2(void*m, const int*refs, size_t nrefs, double*vals) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if (a) {
    status=a->dyFmiGetReal(a->m, refs, nrefs, vals);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"GetReal failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end fmiGetReal;

    function fmiGetIntegerScalar
      input fmiModel fmi;
      input Integer ref;
      input Integer dummy;
      output Integer val;
    algorithm
        val := scalar(fmiGetInteger(fmi, {ref}, dummy));
    end fmiGetIntegerScalar;

    function fmiGetInteger
      input fmiModel fmi;
      input Integer refs[:];
      output Integer vals[size(refs, 1)];
      input Integer preAvailable;
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetInteger2(
        fmi,
        refs,
        size(refs, 1),
        vals);
      annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetInteger_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetInteger_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetInteger2(void*m, const int*refs, size_t nrefs, int*vals) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if (a) {
    status=a->dyFmiGetInteger(a->m, refs, nrefs, vals);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"GetInteger failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end fmiGetInteger;

    function fmiSetInteger
    input fmiModel fmi;
      input Integer refs[:];
      input Integer vals[size(refs, 1)];
      output Real dummy= 1;
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetInteger2(
        fmi,
        refs,
        size(refs, 1),
        vals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetInteger_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetInteger_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetInteger2(void*m, const int*refs, size_t nrefs, int*vals) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if(!nrefs){return;}
  if (a) {
    status=a->dyFmiSetInteger(a->m, refs, nrefs, vals);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetInteger failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetInteger;

    function fmiSetIntegerParam
    input fmiModel fmi;
      input Integer refs[:];
      input Integer vals[size(refs, 1)];
    protected
      Integer oldVals[size(refs, 1)];
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetIntegerParam2(
        fmi,
        refs,
        size(refs, 1),
        vals,
        oldVals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetIntegerParam_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetIntegerParam_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetIntegerParam2(void*m, const int*refs, size_t nrefs, int*vals, int*oldVals) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  int i=0;
  if(!nrefs){return;}
  if (a) {
    if(a->currentMode == dyInstantiationMode){
      status=a->dyFmiSetInteger(a->m, refs, nrefs, vals);
    }else{
      status=a->dyFmiGetInteger(a->m, refs, nrefs, oldVals);
      for(i = 0; i< nrefs; ++i){
        if(vals[i]!=oldVals[i]){
          ModelicaError(\"SetIntegerParameter: new parameters with diferent values are being set after initialization, this is not allowed\");
        }
      }
    }
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetInteger failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetIntegerParam;

    function fmiGetBooleanScalar
      input fmiModel fmi;
      input Integer ref;
      input Integer dummy;
      output Boolean val;
    algorithm
        val := scalar(fmiGetBoolean(fmi, {ref}, dummy));
    end fmiGetBooleanScalar;

    function fmiGetBoolean
      input fmiModel fmi;
      input Integer refs[:];
      output Boolean vals[size(refs, 1)];
      input Integer preAvailable;
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetBoolean2(
        fmi,
        refs,
        size(refs, 1),
        vals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetBoolean_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetBoolean_C 1
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetBoolean2(void*m, const int* refs, size_t nr, int* vals) {
  int i;
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if (a) {
    status=a->dyFmiGetBoolean(a->m, refs, nr, (fmiBoolean*)(vals));
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"GetBoolean failed\");
  for(i=nr-1;i>=0;i--) vals[i]=((fmiBoolean*)(vals))[i];
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end fmiGetBoolean;

    function fmiSetBoolean
      input fmiModel fmi;
      input Integer refs[:];
      input Boolean vals[size(refs, 1)];
      output Real dummy2= 1;
    protected
      Boolean dummy[size(refs, 1)];
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetBoolean2(
        fmi,
        refs,
        size(refs, 1),
        vals,
        dummy);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetBoolean_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetBoolean_C 1
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetBoolean2(void*m, const int* refs, size_t nr, const int* vals,int*dummy) {
  int i;
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if(!nr){return;}
  for(i=0;i<nr;++i) ((fmiBoolean*)(dummy))[i]=vals[i];
  if (a) {
    status=a->dyFmiSetBoolean(a->m, refs, nr, (fmiBoolean*)(dummy));
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetBoolean failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetBoolean;

    function fmiSetBooleanParam
      input fmiModel fmi;
      input Integer refs[:];
      input Boolean vals[size(refs, 1)];
    protected
      Boolean dummy[size(refs, 1)];
      Boolean oldVals[size(refs, 1)];
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetBooleanParam2(
      fmi,
        refs,
        size(refs, 1),
        vals,
        dummy,
        oldVals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetBooleanParam_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetBooleanParam_C 1
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetBooleanParam2(void*m, const int* refs, size_t nr, const int* vals,int*dummy,int*oldVals) {
  int i;
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if(!nr){return;}
  for(i=0;i<nr;++i) ((fmiBoolean*)(dummy))[i]=vals[i];
  if (a) {
    if(a->currentMode == dyInstantiationMode){
      status=a->dyFmiSetBoolean(a->m, refs, nr, (fmiBoolean*)(dummy));
    }else{
      status=a->dyFmiGetBoolean(a->m, refs, nr, (fmiBoolean*)(oldVals));
      for(i=nr-1;i>=0;i--){
        oldVals[i]=((fmiBoolean*)(oldVals))[i];
        if(oldVals[i]!=dummy[i]){
          ModelicaError(\"SetIntegerParameter: new parameters with diferent values are being set after initialization, this is not allowed\");
        }
      }
    }
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetBoolean failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetBooleanParam;

    function fmiGetString
      input fmiModel fmi;
      input Integer refs[:];
      output String vals[size(refs, 1)];
      input Integer preAvailable;
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetString2(
        fmi,
        refs,
        size(refs, 1),
        vals);
      annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetString_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_GetString_C 1
#include <stdlib.h>
#include \"FMI/fmiImport.h\"
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiGetString2(void*m, const int*refs, size_t nrefs, fmiString* vals) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if (a) {
    status=a->dyFmiGetString(a->m, refs, nrefs, vals);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"StringInteger failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym");
    end fmiGetString;

    function fmiSetString
    input fmiModel fmi;
      input Integer refs[:];
      input String vals[size(refs, 1)];
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetString2(
        fmi,
        refs,
        size(refs, 1),
        vals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetString_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetString_C 1
#include \"FMI/fmiImport.h\"
#include <stdlib.h>
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetString2(void*m, const int*refs, size_t nrefs, const fmiString vals[]) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if(!nrefs){return;}
  if (a) {
    status=a->dyFmiSetString(a->m, refs, nrefs, vals);
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetString failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetString;

    function fmiSetStringParam
    input fmiModel fmi;
      input Integer refs[:];
      input String vals[size(refs, 1)];
      external"C" Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetStringParam2(
        fmi,
        refs,
        size(refs, 1),
        vals);
        annotation (Header="
#ifndef Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetStringParam_C
#define Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_SetStringParam_C 1
#include \"FMI/fmiImport.h\"
#include <stdlib.h>
void Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym_fmiSetStringParam2(void*m, const int*refs, size_t nrefs, const fmiString vals[]) {
  struct dy_Extended*a=m;
  fmiStatus status=fmiFatal;
  if(!nrefs){return;}
  if (a) {
    if(a->currentMode == dyInstantiationMode){
                status=a->dyFmiSetString(a->m, refs, nrefs, vals);
    }else{
      status=fmiOK;
    }
  }
  if (status!=fmiOK && status!=fmiWarning) ModelicaError(\"SetString failed\");
}
#endif", Library="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym", LibraryDirectory="modelica://DCOL/Resources/Library/FMU/IceStorage_FMU/binaries",               __Dymola_CriticalRegion="Modelica_0IK4_0TEKNIKER_DCOL_Generation_LatentStorages_FMI_IceStorage_0Dym",__Dymola_IdemPotent=true, __Dymola_VectorizedExceptFirst=true);
    end fmiSetStringParam;

    function noHysteresis
      input Real x;
      output Real y;
    algorithm
      y:=x+(if (x < 0) then -1 else 1);
    end noHysteresis;
end fmi_Functions;
equation
  when initial() then
    fmi = fmi_Functions.fmiModel(fmi_instanceName, fmi_loggingOn, fmi_fmuLocation);
  end when;
algorithm
  when {initial(), sample(fmi_StartTime, fmi_CommunicationStepSize)} then
    if time>=fmi_CommunicationStepSize +fmi_StartTime then
    if fmi_InputTime then
      fmi_Functions.fmiSetReal(fmi, {352321536}, {_ambient_T_old});
    else
      if fmi_UsePreOnInputSignals then
        fmi_Functions.fmiSetReal(fmi, {352321536}, {pre(ambient_T)});
      else
        fmi_Functions.fmiSetReal(fmi, {352321536}, {ambient_T});
      end if;
    end if;
    if fmi_InputTime then
      fmi_Functions.fmiSetReal(fmi, {352321537}, {_HTF_m_flow_old});
    else
      if fmi_UsePreOnInputSignals then
        fmi_Functions.fmiSetReal(fmi, {352321537}, {pre(HTF_m_flow)});
      else
        fmi_Functions.fmiSetReal(fmi, {352321537}, {HTF_m_flow});
      end if;
    end if;
    if fmi_InputTime then
      fmi_Functions.fmiSetReal(fmi, {352321538}, {_HTF_T_old});
    else
      if fmi_UsePreOnInputSignals then
        fmi_Functions.fmiSetReal(fmi, {352321538}, {pre(HTF_T)});
      else
        fmi_Functions.fmiSetReal(fmi, {352321538}, {HTF_T});
      end if;
    end if;
    if fmi_InputTime then
      fmi_Functions.fmiSetReal(fmi, {352321539}, {_floor_T_old});
    else
      if fmi_UsePreOnInputSignals then
        fmi_Functions.fmiSetReal(fmi, {352321539}, {pre(floor_T)});
      else
        fmi_Functions.fmiSetReal(fmi, {352321539}, {floor_T});
      end if;
    end if;
      for stepSizeIndex in 1:stepSizeScaleFactor loop
        fmi_StepOK :=fmi_Functions.fmiDoStep(
          fmi,
          time + (stepSizeIndex - 1 - stepSizeScaleFactor)*
            fmi_CommunicationStepSize/stepSizeScaleFactor,
          fmi_CommunicationStepSize/stepSizeScaleFactor);
      end for;
    end if;
    _ambient_T_old := ambient_T;
    _HTF_m_flow_old := HTF_m_flow;
    _HTF_T_old := HTF_T;
    _floor_T_old := floor_T;
  inletHTF_T :=fmi_Functions.fmiGetRealScalar(
      fmi,
      335544320,
      1);
  PCM_T :=fmi_Functions.fmiGetRealScalar(
      fmi,
      335544321,
      1);
  outletHTF_T :=fmi_Functions.fmiGetRealScalar(
      fmi,
      335544322,
      1);
RealVariables1 :=fmi_Functions.fmiGetReal(
      fmi,
      {352321536,905969683,352321536,352321537,905974411,369098812,637534269,
        369098883,100668030,369098884,637534341,369103100,637534342,369103100,
        637534343,369103100,369098890,33554432,587202560,369098891,369098892,
        369098893,369098902,905969815,369098904,369098906,905969819,369098908,
        905969821,369103102,637534367,369103102,637534368,369103102,369098915,
        33554433,587202561,369098916,369098917,369098918,369098927,905969840,
        369098929,369098931,905969844,369098933,905969846,369103104,637534392,
        369103104,637534393,369103104,369098940,33554434,587202562,369098941,
        369098942,369098943,369098952,905969865,369098954,369098956,905969869,
        369098958,905969871,369103106,637534417,369103106,637534418,369103106,
        369098965,33554435,587202563,369098966,369098967,369098968,369098977,
        905969890,369098979,369098981,905969894,369098983,905969896,369103108,
        637534442,369103108,637534443,369103108,369098990,33554436,587202564,
        369098991,369098992,369098993,369099002,905969915,369099004,369099006,
        905969919,369099008},
      1);
RealVariables2 :=fmi_Functions.fmiGetReal(
      fmi,
      {905969921,369103110,637534467,369103110,637534468,369103110,369099015,
        33554437,587202565,369099016,369099017,369099018,369099027,905969940,
        369099029,369099031,905969944,369099033,905969946,369103112,637534492,
        369103112,637534493,369103112,369099040,33554438,587202566,369099041,
        369099042,369099043,369099052,905969965,369099054,369099056,905969969,
        369099058,905969971,369103114,637534517,369103114,637534518,369103114,
        369099065,33554439,587202567,369099066,369099067,369099068,369099077,
        905969990,369099079,369099081,905969994,369099083,905969996,369103116,
        637534542,369103116,637534543,369103116,369099090,33554440,587202568,
        369099091,369099092,369099093,369099102,905970015,369099104,369099106,
        905970019,369099108,905970021,369103118,637534567,369103118,637534568,
        369103118,369099115,33554441,587202569,369099116,369099117,369099118,
        369099127,905970040,369099129,369099131,905970044,369099133,905970046,
        369103120,637534592,369103120,637534593,369103120,369099140,33554442,
        587202570,369099141},
      1);
RealVariables3 :=fmi_Functions.fmiGetReal(
      fmi,
      {369099142,369099143,369099152,905970065,369099154,369099156,905970069,
        369099158,905970071,369103122,637534617,369103122,637534618,369103122,
        369099165,33554443,587202571,369099166,369099167,369099168,369099177,
        905970090,369099179,369099181,905970094,369099183,905970096,369103124,
        637534642,369103124,637534643,369103124,369099190,33554444,587202572,
        369099191,369099192,369099193,369099202,905970115,369099204,369099206,
        905970119,369099208,905970121,369103126,637534667,369103126,637534668,
        369103126,369099215,33554445,587202573,369099216,369099217,369099218,
        369099227,905970140,369099229,369099231,905970144,369099233,905970146,
        369103128,637534692,369103128,637534693,369103128,369099240,33554446,
        587202574,369099241,369099242,369099243,369099252,905970165,369099254,
        369099256,905970169,369099258,905970171,369103130,637534717,369103130,
        637534718,369103130,369099265,33554447,587202575,369099266,369099267,
        369099268,369099277,905970190,369099279,369099281,905970194,369099283,
        905970196,369103132},
      1);
RealVariables4 :=fmi_Functions.fmiGetReal(
      fmi,
      {637534742,369103132,637534743,369103132,369099290,33554448,587202576,
        369099291,369099292,369099293,369099302,905970215,369099304,369099306,
        905970219,369099308,905970221,369103134,637534767,369103134,637534768,
        369103134,369099315,33554449,587202577,369099316,369099317,369099318,
        369099327,905970240,369099329,369099331,905970244,369099333,905970246,
        369103136,637534792,369103136,637534793,369103136,369099340,33554450,
        587202578,369099341,369099342,369099343,369099352,905970265,369099354,
        369099356,905970269,369099358,905970271,369103138,637534817,369103138,
        637534818,369103138,369099365,33554451,587202579,369099366,369099367,
        369099368,369099377,905970290,369099379,369099381,905970294,369099383,
        905970296,369103140,637534842,369103140,637534843,369103140,369099390,
        33554452,587202580,369099391,369099392,369099393,369099402,905970315,
        369099404,369099406,905970319,369099408,905970321,369103142,637534867,
        369103142,637534868,369103142,369099415,33554453,587202581,369099416,
        369099417,369099418},
      1);
RealVariables5 :=fmi_Functions.fmiGetReal(
      fmi,
      {369099427,905970340,369099429,369099431,905970344,369099433,905970346,
        369103144,637534892,369103144,637534893,369103144,369099440,33554454,
        587202582,369099441,369099442,369099443,369099452,905970365,369099454,
        369099456,905970369,369099458,905970371,369103146,637534917,369103146,
        637534918,369103146,369099465,33554455,587202583,369099466,369099467,
        369099468,369099477,905970390,369099479,369099481,905970394,369099483,
        905970396,369103148,637534942,369103148,637534943,369103148,369099490,
        33554456,587202584,369099491,369099492,369099493,369099502,905970415,
        369099504,369099506,905970419,369099508,905970421,369103150,637534967,
        369103150,637534968,369103150,369099515,33554457,587202585,369099516,
        369099517,369099518,369099527,905970440,369099529,369099531,905970444,
        369099533,905970446,369103152,637534992,369103152,637534993,369103152,
        369099540,33554458,587202586,369099541,369099542,369099543,369099552,
        905970465,369099554,369099556,905970469,369099558,905970471,369103154,
        637535017,369103154},
      1);
RealVariables6 :=fmi_Functions.fmiGetReal(
      fmi,
      {637535018,369103154,369099565,33554459,587202587,369099566,369099567,
        369099568,369099577,905970490,369099579,369099581,905970494,369099583,
        905970496,369103156,637535042,369103156,637535043,369103156,369099590,
        33554460,587202588,369099591,369099592,369099593,369099602,905970515,
        369099604,369099606,905970519,369099608,905970521,369103158,637535067,
        369103158,637535068,369103158,369099615,33554461,587202589,369099616,
        369099617,369099618,369099627,905970540,369099629,369099631,905970544,
        369099633,905970546,369103160,637535092,369103160,637535093,369103160,
        369099640,33554462,587202590,369099641,369099642,369099643,369099652,
        905970565,369099654,369099656,905970569,369099658,905970571,369103162,
        637535117,369103162,637535118,369103162,369099665,33554463,587202591,
        369099666,369099667,369099668,369099677,905970590,369099679,369099681,
        905970594,369099683,905970596,369103164,637535142,369103164,637535143,
        369103164,369099690,33554464,587202592,369099691,369099692,369099693,
        369099702,905970615},
      1);
RealVariables7 :=fmi_Functions.fmiGetReal(
      fmi,
      {369099704,369099706,905970619,369099708,905970621,369103166,637535167,
        369103166,637535168,369103166,369099715,33554465,587202593,369099716,
        369099717,369099718,369099727,905970640,369099729,369099731,905970644,
        369099733,905970646,369103168,637535192,369103168,637535193,369103168,
        369099740,33554466,587202594,369099741,369099742,369099743,369099752,
        905970665,369099754,369099756,905970669,369099758,905970671,369103170,
        637535217,369103170,637535218,369103170,369099765,33554467,587202595,
        369099766,369099767,369099768,369099777,905970690,369099779,369099781,
        905970694,369099783,905970696,369103172,637535242,369103172,637535243,
        369103172,369099790,33554468,587202596,369099791,369099792,369099793,
        369099802,905970715,369099804,369099806,905970719,369099808,905970721,
        369103174,637535267,369103174,637535268,369103174,369099815,33554469,
        587202597,369099816,369099817,369099818,369099827,905970740,369099829,
        369099831,905970744,369099833,905970746,369103176,637535292,369103176,
        637535293,369103176},
      1);
RealVariables8 :=fmi_Functions.fmiGetReal(
      fmi,
      {369099840,33554470,587202598,369099841,369099842,369099843,369099852,
        905970765,369099854,369099856,905970769,369099858,905970771,369103178,
        637535317,369103178,637535318,369103178,369099865,33554471,587202599,
        369099866,369099867,369099868,369099877,905970790,369099879,369099881,
        905970794,369099883,905970796,369103180,637535342,369103180,637535343,
        369103180,369099890,33554472,587202600,369099891,369099892,369099893,
        369099902,905970815,369099904,369099906,905970819,369099908,905970821,
        369103182,637535367,369103182,637535368,369103182,369099915,33554473,
        587202601,369099916,369099917,369099918,369099927,905970840,369099929,
        369099931,905970844,369099933,905970846,369103184,637535392,369103184,
        637535393,369103184,369099940,33554474,587202602,369099941,369099942,
        369099943,369099952,905970865,369099954,369099956,905970869,369099958,
        905970871,369103186,637535417,369103186,637535418,369103186,369099965,
        33554475,587202603,369099966,369099967,369099968,369099977,905970890,
        369099979,369099981},
      1);
RealVariables9 :=fmi_Functions.fmiGetReal(
      fmi,
      {905970894,369099983,905970896,369103188,637535442,369103188,637535443,
        369103188,369099990,33554476,587202604,369099991,369099992,369099993,
        369100002,905970915,369100004,369100006,905970919,369100008,905970921,
        369103190,637535467,369103190,637535468,369103190,369100015,33554477,
        587202605,369100016,369100017,369100018,369100027,905970940,369100029,
        369100031,905970944,369100033,905970946,369103192,637535492,369103192,
        637535493,369103192,369100040,33554478,587202606,369100041,369100042,
        369100043,369100052,905970965,369100054,369100056,905970969,369100058,
        905970971,369103194,637535517,369103194,637535518,369103194,369100065,
        33554479,587202607,369100066,369100067,369100068,369100077,905970990,
        369100079,369100081,905970994,369100083,905970996,369103196,637535542,
        369103196,637535543,369103196,369100090,33554480,587202608,369100091,
        369100092,369100093,369100102,905971015,369100104,369100106,905971019,
        369100108,905971021,369103198,637535567,369103198,637535568,369103198,
        369100115,33554481},
      1);
RealVariables10 :=fmi_Functions.fmiGetReal(
      fmi,
      {587202609,369100116,369100117,369100118,369100127,905971040,369100129,
        369100131,905971044,369100133,905971046,369103200,637535592,369103200,
        637535593,369103200,369100140,33554482,587202610,369100141,369100142,
        369100143,369100152,905971065,369100154,369100156,905971069,369100158,
        905971071,369103202,637535617,369103202,637535618,369103202,369100165,
        33554483,587202611,369100166,369100167,369100168,369100177,905971090,
        369100179,369100181,905971094,369100183,905971096,369103204,637535642,
        369103204,637535643,369103204,369100190,33554484,587202612,369100191,
        369100192,369100193,369100202,905971115,369100204,369100206,905971119,
        369100208,905971121,369103206,637535667,369103206,637535668,369103206,
        369100215,33554485,587202613,369100216,369100217,369100218,369100227,
        905971140,369100229,369100231,905971144,369100233,905971146,369103208,
        637535692,369103208,637535693,369103208,369100240,33554486,587202614,
        369100241,369100242,369100243,369100252,905971165,369100254,369100256,
        905971169,369100258},
      1);
RealVariables11 :=fmi_Functions.fmiGetReal(
      fmi,
      {905971171,369103210,637535717,369103210,637535718,369103210,369100265,
        33554487,587202615,369100266,369100267,369100268,369100277,905971190,
        369100279,369100281,905971194,369100283,905971196,369103212,637535742,
        369103212,637535743,369103212,369100290,33554488,587202616,369100291,
        369100292,369100293,369100302,905971215,369100304,369100306,905971219,
        369100308,905971221,369103214,637535767,369103214,637535768,369103214,
        369100315,33554489,587202617,369100316,369100317,369100318,369100327,
        905971240,369100329,369100331,905971244,369100333,905971246,369103216,
        637535792,369103216,637535793,369103216,369100340,33554490,587202618,
        369100341,369100342,369100343,369100352,905971265,369100354,369100356,
        905971269,369100358,905971271,369103218,637535817,369103218,637535818,
        369103218,369100365,33554491,587202619,369100366,369100367,369100368,
        369100377,905971290,369100379,369100381,905971294,369100383,905971296,
        369103220,637535842,369103220,637535843,369103220,369100390,33554492,
        587202620,369100391},
      1);
RealVariables12 :=fmi_Functions.fmiGetReal(
      fmi,
      {369100392,369100393,369100402,905971315,369100404,369100406,905971319,
        369100408,905971321,369103222,637535867,369103222,637535868,369103222,
        369100415,33554493,587202621,369100416,369100417,369100418,369100427,
        905971340,369100429,369100431,905971344,369100433,905971346,369103224,
        637535892,369103224,637535893,369103224,369100440,33554494,587202622,
        369100441,369100442,369100443,369100452,905971365,369100454,369100456,
        905971369,369100458,905971371,369103226,637535917,369103226,637535918,
        369103226,369100465,33554495,587202623,369100466,369100467,369100468,
        369100477,905971390,369100479,369100481,905971394,369100483,905971396,
        369103228,637535942,369103228,637535943,369103228,369100490,33554496,
        587202624,369100491,369100492,369100493,369100502,905971415,369100504,
        369100506,905971419,369100508,905971421,369103230,637535967,369103230,
        637535968,369103230,369100515,33554497,587202625,369100516,369100517,
        369100518,369100527,905971440,369100529,369100531,905971444,369100533,
        905971446,369103232},
      1);
RealVariables13 :=fmi_Functions.fmiGetReal(
      fmi,
      {637535992,369103232,637535993,369103232,369100540,33554498,587202626,
        369100541,369100542,369100543,369100552,905971465,369100554,369100556,
        905971469,369100558,905971471,369103234,637536017,369103234,637536018,
        369103234,369100565,33554499,587202627,369100566,369100567,369100568,
        369100577,905971490,369100579,369100581,905971494,369100583,905971496,
        369103236,637536042,369103236,637536043,369103236,369100590,33554500,
        587202628,369100591,369100592,369100593,369100602,905971515,369100604,
        369100606,905971519,369100608,905971521,369103238,637536067,369103238,
        637536068,369103238,369100615,33554501,587202629,369100616,369100617,
        369100618,369100627,905971540,369100629,369100631,905971544,369100633,
        905971546,369103240,637536092,369103240,637536093,369103240,369100640,
        33554502,587202630,369100641,369100642,369100643,369100652,905971565,
        369100654,369100656,905971569,369100658,905971571,369103242,637536117,
        369103242,637536118,369103242,369100665,33554503,587202631,369100666,
        369100667,369100668},
      1);
RealVariables14 :=fmi_Functions.fmiGetReal(
      fmi,
      {369100677,905971590,369100679,369100681,905971594,369100683,905971596,
        369103244,637536142,369103244,637536143,369103244,369100690,33554504,
        587202632,369100691,369100692,369100693,369100702,905971615,369100704,
        369100706,905971619,369100708,905971621,369103246,637536167,369103246,
        637536168,369103246,369100715,33554505,587202633,369100716,369100717,
        369100718,369100727,905971640,369100729,369100731,905971644,369100733,
        905971646,369103248,637536192,369103248,637536193,369103248,369100740,
        33554506,587202634,369100741,369100742,369100743,369100752,905971665,
        369100754,369100756,905971669,369100758,905971671,369103250,637536217,
        369103250,637536218,369103250,369100765,33554507,587202635,369100766,
        369100767,369100768,369100777,905971690,369100779,369100781,905971694,
        369100783,905971696,369103252,637536242,369103252,637536243,369103252,
        369100790,33554508,587202636,369100791,369100792,369100793,369100802,
        905971715,369100804,369100806,905971719,369100808,905971721,369103254,
        637536267,369103254},
      1);
RealVariables15 :=fmi_Functions.fmiGetReal(
      fmi,
      {637536268,369103254,369100815,33554509,587202637,369100816,369100817,
        369100818,369100827,905971740,369100829,369100831,905971744,369100833,
        905971746,369103256,637536292,369103256,637536293,369103256,369100840,
        33554510,587202638,369100841,369100842,369100843,369100852,905971765,
        369100854,369100856,905971769,369100858,905971771,369103258,637536317,
        369103258,637536318,369103258,369100865,33554511,587202639,369100866,
        369100867,369100868,369100877,905971790,369100879,369100881,905971794,
        369100883,905971796,369103260,637536342,369103260,637536343,369103260,
        369100890,33554512,587202640,369100891,369100892,369100893,369100902,
        905971815,369100904,369100906,905971819,369100908,905971821,369103262,
        637536367,369103262,637536368,369103262,369100915,33554513,587202641,
        369100916,369100917,369100918,369100927,905971840,369100929,369100931,
        905971844,369100933,905971846,369103264,637536392,369103264,637536393,
        369103264,369100940,33554514,587202642,369100941,369100942,369100943,
        369100952,905971865},
      1);
RealVariables16 :=fmi_Functions.fmiGetReal(
      fmi,
      {369100954,369100956,905971869,369100958,905971871,369103266,637536417,
        369103266,637536418,369103266,369100965,33554515,587202643,369100966,
        369100967,369100968,369100977,905971890,369100979,369100981,905971894,
        369100983,905971896,369103268,637536442,369103268,637536443,369103268,
        369100990,33554516,587202644,369100991,369100992,369100993,369101002,
        905971915,369101004,369101006,905971919,369101008,905971921,369103270,
        637536467,369103270,637536468,369103270,369101015,33554517,587202645,
        369101016,369101017,369101018,369101027,905971940,369101029,369101031,
        905971944,369101033,905971946,369103272,637536492,369103272,637536493,
        369103272,369101040,33554518,587202646,369101041,369101042,369101043,
        369101052,905971965,369101054,369101056,905971969,369101058,905971971,
        369103274,637536517,369103274,637536518,369103274,369101065,33554519,
        587202647,369101066,369101067,369101068,369101077,905971990,369101079,
        369101081,905971994,369101083,905971996,369103276,637536542,369103276,
        637536543,369103276},
      1);
RealVariables17 :=fmi_Functions.fmiGetReal(
      fmi,
      {369101090,33554520,587202648,369101091,369101092,369101093,369101102,
        905972015,369101104,369101106,905972019,369101108,905972021,369103278,
        637536567,369103278,637536568,369103278,369101115,33554521,587202649,
        369101116,369101117,369101118,369101127,905972040,369101129,369101131,
        905972044,369101133,905972046,369103280,637536592,369103280,637536593,
        369103280,369101140,33554522,587202650,369101141,369101142,369101143,
        369101152,905972065,369101154,369101156,905972069,369101158,905972071,
        369103282,637536617,369103282,637536618,369103282,369101165,33554523,
        587202651,369101166,369101167,369101168,369101177,905972090,369101179,
        369101181,905972094,369101183,905972096,369103284,637536642,369103284,
        637536643,369103284,369101190,33554524,587202652,369101191,369101192,
        369101193,369101202,905972115,369101204,369101206,905972119,369101208,
        905972121,369103286,637536667,369103286,637536668,369103286,369101215,
        33554525,587202653,369101216,369101217,369101218,369101227,905972140,
        369101229,369101231},
      1);
RealVariables18 :=fmi_Functions.fmiGetReal(
      fmi,
      {905972144,369101233,905972146,369103288,637536692,369103288,637536693,
        369103288,369101240,33554526,587202654,369101241,369101242,369101243,
        369101252,905972165,369101254,369101256,905972169,369101258,905972171,
        369103290,637536717,369103290,637536718,369103290,369101265,33554527,
        587202655,369101266,369101267,369101268,369101277,905972190,369101279,
        369101281,905972194,369101283,905972196,369103292,637536742,369103292,
        637536743,369103292,369101290,33554528,587202656,369101291,369101292,
        369101293,369101302,905972215,369101304,369101306,905972219,369101308,
        905972221,369103294,637536767,369103294,637536768,369103294,369101315,
        33554529,587202657,369101316,369101317,369101318,369101327,905972240,
        369101329,369101331,905972244,369101333,905972246,369103296,637536792,
        369103296,637536793,369103296,369101340,33554530,587202658,369101341,
        369101342,369101343,369101352,905972265,369101354,369101356,905972269,
        369101358,905972271,369103298,637536817,369103298,637536818,369103298,
        369101365,33554531},
      1);
RealVariables19 :=fmi_Functions.fmiGetReal(
      fmi,
      {587202659,369101366,369101367,369101368,369101377,905972290,369101379,
        369101381,905972294,369101383,905972296,637536853,637536844,33554639,
        637536853,33554532,637536845,637534248,637534343,637536846,33554532,
        637534343,369103100,637536847,637534258,33554532,587202660,637536848,
        33554532,637536848,587202660,637536851,33554639,637536853,369103100,
        637536847,637534248,637534258,637536865,637536856,33554641,637536865,
        33554533,637536857,637534249,637534368,637536858,33554533,637534368,
        369103102,637536859,637534259,33554533,587202661,637536860,33554533,
        637536860,587202661,637536863,33554641,637536865,369103102,637536859,
        637534249,637534259,637536877,637536868,33554643,637536877,33554534,
        637536869,637534250,637534393,637536870,33554534,637534393,369103104,
        637536871,637534260,33554534,587202662,637536872,33554534,637536872,
        587202662,637536875,33554643,637536877,369103104,637536871,637534250,
        637534260,637536889,637536880,33554645,637536889,33554535,637536881,
        637534251,637534418},
      1);
RealVariables20 :=fmi_Functions.fmiGetReal(
      fmi,
      {637536882,33554535,637534418,369103106,637536883,637534261,33554535,
        587202663,637536884,33554535,637536884,587202663,637536887,33554645,
        637536889,369103106,637536883,637534251,637534261,637536901,637536892,
        33554647,637536901,33554536,637536893,637534252,637534443,637536894,
        33554536,637534443,369103108,637536895,637534262,33554536,587202664,
        637536896,33554536,637536896,587202664,637536899,33554647,637536901,
        369103108,637536895,637534252,637534262,637536913,637536904,33554649,
        637536913,33554537,637536905,637534253,637534468,637536906,33554537,
        637534468,369103110,637536907,637534263,33554537,587202665,637536908,
        33554537,637536908,587202665,637536911,33554649,637536913,369103110,
        637536907,637534253,637534263,637536925,637536916,33554651,637536925,
        33554538,637536917,637534254,637534493,637536918,33554538,637534493,
        369103112,637536919,637534264,33554538,587202666,637536920,33554538,
        637536920,587202666,637536923,33554651,637536925,369103112,637536919,
        637534254,637534264},
      1);
RealVariables21 :=fmi_Functions.fmiGetReal(
      fmi,
      {637536937,637536928,33554653,637536937,33554539,637536929,637534255,
        637534518,637536930,33554539,637534518,369103114,637536931,637534265,
        33554539,587202667,637536932,33554539,637536932,587202667,637536935,
        33554653,637536937,369103114,637536931,637534255,637534265,637536949,
        637536940,33554655,637536949,33554540,637536941,637534256,637534543,
        637536942,33554540,637534543,369103116,637536943,637534266,33554540,
        587202668,637536944,33554540,637536944,587202668,637536947,33554655,
        637536949,369103116,637536943,637534256,637534266,637536961,637536952,
        33554657,637536961,33554541,637536953,637534257,637534568,637536954,
        33554541,637534568,369103118,637536955,637534267,33554541,587202669,
        637536956,33554541,637536956,587202669,637536959,33554657,637536961,
        369103118,637536955,637534257,637534267,637536973,637536964,33554639,
        637536973,33554542,637536965,637534248,637534593,637536966,33554542,
        637534593,369103120,637536967,637534258,33554542,587202670,637536968,
        33554542,637536968},
      1);
RealVariables22 :=fmi_Functions.fmiGetReal(
      fmi,
      {587202670,637536971,33554639,637536973,369103120,637536967,637534248,
        637534258,637536985,637536976,33554641,637536985,33554543,637536977,
        637534249,637534618,637536978,33554543,637534618,369103122,637536979,
        637534259,33554543,587202671,637536980,33554543,637536980,587202671,
        637536983,33554641,637536985,369103122,637536979,637534249,637534259,
        637536997,637536988,33554643,637536997,33554544,637536989,637534250,
        637534643,637536990,33554544,637534643,369103124,637536991,637534260,
        33554544,587202672,637536992,33554544,637536992,587202672,637536995,
        33554643,637536997,369103124,637536991,637534250,637534260,637537009,
        637537000,33554645,637537009,33554545,637537001,637534251,637534668,
        637537002,33554545,637534668,369103126,637537003,637534261,33554545,
        587202673,637537004,33554545,637537004,587202673,637537007,33554645,
        637537009,369103126,637537003,637534251,637534261,637537021,637537012,
        33554647,637537021,33554546,637537013,637534252,637534693,637537014,
        33554546,637534693},
      1);
RealVariables23 :=fmi_Functions.fmiGetReal(
      fmi,
      {369103128,637537015,637534262,33554546,587202674,637537016,33554546,
        637537016,587202674,637537019,33554647,637537021,369103128,637537015,
        637534252,637534262,637537033,637537024,33554649,637537033,33554547,
        637537025,637534253,637534718,637537026,33554547,637534718,369103130,
        637537027,637534263,33554547,587202675,637537028,33554547,637537028,
        587202675,637537031,33554649,637537033,369103130,637537027,637534253,
        637534263,637537045,637537036,33554651,637537045,33554548,637537037,
        637534254,637534743,637537038,33554548,637534743,369103132,637537039,
        637534264,33554548,587202676,637537040,33554548,637537040,587202676,
        637537043,33554651,637537045,369103132,637537039,637534254,637534264,
        637537057,637537048,33554653,637537057,33554549,637537049,637534255,
        637534768,637537050,33554549,637534768,369103134,637537051,637534265,
        33554549,587202677,637537052,33554549,637537052,587202677,637537055,
        33554653,637537057,369103134,637537051,637534255,637534265,637537069,
        637537060,33554655},
      1);
RealVariables24 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537069,33554550,637537061,637534256,637534793,637537062,33554550,
        637534793,369103136,637537063,637534266,33554550,587202678,637537064,
        33554550,637537064,587202678,637537067,33554655,637537069,369103136,
        637537063,637534256,637534266,637537081,637537072,33554657,637537081,
        33554551,637537073,637534257,637534818,637537074,33554551,637534818,
        369103138,637537075,637534267,33554551,587202679,637537076,33554551,
        637537076,587202679,637537079,33554657,637537081,369103138,637537075,
        637534257,637534267,637537093,637537084,33554639,637537093,33554552,
        637537085,637534248,637534843,637537086,33554552,637534843,369103140,
        637537087,637534258,33554552,587202680,637537088,33554552,637537088,
        587202680,637537091,33554639,637537093,369103140,637537087,637534248,
        637534258,637537105,637537096,33554641,637537105,33554553,637537097,
        637534249,637534868,637537098,33554553,637534868,369103142,637537099,
        637534259,33554553,587202681,637537100,33554553,637537100,587202681,
        637537103,33554641},
      1);
RealVariables25 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537105,369103142,637537099,637534249,637534259,637537117,637537108,
        33554643,637537117,33554554,637537109,637534250,637534893,637537110,
        33554554,637534893,369103144,637537111,637534260,33554554,587202682,
        637537112,33554554,637537112,587202682,637537115,33554643,637537117,
        369103144,637537111,637534250,637534260,637537129,637537120,33554645,
        637537129,33554555,637537121,637534251,637534918,637537122,33554555,
        637534918,369103146,637537123,637534261,33554555,587202683,637537124,
        33554555,637537124,587202683,637537127,33554645,637537129,369103146,
        637537123,637534251,637534261,637537141,637537132,33554647,637537141,
        33554556,637537133,637534252,637534943,637537134,33554556,637534943,
        369103148,637537135,637534262,33554556,587202684,637537136,33554556,
        637537136,587202684,637537139,33554647,637537141,369103148,637537135,
        637534252,637534262,637537153,637537144,33554649,637537153,33554557,
        637537145,637534253,637534968,637537146,33554557,637534968,369103150,
        637537147,637534263},
      1);
RealVariables26 :=fmi_Functions.fmiGetReal(
      fmi,
      {33554557,587202685,637537148,33554557,637537148,587202685,637537151,
        33554649,637537153,369103150,637537147,637534253,637534263,637537165,
        637537156,33554651,637537165,33554558,637537157,637534254,637534993,
        637537158,33554558,637534993,369103152,637537159,637534264,33554558,
        587202686,637537160,33554558,637537160,587202686,637537163,33554651,
        637537165,369103152,637537159,637534254,637534264,637537177,637537168,
        33554653,637537177,33554559,637537169,637534255,637535018,637537170,
        33554559,637535018,369103154,637537171,637534265,33554559,587202687,
        637537172,33554559,637537172,587202687,637537175,33554653,637537177,
        369103154,637537171,637534255,637534265,637537189,637537180,33554655,
        637537189,33554560,637537181,637534256,637535043,637537182,33554560,
        637535043,369103156,637537183,637534266,33554560,587202688,637537184,
        33554560,637537184,587202688,637537187,33554655,637537189,369103156,
        637537183,637534256,637534266,637537201,637537192,33554657,637537201,
        33554561,637537193},
      1);
RealVariables27 :=fmi_Functions.fmiGetReal(
      fmi,
      {637534257,637535068,637537194,33554561,637535068,369103158,637537195,
        637534267,33554561,587202689,637537196,33554561,637537196,587202689,
        637537199,33554657,637537201,369103158,637537195,637534257,637534267,
        637537213,637537204,33554639,637537213,33554562,637537205,637534248,
        637535093,637537206,33554562,637535093,369103160,637537207,637534258,
        33554562,587202690,637537208,33554562,637537208,587202690,637537211,
        33554639,637537213,369103160,637537207,637534248,637534258,637537225,
        637537216,33554641,637537225,33554563,637537217,637534249,637535118,
        637537218,33554563,637535118,369103162,637537219,637534259,33554563,
        587202691,637537220,33554563,637537220,587202691,637537223,33554641,
        637537225,369103162,637537219,637534249,637534259,637537237,637537228,
        33554643,637537237,33554564,637537229,637534250,637535143,637537230,
        33554564,637535143,369103164,637537231,637534260,33554564,587202692,
        637537232,33554564,637537232,587202692,637537235,33554643,637537237,
        369103164,637537231},
      1);
RealVariables28 :=fmi_Functions.fmiGetReal(
      fmi,
      {637534250,637534260,637537249,637537240,33554645,637537249,33554565,
        637537241,637534251,637535168,637537242,33554565,637535168,369103166,
        637537243,637534261,33554565,587202693,637537244,33554565,637537244,
        587202693,637537247,33554645,637537249,369103166,637537243,637534251,
        637534261,637537261,637537252,33554647,637537261,33554566,637537253,
        637534252,637535193,637537254,33554566,637535193,369103168,637537255,
        637534262,33554566,587202694,637537256,33554566,637537256,587202694,
        637537259,33554647,637537261,369103168,637537255,637534252,637534262,
        637537273,637537264,33554649,637537273,33554567,637537265,637534253,
        637535218,637537266,33554567,637535218,369103170,637537267,637534263,
        33554567,587202695,637537268,33554567,637537268,587202695,637537271,
        33554649,637537273,369103170,637537267,637534253,637534263,637537285,
        637537276,33554651,637537285,33554568,637537277,637534254,637535243,
        637537278,33554568,637535243,369103172,637537279,637534264,33554568,
        587202696,637537280},
      1);
RealVariables29 :=fmi_Functions.fmiGetReal(
      fmi,
      {33554568,637537280,587202696,637537283,33554651,637537285,369103172,
        637537279,637534254,637534264,637537297,637537288,33554653,637537297,
        33554569,637537289,637534255,637535268,637537290,33554569,637535268,
        369103174,637537291,637534265,33554569,587202697,637537292,33554569,
        637537292,587202697,637537295,33554653,637537297,369103174,637537291,
        637534255,637534265,637537309,637537300,33554655,637537309,33554570,
        637537301,637534256,637535293,637537302,33554570,637535293,369103176,
        637537303,637534266,33554570,587202698,637537304,33554570,637537304,
        587202698,637537307,33554655,637537309,369103176,637537303,637534256,
        637534266,637537321,637537312,33554657,637537321,33554571,637537313,
        637534257,637535318,637537314,33554571,637535318,369103178,637537315,
        637534267,33554571,587202699,637537316,33554571,637537316,587202699,
        637537319,33554657,637537321,369103178,637537315,637534257,637534267,
        637537333,637537324,33554639,637537333,33554572,637537325,637534248,
        637535343,637537326},
      1);
RealVariables30 :=fmi_Functions.fmiGetReal(
      fmi,
      {33554572,637535343,369103180,637537327,637534258,33554572,587202700,
        637537328,33554572,637537328,587202700,637537331,33554639,637537333,
        369103180,637537327,637534248,637534258,637537345,637537336,33554641,
        637537345,33554573,637537337,637534249,637535368,637537338,33554573,
        637535368,369103182,637537339,637534259,33554573,587202701,637537340,
        33554573,637537340,587202701,637537343,33554641,637537345,369103182,
        637537339,637534249,637534259,637537357,637537348,33554643,637537357,
        33554574,637537349,637534250,637535393,637537350,33554574,637535393,
        369103184,637537351,637534260,33554574,587202702,637537352,33554574,
        637537352,587202702,637537355,33554643,637537357,369103184,637537351,
        637534250,637534260,637537369,637537360,33554645,637537369,33554575,
        637537361,637534251,637535418,637537362,33554575,637535418,369103186,
        637537363,637534261,33554575,587202703,637537364,33554575,637537364,
        587202703,637537367,33554645,637537369,369103186,637537363,637534251,
        637534261,637537381},
      1);
RealVariables31 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537372,33554647,637537381,33554576,637537373,637534252,637535443,
        637537374,33554576,637535443,369103188,637537375,637534262,33554576,
        587202704,637537376,33554576,637537376,587202704,637537379,33554647,
        637537381,369103188,637537375,637534252,637534262,637537393,637537384,
        33554649,637537393,33554577,637537385,637534253,637535468,637537386,
        33554577,637535468,369103190,637537387,637534263,33554577,587202705,
        637537388,33554577,637537388,587202705,637537391,33554649,637537393,
        369103190,637537387,637534253,637534263,637537405,637537396,33554651,
        637537405,33554578,637537397,637534254,637535493,637537398,33554578,
        637535493,369103192,637537399,637534264,33554578,587202706,637537400,
        33554578,637537400,587202706,637537403,33554651,637537405,369103192,
        637537399,637534254,637534264,637537417,637537408,33554653,637537417,
        33554579,637537409,637534255,637535518,637537410,33554579,637535518,
        369103194,637537411,637534265,33554579,587202707,637537412,33554579,
        637537412,587202707},
      1);
RealVariables32 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537415,33554653,637537417,369103194,637537411,637534255,637534265,
        637537429,637537420,33554655,637537429,33554580,637537421,637534256,
        637535543,637537422,33554580,637535543,369103196,637537423,637534266,
        33554580,587202708,637537424,33554580,637537424,587202708,637537427,
        33554655,637537429,369103196,637537423,637534256,637534266,637537441,
        637537432,33554657,637537441,33554581,637537433,637534257,637535568,
        637537434,33554581,637535568,369103198,637537435,637534267,33554581,
        587202709,637537436,33554581,637537436,587202709,637537439,33554657,
        637537441,369103198,637537435,637534257,637534267,637537453,637537444,
        33554639,637537453,33554582,637537445,637534248,637535593,637537446,
        33554582,637535593,369103200,637537447,637534258,33554582,587202710,
        637537448,33554582,637537448,587202710,637537451,33554639,637537453,
        369103200,637537447,637534248,637534258,637537465,637537456,33554641,
        637537465,33554583,637537457,637534249,637535618,637537458,33554583,
        637535618,369103202},
      1);
RealVariables33 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537459,637534259,33554583,587202711,637537460,33554583,637537460,
        587202711,637537463,33554641,637537465,369103202,637537459,637534249,
        637534259,637537477,637537468,33554643,637537477,33554584,637537469,
        637534250,637535643,637537470,33554584,637535643,369103204,637537471,
        637534260,33554584,587202712,637537472,33554584,637537472,587202712,
        637537475,33554643,637537477,369103204,637537471,637534250,637534260,
        637537489,637537480,33554645,637537489,33554585,637537481,637534251,
        637535668,637537482,33554585,637535668,369103206,637537483,637534261,
        33554585,587202713,637537484,33554585,637537484,587202713,637537487,
        33554645,637537489,369103206,637537483,637534251,637534261,637537501,
        637537492,33554647,637537501,33554586,637537493,637534252,637535693,
        637537494,33554586,637535693,369103208,637537495,637534262,33554586,
        587202714,637537496,33554586,637537496,587202714,637537499,33554647,
        637537501,369103208,637537495,637534252,637534262,637537513,637537504,
        33554649,637537513},
      1);
RealVariables34 :=fmi_Functions.fmiGetReal(
      fmi,
      {33554587,637537505,637534253,637535718,637537506,33554587,637535718,
        369103210,637537507,637534263,33554587,587202715,637537508,33554587,
        637537508,587202715,637537511,33554649,637537513,369103210,637537507,
        637534253,637534263,637537525,637537516,33554651,637537525,33554588,
        637537517,637534254,637535743,637537518,33554588,637535743,369103212,
        637537519,637534264,33554588,587202716,637537520,33554588,637537520,
        587202716,637537523,33554651,637537525,369103212,637537519,637534254,
        637534264,637537537,637537528,33554653,637537537,33554589,637537529,
        637534255,637535768,637537530,33554589,637535768,369103214,637537531,
        637534265,33554589,587202717,637537532,33554589,637537532,587202717,
        637537535,33554653,637537537,369103214,637537531,637534255,637534265,
        637537549,637537540,33554655,637537549,33554590,637537541,637534256,
        637535793,637537542,33554590,637535793,369103216,637537543,637534266,
        33554590,587202718,637537544,33554590,637537544,587202718,637537547,
        33554655,637537549},
      1);
RealVariables35 :=fmi_Functions.fmiGetReal(
      fmi,
      {369103216,637537543,637534256,637534266,637537561,637537552,33554657,
        637537561,33554591,637537553,637534257,637535818,637537554,33554591,
        637535818,369103218,637537555,637534267,33554591,587202719,637537556,
        33554591,637537556,587202719,637537559,33554657,637537561,369103218,
        637537555,637534257,637534267,637537573,637537564,33554639,637537573,
        33554592,637537565,637534248,637535843,637537566,33554592,637535843,
        369103220,637537567,637534258,33554592,587202720,637537568,33554592,
        637537568,587202720,637537571,33554639,637537573,369103220,637537567,
        637534248,637534258,637537585,637537576,33554641,637537585,33554593,
        637537577,637534249,637535868,637537578,33554593,637535868,369103222,
        637537579,637534259,33554593,587202721,637537580,33554593,637537580,
        587202721,637537583,33554641,637537585,369103222,637537579,637534249,
        637534259,637537597,637537588,33554643,637537597,33554594,637537589,
        637534250,637535893,637537590,33554594,637535893,369103224,637537591,
        637534260,33554594},
      1);
RealVariables36 :=fmi_Functions.fmiGetReal(
      fmi,
      {587202722,637537592,33554594,637537592,587202722,637537595,33554643,
        637537597,369103224,637537591,637534250,637534260,637537609,637537600,
        33554645,637537609,33554595,637537601,637534251,637535918,637537602,
        33554595,637535918,369103226,637537603,637534261,33554595,587202723,
        637537604,33554595,637537604,587202723,637537607,33554645,637537609,
        369103226,637537603,637534251,637534261,637537621,637537612,33554647,
        637537621,33554596,637537613,637534252,637535943,637537614,33554596,
        637535943,369103228,637537615,637534262,33554596,587202724,637537616,
        33554596,637537616,587202724,637537619,33554647,637537621,369103228,
        637537615,637534252,637534262,637537633,637537624,33554649,637537633,
        33554597,637537625,637534253,637535968,637537626,33554597,637535968,
        369103230,637537627,637534263,33554597,587202725,637537628,33554597,
        637537628,587202725,637537631,33554649,637537633,369103230,637537627,
        637534253,637534263,637537645,637537636,33554651,637537645,33554598,
        637537637,637534254},
      1);
RealVariables37 :=fmi_Functions.fmiGetReal(
      fmi,
      {637535993,637537638,33554598,637535993,369103232,637537639,637534264,
        33554598,587202726,637537640,33554598,637537640,587202726,637537643,
        33554651,637537645,369103232,637537639,637534254,637534264,637537657,
        637537648,33554653,637537657,33554599,637537649,637534255,637536018,
        637537650,33554599,637536018,369103234,637537651,637534265,33554599,
        587202727,637537652,33554599,637537652,587202727,637537655,33554653,
        637537657,369103234,637537651,637534255,637534265,637537669,637537660,
        33554655,637537669,33554600,637537661,637534256,637536043,637537662,
        33554600,637536043,369103236,637537663,637534266,33554600,587202728,
        637537664,33554600,637537664,587202728,637537667,33554655,637537669,
        369103236,637537663,637534256,637534266,637537681,637537672,33554657,
        637537681,33554601,637537673,637534257,637536068,637537674,33554601,
        637536068,369103238,637537675,637534267,33554601,587202729,637537676,
        33554601,637537676,587202729,637537679,33554657,637537681,369103238,
        637537675,637534257},
      1);
RealVariables38 :=fmi_Functions.fmiGetReal(
      fmi,
      {637534267,637537693,637537684,33554639,637537693,33554602,637537685,
        637534248,637536093,637537686,33554602,637536093,369103240,637537687,
        637534258,33554602,587202730,637537688,33554602,637537688,587202730,
        637537691,33554639,637537693,369103240,637537687,637534248,637534258,
        637537705,637537696,33554641,637537705,33554603,637537697,637534249,
        637536118,637537698,33554603,637536118,369103242,637537699,637534259,
        33554603,587202731,637537700,33554603,637537700,587202731,637537703,
        33554641,637537705,369103242,637537699,637534249,637534259,637537717,
        637537708,33554643,637537717,33554604,637537709,637534250,637536143,
        637537710,33554604,637536143,369103244,637537711,637534260,33554604,
        587202732,637537712,33554604,637537712,587202732,637537715,33554643,
        637537717,369103244,637537711,637534250,637534260,637537729,637537720,
        33554645,637537729,33554605,637537721,637534251,637536168,637537722,
        33554605,637536168,369103246,637537723,637534261,33554605,587202733,
        637537724,33554605},
      1);
RealVariables39 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537724,587202733,637537727,33554645,637537729,369103246,637537723,
        637534251,637534261,637537741,637537732,33554647,637537741,33554606,
        637537733,637534252,637536193,637537734,33554606,637536193,369103248,
        637537735,637534262,33554606,587202734,637537736,33554606,637537736,
        587202734,637537739,33554647,637537741,369103248,637537735,637534252,
        637534262,637537753,637537744,33554649,637537753,33554607,637537745,
        637534253,637536218,637537746,33554607,637536218,369103250,637537747,
        637534263,33554607,587202735,637537748,33554607,637537748,587202735,
        637537751,33554649,637537753,369103250,637537747,637534253,637534263,
        637537765,637537756,33554651,637537765,33554608,637537757,637534254,
        637536243,637537758,33554608,637536243,369103252,637537759,637534264,
        33554608,587202736,637537760,33554608,637537760,587202736,637537763,
        33554651,637537765,369103252,637537759,637534254,637534264,637537777,
        637537768,33554653,637537777,33554609,637537769,637534255,637536268,
        637537770,33554609},
      1);
RealVariables40 :=fmi_Functions.fmiGetReal(
      fmi,
      {637536268,369103254,637537771,637534265,33554609,587202737,637537772,
        33554609,637537772,587202737,637537775,33554653,637537777,369103254,
        637537771,637534255,637534265,637537789,637537780,33554655,637537789,
        33554610,637537781,637534256,637536293,637537782,33554610,637536293,
        369103256,637537783,637534266,33554610,587202738,637537784,33554610,
        637537784,587202738,637537787,33554655,637537789,369103256,637537783,
        637534256,637534266,637537801,637537792,33554657,637537801,33554611,
        637537793,637534257,637536318,637537794,33554611,637536318,369103258,
        637537795,637534267,33554611,587202739,637537796,33554611,637537796,
        587202739,637537799,33554657,637537801,369103258,637537795,637534257,
        637534267,637537813,637537804,33554639,637537813,33554612,637537805,
        637534248,637536343,637537806,33554612,637536343,369103260,637537807,
        637534258,33554612,587202740,637537808,33554612,637537808,587202740,
        637537811,33554639,637537813,369103260,637537807,637534248,637534258,
        637537825,637537816},
      1);
RealVariables41 :=fmi_Functions.fmiGetReal(
      fmi,
      {33554641,637537825,33554613,637537817,637534249,637536368,637537818,
        33554613,637536368,369103262,637537819,637534259,33554613,587202741,
        637537820,33554613,637537820,587202741,637537823,33554641,637537825,
        369103262,637537819,637534249,637534259,637537837,637537828,33554643,
        637537837,33554614,637537829,637534250,637536393,637537830,33554614,
        637536393,369103264,637537831,637534260,33554614,587202742,637537832,
        33554614,637537832,587202742,637537835,33554643,637537837,369103264,
        637537831,637534250,637534260,637537849,637537840,33554645,637537849,
        33554615,637537841,637534251,637536418,637537842,33554615,637536418,
        369103266,637537843,637534261,33554615,587202743,637537844,33554615,
        637537844,587202743,637537847,33554645,637537849,369103266,637537843,
        637534251,637534261,637537861,637537852,33554647,637537861,33554616,
        637537853,637534252,637536443,637537854,33554616,637536443,369103268,
        637537855,637534262,33554616,587202744,637537856,33554616,637537856,
        587202744,637537859},
      1);
RealVariables42 :=fmi_Functions.fmiGetReal(
      fmi,
      {33554647,637537861,369103268,637537855,637534252,637534262,637537873,
        637537864,33554649,637537873,33554617,637537865,637534253,637536468,
        637537866,33554617,637536468,369103270,637537867,637534263,33554617,
        587202745,637537868,33554617,637537868,587202745,637537871,33554649,
        637537873,369103270,637537867,637534253,637534263,637537885,637537876,
        33554651,637537885,33554618,637537877,637534254,637536493,637537878,
        33554618,637536493,369103272,637537879,637534264,33554618,587202746,
        637537880,33554618,637537880,587202746,637537883,33554651,637537885,
        369103272,637537879,637534254,637534264,637537897,637537888,33554653,
        637537897,33554619,637537889,637534255,637536518,637537890,33554619,
        637536518,369103274,637537891,637534265,33554619,587202747,637537892,
        33554619,637537892,587202747,637537895,33554653,637537897,369103274,
        637537891,637534255,637534265,637537909,637537900,33554655,637537909,
        33554620,637537901,637534256,637536543,637537902,33554620,637536543,
        369103276,637537903},
      1);
RealVariables43 :=fmi_Functions.fmiGetReal(
      fmi,
      {637534266,33554620,587202748,637537904,33554620,637537904,587202748,
        637537907,33554655,637537909,369103276,637537903,637534256,637534266,
        637537921,637537912,33554657,637537921,33554621,637537913,637534257,
        637536568,637537914,33554621,637536568,369103278,637537915,637534267,
        33554621,587202749,637537916,33554621,637537916,587202749,637537919,
        33554657,637537921,369103278,637537915,637534257,637534267,637537933,
        637537924,33554639,637537933,33554622,637537925,637534248,637536593,
        637537926,33554622,637536593,369103280,637537927,637534258,33554622,
        587202750,637537928,33554622,637537928,587202750,637537931,33554639,
        637537933,369103280,637537927,637534248,637534258,637537945,637537936,
        33554641,637537945,33554623,637537937,637534249,637536618,637537938,
        33554623,637536618,369103282,637537939,637534259,33554623,587202751,
        637537940,33554623,637537940,587202751,637537943,33554641,637537945,
        369103282,637537939,637534249,637534259,637537957,637537948,33554643,
        637537957,33554624},
      1);
RealVariables44 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537949,637534250,637536643,637537950,33554624,637536643,369103284,
        637537951,637534260,33554624,587202752,637537952,33554624,637537952,
        587202752,637537955,33554643,637537957,369103284,637537951,637534250,
        637534260,637537969,637537960,33554645,637537969,33554625,637537961,
        637534251,637536668,637537962,33554625,637536668,369103286,637537963,
        637534261,33554625,587202753,637537964,33554625,637537964,587202753,
        637537967,33554645,637537969,369103286,637537963,637534251,637534261,
        637537981,637537972,33554647,637537981,33554626,637537973,637534252,
        637536693,637537974,33554626,637536693,369103288,637537975,637534262,
        33554626,587202754,637537976,33554626,637537976,587202754,637537979,
        33554647,637537981,369103288,637537975,637534252,637534262,637537993,
        637537984,33554649,637537993,33554627,637537985,637534253,637536718,
        637537986,33554627,637536718,369103290,637537987,637534263,33554627,
        587202755,637537988,33554627,637537988,587202755,637537991,33554649,
        637537993,369103290},
      1);
RealVariables45 :=fmi_Functions.fmiGetReal(
      fmi,
      {637537987,637534253,637534263,637538005,637537996,33554651,637538005,
        33554628,637537997,637534254,637536743,637537998,33554628,637536743,
        369103292,637537999,637534264,33554628,587202756,637538000,33554628,
        637538000,587202756,637538003,33554651,637538005,369103292,637537999,
        637534254,637534264,637538017,637538008,33554653,637538017,33554629,
        637538009,637534255,637536768,637538010,33554629,637536768,369103294,
        637538011,637534265,33554629,587202757,637538012,33554629,637538012,
        587202757,637538015,33554653,637538017,369103294,637538011,637534255,
        637534265,637538029,637538020,33554655,637538029,33554630,637538021,
        637534256,637536793,637538022,33554630,637536793,369103296,637538023,
        637534266,33554630,587202758,637538024,33554630,637538024,587202758,
        637538027,33554655,637538029,369103296,637538023,637534256,637534266,
        637538041,637538032,33554657,637538041,33554631,637538033,637534257,
        637536818,637538034,33554631,637536818,369103298,637538035,637534267,
        33554631,587202759},
      1);
RealVariables46 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538036,33554631,637538036,587202759,637538039,33554657,637538041,
        369103298,637538035,637534257,637534267,352321537,905974411,369098812,
        369098883,33554656,369098884,905973540,637538094,905973541,637538095,
        905973542,637538096,905973543,637538097,905973544,637538098,905973545,
        637538099,905973546,637538100,905973547,637538101,905973548,637538102,
        905973549,637538103,637538104,637538114,637538105,637538115,637538106,
        637538116,637538107,637538117,637538108,637538118,637538109,637538119,
        637538110,637538120,637538111,637538121,637538112,637538122,637538113,
        637538123,637538114,637538115,637538116,637538117,637538118,637538119,
        637538120,637538121,637538122,637538123,637538124,637538125,637538126,
        637538127,637538128,637538129,637538130,637538131,637538132,637538133,
        637538134,637538135,637538136,637538137,637538138,637538139,637538140,
        637538141,637538142,637538143,637538144,637538145,637538146,637538147,
        637538148,637538149,637538150,637538151,637538152,637538153,905973670,
        905973671,905973672},
      1);
RealVariables47 :=fmi_Functions.fmiGetReal(
      fmi,
      {905973673,905974411,33554639,33554640,33554641,33554642,33554643,
        33554644,33554645,33554646,33554647,33554648,33554649,33554650,33554651,
        33554652,33554653,33554654,33554655,33554656,33554657,905974411,
        33554639,33554640,33554641,33554642,33554643,33554644,33554645,33554646,
        33554647,33554648,33554649,33554650,33554651,33554652,33554653,33554654,
        33554655,33554656,33554657,637538385,637538386,637538387,637538388,
        637538389,637538390,637538391,637538392,637538393,637538394,100667252,
        100667253,100667254,100667255,100667256,100667257,100667258,100667259,
        100667260,100667261,100667262,100667263,100667264,100667265,100667266,
        100667267,100667268,100667269,100667270,100667271,100667272,100667273,
        100667274,100667275,100667276,100667277,100667278,100667279,100667280,
        100667281,637538364,637538365,637538366,637538367,637538368,637538369,
        637538370,637538371,637538372,905973702,637538365,637538366,637538367,
        637538368,637538369,637538370,637538371,905973703,637538257},
      1);
RealVariables48 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538258,637538259,637538260,637538261,637538262,637538263,637538264,
        637538265,637538266,637538267,637538268,637538269,637538270,637538271,
        637538272,637538273,637538274,637538277,637538278,637538279,637538280,
        637538281,637538282,637538283,637538284,637538285,637538286,905973743,
        905973744,905973745,905973746,905973747,905973748,905973749,905973750,
        905973751,637538296,637538297,637538298,637538299,637538300,637538301,
        637538302,637538303,637538304,637538305,905973762,905973763,905973764,
        905973765,905973766,905973767,905973768,905973769,905973770,637538315,
        637538316,637538317,637538318,637538319,637538320,637538321,637538322,
        637538323,352321537,637538364,637538365,637538366,637538367,637538368,
        637538369,637538370,637538371,637538372,369102917,637538374,637538375,
        637538376,637538377,637538378,637538379,637538380,637538381,637538382,
        637538383,637538384,637538385,637538386,637538387,637538388,637538389,
        637538390,637538391,637538392,637538393,637538394,33554639,637538134,
        33554641,637538135},
      1);
RealVariables49 :=fmi_Functions.fmiGetReal(
      fmi,
      {33554643,637538136,33554645,637538137,33554647,637538138,33554649,
        637538139,33554651,637538140,33554653,637538141,33554655,637538142,
        33554657,637538143,905974411,33554639,33554640,33554641,33554642,
        33554643,33554644,33554645,33554646,33554647,33554648,33554649,33554650,
        33554651,33554652,33554653,33554654,33554655,33554656,33554657,
        100667138,100667138,100667138,100667138,100667138,100667138,100667138,
        100667138,100667138,100667138,637538134,637538135,637538136,637538137,
        637538138,637538139,637538140,637538141,637538142,637538143,33554639,
        637538134,33554641,637538135,33554643,637538136,33554645,637538137,
        33554647,637538138,33554649,637538139,33554651,637538140,33554653,
        637538141,33554655,637538142,33554657,637538143,33554639,33554641,
        33554643,33554645,33554647,33554649,33554651,33554653,33554655,33554657,
        637538385,637538386,637538387,637538388,637538389,637538390,637538391,
        637538392,637538393,637538394,100667262,100667263,100667264,100667265},
      1);
RealVariables50 :=fmi_Functions.fmiGetReal(
      fmi,
      {100667266,100667267,100667268,100667269,100667270,100667271,100667272,
        100667273,100667274,100667275,100667276,100667277,100667278,100667279,
        100667280,100667281,33554638,587202766,369098812,637538972,637538973,
        33554639,587202767,637538975,637538976,905974411,33554639,905974437,
        905974438,33554640,587202768,637538983,637538984,637538985,637538986,
        33554641,587202769,637538988,637538989,33554640,33554641,905974450,
        905974451,33554642,587202770,637538996,637538997,637538998,637538999,
        33554643,587202771,637539001,637539002,33554642,33554643,905974463,
        905974464,33554644,587202772,637539009,637539010,637539011,637539012,
        33554645,587202773,637539014,637539015,33554644,33554645,905974476,
        905974477,33554646,587202774,637539022,637539023,637539024,637539025,
        33554647,587202775,637539027,637539028,33554646,33554647,905974489,
        905974490,33554648,587202776,637539035,637539036,637539037,637539038,
        33554649,587202777,637539040,637539041,33554648,33554649,905974502,
        905974503,33554650},
      1);
RealVariables51 :=fmi_Functions.fmiGetReal(
      fmi,
      {587202778,637539048,637539049,637539050,637539051,33554651,587202779,
        637539053,637539054,33554650,33554651,905974515,905974516,33554652,
        587202780,637539061,637539062,637539063,637539064,33554653,587202781,
        637539066,637539067,33554652,33554653,905974528,905974529,33554654,
        587202782,637539074,637539075,637539076,637539077,33554655,587202783,
        637539079,637539080,33554654,33554655,905974541,905974542,33554656,
        587202784,369098884,637539087,637539088,33554657,587202785,637539090,
        637539091,33554656,33554657,905974552,905974553,352321536,905973895,
        369102917,33554656,100668024,369098883,100668030,369098884,369102917,
        369102992,905973905,905973906,905973907,637534258,637534259,637534260,
        637534261,637534262,637534263,637534264,637534265,637534266,637534267,
        637534248,637534249,637534250,637534251,637534252,637534253,637534254,
        637534255,637534256,637534257,352321539,637538463,33554632,587202760,
        637538474,33554632,637538474,587202760,637538477,33554633,587202761,
        637538479,33554633},
      1);
RealVariables52 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538479,587202761,637538482,33554634,587202762,637538484,33554634,
        637538484,587202762,637538487,33554635,587202763,637538489,33554635,
        637538489,587202763,637538492,637538494,637538495,352321536,637538494,
        33554632,637538496,637538497,637538498,637538499,637538502,637538503,
        352321536,637538502,33554633,637538504,637538505,637538506,637538507,
        637538510,637538511,33554632,637538510,637538800,637538512,637538513,
        637538514,637538515,637538518,637538519,33554633,637538518,637538800,
        637538520,637538521,637538522,637538523,637538526,637538527,33554634,
        637538526,637538800,637538528,637538529,637538530,637538531,637538534,
        637538535,33554635,637538534,637538800,637538536,637538537,637538538,
        637538539,637538542,637538543,352321536,637538542,33554634,637538544,
        637538545,637538546,637538547,637538463,637538550,352321539,637538463,
        33554635,637538971,637538551,637538552,637538553,369103100,637538557,
        369103102,637538559,369103104,637538561,369103106,637538563,369103108,
        637538565,369103110},
      1);
RealVariables53 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538567,369103112,637538569,369103114,637538571,369103116,637538573,
        369103118,637538575,369103120,637538577,369103122,637538579,369103124,
        637538581,369103126,637538583,369103128,637538585,369103130,637538587,
        369103132,637538589,369103134,637538591,369103136,637538593,369103138,
        637538595,369103140,637538597,369103142,637538599,369103144,637538601,
        369103146,637538603,369103148,637538605,369103150,637538607,369103152,
        637538609,369103154,637538611,369103156,637538613,369103158,637538615,
        369103160,637538617,369103162,637538619,369103164,637538621,369103166,
        637538623,369103168,637538625,369103170,637538627,369103172,637538629,
        369103174,637538631,369103176,637538633,369103178,637538635,369103180,
        637538637,369103182,637538639,369103184,637538641,369103186,637538643,
        369103188,637538645,369103190,637538647,369103192,637538649,369103194,
        637538651,369103196,637538653,369103198,637538655,369103200,637538657,
        369103202,637538659,369103204,637538661,369103206,637538663,369103208,
        637538665,369103210},
      1);
RealVariables54 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538667,369103212,637538669,369103214,637538671,369103216,637538673,
        369103218,637538675,369103220,637538677,369103222,637538679,369103224,
        637538681,369103226,637538683,369103228,637538685,369103230,637538687,
        369103232,637538689,369103234,637538691,369103236,637538693,369103238,
        637538695,369103240,637538697,369103242,637538699,369103244,637538701,
        369103246,637538703,369103248,637538705,369103250,637538707,369103252,
        637538709,369103254,637538711,369103256,637538713,369103258,637538715,
        369103260,637538717,369103262,637538719,369103264,637538721,369103266,
        637538723,369103268,637538725,369103270,637538727,369103272,637538729,
        369103274,637538731,369103276,637538733,369103278,637538735,369103280,
        637538737,369103282,637538739,369103284,637538741,369103286,637538743,
        369103288,637538745,369103290,637538747,369103292,637538749,369103294,
        637538751,369103296,637538753,369103298,637538755,352321536,905973895,
        33554636,587202764,637538756,33554636,637538756,587202764,637538759,
        33554637,587202765},
      1);
RealVariables55 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538761,33554637,637538761,587202765,637538764,637538766,637538767,
        33554636,637538766,637538800,637538768,637538769,637538770,637538771,
        637538774,637538775,33554637,637538774,637538800,637538776,637538777,
        637538778,637538779,637538782,637538783,352321536,637538782,33554636,
        637538784,637538785,637538786,637538787,637538790,637538791,352321536,
        637538790,33554637,637538792,637538793,637538794,637538795,369103100,
        637538557,369103102,637538559,369103104,637538561,369103106,637538563,
        369103108,637538565,369103110,637538567,369103112,637538569,369103114,
        637538571,369103116,637538573,369103118,637538575,369103120,637538577,
        369103122,637538579,369103124,637538581,369103126,637538583,369103128,
        637538585,369103130,637538587,369103132,637538589,369103134,637538591,
        369103136,637538593,369103138,637538595,369103140,637538597,369103142,
        637538599,369103144,637538601,369103146,637538603,369103148,637538605,
        369103150,637538607,369103152,637538609,369103154,637538611,369103156,
        637538613,369103158},
      1);
RealVariables56 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538615,369103160,637538617,369103162,637538619,369103164,637538621,
        369103166,637538623,369103168,637538625,369103170,637538627,369103172,
        637538629,369103174,637538631,369103176,637538633,369103178,637538635,
        369103180,637538637,369103182,637538639,369103184,637538641,369103186,
        637538643,369103188,637538645,369103190,637538647,369103192,637538649,
        369103194,637538651,369103196,637538653,369103198,637538655,369103200,
        637538657,369103202,637538659,369103204,637538661,369103206,637538663,
        369103208,637538665,369103210,637538667,369103212,637538669,369103214,
        637538671,369103216,637538673,369103218,637538675,369103220,637538677,
        369103222,637538679,369103224,637538681,369103226,637538683,369103228,
        637538685,369103230,637538687,369103232,637538689,369103234,637538691,
        369103236,637538693,369103238,637538695,369103240,637538697,369103242,
        637538699,369103244,637538701,369103246,637538703,369103248,637538705,
        369103250,637538707,369103252,637538709,369103254,637538711,369103256,
        637538713,369103258},
      1);
RealVariables57 :=fmi_Functions.fmiGetReal(
      fmi,
      {637538715,369103260,637538717,369103262,637538719,369103264,637538721,
        369103266,637538723,369103268,637538725,369103270,637538727,369103272,
        637538729,369103274,637538731,369103276,637538733,369103278,637538735,
        369103280,637538737,369103282,637538739,369103284,637538741,369103286,
        637538743,369103288,637538745,369103290,637538747,369103292,637538749,
        369103294,637538751,369103296,637538753,369103298,637538755,637538800,
        637538801,352321539,637538463,335544321,905974260,637538879,637538880,
        637538881,637538882,637538883,637538884,637538885,637538886,637538887,
        637538888,905974345,637538892,637538893,637538894,637538895,637538896,
        637538897,637538898,637538899,637538900,637538901,905974358,905974359,
        369103448,637538906,637538907,637538908,637538909,637538910,637538911,
        637538912,637538913,637538914,637538915,637538916,637538917,637538918,
        637538919,637538920,637538921,637538922,637538923,637538924,637538925,
        100668030,100668024,100668031,100668030,100668031,369102917,100668030,
        905974411,369103500},
      1);
RealVariables58 :=fmi_Functions.fmiGetReal(
      fmi,
      {905974401,352321538,905974403,905974411,352321538,905974408,905974409,
        905974410,905974411,369103500,352321537,352321538,905974411,335544320,
        100668030,335544322,352321539,637538971,352321539},
      1);
BooleanVariables1 :=fmi_Functions.fmiGetBoolean(
      fmi,
      {369098790,905969703,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790,369098790,369098790,369098790,369098790,369098790,
        369098790,369098790},
      1);
BooleanVariables2 :=fmi_Functions.fmiGetBoolean(
      fmi,
      {369098790,369098790},
      1);
  end when;
initial algorithm
  fmi_AParamsAndStart:=1;
 // 345 Real parameters
  fmi_Functions.fmiSetRealParam(fmi, {16777216, 16777217, 16777218, 16777219, 16777220, 16777221, 16777222, 16777223, 16777224, 16777225, 16777226, 16777227, 16777228, 16777229, 16777230, 16777231, 16777232, 16777233, 16777234, 16777235, 16777236, 16777237, 16777238, 16777239, 16777240, 16777241, 16777242, 16777243, 16777244, 16777245, 16777246, 16777247, 16777248, 16777249, 16777250, 16777251, 16777252, 16777253, 16777254, 16777255, 16777256, 16777257, 16777258, 16777259, 16777260, 16777261, 16777262, 16777263, 16777264, 16777265, 16777266, 16777267, 16777268, 16777269, 16777270, 16777271, 16777272, 16777273, 16777274, 16777275, 16777276, 16777277, 16777278, 16777279, 16777280, 16777281, 16777282, 16777283, 16777284, 16777285, 16777286, 16777287, 16777288, 16777289, 16777290, 16777291, 16777292, 16777293, 16777294, 16777295, 16777296, 16777297, 16777298, 16777299, 16777300, 16777301, 16777302, 16777303, 16777304, 16777305, 16777306, 16777307, 16777308, 16777309, 16777310, 16777311, 16777312, 16777313, 16777314, 16777315}, {'system'.T_ambient, 'system'.g, 'system'.eps_m_flow, 'system'.dp_small, 'system'.m_flow_small, D_tube_in, p_PCM, D_tube_out, a, b, h, w, e, k_PCMs, h_PCMl, k_PCMl, h_HTF, iceStorageInternalMelt.'ice_WaterRing[1, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[1, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[2, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[3, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[4, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[5, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[6, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[7, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[8, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 3]'.x_liquid_start});
  fmi_Functions.fmiSetRealParam(fmi, {16777316, 16777317, 16777318, 16777319, 16777320, 16777321, 16777322, 16777323, 16777324, 16777325, 16777326, 16777327, 16777328, 16777329, 16777330, 16777331, 16777332, 16777333, 16777334, 16777335, 16777336, 16777337, 16777338, 16777339, 16777340, 16777341, 16777342, 16777343, 16777344, 16777345, 16777346, 16777347, 16777348, 16777349, 16777350, 16777351, 16777352, 16777353, 16777354, 16777355, 16777356, 16777357, 16777358, 16777359, 16777360, 16777361, 16777362, 16777363, 16777364, 16777365, 16777366, 16777367, 16777368, 16777369, 16777370, 16777371, 16777372, 16777373, 16777374, 16777375, 16777376, 16777377, 16777378, 16777379, 16777380, 16777381, 16777382, 16777383, 16777384, 16777385, 16777386, 16777387, 16777388, 16777389, 16777390, 16777391, 16777392, 16777393, 16777394, 16777395, 16777396, 16777397, 16777398, 16777399, 16777400, 16777401, 16777402, 16777403, 16777404, 16777405, 16777406, 16777407, 16777408, 16777409, 16777410, 16777411, 16777412, 16777413, 16777414, 16777415}, {iceStorageInternalMelt.'ice_WaterRing[9, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[9, 10]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 1]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 2]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 3]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 4]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 5]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 6]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 7]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 8]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 9]'.x_liquid_start, iceStorageInternalMelt.'ice_WaterRing[10, 10]'.x_liquid_start, iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.T_start});
  fmi_Functions.fmiSetRealParam(fmi, {16777416, 16777417, 16777418, 16777419, 16777420, 16777421, 16777422, 16777423, 16777424, 16777425, 16777426, 16777427, 16777428, 16777429, 16777430, 16777431, 16777432, 16777433, 16777434, 16777435, 16777436, 16777437, 16777438, 16777439, 16777440, 16777441, 16777442, 16777443, 16777444, 16777445, 16777446, 16777447, 16777448, 16777449, 16777450, 16777451, 16777452, 16777453, 16777454, 16777455, 16777456, 16777457, 16777458, 16777459, 16777460, 16777461, 16777462, 16777463, 16777464, 16777465, 16777466, 16777467, 16777468, 16777469, 16777470, 16777471, 16777472, 16777473, 16777474, 16777475, 16777476, 16777477, 16777478, 16777479, 16777480, 16777481, 16777482, 16777483, 16777484, 16777485, 16777486, 16777487, 16777488, 16777489, 16777490, 16777491, 16777492, 16777493, 16777494, 16777495, 16777496, 16777497, 16777498, 16777499, 16777500, 16777501, 16777502, 16777503, 16777504, 16777505, 16777506, 16777507, 16777508, 16777509, 16777510, 16777511, 16777512, 16777513, 16777514, 16777515}, {iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.T_start});
  fmi_Functions.fmiSetRealParam(fmi, {16777516, 16777517, 16777518, 16777519, 16777520, 16777521, 16777522, 16777523, 16777524, 16777525, 16777526, 16777527, 16777528, 16777529, 16777530, 16777531, 16777532, 16777534, 16777537, 16777538, 16777539, 16777540, 16777541, 16777542, 16777543, 16777544, 16777545, 16777546, 16777547, 16777548, 16777549, 16777550, 16777551, 16777552, 16777553, 16777554, 16777555, 16777556, 16777557, 16777558, 16777559, 16777560, 16777561, 16777562, 16777563}, {iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.der_T_start, iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.T_start, iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.der_T_start, iceStorageInternalMelt.pipe.roughness, iceStorageInternalMelt.storageWall.'sideInertia[1]'.T_start, iceStorageInternalMelt.storageWall.'sideInertia[1]'.der_T_start, iceStorageInternalMelt.storageWall.'sideInertia[2]'.T_start, iceStorageInternalMelt.storageWall.'sideInertia[2]'.der_T_start, iceStorageInternalMelt.storageWall.'topInertia[1]'.T_start, iceStorageInternalMelt.storageWall.'topInertia[1]'.der_T_start, iceStorageInternalMelt.storageWall.'topInertia[2]'.T_start, iceStorageInternalMelt.storageWall.'topInertia[2]'.der_T_start, iceStorageInternalMelt.storageWall.'sideCond2[1]'.T_start, iceStorageInternalMelt.storageWall.'sideCond2[2]'.T_start, iceStorageInternalMelt.storageWall.'sideCond1[1]'.T_start, iceStorageInternalMelt.storageWall.'sideCond1[2]'.T_start, iceStorageInternalMelt.storageWall.'topCond1[1]'.T_start, iceStorageInternalMelt.storageWall.'topCond1[2]'.T_start, iceStorageInternalMelt.storageWall.'topCond2[1]'.T_start, iceStorageInternalMelt.storageWall.'topCond2[2]'.T_start, iceStorageInternalMelt.storageWall.'frontInertia[1]'.T_start, iceStorageInternalMelt.storageWall.'frontInertia[1]'.der_T_start, iceStorageInternalMelt.storageWall.'frontInertia[2]'.T_start, iceStorageInternalMelt.storageWall.'frontInertia[2]'.der_T_start, iceStorageInternalMelt.storageWall.'frontCond1[1]'.T_start, iceStorageInternalMelt.storageWall.'frontCond1[2]'.T_start, iceStorageInternalMelt.storageWall.'frontCond2[1]'.T_start, iceStorageInternalMelt.storageWall.'frontCond2[2]'.T_start, outlet_HTF.p, outlet_HTF.T, outlet_HTF.'X[1]'});
 // 110 Real start values
  fmi_Functions.fmiSetRealParam(fmi, {33554532, 33554533, 33554534, 33554535, 33554536, 33554537, 33554538, 33554539, 33554540, 33554541, 33554542, 33554543, 33554544, 33554545, 33554546, 33554547, 33554548, 33554549, 33554550, 33554551, 33554552, 33554553, 33554554, 33554555, 33554556, 33554557, 33554558, 33554559, 33554560, 33554561, 33554562, 33554563, 33554564, 33554565, 33554566, 33554567, 33554568, 33554569, 33554570, 33554571, 33554572, 33554573, 33554574, 33554575, 33554576, 33554577, 33554578, 33554579, 33554580, 33554581, 33554582, 33554583, 33554584, 33554585, 33554586, 33554587, 33554588, 33554589, 33554590, 33554591, 33554592, 33554593, 33554594, 33554595, 33554596, 33554597, 33554598, 33554599, 33554600, 33554601, 33554602, 33554603, 33554604, 33554605, 33554606, 33554607, 33554608, 33554609, 33554610, 33554611, 33554612, 33554613, 33554614, 33554615, 33554616, 33554617, 33554618, 33554619, 33554620, 33554621, 33554622, 33554623, 33554624, 33554625, 33554626, 33554627, 33554628, 33554629, 33554630, 33554631}, {iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia._T_start, iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia._T_start});
  fmi_Functions.fmiSetRealParam(fmi, {33554639, 33554641, 33554643, 33554645, 33554647, 33554649, 33554651, 33554653, 33554655, 33554657}, {iceStorageInternalMelt.pipe.'mediums[1]'._T_start, iceStorageInternalMelt.pipe.'mediums[2]'._T_start, iceStorageInternalMelt.pipe.'mediums[3]'._T_start, iceStorageInternalMelt.pipe.'mediums[4]'._T_start, iceStorageInternalMelt.pipe.'mediums[5]'._T_start, iceStorageInternalMelt.pipe.'mediums[6]'._T_start, iceStorageInternalMelt.pipe.'mediums[7]'._T_start, iceStorageInternalMelt.pipe.'mediums[8]'._T_start, iceStorageInternalMelt.pipe.'mediums[9]'._T_start, iceStorageInternalMelt.pipe.'mediums[10]'._T_start});
 // 0 Integer parameters
 // 0 Integer start values
 // 0 Boolean parameters
 // 0 Boolean start values
 // 0 Enumeration parameters
 // 0 Enumeration start values
 // 0 String parameters
initial equation
if fmi_pullInputsForInitialization then fmi_initInput0 = fmi_Functions.fmiSetReal(fmi, {352321536}, {pre(ambient_T)}); else fmi_initInput0 = fmi_Functions.fmiSetReal(fmi, {352321536}, {_ambient_T_start}); end if;
if fmi_pullInputsForInitialization then fmi_initInput1 = fmi_Functions.fmiSetReal(fmi, {352321537}, {pre(HTF_m_flow)}); else fmi_initInput1 = fmi_Functions.fmiSetReal(fmi, {352321537}, {_HTF_m_flow_start}); end if;
if fmi_pullInputsForInitialization then fmi_initInput2 = fmi_Functions.fmiSetReal(fmi, {352321538}, {pre(HTF_T)}); else fmi_initInput2 = fmi_Functions.fmiSetReal(fmi, {352321538}, {_HTF_T_start}); end if;
if fmi_pullInputsForInitialization then fmi_initInput3 = fmi_Functions.fmiSetReal(fmi, {352321539}, {pre(floor_T)}); else fmi_initInput3 = fmi_Functions.fmiSetReal(fmi, {352321539}, {_floor_T_start}); end if;
  fmi_Initialized = fmi_Functions.fmiInitializeSlave(fmi, fmi_StartTime, fmi_forceShutDownAtStopTime, fmi_StopTime,fmi_AParamsAndStart+ fmi_initInput0+ fmi_initInput1+ fmi_initInput2+ fmi_initInput3);
RealDependentParameters1 = fmi_Functions.fmiGetReal(fmi, {100663305, 100663307, 100663319, 100663322, 100663323, 100663324, 100663328, 100663329, 100663330, 100663331, 100663332, 100663333, 100663432, 100663433, 100663440, 100663449, 100663454, 100663457, 100663458, 100663465, 100663474, 100663479, 100663482, 100663483, 100663490, 100663499, 100663504, 100663507, 100663508, 100663515, 100663524, 100663529, 100663532, 100663533, 100663540, 100663549, 100663554, 100663557, 100663558, 100663565, 100663574, 100663579, 100663582, 100663583, 100663590, 100663599, 100663604, 100663607, 100663608, 100663615, 100663624, 100663629, 100663632, 100663633, 100663640, 100663649, 100663654, 100663657, 100663658, 100663665, 100663674, 100663679, 100663682, 100663683, 100663690, 100663699, 100663704, 100663707, 100663708, 100663715, 100663724, 100663729, 100663732, 100663733, 100663740, 100663749, 100663754, 100663757, 100663758, 100663765, 100663774, 100663779, 100663782, 100663783, 100663790, 100663799, 100663804, 100663807, 100663808, 100663815, 100663824, 100663829, 100663832, 100663833, 100663840, 100663849, 100663854, 100663857, 100663858, 100663865},fmi_Initialized);
RealDependentParameters2 = fmi_Functions.fmiGetReal(fmi, {100663874, 100663879, 100663882, 100663883, 100663890, 100663899, 100663904, 100663907, 100663908, 100663915, 100663924, 100663929, 100663932, 100663933, 100663940, 100663949, 100663954, 100663957, 100663958, 100663965, 100663974, 100663979, 100663982, 100663983, 100663990, 100663999, 100664004, 100664007, 100664008, 100664015, 100664024, 100664029, 100664032, 100664033, 100664040, 100664049, 100664054, 100664057, 100664058, 100664065, 100664074, 100664079, 100664082, 100664083, 100664090, 100664099, 100664104, 100664107, 100664108, 100664115, 100664124, 100664129, 100664132, 100664133, 100664140, 100664149, 100664154, 100664157, 100664158, 100664165, 100664174, 100664179, 100664182, 100664183, 100664190, 100664199, 100664204, 100664207, 100664208, 100664215, 100664224, 100664229, 100664232, 100664233, 100664240, 100664249, 100664254, 100664257, 100664258, 100664265, 100664274, 100664279, 100664282, 100664283, 100664290, 100664299, 100664304, 100664307, 100664308, 100664315, 100664324, 100664329, 100664332, 100664333, 100664340, 100664349, 100664354, 100664357, 100664358, 100664365},fmi_Initialized);
RealDependentParameters3 = fmi_Functions.fmiGetReal(fmi, {100664374, 100664379, 100664382, 100664383, 100664390, 100664399, 100664404, 100664407, 100664408, 100664415, 100664424, 100664429, 100664432, 100664433, 100664440, 100664449, 100664454, 100664457, 100664458, 100664465, 100664474, 100664479, 100664482, 100664483, 100664490, 100664499, 100664504, 100664507, 100664508, 100664515, 100664524, 100664529, 100664532, 100664533, 100664540, 100664549, 100664554, 100664557, 100664558, 100664565, 100664574, 100664579, 100664582, 100664583, 100664590, 100664599, 100664604, 100664607, 100664608, 100664615, 100664624, 100664629, 100664632, 100664633, 100664640, 100664649, 100664654, 100664657, 100664658, 100664665, 100664674, 100664679, 100664682, 100664683, 100664690, 100664699, 100664704, 100664707, 100664708, 100664715, 100664724, 100664729, 100664732, 100664733, 100664740, 100664749, 100664754, 100664757, 100664758, 100664765, 100664774, 100664779, 100664782, 100664783, 100664790, 100664799, 100664804, 100664807, 100664808, 100664815, 100664824, 100664829, 100664832, 100664833, 100664840, 100664849, 100664854, 100664857, 100664858, 100664865},fmi_Initialized);
RealDependentParameters4 = fmi_Functions.fmiGetReal(fmi, {100664874, 100664879, 100664882, 100664883, 100664890, 100664899, 100664904, 100664907, 100664908, 100664915, 100664924, 100664929, 100664932, 100664933, 100664940, 100664949, 100664954, 100664957, 100664958, 100664965, 100664974, 100664979, 100664982, 100664983, 100664990, 100664999, 100665004, 100665007, 100665008, 100665015, 100665024, 100665029, 100665032, 100665033, 100665040, 100665049, 100665054, 100665057, 100665058, 100665065, 100665074, 100665079, 100665082, 100665083, 100665090, 100665099, 100665104, 100665107, 100665108, 100665115, 100665124, 100665129, 100665132, 100665133, 100665140, 100665149, 100665154, 100665157, 100665158, 100665165, 100665174, 100665179, 100665182, 100665183, 100665190, 100665199, 100665204, 100665207, 100665208, 100665215, 100665224, 100665229, 100665232, 100665233, 100665240, 100665249, 100665254, 100665257, 100665258, 100665265, 100665274, 100665279, 100665282, 100665283, 100665290, 100665299, 100665304, 100665307, 100665308, 100665315, 100665324, 100665329, 100665332, 100665333, 100665340, 100665349, 100665354, 100665357, 100665358, 100665365},fmi_Initialized);
RealDependentParameters5 = fmi_Functions.fmiGetReal(fmi, {100665374, 100665379, 100665382, 100665383, 100665390, 100665399, 100665404, 100665407, 100665408, 100665415, 100665424, 100665429, 100665432, 100665433, 100665440, 100665449, 100665454, 100665457, 100665458, 100665465, 100665474, 100665479, 100665482, 100665483, 100665490, 100665499, 100665504, 100665507, 100665508, 100665515, 100665524, 100665529, 100665532, 100665533, 100665540, 100665549, 100665554, 100665557, 100665558, 100665565, 100665574, 100665579, 100665582, 100665583, 100665590, 100665599, 100665604, 100665607, 100665608, 100665615, 100665624, 100665629, 100665632, 100665633, 100665640, 100665649, 100665654, 100665657, 100665658, 100665665, 100665674, 100665679, 100665682, 100665683, 100665690, 100665699, 100665704, 100665707, 100665708, 100665715, 100665724, 100665729, 100665732, 100665733, 100665740, 100665749, 100665754, 100665757, 100665758, 100665765, 100665774, 100665779, 100665782, 100665783, 100665790, 100665799, 100665804, 100665807, 100665808, 100665815, 100665824, 100665829, 100665832, 100665833, 100665840, 100665849, 100665854, 100665857, 100665858, 100665865},fmi_Initialized);
RealDependentParameters6 = fmi_Functions.fmiGetReal(fmi, {100665874, 100665879, 100665882, 100665883, 100665890, 100665899, 100665904, 100665907, 100665908, 100665915, 100665924, 100665929, 100665930, 100665937, 100665938, 100665942, 100665949, 100665950, 100665954, 100665961, 100665962, 100665966, 100665973, 100665974, 100665978, 100665985, 100665986, 100665990, 100665997, 100665998, 100666002, 100666009, 100666010, 100666014, 100666021, 100666022, 100666026, 100666033, 100666034, 100666038, 100666045, 100666046, 100666050, 100666057, 100666058, 100666062, 100666069, 100666070, 100666074, 100666081, 100666082, 100666086, 100666093, 100666094, 100666098, 100666105, 100666106, 100666110, 100666117, 100666118, 100666122, 100666129, 100666130, 100666134, 100666141, 100666142, 100666146, 100666153, 100666154, 100666158, 100666165, 100666166, 100666170, 100666177, 100666178, 100666182, 100666189, 100666190, 100666194, 100666201, 100666202, 100666206, 100666213, 100666214, 100666218, 100666225, 100666226, 100666230, 100666237, 100666238, 100666242, 100666249, 100666250, 100666254, 100666261, 100666262, 100666266, 100666273, 100666274, 100666278},fmi_Initialized);
RealDependentParameters7 = fmi_Functions.fmiGetReal(fmi, {100666285, 100666286, 100666290, 100666297, 100666298, 100666302, 100666309, 100666310, 100666314, 100666321, 100666322, 100666326, 100666333, 100666334, 100666338, 100666345, 100666346, 100666350, 100666357, 100666358, 100666362, 100666369, 100666370, 100666374, 100666381, 100666382, 100666386, 100666393, 100666394, 100666398, 100666405, 100666406, 100666410, 100666417, 100666418, 100666422, 100666429, 100666430, 100666434, 100666441, 100666442, 100666446, 100666453, 100666454, 100666458, 100666465, 100666466, 100666470, 100666477, 100666478, 100666482, 100666489, 100666490, 100666494, 100666501, 100666502, 100666506, 100666513, 100666514, 100666518, 100666525, 100666526, 100666530, 100666537, 100666538, 100666542, 100666549, 100666550, 100666554, 100666561, 100666562, 100666566, 100666573, 100666574, 100666578, 100666585, 100666586, 100666590, 100666597, 100666598, 100666602, 100666609, 100666610, 100666614, 100666621, 100666622, 100666626, 100666633, 100666634, 100666638, 100666645, 100666646, 100666650, 100666657, 100666658, 100666662, 100666669, 100666670, 100666674, 100666681},fmi_Initialized);
RealDependentParameters8 = fmi_Functions.fmiGetReal(fmi, {100666682, 100666686, 100666693, 100666694, 100666698, 100666705, 100666706, 100666710, 100666717, 100666718, 100666722, 100666729, 100666730, 100666734, 100666741, 100666742, 100666746, 100666753, 100666754, 100666758, 100666765, 100666766, 100666770, 100666777, 100666778, 100666782, 100666789, 100666790, 100666794, 100666801, 100666802, 100666806, 100666813, 100666814, 100666818, 100666825, 100666826, 100666830, 100666837, 100666838, 100666842, 100666849, 100666850, 100666854, 100666861, 100666862, 100666866, 100666873, 100666874, 100666878, 100666885, 100666886, 100666890, 100666897, 100666898, 100666902, 100666909, 100666910, 100666914, 100666921, 100666922, 100666926, 100666933, 100666934, 100666938, 100666945, 100666946, 100666950, 100666957, 100666958, 100666962, 100666969, 100666970, 100666974, 100666981, 100666982, 100666986, 100666993, 100666994, 100666998, 100667005, 100667006, 100667010, 100667017, 100667018, 100667022, 100667029, 100667030, 100667034, 100667041, 100667042, 100667046, 100667053, 100667054, 100667058, 100667065, 100667066, 100667070, 100667077, 100667078},fmi_Initialized);
RealDependentParameters9 = fmi_Functions.fmiGetReal(fmi, {100667082, 100667089, 100667090, 100667094, 100667101, 100667102, 100667106, 100667113, 100667114, 100667118, 100667125, 100667126, 100667136, 100667137, 100667138, 100667139, 100667142, 100667143, 100667144, 100667145, 100667146, 100667147, 100667148, 100667149, 100667150, 100667151, 100667170, 100667252, 100667253, 100667254, 100667255, 100667256, 100667257, 100667258, 100667259, 100667260, 100667261, 100667262, 100667263, 100667264, 100667265, 100667266, 100667267, 100667268, 100667269, 100667270, 100667271, 100667272, 100667273, 100667274, 100667275, 100667276, 100667277, 100667278, 100667279, 100667280, 100667281, 100667318, 100667436, 100667437, 100667438, 100667505, 100667533, 100667544, 100667545, 100667554, 100667555, 100667556, 100667558, 100667563, 100667564, 100667568, 100667569, 100667573, 100667574, 100667578, 100667579, 100667588, 100667589, 100667596, 100667597, 100667604, 100667605, 100667612, 100667613, 100667620, 100667621, 100667628, 100667629, 100667636, 100667637, 100667642, 100667643, 100667845, 100667846, 100667850, 100667851, 100667860, 100667861, 100667868},fmi_Initialized);
RealDependentParameters10 = fmi_Functions.fmiGetReal(fmi, {100667869, 100667876, 100667877, 100667884, 100667885, 100667890, 100667891, 100667966, 100667978, 100667979, 100667993, 100668015, 100668017, 100668022, 100668023, 100668024, 100668027, 100668029, 100668055, 100668058},fmi_Initialized);
equation
  ambientTemperature.port.T = RealVariables1[1];
  ambientTemperature.port.Q_flow = RealVariables1[2];
  ambientTemperature.T = RealVariables1[3];
  iceStorageInternalMelt.port_a_HTF.m_flow = RealVariables1[4];
  iceStorageInternalMelt.port_a_HTF.p = RealVariables1[5];
  iceStorageInternalMelt.port_a_HTF.h_outflow = RealVariables1[6];
  iceStorageInternalMelt.port_a_HTF.h_outflow_der = RealVariables1[7];
  iceStorageInternalMelt.port_b_HTF.m_flow = RealVariables1[8];
  iceStorageInternalMelt.port_b_HTF.p = RealVariables1[9];
  iceStorageInternalMelt.port_b_HTF.h_outflow = RealVariables1[10];
  iceStorageInternalMelt.port_b_HTF.h_outflow_der = RealVariables1[11];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.port_a_heatToAmbient.T = RealVariables1[12];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.port_a_heatToAmbient.Q_flow = RealVariables1[13];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.port_a_heatToHTF.T = RealVariables1[14];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.port_a_heatToHTF.Q_flow = RealVariables1[15];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.T = RealVariables1[16];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.x_liquid = RealVariables1[17];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.U = RealVariables1[18];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.U_der = RealVariables1[19];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.V_PCM = RealVariables1[20];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.h_PCM = RealVariables1[21];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.rho = RealVariables1[22];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.m_PCMs = RealVariables1[23];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.T_s = RealVariables1[24];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.D_s = RealVariables1[25];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.m_PCMl = RealVariables1[26];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.T_l = RealVariables1[27];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.D_l = RealVariables1[28];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.D_l_out = RealVariables1[29];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.port_a_heatToAmbient.T = RealVariables1[30];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.port_a_heatToAmbient.Q_flow = RealVariables1[31];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.port_a_heatToHTF.T = RealVariables1[32];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.port_a_heatToHTF.Q_flow = RealVariables1[33];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.T = RealVariables1[34];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.x_liquid = RealVariables1[35];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.U = RealVariables1[36];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.U_der = RealVariables1[37];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.V_PCM = RealVariables1[38];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.h_PCM = RealVariables1[39];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.rho = RealVariables1[40];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.m_PCMs = RealVariables1[41];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.T_s = RealVariables1[42];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.D_s = RealVariables1[43];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.m_PCMl = RealVariables1[44];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.T_l = RealVariables1[45];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.D_l = RealVariables1[46];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.D_l_out = RealVariables1[47];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.port_a_heatToAmbient.T = RealVariables1[48];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.port_a_heatToAmbient.Q_flow = RealVariables1[49];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.port_a_heatToHTF.T = RealVariables1[50];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.port_a_heatToHTF.Q_flow = RealVariables1[51];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.T = RealVariables1[52];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.x_liquid = RealVariables1[53];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.U = RealVariables1[54];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.U_der = RealVariables1[55];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.V_PCM = RealVariables1[56];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.h_PCM = RealVariables1[57];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.rho = RealVariables1[58];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.m_PCMs = RealVariables1[59];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.T_s = RealVariables1[60];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.D_s = RealVariables1[61];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.m_PCMl = RealVariables1[62];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.T_l = RealVariables1[63];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.D_l = RealVariables1[64];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.D_l_out = RealVariables1[65];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.port_a_heatToAmbient.T = RealVariables1[66];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.port_a_heatToAmbient.Q_flow = RealVariables1[67];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.port_a_heatToHTF.T = RealVariables1[68];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.port_a_heatToHTF.Q_flow = RealVariables1[69];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.T = RealVariables1[70];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.x_liquid = RealVariables1[71];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.U = RealVariables1[72];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.U_der = RealVariables1[73];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.V_PCM = RealVariables1[74];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.h_PCM = RealVariables1[75];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.rho = RealVariables1[76];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.m_PCMs = RealVariables1[77];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.T_s = RealVariables1[78];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.D_s = RealVariables1[79];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.m_PCMl = RealVariables1[80];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.T_l = RealVariables1[81];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.D_l = RealVariables1[82];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.D_l_out = RealVariables1[83];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.port_a_heatToAmbient.T = RealVariables1[84];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.port_a_heatToAmbient.Q_flow = RealVariables1[85];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.port_a_heatToHTF.T = RealVariables1[86];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.port_a_heatToHTF.Q_flow = RealVariables1[87];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.T = RealVariables1[88];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.x_liquid = RealVariables1[89];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.U = RealVariables1[90];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.U_der = RealVariables1[91];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.V_PCM = RealVariables1[92];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.h_PCM = RealVariables1[93];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.rho = RealVariables1[94];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.m_PCMs = RealVariables1[95];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.T_s = RealVariables1[96];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.D_s = RealVariables1[97];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.m_PCMl = RealVariables1[98];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.T_l = RealVariables1[99];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.D_l = RealVariables1[100];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.D_l_out = RealVariables2[1];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.port_a_heatToAmbient.T = RealVariables2[2];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.port_a_heatToAmbient.Q_flow = RealVariables2[3];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.port_a_heatToHTF.T = RealVariables2[4];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.port_a_heatToHTF.Q_flow = RealVariables2[5];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.T = RealVariables2[6];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.x_liquid = RealVariables2[7];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.U = RealVariables2[8];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.U_der = RealVariables2[9];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.V_PCM = RealVariables2[10];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.h_PCM = RealVariables2[11];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.rho = RealVariables2[12];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.m_PCMs = RealVariables2[13];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.T_s = RealVariables2[14];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.D_s = RealVariables2[15];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.m_PCMl = RealVariables2[16];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.T_l = RealVariables2[17];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.D_l = RealVariables2[18];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.D_l_out = RealVariables2[19];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.port_a_heatToAmbient.T = RealVariables2[20];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.port_a_heatToAmbient.Q_flow = RealVariables2[21];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.port_a_heatToHTF.T = RealVariables2[22];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.port_a_heatToHTF.Q_flow = RealVariables2[23];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.T = RealVariables2[24];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.x_liquid = RealVariables2[25];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.U = RealVariables2[26];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.U_der = RealVariables2[27];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.V_PCM = RealVariables2[28];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.h_PCM = RealVariables2[29];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.rho = RealVariables2[30];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.m_PCMs = RealVariables2[31];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.T_s = RealVariables2[32];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.D_s = RealVariables2[33];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.m_PCMl = RealVariables2[34];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.T_l = RealVariables2[35];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.D_l = RealVariables2[36];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.D_l_out = RealVariables2[37];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.port_a_heatToAmbient.T = RealVariables2[38];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.port_a_heatToAmbient.Q_flow = RealVariables2[39];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.port_a_heatToHTF.T = RealVariables2[40];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.port_a_heatToHTF.Q_flow = RealVariables2[41];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.T = RealVariables2[42];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.x_liquid = RealVariables2[43];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.U = RealVariables2[44];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.U_der = RealVariables2[45];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.V_PCM = RealVariables2[46];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.h_PCM = RealVariables2[47];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.rho = RealVariables2[48];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.m_PCMs = RealVariables2[49];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.T_s = RealVariables2[50];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.D_s = RealVariables2[51];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.m_PCMl = RealVariables2[52];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.T_l = RealVariables2[53];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.D_l = RealVariables2[54];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.D_l_out = RealVariables2[55];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.port_a_heatToAmbient.T = RealVariables2[56];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.port_a_heatToAmbient.Q_flow = RealVariables2[57];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.port_a_heatToHTF.T = RealVariables2[58];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.port_a_heatToHTF.Q_flow = RealVariables2[59];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.T = RealVariables2[60];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.x_liquid = RealVariables2[61];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.U = RealVariables2[62];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.U_der = RealVariables2[63];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.V_PCM = RealVariables2[64];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.h_PCM = RealVariables2[65];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.rho = RealVariables2[66];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.m_PCMs = RealVariables2[67];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.T_s = RealVariables2[68];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.D_s = RealVariables2[69];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.m_PCMl = RealVariables2[70];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.T_l = RealVariables2[71];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.D_l = RealVariables2[72];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.D_l_out = RealVariables2[73];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.port_a_heatToAmbient.T = RealVariables2[74];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.port_a_heatToAmbient.Q_flow = RealVariables2[75];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.port_a_heatToHTF.T = RealVariables2[76];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.port_a_heatToHTF.Q_flow = RealVariables2[77];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.T = RealVariables2[78];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.x_liquid = RealVariables2[79];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.U = RealVariables2[80];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.U_der = RealVariables2[81];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.V_PCM = RealVariables2[82];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.h_PCM = RealVariables2[83];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.rho = RealVariables2[84];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.m_PCMs = RealVariables2[85];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.T_s = RealVariables2[86];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.D_s = RealVariables2[87];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.m_PCMl = RealVariables2[88];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.T_l = RealVariables2[89];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.D_l = RealVariables2[90];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.D_l_out = RealVariables2[91];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.port_a_heatToAmbient.T = RealVariables2[92];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.port_a_heatToAmbient.Q_flow = RealVariables2[93];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.port_a_heatToHTF.T = RealVariables2[94];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.port_a_heatToHTF.Q_flow = RealVariables2[95];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.T = RealVariables2[96];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.x_liquid = RealVariables2[97];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.U = RealVariables2[98];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.U_der = RealVariables2[99];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.V_PCM = RealVariables2[100];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.h_PCM = RealVariables3[1];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.rho = RealVariables3[2];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.m_PCMs = RealVariables3[3];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.T_s = RealVariables3[4];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.D_s = RealVariables3[5];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.m_PCMl = RealVariables3[6];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.T_l = RealVariables3[7];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.D_l = RealVariables3[8];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.D_l_out = RealVariables3[9];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.port_a_heatToAmbient.T = RealVariables3[10];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.port_a_heatToAmbient.Q_flow = RealVariables3[11];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.port_a_heatToHTF.T = RealVariables3[12];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.port_a_heatToHTF.Q_flow = RealVariables3[13];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.T = RealVariables3[14];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.x_liquid = RealVariables3[15];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.U = RealVariables3[16];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.U_der = RealVariables3[17];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.V_PCM = RealVariables3[18];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.h_PCM = RealVariables3[19];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.rho = RealVariables3[20];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.m_PCMs = RealVariables3[21];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.T_s = RealVariables3[22];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.D_s = RealVariables3[23];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.m_PCMl = RealVariables3[24];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.T_l = RealVariables3[25];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.D_l = RealVariables3[26];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.D_l_out = RealVariables3[27];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.port_a_heatToAmbient.T = RealVariables3[28];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.port_a_heatToAmbient.Q_flow = RealVariables3[29];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.port_a_heatToHTF.T = RealVariables3[30];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.port_a_heatToHTF.Q_flow = RealVariables3[31];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.T = RealVariables3[32];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.x_liquid = RealVariables3[33];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.U = RealVariables3[34];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.U_der = RealVariables3[35];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.V_PCM = RealVariables3[36];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.h_PCM = RealVariables3[37];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.rho = RealVariables3[38];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.m_PCMs = RealVariables3[39];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.T_s = RealVariables3[40];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.D_s = RealVariables3[41];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.m_PCMl = RealVariables3[42];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.T_l = RealVariables3[43];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.D_l = RealVariables3[44];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.D_l_out = RealVariables3[45];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.port_a_heatToAmbient.T = RealVariables3[46];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.port_a_heatToAmbient.Q_flow = RealVariables3[47];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.port_a_heatToHTF.T = RealVariables3[48];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.port_a_heatToHTF.Q_flow = RealVariables3[49];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.T = RealVariables3[50];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.x_liquid = RealVariables3[51];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.U = RealVariables3[52];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.U_der = RealVariables3[53];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.V_PCM = RealVariables3[54];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.h_PCM = RealVariables3[55];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.rho = RealVariables3[56];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.m_PCMs = RealVariables3[57];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.T_s = RealVariables3[58];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.D_s = RealVariables3[59];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.m_PCMl = RealVariables3[60];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.T_l = RealVariables3[61];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.D_l = RealVariables3[62];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.D_l_out = RealVariables3[63];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.port_a_heatToAmbient.T = RealVariables3[64];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.port_a_heatToAmbient.Q_flow = RealVariables3[65];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.port_a_heatToHTF.T = RealVariables3[66];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.port_a_heatToHTF.Q_flow = RealVariables3[67];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.T = RealVariables3[68];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.x_liquid = RealVariables3[69];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.U = RealVariables3[70];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.U_der = RealVariables3[71];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.V_PCM = RealVariables3[72];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.h_PCM = RealVariables3[73];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.rho = RealVariables3[74];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.m_PCMs = RealVariables3[75];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.T_s = RealVariables3[76];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.D_s = RealVariables3[77];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.m_PCMl = RealVariables3[78];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.T_l = RealVariables3[79];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.D_l = RealVariables3[80];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.D_l_out = RealVariables3[81];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.port_a_heatToAmbient.T = RealVariables3[82];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.port_a_heatToAmbient.Q_flow = RealVariables3[83];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.port_a_heatToHTF.T = RealVariables3[84];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.port_a_heatToHTF.Q_flow = RealVariables3[85];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.T = RealVariables3[86];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.x_liquid = RealVariables3[87];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.U = RealVariables3[88];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.U_der = RealVariables3[89];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.V_PCM = RealVariables3[90];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.h_PCM = RealVariables3[91];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.rho = RealVariables3[92];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.m_PCMs = RealVariables3[93];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.T_s = RealVariables3[94];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.D_s = RealVariables3[95];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.m_PCMl = RealVariables3[96];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.T_l = RealVariables3[97];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.D_l = RealVariables3[98];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.D_l_out = RealVariables3[99];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.port_a_heatToAmbient.T = RealVariables3[100];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.port_a_heatToAmbient.Q_flow = RealVariables4[1];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.port_a_heatToHTF.T = RealVariables4[2];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.port_a_heatToHTF.Q_flow = RealVariables4[3];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.T = RealVariables4[4];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.x_liquid = RealVariables4[5];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.U = RealVariables4[6];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.U_der = RealVariables4[7];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.V_PCM = RealVariables4[8];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.h_PCM = RealVariables4[9];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.rho = RealVariables4[10];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.m_PCMs = RealVariables4[11];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.T_s = RealVariables4[12];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.D_s = RealVariables4[13];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.m_PCMl = RealVariables4[14];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.T_l = RealVariables4[15];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.D_l = RealVariables4[16];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.D_l_out = RealVariables4[17];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.port_a_heatToAmbient.T = RealVariables4[18];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.port_a_heatToAmbient.Q_flow = RealVariables4[19];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.port_a_heatToHTF.T = RealVariables4[20];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.port_a_heatToHTF.Q_flow = RealVariables4[21];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.T = RealVariables4[22];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.x_liquid = RealVariables4[23];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.U = RealVariables4[24];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.U_der = RealVariables4[25];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.V_PCM = RealVariables4[26];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.h_PCM = RealVariables4[27];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.rho = RealVariables4[28];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.m_PCMs = RealVariables4[29];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.T_s = RealVariables4[30];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.D_s = RealVariables4[31];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.m_PCMl = RealVariables4[32];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.T_l = RealVariables4[33];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.D_l = RealVariables4[34];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.D_l_out = RealVariables4[35];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.port_a_heatToAmbient.T = RealVariables4[36];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.port_a_heatToAmbient.Q_flow = RealVariables4[37];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.port_a_heatToHTF.T = RealVariables4[38];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.port_a_heatToHTF.Q_flow = RealVariables4[39];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.T = RealVariables4[40];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.x_liquid = RealVariables4[41];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.U = RealVariables4[42];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.U_der = RealVariables4[43];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.V_PCM = RealVariables4[44];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.h_PCM = RealVariables4[45];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.rho = RealVariables4[46];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.m_PCMs = RealVariables4[47];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.T_s = RealVariables4[48];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.D_s = RealVariables4[49];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.m_PCMl = RealVariables4[50];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.T_l = RealVariables4[51];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.D_l = RealVariables4[52];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.D_l_out = RealVariables4[53];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.port_a_heatToAmbient.T = RealVariables4[54];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.port_a_heatToAmbient.Q_flow = RealVariables4[55];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.port_a_heatToHTF.T = RealVariables4[56];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.port_a_heatToHTF.Q_flow = RealVariables4[57];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.T = RealVariables4[58];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.x_liquid = RealVariables4[59];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.U = RealVariables4[60];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.U_der = RealVariables4[61];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.V_PCM = RealVariables4[62];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.h_PCM = RealVariables4[63];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.rho = RealVariables4[64];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.m_PCMs = RealVariables4[65];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.T_s = RealVariables4[66];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.D_s = RealVariables4[67];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.m_PCMl = RealVariables4[68];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.T_l = RealVariables4[69];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.D_l = RealVariables4[70];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.D_l_out = RealVariables4[71];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.port_a_heatToAmbient.T = RealVariables4[72];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.port_a_heatToAmbient.Q_flow = RealVariables4[73];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.port_a_heatToHTF.T = RealVariables4[74];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.port_a_heatToHTF.Q_flow = RealVariables4[75];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.T = RealVariables4[76];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.x_liquid = RealVariables4[77];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.U = RealVariables4[78];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.U_der = RealVariables4[79];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.V_PCM = RealVariables4[80];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.h_PCM = RealVariables4[81];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.rho = RealVariables4[82];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.m_PCMs = RealVariables4[83];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.T_s = RealVariables4[84];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.D_s = RealVariables4[85];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.m_PCMl = RealVariables4[86];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.T_l = RealVariables4[87];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.D_l = RealVariables4[88];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.D_l_out = RealVariables4[89];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.port_a_heatToAmbient.T = RealVariables4[90];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.port_a_heatToAmbient.Q_flow = RealVariables4[91];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.port_a_heatToHTF.T = RealVariables4[92];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.port_a_heatToHTF.Q_flow = RealVariables4[93];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.T = RealVariables4[94];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.x_liquid = RealVariables4[95];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.U = RealVariables4[96];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.U_der = RealVariables4[97];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.V_PCM = RealVariables4[98];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.h_PCM = RealVariables4[99];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.rho = RealVariables4[100];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.m_PCMs = RealVariables5[1];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.T_s = RealVariables5[2];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.D_s = RealVariables5[3];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.m_PCMl = RealVariables5[4];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.T_l = RealVariables5[5];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.D_l = RealVariables5[6];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.D_l_out = RealVariables5[7];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.port_a_heatToAmbient.T = RealVariables5[8];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.port_a_heatToAmbient.Q_flow = RealVariables5[9];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.port_a_heatToHTF.T = RealVariables5[10];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.port_a_heatToHTF.Q_flow = RealVariables5[11];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.T = RealVariables5[12];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.x_liquid = RealVariables5[13];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.U = RealVariables5[14];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.U_der = RealVariables5[15];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.V_PCM = RealVariables5[16];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.h_PCM = RealVariables5[17];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.rho = RealVariables5[18];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.m_PCMs = RealVariables5[19];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.T_s = RealVariables5[20];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.D_s = RealVariables5[21];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.m_PCMl = RealVariables5[22];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.T_l = RealVariables5[23];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.D_l = RealVariables5[24];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.D_l_out = RealVariables5[25];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.port_a_heatToAmbient.T = RealVariables5[26];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.port_a_heatToAmbient.Q_flow = RealVariables5[27];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.port_a_heatToHTF.T = RealVariables5[28];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.port_a_heatToHTF.Q_flow = RealVariables5[29];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.T = RealVariables5[30];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.x_liquid = RealVariables5[31];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.U = RealVariables5[32];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.U_der = RealVariables5[33];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.V_PCM = RealVariables5[34];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.h_PCM = RealVariables5[35];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.rho = RealVariables5[36];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.m_PCMs = RealVariables5[37];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.T_s = RealVariables5[38];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.D_s = RealVariables5[39];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.m_PCMl = RealVariables5[40];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.T_l = RealVariables5[41];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.D_l = RealVariables5[42];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.D_l_out = RealVariables5[43];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.port_a_heatToAmbient.T = RealVariables5[44];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.port_a_heatToAmbient.Q_flow = RealVariables5[45];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.port_a_heatToHTF.T = RealVariables5[46];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.port_a_heatToHTF.Q_flow = RealVariables5[47];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.T = RealVariables5[48];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.x_liquid = RealVariables5[49];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.U = RealVariables5[50];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.U_der = RealVariables5[51];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.V_PCM = RealVariables5[52];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.h_PCM = RealVariables5[53];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.rho = RealVariables5[54];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.m_PCMs = RealVariables5[55];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.T_s = RealVariables5[56];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.D_s = RealVariables5[57];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.m_PCMl = RealVariables5[58];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.T_l = RealVariables5[59];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.D_l = RealVariables5[60];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.D_l_out = RealVariables5[61];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.port_a_heatToAmbient.T = RealVariables5[62];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.port_a_heatToAmbient.Q_flow = RealVariables5[63];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.port_a_heatToHTF.T = RealVariables5[64];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.port_a_heatToHTF.Q_flow = RealVariables5[65];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.T = RealVariables5[66];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.x_liquid = RealVariables5[67];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.U = RealVariables5[68];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.U_der = RealVariables5[69];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.V_PCM = RealVariables5[70];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.h_PCM = RealVariables5[71];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.rho = RealVariables5[72];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.m_PCMs = RealVariables5[73];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.T_s = RealVariables5[74];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.D_s = RealVariables5[75];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.m_PCMl = RealVariables5[76];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.T_l = RealVariables5[77];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.D_l = RealVariables5[78];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.D_l_out = RealVariables5[79];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.port_a_heatToAmbient.T = RealVariables5[80];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.port_a_heatToAmbient.Q_flow = RealVariables5[81];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.port_a_heatToHTF.T = RealVariables5[82];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.port_a_heatToHTF.Q_flow = RealVariables5[83];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.T = RealVariables5[84];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.x_liquid = RealVariables5[85];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.U = RealVariables5[86];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.U_der = RealVariables5[87];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.V_PCM = RealVariables5[88];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.h_PCM = RealVariables5[89];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.rho = RealVariables5[90];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.m_PCMs = RealVariables5[91];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.T_s = RealVariables5[92];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.D_s = RealVariables5[93];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.m_PCMl = RealVariables5[94];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.T_l = RealVariables5[95];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.D_l = RealVariables5[96];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.D_l_out = RealVariables5[97];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.port_a_heatToAmbient.T = RealVariables5[98];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.port_a_heatToAmbient.Q_flow = RealVariables5[99];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.port_a_heatToHTF.T = RealVariables5[100];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.port_a_heatToHTF.Q_flow = RealVariables6[1];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.T = RealVariables6[2];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.x_liquid = RealVariables6[3];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.U = RealVariables6[4];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.U_der = RealVariables6[5];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.V_PCM = RealVariables6[6];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.h_PCM = RealVariables6[7];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.rho = RealVariables6[8];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.m_PCMs = RealVariables6[9];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.T_s = RealVariables6[10];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.D_s = RealVariables6[11];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.m_PCMl = RealVariables6[12];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.T_l = RealVariables6[13];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.D_l = RealVariables6[14];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.D_l_out = RealVariables6[15];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.port_a_heatToAmbient.T = RealVariables6[16];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.port_a_heatToAmbient.Q_flow = RealVariables6[17];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.port_a_heatToHTF.T = RealVariables6[18];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.port_a_heatToHTF.Q_flow = RealVariables6[19];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.T = RealVariables6[20];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.x_liquid = RealVariables6[21];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.U = RealVariables6[22];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.U_der = RealVariables6[23];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.V_PCM = RealVariables6[24];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.h_PCM = RealVariables6[25];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.rho = RealVariables6[26];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.m_PCMs = RealVariables6[27];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.T_s = RealVariables6[28];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.D_s = RealVariables6[29];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.m_PCMl = RealVariables6[30];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.T_l = RealVariables6[31];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.D_l = RealVariables6[32];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.D_l_out = RealVariables6[33];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.port_a_heatToAmbient.T = RealVariables6[34];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.port_a_heatToAmbient.Q_flow = RealVariables6[35];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.port_a_heatToHTF.T = RealVariables6[36];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.port_a_heatToHTF.Q_flow = RealVariables6[37];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.T = RealVariables6[38];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.x_liquid = RealVariables6[39];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.U = RealVariables6[40];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.U_der = RealVariables6[41];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.V_PCM = RealVariables6[42];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.h_PCM = RealVariables6[43];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.rho = RealVariables6[44];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.m_PCMs = RealVariables6[45];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.T_s = RealVariables6[46];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.D_s = RealVariables6[47];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.m_PCMl = RealVariables6[48];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.T_l = RealVariables6[49];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.D_l = RealVariables6[50];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.D_l_out = RealVariables6[51];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.port_a_heatToAmbient.T = RealVariables6[52];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.port_a_heatToAmbient.Q_flow = RealVariables6[53];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.port_a_heatToHTF.T = RealVariables6[54];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.port_a_heatToHTF.Q_flow = RealVariables6[55];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.T = RealVariables6[56];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.x_liquid = RealVariables6[57];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.U = RealVariables6[58];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.U_der = RealVariables6[59];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.V_PCM = RealVariables6[60];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.h_PCM = RealVariables6[61];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.rho = RealVariables6[62];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.m_PCMs = RealVariables6[63];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.T_s = RealVariables6[64];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.D_s = RealVariables6[65];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.m_PCMl = RealVariables6[66];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.T_l = RealVariables6[67];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.D_l = RealVariables6[68];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.D_l_out = RealVariables6[69];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.port_a_heatToAmbient.T = RealVariables6[70];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.port_a_heatToAmbient.Q_flow = RealVariables6[71];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.port_a_heatToHTF.T = RealVariables6[72];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.port_a_heatToHTF.Q_flow = RealVariables6[73];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.T = RealVariables6[74];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.x_liquid = RealVariables6[75];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.U = RealVariables6[76];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.U_der = RealVariables6[77];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.V_PCM = RealVariables6[78];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.h_PCM = RealVariables6[79];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.rho = RealVariables6[80];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.m_PCMs = RealVariables6[81];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.T_s = RealVariables6[82];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.D_s = RealVariables6[83];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.m_PCMl = RealVariables6[84];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.T_l = RealVariables6[85];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.D_l = RealVariables6[86];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.D_l_out = RealVariables6[87];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.port_a_heatToAmbient.T = RealVariables6[88];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.port_a_heatToAmbient.Q_flow = RealVariables6[89];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.port_a_heatToHTF.T = RealVariables6[90];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.port_a_heatToHTF.Q_flow = RealVariables6[91];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.T = RealVariables6[92];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.x_liquid = RealVariables6[93];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.U = RealVariables6[94];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.U_der = RealVariables6[95];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.V_PCM = RealVariables6[96];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.h_PCM = RealVariables6[97];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.rho = RealVariables6[98];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.m_PCMs = RealVariables6[99];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.T_s = RealVariables6[100];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.D_s = RealVariables7[1];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.m_PCMl = RealVariables7[2];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.T_l = RealVariables7[3];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.D_l = RealVariables7[4];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.D_l_out = RealVariables7[5];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.port_a_heatToAmbient.T = RealVariables7[6];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.port_a_heatToAmbient.Q_flow = RealVariables7[7];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.port_a_heatToHTF.T = RealVariables7[8];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.port_a_heatToHTF.Q_flow = RealVariables7[9];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.T = RealVariables7[10];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.x_liquid = RealVariables7[11];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.U = RealVariables7[12];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.U_der = RealVariables7[13];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.V_PCM = RealVariables7[14];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.h_PCM = RealVariables7[15];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.rho = RealVariables7[16];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.m_PCMs = RealVariables7[17];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.T_s = RealVariables7[18];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.D_s = RealVariables7[19];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.m_PCMl = RealVariables7[20];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.T_l = RealVariables7[21];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.D_l = RealVariables7[22];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.D_l_out = RealVariables7[23];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.port_a_heatToAmbient.T = RealVariables7[24];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.port_a_heatToAmbient.Q_flow = RealVariables7[25];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.port_a_heatToHTF.T = RealVariables7[26];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.port_a_heatToHTF.Q_flow = RealVariables7[27];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.T = RealVariables7[28];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.x_liquid = RealVariables7[29];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.U = RealVariables7[30];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.U_der = RealVariables7[31];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.V_PCM = RealVariables7[32];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.h_PCM = RealVariables7[33];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.rho = RealVariables7[34];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.m_PCMs = RealVariables7[35];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.T_s = RealVariables7[36];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.D_s = RealVariables7[37];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.m_PCMl = RealVariables7[38];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.T_l = RealVariables7[39];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.D_l = RealVariables7[40];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.D_l_out = RealVariables7[41];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.port_a_heatToAmbient.T = RealVariables7[42];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.port_a_heatToAmbient.Q_flow = RealVariables7[43];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.port_a_heatToHTF.T = RealVariables7[44];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.port_a_heatToHTF.Q_flow = RealVariables7[45];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.T = RealVariables7[46];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.x_liquid = RealVariables7[47];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.U = RealVariables7[48];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.U_der = RealVariables7[49];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.V_PCM = RealVariables7[50];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.h_PCM = RealVariables7[51];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.rho = RealVariables7[52];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.m_PCMs = RealVariables7[53];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.T_s = RealVariables7[54];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.D_s = RealVariables7[55];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.m_PCMl = RealVariables7[56];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.T_l = RealVariables7[57];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.D_l = RealVariables7[58];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.D_l_out = RealVariables7[59];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.port_a_heatToAmbient.T = RealVariables7[60];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.port_a_heatToAmbient.Q_flow = RealVariables7[61];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.port_a_heatToHTF.T = RealVariables7[62];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.port_a_heatToHTF.Q_flow = RealVariables7[63];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.T = RealVariables7[64];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.x_liquid = RealVariables7[65];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.U = RealVariables7[66];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.U_der = RealVariables7[67];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.V_PCM = RealVariables7[68];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.h_PCM = RealVariables7[69];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.rho = RealVariables7[70];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.m_PCMs = RealVariables7[71];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.T_s = RealVariables7[72];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.D_s = RealVariables7[73];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.m_PCMl = RealVariables7[74];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.T_l = RealVariables7[75];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.D_l = RealVariables7[76];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.D_l_out = RealVariables7[77];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.port_a_heatToAmbient.T = RealVariables7[78];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.port_a_heatToAmbient.Q_flow = RealVariables7[79];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.port_a_heatToHTF.T = RealVariables7[80];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.port_a_heatToHTF.Q_flow = RealVariables7[81];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.T = RealVariables7[82];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.x_liquid = RealVariables7[83];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.U = RealVariables7[84];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.U_der = RealVariables7[85];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.V_PCM = RealVariables7[86];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.h_PCM = RealVariables7[87];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.rho = RealVariables7[88];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.m_PCMs = RealVariables7[89];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.T_s = RealVariables7[90];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.D_s = RealVariables7[91];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.m_PCMl = RealVariables7[92];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.T_l = RealVariables7[93];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.D_l = RealVariables7[94];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.D_l_out = RealVariables7[95];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.port_a_heatToAmbient.T = RealVariables7[96];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.port_a_heatToAmbient.Q_flow = RealVariables7[97];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.port_a_heatToHTF.T = RealVariables7[98];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.port_a_heatToHTF.Q_flow = RealVariables7[99];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.T = RealVariables7[100];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.x_liquid = RealVariables8[1];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.U = RealVariables8[2];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.U_der = RealVariables8[3];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.V_PCM = RealVariables8[4];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.h_PCM = RealVariables8[5];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.rho = RealVariables8[6];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.m_PCMs = RealVariables8[7];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.T_s = RealVariables8[8];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.D_s = RealVariables8[9];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.m_PCMl = RealVariables8[10];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.T_l = RealVariables8[11];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.D_l = RealVariables8[12];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.D_l_out = RealVariables8[13];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.port_a_heatToAmbient.T = RealVariables8[14];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.port_a_heatToAmbient.Q_flow = RealVariables8[15];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.port_a_heatToHTF.T = RealVariables8[16];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.port_a_heatToHTF.Q_flow = RealVariables8[17];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.T = RealVariables8[18];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.x_liquid = RealVariables8[19];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.U = RealVariables8[20];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.U_der = RealVariables8[21];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.V_PCM = RealVariables8[22];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.h_PCM = RealVariables8[23];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.rho = RealVariables8[24];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.m_PCMs = RealVariables8[25];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.T_s = RealVariables8[26];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.D_s = RealVariables8[27];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.m_PCMl = RealVariables8[28];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.T_l = RealVariables8[29];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.D_l = RealVariables8[30];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.D_l_out = RealVariables8[31];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.port_a_heatToAmbient.T = RealVariables8[32];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.port_a_heatToAmbient.Q_flow = RealVariables8[33];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.port_a_heatToHTF.T = RealVariables8[34];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.port_a_heatToHTF.Q_flow = RealVariables8[35];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.T = RealVariables8[36];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.x_liquid = RealVariables8[37];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.U = RealVariables8[38];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.U_der = RealVariables8[39];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.V_PCM = RealVariables8[40];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.h_PCM = RealVariables8[41];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.rho = RealVariables8[42];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.m_PCMs = RealVariables8[43];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.T_s = RealVariables8[44];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.D_s = RealVariables8[45];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.m_PCMl = RealVariables8[46];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.T_l = RealVariables8[47];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.D_l = RealVariables8[48];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.D_l_out = RealVariables8[49];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.port_a_heatToAmbient.T = RealVariables8[50];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.port_a_heatToAmbient.Q_flow = RealVariables8[51];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.port_a_heatToHTF.T = RealVariables8[52];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.port_a_heatToHTF.Q_flow = RealVariables8[53];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.T = RealVariables8[54];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.x_liquid = RealVariables8[55];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.U = RealVariables8[56];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.U_der = RealVariables8[57];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.V_PCM = RealVariables8[58];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.h_PCM = RealVariables8[59];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.rho = RealVariables8[60];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.m_PCMs = RealVariables8[61];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.T_s = RealVariables8[62];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.D_s = RealVariables8[63];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.m_PCMl = RealVariables8[64];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.T_l = RealVariables8[65];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.D_l = RealVariables8[66];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.D_l_out = RealVariables8[67];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.port_a_heatToAmbient.T = RealVariables8[68];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.port_a_heatToAmbient.Q_flow = RealVariables8[69];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.port_a_heatToHTF.T = RealVariables8[70];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.port_a_heatToHTF.Q_flow = RealVariables8[71];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.T = RealVariables8[72];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.x_liquid = RealVariables8[73];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.U = RealVariables8[74];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.U_der = RealVariables8[75];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.V_PCM = RealVariables8[76];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.h_PCM = RealVariables8[77];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.rho = RealVariables8[78];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.m_PCMs = RealVariables8[79];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.T_s = RealVariables8[80];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.D_s = RealVariables8[81];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.m_PCMl = RealVariables8[82];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.T_l = RealVariables8[83];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.D_l = RealVariables8[84];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.D_l_out = RealVariables8[85];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.port_a_heatToAmbient.T = RealVariables8[86];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.port_a_heatToAmbient.Q_flow = RealVariables8[87];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.port_a_heatToHTF.T = RealVariables8[88];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.port_a_heatToHTF.Q_flow = RealVariables8[89];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.T = RealVariables8[90];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.x_liquid = RealVariables8[91];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.U = RealVariables8[92];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.U_der = RealVariables8[93];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.V_PCM = RealVariables8[94];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.h_PCM = RealVariables8[95];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.rho = RealVariables8[96];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.m_PCMs = RealVariables8[97];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.T_s = RealVariables8[98];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.D_s = RealVariables8[99];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.m_PCMl = RealVariables8[100];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.T_l = RealVariables9[1];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.D_l = RealVariables9[2];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.D_l_out = RealVariables9[3];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.port_a_heatToAmbient.T = RealVariables9[4];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.port_a_heatToAmbient.Q_flow = RealVariables9[5];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.port_a_heatToHTF.T = RealVariables9[6];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.port_a_heatToHTF.Q_flow = RealVariables9[7];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.T = RealVariables9[8];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.x_liquid = RealVariables9[9];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.U = RealVariables9[10];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.U_der = RealVariables9[11];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.V_PCM = RealVariables9[12];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.h_PCM = RealVariables9[13];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.rho = RealVariables9[14];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.m_PCMs = RealVariables9[15];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.T_s = RealVariables9[16];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.D_s = RealVariables9[17];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.m_PCMl = RealVariables9[18];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.T_l = RealVariables9[19];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.D_l = RealVariables9[20];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.D_l_out = RealVariables9[21];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.port_a_heatToAmbient.T = RealVariables9[22];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.port_a_heatToAmbient.Q_flow = RealVariables9[23];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.port_a_heatToHTF.T = RealVariables9[24];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.port_a_heatToHTF.Q_flow = RealVariables9[25];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.T = RealVariables9[26];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.x_liquid = RealVariables9[27];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.U = RealVariables9[28];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.U_der = RealVariables9[29];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.V_PCM = RealVariables9[30];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.h_PCM = RealVariables9[31];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.rho = RealVariables9[32];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.m_PCMs = RealVariables9[33];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.T_s = RealVariables9[34];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.D_s = RealVariables9[35];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.m_PCMl = RealVariables9[36];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.T_l = RealVariables9[37];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.D_l = RealVariables9[38];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.D_l_out = RealVariables9[39];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.port_a_heatToAmbient.T = RealVariables9[40];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.port_a_heatToAmbient.Q_flow = RealVariables9[41];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.port_a_heatToHTF.T = RealVariables9[42];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.port_a_heatToHTF.Q_flow = RealVariables9[43];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.T = RealVariables9[44];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.x_liquid = RealVariables9[45];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.U = RealVariables9[46];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.U_der = RealVariables9[47];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.V_PCM = RealVariables9[48];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.h_PCM = RealVariables9[49];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.rho = RealVariables9[50];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.m_PCMs = RealVariables9[51];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.T_s = RealVariables9[52];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.D_s = RealVariables9[53];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.m_PCMl = RealVariables9[54];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.T_l = RealVariables9[55];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.D_l = RealVariables9[56];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.D_l_out = RealVariables9[57];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.port_a_heatToAmbient.T = RealVariables9[58];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.port_a_heatToAmbient.Q_flow = RealVariables9[59];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.port_a_heatToHTF.T = RealVariables9[60];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.port_a_heatToHTF.Q_flow = RealVariables9[61];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.T = RealVariables9[62];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.x_liquid = RealVariables9[63];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.U = RealVariables9[64];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.U_der = RealVariables9[65];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.V_PCM = RealVariables9[66];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.h_PCM = RealVariables9[67];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.rho = RealVariables9[68];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.m_PCMs = RealVariables9[69];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.T_s = RealVariables9[70];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.D_s = RealVariables9[71];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.m_PCMl = RealVariables9[72];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.T_l = RealVariables9[73];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.D_l = RealVariables9[74];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.D_l_out = RealVariables9[75];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.port_a_heatToAmbient.T = RealVariables9[76];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.port_a_heatToAmbient.Q_flow = RealVariables9[77];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.port_a_heatToHTF.T = RealVariables9[78];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.port_a_heatToHTF.Q_flow = RealVariables9[79];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.T = RealVariables9[80];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.x_liquid = RealVariables9[81];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.U = RealVariables9[82];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.U_der = RealVariables9[83];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.V_PCM = RealVariables9[84];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.h_PCM = RealVariables9[85];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.rho = RealVariables9[86];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.m_PCMs = RealVariables9[87];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.T_s = RealVariables9[88];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.D_s = RealVariables9[89];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.m_PCMl = RealVariables9[90];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.T_l = RealVariables9[91];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.D_l = RealVariables9[92];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.D_l_out = RealVariables9[93];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.port_a_heatToAmbient.T = RealVariables9[94];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.port_a_heatToAmbient.Q_flow = RealVariables9[95];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.port_a_heatToHTF.T = RealVariables9[96];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.port_a_heatToHTF.Q_flow = RealVariables9[97];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.T = RealVariables9[98];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.x_liquid = RealVariables9[99];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.U = RealVariables9[100];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.U_der = RealVariables10[1];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.V_PCM = RealVariables10[2];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.h_PCM = RealVariables10[3];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.rho = RealVariables10[4];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.m_PCMs = RealVariables10[5];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.T_s = RealVariables10[6];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.D_s = RealVariables10[7];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.m_PCMl = RealVariables10[8];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.T_l = RealVariables10[9];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.D_l = RealVariables10[10];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.D_l_out = RealVariables10[11];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.port_a_heatToAmbient.T = RealVariables10[12];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.port_a_heatToAmbient.Q_flow = RealVariables10[13];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.port_a_heatToHTF.T = RealVariables10[14];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.port_a_heatToHTF.Q_flow = RealVariables10[15];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.T = RealVariables10[16];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.x_liquid = RealVariables10[17];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.U = RealVariables10[18];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.U_der = RealVariables10[19];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.V_PCM = RealVariables10[20];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.h_PCM = RealVariables10[21];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.rho = RealVariables10[22];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.m_PCMs = RealVariables10[23];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.T_s = RealVariables10[24];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.D_s = RealVariables10[25];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.m_PCMl = RealVariables10[26];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.T_l = RealVariables10[27];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.D_l = RealVariables10[28];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.D_l_out = RealVariables10[29];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.port_a_heatToAmbient.T = RealVariables10[30];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.port_a_heatToAmbient.Q_flow = RealVariables10[31];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.port_a_heatToHTF.T = RealVariables10[32];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.port_a_heatToHTF.Q_flow = RealVariables10[33];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.T = RealVariables10[34];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.x_liquid = RealVariables10[35];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.U = RealVariables10[36];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.U_der = RealVariables10[37];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.V_PCM = RealVariables10[38];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.h_PCM = RealVariables10[39];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.rho = RealVariables10[40];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.m_PCMs = RealVariables10[41];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.T_s = RealVariables10[42];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.D_s = RealVariables10[43];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.m_PCMl = RealVariables10[44];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.T_l = RealVariables10[45];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.D_l = RealVariables10[46];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.D_l_out = RealVariables10[47];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.port_a_heatToAmbient.T = RealVariables10[48];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.port_a_heatToAmbient.Q_flow = RealVariables10[49];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.port_a_heatToHTF.T = RealVariables10[50];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.port_a_heatToHTF.Q_flow = RealVariables10[51];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.T = RealVariables10[52];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.x_liquid = RealVariables10[53];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.U = RealVariables10[54];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.U_der = RealVariables10[55];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.V_PCM = RealVariables10[56];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.h_PCM = RealVariables10[57];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.rho = RealVariables10[58];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.m_PCMs = RealVariables10[59];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.T_s = RealVariables10[60];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.D_s = RealVariables10[61];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.m_PCMl = RealVariables10[62];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.T_l = RealVariables10[63];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.D_l = RealVariables10[64];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.D_l_out = RealVariables10[65];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.port_a_heatToAmbient.T = RealVariables10[66];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.port_a_heatToAmbient.Q_flow = RealVariables10[67];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.port_a_heatToHTF.T = RealVariables10[68];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.port_a_heatToHTF.Q_flow = RealVariables10[69];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.T = RealVariables10[70];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.x_liquid = RealVariables10[71];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.U = RealVariables10[72];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.U_der = RealVariables10[73];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.V_PCM = RealVariables10[74];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.h_PCM = RealVariables10[75];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.rho = RealVariables10[76];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.m_PCMs = RealVariables10[77];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.T_s = RealVariables10[78];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.D_s = RealVariables10[79];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.m_PCMl = RealVariables10[80];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.T_l = RealVariables10[81];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.D_l = RealVariables10[82];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.D_l_out = RealVariables10[83];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.port_a_heatToAmbient.T = RealVariables10[84];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.port_a_heatToAmbient.Q_flow = RealVariables10[85];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.port_a_heatToHTF.T = RealVariables10[86];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.port_a_heatToHTF.Q_flow = RealVariables10[87];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.T = RealVariables10[88];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.x_liquid = RealVariables10[89];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.U = RealVariables10[90];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.U_der = RealVariables10[91];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.V_PCM = RealVariables10[92];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.h_PCM = RealVariables10[93];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.rho = RealVariables10[94];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.m_PCMs = RealVariables10[95];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.T_s = RealVariables10[96];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.D_s = RealVariables10[97];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.m_PCMl = RealVariables10[98];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.T_l = RealVariables10[99];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.D_l = RealVariables10[100];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.D_l_out = RealVariables11[1];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.port_a_heatToAmbient.T = RealVariables11[2];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.port_a_heatToAmbient.Q_flow = RealVariables11[3];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.port_a_heatToHTF.T = RealVariables11[4];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.port_a_heatToHTF.Q_flow = RealVariables11[5];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.T = RealVariables11[6];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.x_liquid = RealVariables11[7];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.U = RealVariables11[8];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.U_der = RealVariables11[9];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.V_PCM = RealVariables11[10];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.h_PCM = RealVariables11[11];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.rho = RealVariables11[12];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.m_PCMs = RealVariables11[13];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.T_s = RealVariables11[14];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.D_s = RealVariables11[15];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.m_PCMl = RealVariables11[16];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.T_l = RealVariables11[17];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.D_l = RealVariables11[18];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.D_l_out = RealVariables11[19];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.port_a_heatToAmbient.T = RealVariables11[20];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.port_a_heatToAmbient.Q_flow = RealVariables11[21];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.port_a_heatToHTF.T = RealVariables11[22];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.port_a_heatToHTF.Q_flow = RealVariables11[23];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.T = RealVariables11[24];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.x_liquid = RealVariables11[25];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.U = RealVariables11[26];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.U_der = RealVariables11[27];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.V_PCM = RealVariables11[28];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.h_PCM = RealVariables11[29];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.rho = RealVariables11[30];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.m_PCMs = RealVariables11[31];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.T_s = RealVariables11[32];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.D_s = RealVariables11[33];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.m_PCMl = RealVariables11[34];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.T_l = RealVariables11[35];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.D_l = RealVariables11[36];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.D_l_out = RealVariables11[37];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.port_a_heatToAmbient.T = RealVariables11[38];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.port_a_heatToAmbient.Q_flow = RealVariables11[39];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.port_a_heatToHTF.T = RealVariables11[40];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.port_a_heatToHTF.Q_flow = RealVariables11[41];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.T = RealVariables11[42];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.x_liquid = RealVariables11[43];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.U = RealVariables11[44];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.U_der = RealVariables11[45];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.V_PCM = RealVariables11[46];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.h_PCM = RealVariables11[47];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.rho = RealVariables11[48];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.m_PCMs = RealVariables11[49];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.T_s = RealVariables11[50];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.D_s = RealVariables11[51];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.m_PCMl = RealVariables11[52];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.T_l = RealVariables11[53];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.D_l = RealVariables11[54];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.D_l_out = RealVariables11[55];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.port_a_heatToAmbient.T = RealVariables11[56];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.port_a_heatToAmbient.Q_flow = RealVariables11[57];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.port_a_heatToHTF.T = RealVariables11[58];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.port_a_heatToHTF.Q_flow = RealVariables11[59];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.T = RealVariables11[60];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.x_liquid = RealVariables11[61];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.U = RealVariables11[62];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.U_der = RealVariables11[63];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.V_PCM = RealVariables11[64];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.h_PCM = RealVariables11[65];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.rho = RealVariables11[66];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.m_PCMs = RealVariables11[67];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.T_s = RealVariables11[68];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.D_s = RealVariables11[69];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.m_PCMl = RealVariables11[70];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.T_l = RealVariables11[71];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.D_l = RealVariables11[72];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.D_l_out = RealVariables11[73];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.port_a_heatToAmbient.T = RealVariables11[74];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.port_a_heatToAmbient.Q_flow = RealVariables11[75];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.port_a_heatToHTF.T = RealVariables11[76];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.port_a_heatToHTF.Q_flow = RealVariables11[77];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.T = RealVariables11[78];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.x_liquid = RealVariables11[79];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.U = RealVariables11[80];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.U_der = RealVariables11[81];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.V_PCM = RealVariables11[82];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.h_PCM = RealVariables11[83];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.rho = RealVariables11[84];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.m_PCMs = RealVariables11[85];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.T_s = RealVariables11[86];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.D_s = RealVariables11[87];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.m_PCMl = RealVariables11[88];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.T_l = RealVariables11[89];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.D_l = RealVariables11[90];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.D_l_out = RealVariables11[91];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.port_a_heatToAmbient.T = RealVariables11[92];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.port_a_heatToAmbient.Q_flow = RealVariables11[93];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.port_a_heatToHTF.T = RealVariables11[94];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.port_a_heatToHTF.Q_flow = RealVariables11[95];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.T = RealVariables11[96];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.x_liquid = RealVariables11[97];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.U = RealVariables11[98];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.U_der = RealVariables11[99];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.V_PCM = RealVariables11[100];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.h_PCM = RealVariables12[1];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.rho = RealVariables12[2];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.m_PCMs = RealVariables12[3];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.T_s = RealVariables12[4];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.D_s = RealVariables12[5];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.m_PCMl = RealVariables12[6];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.T_l = RealVariables12[7];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.D_l = RealVariables12[8];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.D_l_out = RealVariables12[9];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.port_a_heatToAmbient.T = RealVariables12[10];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.port_a_heatToAmbient.Q_flow = RealVariables12[11];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.port_a_heatToHTF.T = RealVariables12[12];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.port_a_heatToHTF.Q_flow = RealVariables12[13];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.T = RealVariables12[14];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.x_liquid = RealVariables12[15];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.U = RealVariables12[16];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.U_der = RealVariables12[17];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.V_PCM = RealVariables12[18];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.h_PCM = RealVariables12[19];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.rho = RealVariables12[20];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.m_PCMs = RealVariables12[21];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.T_s = RealVariables12[22];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.D_s = RealVariables12[23];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.m_PCMl = RealVariables12[24];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.T_l = RealVariables12[25];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.D_l = RealVariables12[26];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.D_l_out = RealVariables12[27];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.port_a_heatToAmbient.T = RealVariables12[28];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.port_a_heatToAmbient.Q_flow = RealVariables12[29];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.port_a_heatToHTF.T = RealVariables12[30];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.port_a_heatToHTF.Q_flow = RealVariables12[31];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.T = RealVariables12[32];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.x_liquid = RealVariables12[33];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.U = RealVariables12[34];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.U_der = RealVariables12[35];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.V_PCM = RealVariables12[36];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.h_PCM = RealVariables12[37];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.rho = RealVariables12[38];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.m_PCMs = RealVariables12[39];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.T_s = RealVariables12[40];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.D_s = RealVariables12[41];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.m_PCMl = RealVariables12[42];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.T_l = RealVariables12[43];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.D_l = RealVariables12[44];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.D_l_out = RealVariables12[45];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.port_a_heatToAmbient.T = RealVariables12[46];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.port_a_heatToAmbient.Q_flow = RealVariables12[47];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.port_a_heatToHTF.T = RealVariables12[48];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.port_a_heatToHTF.Q_flow = RealVariables12[49];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.T = RealVariables12[50];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.x_liquid = RealVariables12[51];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.U = RealVariables12[52];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.U_der = RealVariables12[53];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.V_PCM = RealVariables12[54];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.h_PCM = RealVariables12[55];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.rho = RealVariables12[56];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.m_PCMs = RealVariables12[57];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.T_s = RealVariables12[58];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.D_s = RealVariables12[59];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.m_PCMl = RealVariables12[60];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.T_l = RealVariables12[61];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.D_l = RealVariables12[62];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.D_l_out = RealVariables12[63];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.port_a_heatToAmbient.T = RealVariables12[64];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.port_a_heatToAmbient.Q_flow = RealVariables12[65];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.port_a_heatToHTF.T = RealVariables12[66];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.port_a_heatToHTF.Q_flow = RealVariables12[67];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.T = RealVariables12[68];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.x_liquid = RealVariables12[69];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.U = RealVariables12[70];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.U_der = RealVariables12[71];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.V_PCM = RealVariables12[72];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.h_PCM = RealVariables12[73];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.rho = RealVariables12[74];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.m_PCMs = RealVariables12[75];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.T_s = RealVariables12[76];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.D_s = RealVariables12[77];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.m_PCMl = RealVariables12[78];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.T_l = RealVariables12[79];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.D_l = RealVariables12[80];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.D_l_out = RealVariables12[81];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.port_a_heatToAmbient.T = RealVariables12[82];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.port_a_heatToAmbient.Q_flow = RealVariables12[83];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.port_a_heatToHTF.T = RealVariables12[84];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.port_a_heatToHTF.Q_flow = RealVariables12[85];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.T = RealVariables12[86];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.x_liquid = RealVariables12[87];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.U = RealVariables12[88];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.U_der = RealVariables12[89];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.V_PCM = RealVariables12[90];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.h_PCM = RealVariables12[91];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.rho = RealVariables12[92];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.m_PCMs = RealVariables12[93];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.T_s = RealVariables12[94];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.D_s = RealVariables12[95];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.m_PCMl = RealVariables12[96];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.T_l = RealVariables12[97];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.D_l = RealVariables12[98];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.D_l_out = RealVariables12[99];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.port_a_heatToAmbient.T = RealVariables12[100];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.port_a_heatToAmbient.Q_flow = RealVariables13[1];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.port_a_heatToHTF.T = RealVariables13[2];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.port_a_heatToHTF.Q_flow = RealVariables13[3];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.T = RealVariables13[4];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.x_liquid = RealVariables13[5];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.U = RealVariables13[6];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.U_der = RealVariables13[7];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.V_PCM = RealVariables13[8];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.h_PCM = RealVariables13[9];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.rho = RealVariables13[10];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.m_PCMs = RealVariables13[11];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.T_s = RealVariables13[12];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.D_s = RealVariables13[13];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.m_PCMl = RealVariables13[14];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.T_l = RealVariables13[15];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.D_l = RealVariables13[16];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.D_l_out = RealVariables13[17];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.port_a_heatToAmbient.T = RealVariables13[18];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.port_a_heatToAmbient.Q_flow = RealVariables13[19];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.port_a_heatToHTF.T = RealVariables13[20];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.port_a_heatToHTF.Q_flow = RealVariables13[21];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.T = RealVariables13[22];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.x_liquid = RealVariables13[23];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.U = RealVariables13[24];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.U_der = RealVariables13[25];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.V_PCM = RealVariables13[26];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.h_PCM = RealVariables13[27];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.rho = RealVariables13[28];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.m_PCMs = RealVariables13[29];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.T_s = RealVariables13[30];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.D_s = RealVariables13[31];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.m_PCMl = RealVariables13[32];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.T_l = RealVariables13[33];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.D_l = RealVariables13[34];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.D_l_out = RealVariables13[35];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.port_a_heatToAmbient.T = RealVariables13[36];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.port_a_heatToAmbient.Q_flow = RealVariables13[37];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.port_a_heatToHTF.T = RealVariables13[38];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.port_a_heatToHTF.Q_flow = RealVariables13[39];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.T = RealVariables13[40];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.x_liquid = RealVariables13[41];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.U = RealVariables13[42];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.U_der = RealVariables13[43];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.V_PCM = RealVariables13[44];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.h_PCM = RealVariables13[45];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.rho = RealVariables13[46];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.m_PCMs = RealVariables13[47];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.T_s = RealVariables13[48];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.D_s = RealVariables13[49];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.m_PCMl = RealVariables13[50];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.T_l = RealVariables13[51];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.D_l = RealVariables13[52];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.D_l_out = RealVariables13[53];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.port_a_heatToAmbient.T = RealVariables13[54];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.port_a_heatToAmbient.Q_flow = RealVariables13[55];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.port_a_heatToHTF.T = RealVariables13[56];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.port_a_heatToHTF.Q_flow = RealVariables13[57];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.T = RealVariables13[58];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.x_liquid = RealVariables13[59];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.U = RealVariables13[60];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.U_der = RealVariables13[61];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.V_PCM = RealVariables13[62];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.h_PCM = RealVariables13[63];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.rho = RealVariables13[64];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.m_PCMs = RealVariables13[65];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.T_s = RealVariables13[66];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.D_s = RealVariables13[67];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.m_PCMl = RealVariables13[68];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.T_l = RealVariables13[69];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.D_l = RealVariables13[70];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.D_l_out = RealVariables13[71];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.port_a_heatToAmbient.T = RealVariables13[72];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.port_a_heatToAmbient.Q_flow = RealVariables13[73];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.port_a_heatToHTF.T = RealVariables13[74];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.port_a_heatToHTF.Q_flow = RealVariables13[75];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.T = RealVariables13[76];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.x_liquid = RealVariables13[77];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.U = RealVariables13[78];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.U_der = RealVariables13[79];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.V_PCM = RealVariables13[80];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.h_PCM = RealVariables13[81];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.rho = RealVariables13[82];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.m_PCMs = RealVariables13[83];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.T_s = RealVariables13[84];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.D_s = RealVariables13[85];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.m_PCMl = RealVariables13[86];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.T_l = RealVariables13[87];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.D_l = RealVariables13[88];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.D_l_out = RealVariables13[89];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.port_a_heatToAmbient.T = RealVariables13[90];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.port_a_heatToAmbient.Q_flow = RealVariables13[91];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.port_a_heatToHTF.T = RealVariables13[92];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.port_a_heatToHTF.Q_flow = RealVariables13[93];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.T = RealVariables13[94];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.x_liquid = RealVariables13[95];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.U = RealVariables13[96];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.U_der = RealVariables13[97];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.V_PCM = RealVariables13[98];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.h_PCM = RealVariables13[99];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.rho = RealVariables13[100];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.m_PCMs = RealVariables14[1];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.T_s = RealVariables14[2];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.D_s = RealVariables14[3];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.m_PCMl = RealVariables14[4];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.T_l = RealVariables14[5];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.D_l = RealVariables14[6];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.D_l_out = RealVariables14[7];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.port_a_heatToAmbient.T = RealVariables14[8];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.port_a_heatToAmbient.Q_flow = RealVariables14[9];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.port_a_heatToHTF.T = RealVariables14[10];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.port_a_heatToHTF.Q_flow = RealVariables14[11];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.T = RealVariables14[12];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.x_liquid = RealVariables14[13];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.U = RealVariables14[14];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.U_der = RealVariables14[15];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.V_PCM = RealVariables14[16];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.h_PCM = RealVariables14[17];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.rho = RealVariables14[18];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.m_PCMs = RealVariables14[19];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.T_s = RealVariables14[20];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.D_s = RealVariables14[21];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.m_PCMl = RealVariables14[22];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.T_l = RealVariables14[23];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.D_l = RealVariables14[24];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.D_l_out = RealVariables14[25];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.port_a_heatToAmbient.T = RealVariables14[26];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.port_a_heatToAmbient.Q_flow = RealVariables14[27];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.port_a_heatToHTF.T = RealVariables14[28];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.port_a_heatToHTF.Q_flow = RealVariables14[29];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.T = RealVariables14[30];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.x_liquid = RealVariables14[31];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.U = RealVariables14[32];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.U_der = RealVariables14[33];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.V_PCM = RealVariables14[34];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.h_PCM = RealVariables14[35];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.rho = RealVariables14[36];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.m_PCMs = RealVariables14[37];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.T_s = RealVariables14[38];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.D_s = RealVariables14[39];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.m_PCMl = RealVariables14[40];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.T_l = RealVariables14[41];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.D_l = RealVariables14[42];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.D_l_out = RealVariables14[43];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.port_a_heatToAmbient.T = RealVariables14[44];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.port_a_heatToAmbient.Q_flow = RealVariables14[45];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.port_a_heatToHTF.T = RealVariables14[46];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.port_a_heatToHTF.Q_flow = RealVariables14[47];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.T = RealVariables14[48];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.x_liquid = RealVariables14[49];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.U = RealVariables14[50];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.U_der = RealVariables14[51];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.V_PCM = RealVariables14[52];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.h_PCM = RealVariables14[53];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.rho = RealVariables14[54];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.m_PCMs = RealVariables14[55];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.T_s = RealVariables14[56];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.D_s = RealVariables14[57];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.m_PCMl = RealVariables14[58];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.T_l = RealVariables14[59];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.D_l = RealVariables14[60];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.D_l_out = RealVariables14[61];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.port_a_heatToAmbient.T = RealVariables14[62];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.port_a_heatToAmbient.Q_flow = RealVariables14[63];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.port_a_heatToHTF.T = RealVariables14[64];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.port_a_heatToHTF.Q_flow = RealVariables14[65];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.T = RealVariables14[66];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.x_liquid = RealVariables14[67];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.U = RealVariables14[68];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.U_der = RealVariables14[69];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.V_PCM = RealVariables14[70];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.h_PCM = RealVariables14[71];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.rho = RealVariables14[72];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.m_PCMs = RealVariables14[73];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.T_s = RealVariables14[74];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.D_s = RealVariables14[75];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.m_PCMl = RealVariables14[76];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.T_l = RealVariables14[77];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.D_l = RealVariables14[78];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.D_l_out = RealVariables14[79];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.port_a_heatToAmbient.T = RealVariables14[80];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.port_a_heatToAmbient.Q_flow = RealVariables14[81];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.port_a_heatToHTF.T = RealVariables14[82];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.port_a_heatToHTF.Q_flow = RealVariables14[83];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.T = RealVariables14[84];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.x_liquid = RealVariables14[85];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.U = RealVariables14[86];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.U_der = RealVariables14[87];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.V_PCM = RealVariables14[88];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.h_PCM = RealVariables14[89];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.rho = RealVariables14[90];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.m_PCMs = RealVariables14[91];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.T_s = RealVariables14[92];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.D_s = RealVariables14[93];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.m_PCMl = RealVariables14[94];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.T_l = RealVariables14[95];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.D_l = RealVariables14[96];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.D_l_out = RealVariables14[97];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.port_a_heatToAmbient.T = RealVariables14[98];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.port_a_heatToAmbient.Q_flow = RealVariables14[99];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.port_a_heatToHTF.T = RealVariables14[100];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.port_a_heatToHTF.Q_flow = RealVariables15[1];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.T = RealVariables15[2];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.x_liquid = RealVariables15[3];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.U = RealVariables15[4];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.U_der = RealVariables15[5];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.V_PCM = RealVariables15[6];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.h_PCM = RealVariables15[7];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.rho = RealVariables15[8];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.m_PCMs = RealVariables15[9];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.T_s = RealVariables15[10];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.D_s = RealVariables15[11];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.m_PCMl = RealVariables15[12];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.T_l = RealVariables15[13];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.D_l = RealVariables15[14];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.D_l_out = RealVariables15[15];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.port_a_heatToAmbient.T = RealVariables15[16];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.port_a_heatToAmbient.Q_flow = RealVariables15[17];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.port_a_heatToHTF.T = RealVariables15[18];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.port_a_heatToHTF.Q_flow = RealVariables15[19];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.T = RealVariables15[20];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.x_liquid = RealVariables15[21];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.U = RealVariables15[22];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.U_der = RealVariables15[23];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.V_PCM = RealVariables15[24];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.h_PCM = RealVariables15[25];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.rho = RealVariables15[26];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.m_PCMs = RealVariables15[27];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.T_s = RealVariables15[28];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.D_s = RealVariables15[29];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.m_PCMl = RealVariables15[30];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.T_l = RealVariables15[31];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.D_l = RealVariables15[32];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.D_l_out = RealVariables15[33];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.port_a_heatToAmbient.T = RealVariables15[34];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.port_a_heatToAmbient.Q_flow = RealVariables15[35];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.port_a_heatToHTF.T = RealVariables15[36];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.port_a_heatToHTF.Q_flow = RealVariables15[37];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.T = RealVariables15[38];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.x_liquid = RealVariables15[39];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.U = RealVariables15[40];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.U_der = RealVariables15[41];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.V_PCM = RealVariables15[42];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.h_PCM = RealVariables15[43];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.rho = RealVariables15[44];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.m_PCMs = RealVariables15[45];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.T_s = RealVariables15[46];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.D_s = RealVariables15[47];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.m_PCMl = RealVariables15[48];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.T_l = RealVariables15[49];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.D_l = RealVariables15[50];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.D_l_out = RealVariables15[51];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.port_a_heatToAmbient.T = RealVariables15[52];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.port_a_heatToAmbient.Q_flow = RealVariables15[53];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.port_a_heatToHTF.T = RealVariables15[54];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.port_a_heatToHTF.Q_flow = RealVariables15[55];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.T = RealVariables15[56];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.x_liquid = RealVariables15[57];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.U = RealVariables15[58];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.U_der = RealVariables15[59];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.V_PCM = RealVariables15[60];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.h_PCM = RealVariables15[61];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.rho = RealVariables15[62];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.m_PCMs = RealVariables15[63];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.T_s = RealVariables15[64];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.D_s = RealVariables15[65];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.m_PCMl = RealVariables15[66];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.T_l = RealVariables15[67];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.D_l = RealVariables15[68];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.D_l_out = RealVariables15[69];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.port_a_heatToAmbient.T = RealVariables15[70];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.port_a_heatToAmbient.Q_flow = RealVariables15[71];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.port_a_heatToHTF.T = RealVariables15[72];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.port_a_heatToHTF.Q_flow = RealVariables15[73];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.T = RealVariables15[74];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.x_liquid = RealVariables15[75];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.U = RealVariables15[76];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.U_der = RealVariables15[77];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.V_PCM = RealVariables15[78];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.h_PCM = RealVariables15[79];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.rho = RealVariables15[80];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.m_PCMs = RealVariables15[81];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.T_s = RealVariables15[82];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.D_s = RealVariables15[83];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.m_PCMl = RealVariables15[84];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.T_l = RealVariables15[85];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.D_l = RealVariables15[86];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.D_l_out = RealVariables15[87];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.port_a_heatToAmbient.T = RealVariables15[88];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.port_a_heatToAmbient.Q_flow = RealVariables15[89];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.port_a_heatToHTF.T = RealVariables15[90];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.port_a_heatToHTF.Q_flow = RealVariables15[91];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.T = RealVariables15[92];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.x_liquid = RealVariables15[93];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.U = RealVariables15[94];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.U_der = RealVariables15[95];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.V_PCM = RealVariables15[96];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.h_PCM = RealVariables15[97];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.rho = RealVariables15[98];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.m_PCMs = RealVariables15[99];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.T_s = RealVariables15[100];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.D_s = RealVariables16[1];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.m_PCMl = RealVariables16[2];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.T_l = RealVariables16[3];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.D_l = RealVariables16[4];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.D_l_out = RealVariables16[5];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.port_a_heatToAmbient.T = RealVariables16[6];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.port_a_heatToAmbient.Q_flow = RealVariables16[7];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.port_a_heatToHTF.T = RealVariables16[8];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.port_a_heatToHTF.Q_flow = RealVariables16[9];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.T = RealVariables16[10];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.x_liquid = RealVariables16[11];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.U = RealVariables16[12];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.U_der = RealVariables16[13];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.V_PCM = RealVariables16[14];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.h_PCM = RealVariables16[15];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.rho = RealVariables16[16];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.m_PCMs = RealVariables16[17];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.T_s = RealVariables16[18];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.D_s = RealVariables16[19];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.m_PCMl = RealVariables16[20];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.T_l = RealVariables16[21];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.D_l = RealVariables16[22];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.D_l_out = RealVariables16[23];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.port_a_heatToAmbient.T = RealVariables16[24];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.port_a_heatToAmbient.Q_flow = RealVariables16[25];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.port_a_heatToHTF.T = RealVariables16[26];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.port_a_heatToHTF.Q_flow = RealVariables16[27];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.T = RealVariables16[28];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.x_liquid = RealVariables16[29];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.U = RealVariables16[30];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.U_der = RealVariables16[31];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.V_PCM = RealVariables16[32];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.h_PCM = RealVariables16[33];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.rho = RealVariables16[34];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.m_PCMs = RealVariables16[35];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.T_s = RealVariables16[36];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.D_s = RealVariables16[37];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.m_PCMl = RealVariables16[38];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.T_l = RealVariables16[39];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.D_l = RealVariables16[40];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.D_l_out = RealVariables16[41];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.port_a_heatToAmbient.T = RealVariables16[42];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.port_a_heatToAmbient.Q_flow = RealVariables16[43];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.port_a_heatToHTF.T = RealVariables16[44];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.port_a_heatToHTF.Q_flow = RealVariables16[45];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.T = RealVariables16[46];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.x_liquid = RealVariables16[47];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.U = RealVariables16[48];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.U_der = RealVariables16[49];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.V_PCM = RealVariables16[50];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.h_PCM = RealVariables16[51];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.rho = RealVariables16[52];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.m_PCMs = RealVariables16[53];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.T_s = RealVariables16[54];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.D_s = RealVariables16[55];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.m_PCMl = RealVariables16[56];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.T_l = RealVariables16[57];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.D_l = RealVariables16[58];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.D_l_out = RealVariables16[59];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.port_a_heatToAmbient.T = RealVariables16[60];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.port_a_heatToAmbient.Q_flow = RealVariables16[61];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.port_a_heatToHTF.T = RealVariables16[62];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.port_a_heatToHTF.Q_flow = RealVariables16[63];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.T = RealVariables16[64];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.x_liquid = RealVariables16[65];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.U = RealVariables16[66];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.U_der = RealVariables16[67];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.V_PCM = RealVariables16[68];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.h_PCM = RealVariables16[69];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.rho = RealVariables16[70];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.m_PCMs = RealVariables16[71];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.T_s = RealVariables16[72];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.D_s = RealVariables16[73];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.m_PCMl = RealVariables16[74];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.T_l = RealVariables16[75];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.D_l = RealVariables16[76];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.D_l_out = RealVariables16[77];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.port_a_heatToAmbient.T = RealVariables16[78];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.port_a_heatToAmbient.Q_flow = RealVariables16[79];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.port_a_heatToHTF.T = RealVariables16[80];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.port_a_heatToHTF.Q_flow = RealVariables16[81];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.T = RealVariables16[82];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.x_liquid = RealVariables16[83];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.U = RealVariables16[84];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.U_der = RealVariables16[85];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.V_PCM = RealVariables16[86];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.h_PCM = RealVariables16[87];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.rho = RealVariables16[88];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.m_PCMs = RealVariables16[89];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.T_s = RealVariables16[90];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.D_s = RealVariables16[91];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.m_PCMl = RealVariables16[92];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.T_l = RealVariables16[93];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.D_l = RealVariables16[94];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.D_l_out = RealVariables16[95];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.port_a_heatToAmbient.T = RealVariables16[96];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.port_a_heatToAmbient.Q_flow = RealVariables16[97];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.port_a_heatToHTF.T = RealVariables16[98];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.port_a_heatToHTF.Q_flow = RealVariables16[99];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.T = RealVariables16[100];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.x_liquid = RealVariables17[1];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.U = RealVariables17[2];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.U_der = RealVariables17[3];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.V_PCM = RealVariables17[4];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.h_PCM = RealVariables17[5];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.rho = RealVariables17[6];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.m_PCMs = RealVariables17[7];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.T_s = RealVariables17[8];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.D_s = RealVariables17[9];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.m_PCMl = RealVariables17[10];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.T_l = RealVariables17[11];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.D_l = RealVariables17[12];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.D_l_out = RealVariables17[13];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.port_a_heatToAmbient.T = RealVariables17[14];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.port_a_heatToAmbient.Q_flow = RealVariables17[15];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.port_a_heatToHTF.T = RealVariables17[16];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.port_a_heatToHTF.Q_flow = RealVariables17[17];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.T = RealVariables17[18];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.x_liquid = RealVariables17[19];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.U = RealVariables17[20];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.U_der = RealVariables17[21];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.V_PCM = RealVariables17[22];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.h_PCM = RealVariables17[23];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.rho = RealVariables17[24];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.m_PCMs = RealVariables17[25];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.T_s = RealVariables17[26];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.D_s = RealVariables17[27];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.m_PCMl = RealVariables17[28];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.T_l = RealVariables17[29];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.D_l = RealVariables17[30];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.D_l_out = RealVariables17[31];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.port_a_heatToAmbient.T = RealVariables17[32];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.port_a_heatToAmbient.Q_flow = RealVariables17[33];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.port_a_heatToHTF.T = RealVariables17[34];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.port_a_heatToHTF.Q_flow = RealVariables17[35];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.T = RealVariables17[36];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.x_liquid = RealVariables17[37];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.U = RealVariables17[38];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.U_der = RealVariables17[39];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.V_PCM = RealVariables17[40];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.h_PCM = RealVariables17[41];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.rho = RealVariables17[42];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.m_PCMs = RealVariables17[43];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.T_s = RealVariables17[44];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.D_s = RealVariables17[45];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.m_PCMl = RealVariables17[46];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.T_l = RealVariables17[47];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.D_l = RealVariables17[48];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.D_l_out = RealVariables17[49];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.port_a_heatToAmbient.T = RealVariables17[50];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.port_a_heatToAmbient.Q_flow = RealVariables17[51];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.port_a_heatToHTF.T = RealVariables17[52];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.port_a_heatToHTF.Q_flow = RealVariables17[53];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.T = RealVariables17[54];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.x_liquid = RealVariables17[55];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.U = RealVariables17[56];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.U_der = RealVariables17[57];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.V_PCM = RealVariables17[58];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.h_PCM = RealVariables17[59];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.rho = RealVariables17[60];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.m_PCMs = RealVariables17[61];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.T_s = RealVariables17[62];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.D_s = RealVariables17[63];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.m_PCMl = RealVariables17[64];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.T_l = RealVariables17[65];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.D_l = RealVariables17[66];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.D_l_out = RealVariables17[67];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.port_a_heatToAmbient.T = RealVariables17[68];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.port_a_heatToAmbient.Q_flow = RealVariables17[69];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.port_a_heatToHTF.T = RealVariables17[70];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.port_a_heatToHTF.Q_flow = RealVariables17[71];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.T = RealVariables17[72];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.x_liquid = RealVariables17[73];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.U = RealVariables17[74];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.U_der = RealVariables17[75];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.V_PCM = RealVariables17[76];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.h_PCM = RealVariables17[77];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.rho = RealVariables17[78];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.m_PCMs = RealVariables17[79];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.T_s = RealVariables17[80];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.D_s = RealVariables17[81];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.m_PCMl = RealVariables17[82];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.T_l = RealVariables17[83];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.D_l = RealVariables17[84];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.D_l_out = RealVariables17[85];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.port_a_heatToAmbient.T = RealVariables17[86];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.port_a_heatToAmbient.Q_flow = RealVariables17[87];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.port_a_heatToHTF.T = RealVariables17[88];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.port_a_heatToHTF.Q_flow = RealVariables17[89];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.T = RealVariables17[90];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.x_liquid = RealVariables17[91];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.U = RealVariables17[92];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.U_der = RealVariables17[93];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.V_PCM = RealVariables17[94];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.h_PCM = RealVariables17[95];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.rho = RealVariables17[96];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.m_PCMs = RealVariables17[97];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.T_s = RealVariables17[98];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.D_s = RealVariables17[99];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.m_PCMl = RealVariables17[100];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.T_l = RealVariables18[1];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.D_l = RealVariables18[2];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.D_l_out = RealVariables18[3];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.port_a_heatToAmbient.T = RealVariables18[4];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.port_a_heatToAmbient.Q_flow = RealVariables18[5];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.port_a_heatToHTF.T = RealVariables18[6];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.port_a_heatToHTF.Q_flow = RealVariables18[7];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.T = RealVariables18[8];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.x_liquid = RealVariables18[9];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.U = RealVariables18[10];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.U_der = RealVariables18[11];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.V_PCM = RealVariables18[12];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.h_PCM = RealVariables18[13];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.rho = RealVariables18[14];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.m_PCMs = RealVariables18[15];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.T_s = RealVariables18[16];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.D_s = RealVariables18[17];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.m_PCMl = RealVariables18[18];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.T_l = RealVariables18[19];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.D_l = RealVariables18[20];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.D_l_out = RealVariables18[21];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.port_a_heatToAmbient.T = RealVariables18[22];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.port_a_heatToAmbient.Q_flow = RealVariables18[23];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.port_a_heatToHTF.T = RealVariables18[24];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.port_a_heatToHTF.Q_flow = RealVariables18[25];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.T = RealVariables18[26];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.x_liquid = RealVariables18[27];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.U = RealVariables18[28];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.U_der = RealVariables18[29];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.V_PCM = RealVariables18[30];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.h_PCM = RealVariables18[31];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.rho = RealVariables18[32];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.m_PCMs = RealVariables18[33];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.T_s = RealVariables18[34];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.D_s = RealVariables18[35];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.m_PCMl = RealVariables18[36];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.T_l = RealVariables18[37];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.D_l = RealVariables18[38];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.D_l_out = RealVariables18[39];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.port_a_heatToAmbient.T = RealVariables18[40];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.port_a_heatToAmbient.Q_flow = RealVariables18[41];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.port_a_heatToHTF.T = RealVariables18[42];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.port_a_heatToHTF.Q_flow = RealVariables18[43];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.T = RealVariables18[44];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.x_liquid = RealVariables18[45];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.U = RealVariables18[46];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.U_der = RealVariables18[47];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.V_PCM = RealVariables18[48];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.h_PCM = RealVariables18[49];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.rho = RealVariables18[50];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.m_PCMs = RealVariables18[51];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.T_s = RealVariables18[52];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.D_s = RealVariables18[53];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.m_PCMl = RealVariables18[54];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.T_l = RealVariables18[55];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.D_l = RealVariables18[56];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.D_l_out = RealVariables18[57];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.port_a_heatToAmbient.T = RealVariables18[58];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.port_a_heatToAmbient.Q_flow = RealVariables18[59];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.port_a_heatToHTF.T = RealVariables18[60];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.port_a_heatToHTF.Q_flow = RealVariables18[61];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.T = RealVariables18[62];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.x_liquid = RealVariables18[63];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.U = RealVariables18[64];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.U_der = RealVariables18[65];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.V_PCM = RealVariables18[66];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.h_PCM = RealVariables18[67];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.rho = RealVariables18[68];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.m_PCMs = RealVariables18[69];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.T_s = RealVariables18[70];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.D_s = RealVariables18[71];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.m_PCMl = RealVariables18[72];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.T_l = RealVariables18[73];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.D_l = RealVariables18[74];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.D_l_out = RealVariables18[75];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.port_a_heatToAmbient.T = RealVariables18[76];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.port_a_heatToAmbient.Q_flow = RealVariables18[77];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.port_a_heatToHTF.T = RealVariables18[78];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.port_a_heatToHTF.Q_flow = RealVariables18[79];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.T = RealVariables18[80];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.x_liquid = RealVariables18[81];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.U = RealVariables18[82];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.U_der = RealVariables18[83];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.V_PCM = RealVariables18[84];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.h_PCM = RealVariables18[85];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.rho = RealVariables18[86];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.m_PCMs = RealVariables18[87];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.T_s = RealVariables18[88];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.D_s = RealVariables18[89];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.m_PCMl = RealVariables18[90];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.T_l = RealVariables18[91];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.D_l = RealVariables18[92];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.D_l_out = RealVariables18[93];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.port_a_heatToAmbient.T = RealVariables18[94];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.port_a_heatToAmbient.Q_flow = RealVariables18[95];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.port_a_heatToHTF.T = RealVariables18[96];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.port_a_heatToHTF.Q_flow = RealVariables18[97];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.T = RealVariables18[98];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.x_liquid = RealVariables18[99];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.U = RealVariables18[100];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.U_der = RealVariables19[1];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.V_PCM = RealVariables19[2];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.h_PCM = RealVariables19[3];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.rho = RealVariables19[4];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.m_PCMs = RealVariables19[5];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.T_s = RealVariables19[6];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.D_s = RealVariables19[7];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.m_PCMl = RealVariables19[8];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.T_l = RealVariables19[9];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.D_l = RealVariables19[10];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.D_l_out = RealVariables19[11];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.HTFtoTube.Q_flow = RealVariables19[12];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.HTFtoTube.dT = RealVariables19[13];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.HTFtoTube.port_a.T = RealVariables19[14];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.HTFtoTube.port_a.Q_flow = RealVariables19[15];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.HTFtoTube.port_b.T = RealVariables19[16];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.HTFtoTube.port_b.Q_flow = RealVariables19[17];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.HTFtoTube.G = RealVariables19[18];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubetoPCM.Q_flow = RealVariables19[19];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubetoPCM.dT = RealVariables19[20];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubetoPCM.port_a.T = RealVariables19[21];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubetoPCM.port_a.Q_flow = RealVariables19[22];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubetoPCM.port_b.T = RealVariables19[23];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubetoPCM.port_b.Q_flow = RealVariables19[24];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubetoPCM.G = RealVariables19[25];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.T = RealVariables19[26];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.T_der = RealVariables19[27];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.Q_flow = RealVariables19[28];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.port.T = RealVariables19[29];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.port.Q_flow = RealVariables19[30];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.der_T = RealVariables19[31];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.C = RealVariables19[32];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.port_a.T = RealVariables19[33];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.port_a.Q_flow = RealVariables19[34];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.port_b.T = RealVariables19[35];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.port_b.Q_flow = RealVariables19[36];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.G_HTFtoTube = RealVariables19[37];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.G_TubetoPCM = RealVariables19[38];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.HTFtoTube.Q_flow = RealVariables19[39];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.HTFtoTube.dT = RealVariables19[40];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.HTFtoTube.port_a.T = RealVariables19[41];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.HTFtoTube.port_a.Q_flow = RealVariables19[42];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.HTFtoTube.port_b.T = RealVariables19[43];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.HTFtoTube.port_b.Q_flow = RealVariables19[44];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.HTFtoTube.G = RealVariables19[45];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubetoPCM.Q_flow = RealVariables19[46];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubetoPCM.dT = RealVariables19[47];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubetoPCM.port_a.T = RealVariables19[48];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubetoPCM.port_a.Q_flow = RealVariables19[49];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubetoPCM.port_b.T = RealVariables19[50];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubetoPCM.port_b.Q_flow = RealVariables19[51];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubetoPCM.G = RealVariables19[52];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.T = RealVariables19[53];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.T_der = RealVariables19[54];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.Q_flow = RealVariables19[55];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.port.T = RealVariables19[56];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.port.Q_flow = RealVariables19[57];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.der_T = RealVariables19[58];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.C = RealVariables19[59];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.port_a.T = RealVariables19[60];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.port_a.Q_flow = RealVariables19[61];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.port_b.T = RealVariables19[62];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.port_b.Q_flow = RealVariables19[63];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.G_HTFtoTube = RealVariables19[64];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.G_TubetoPCM = RealVariables19[65];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.HTFtoTube.Q_flow = RealVariables19[66];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.HTFtoTube.dT = RealVariables19[67];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.HTFtoTube.port_a.T = RealVariables19[68];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.HTFtoTube.port_a.Q_flow = RealVariables19[69];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.HTFtoTube.port_b.T = RealVariables19[70];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.HTFtoTube.port_b.Q_flow = RealVariables19[71];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.HTFtoTube.G = RealVariables19[72];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubetoPCM.Q_flow = RealVariables19[73];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubetoPCM.dT = RealVariables19[74];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubetoPCM.port_a.T = RealVariables19[75];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubetoPCM.port_a.Q_flow = RealVariables19[76];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubetoPCM.port_b.T = RealVariables19[77];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubetoPCM.port_b.Q_flow = RealVariables19[78];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubetoPCM.G = RealVariables19[79];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.T = RealVariables19[80];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.T_der = RealVariables19[81];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.Q_flow = RealVariables19[82];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.port.T = RealVariables19[83];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.port.Q_flow = RealVariables19[84];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.der_T = RealVariables19[85];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.C = RealVariables19[86];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.port_a.T = RealVariables19[87];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.port_a.Q_flow = RealVariables19[88];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.port_b.T = RealVariables19[89];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.port_b.Q_flow = RealVariables19[90];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.G_HTFtoTube = RealVariables19[91];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.G_TubetoPCM = RealVariables19[92];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.HTFtoTube.Q_flow = RealVariables19[93];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.HTFtoTube.dT = RealVariables19[94];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.HTFtoTube.port_a.T = RealVariables19[95];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.HTFtoTube.port_a.Q_flow = RealVariables19[96];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.HTFtoTube.port_b.T = RealVariables19[97];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.HTFtoTube.port_b.Q_flow = RealVariables19[98];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.HTFtoTube.G = RealVariables19[99];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubetoPCM.Q_flow = RealVariables19[100];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubetoPCM.dT = RealVariables20[1];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubetoPCM.port_a.T = RealVariables20[2];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubetoPCM.port_a.Q_flow = RealVariables20[3];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubetoPCM.port_b.T = RealVariables20[4];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubetoPCM.port_b.Q_flow = RealVariables20[5];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubetoPCM.G = RealVariables20[6];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.T = RealVariables20[7];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.T_der = RealVariables20[8];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.Q_flow = RealVariables20[9];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.port.T = RealVariables20[10];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.port.Q_flow = RealVariables20[11];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.der_T = RealVariables20[12];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.C = RealVariables20[13];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.port_a.T = RealVariables20[14];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.port_a.Q_flow = RealVariables20[15];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.port_b.T = RealVariables20[16];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.port_b.Q_flow = RealVariables20[17];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.G_HTFtoTube = RealVariables20[18];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.G_TubetoPCM = RealVariables20[19];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.HTFtoTube.Q_flow = RealVariables20[20];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.HTFtoTube.dT = RealVariables20[21];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.HTFtoTube.port_a.T = RealVariables20[22];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.HTFtoTube.port_a.Q_flow = RealVariables20[23];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.HTFtoTube.port_b.T = RealVariables20[24];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.HTFtoTube.port_b.Q_flow = RealVariables20[25];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.HTFtoTube.G = RealVariables20[26];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubetoPCM.Q_flow = RealVariables20[27];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubetoPCM.dT = RealVariables20[28];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubetoPCM.port_a.T = RealVariables20[29];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubetoPCM.port_a.Q_flow = RealVariables20[30];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubetoPCM.port_b.T = RealVariables20[31];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubetoPCM.port_b.Q_flow = RealVariables20[32];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubetoPCM.G = RealVariables20[33];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.T = RealVariables20[34];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.T_der = RealVariables20[35];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.Q_flow = RealVariables20[36];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.port.T = RealVariables20[37];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.port.Q_flow = RealVariables20[38];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.der_T = RealVariables20[39];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.C = RealVariables20[40];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.port_a.T = RealVariables20[41];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.port_a.Q_flow = RealVariables20[42];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.port_b.T = RealVariables20[43];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.port_b.Q_flow = RealVariables20[44];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.G_HTFtoTube = RealVariables20[45];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.G_TubetoPCM = RealVariables20[46];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.HTFtoTube.Q_flow = RealVariables20[47];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.HTFtoTube.dT = RealVariables20[48];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.HTFtoTube.port_a.T = RealVariables20[49];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.HTFtoTube.port_a.Q_flow = RealVariables20[50];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.HTFtoTube.port_b.T = RealVariables20[51];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.HTFtoTube.port_b.Q_flow = RealVariables20[52];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.HTFtoTube.G = RealVariables20[53];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubetoPCM.Q_flow = RealVariables20[54];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubetoPCM.dT = RealVariables20[55];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubetoPCM.port_a.T = RealVariables20[56];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubetoPCM.port_a.Q_flow = RealVariables20[57];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubetoPCM.port_b.T = RealVariables20[58];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubetoPCM.port_b.Q_flow = RealVariables20[59];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubetoPCM.G = RealVariables20[60];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.T = RealVariables20[61];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.T_der = RealVariables20[62];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.Q_flow = RealVariables20[63];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.port.T = RealVariables20[64];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.port.Q_flow = RealVariables20[65];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.der_T = RealVariables20[66];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.C = RealVariables20[67];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.port_a.T = RealVariables20[68];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.port_a.Q_flow = RealVariables20[69];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.port_b.T = RealVariables20[70];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.port_b.Q_flow = RealVariables20[71];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.G_HTFtoTube = RealVariables20[72];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.G_TubetoPCM = RealVariables20[73];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.HTFtoTube.Q_flow = RealVariables20[74];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.HTFtoTube.dT = RealVariables20[75];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.HTFtoTube.port_a.T = RealVariables20[76];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.HTFtoTube.port_a.Q_flow = RealVariables20[77];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.HTFtoTube.port_b.T = RealVariables20[78];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.HTFtoTube.port_b.Q_flow = RealVariables20[79];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.HTFtoTube.G = RealVariables20[80];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubetoPCM.Q_flow = RealVariables20[81];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubetoPCM.dT = RealVariables20[82];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubetoPCM.port_a.T = RealVariables20[83];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubetoPCM.port_a.Q_flow = RealVariables20[84];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubetoPCM.port_b.T = RealVariables20[85];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubetoPCM.port_b.Q_flow = RealVariables20[86];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubetoPCM.G = RealVariables20[87];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.T = RealVariables20[88];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.T_der = RealVariables20[89];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.Q_flow = RealVariables20[90];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.port.T = RealVariables20[91];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.port.Q_flow = RealVariables20[92];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.der_T = RealVariables20[93];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.C = RealVariables20[94];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.port_a.T = RealVariables20[95];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.port_a.Q_flow = RealVariables20[96];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.port_b.T = RealVariables20[97];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.port_b.Q_flow = RealVariables20[98];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.G_HTFtoTube = RealVariables20[99];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.G_TubetoPCM = RealVariables20[100];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.HTFtoTube.Q_flow = RealVariables21[1];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.HTFtoTube.dT = RealVariables21[2];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.HTFtoTube.port_a.T = RealVariables21[3];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.HTFtoTube.port_a.Q_flow = RealVariables21[4];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.HTFtoTube.port_b.T = RealVariables21[5];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.HTFtoTube.port_b.Q_flow = RealVariables21[6];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.HTFtoTube.G = RealVariables21[7];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubetoPCM.Q_flow = RealVariables21[8];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubetoPCM.dT = RealVariables21[9];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubetoPCM.port_a.T = RealVariables21[10];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubetoPCM.port_a.Q_flow = RealVariables21[11];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubetoPCM.port_b.T = RealVariables21[12];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubetoPCM.port_b.Q_flow = RealVariables21[13];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubetoPCM.G = RealVariables21[14];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.T = RealVariables21[15];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.T_der = RealVariables21[16];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.Q_flow = RealVariables21[17];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.port.T = RealVariables21[18];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.port.Q_flow = RealVariables21[19];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.der_T = RealVariables21[20];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.C = RealVariables21[21];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.port_a.T = RealVariables21[22];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.port_a.Q_flow = RealVariables21[23];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.port_b.T = RealVariables21[24];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.port_b.Q_flow = RealVariables21[25];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.G_HTFtoTube = RealVariables21[26];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.G_TubetoPCM = RealVariables21[27];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.HTFtoTube.Q_flow = RealVariables21[28];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.HTFtoTube.dT = RealVariables21[29];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.HTFtoTube.port_a.T = RealVariables21[30];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.HTFtoTube.port_a.Q_flow = RealVariables21[31];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.HTFtoTube.port_b.T = RealVariables21[32];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.HTFtoTube.port_b.Q_flow = RealVariables21[33];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.HTFtoTube.G = RealVariables21[34];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubetoPCM.Q_flow = RealVariables21[35];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubetoPCM.dT = RealVariables21[36];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubetoPCM.port_a.T = RealVariables21[37];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubetoPCM.port_a.Q_flow = RealVariables21[38];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubetoPCM.port_b.T = RealVariables21[39];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubetoPCM.port_b.Q_flow = RealVariables21[40];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubetoPCM.G = RealVariables21[41];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.T = RealVariables21[42];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.T_der = RealVariables21[43];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.Q_flow = RealVariables21[44];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.port.T = RealVariables21[45];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.port.Q_flow = RealVariables21[46];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.der_T = RealVariables21[47];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.C = RealVariables21[48];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.port_a.T = RealVariables21[49];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.port_a.Q_flow = RealVariables21[50];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.port_b.T = RealVariables21[51];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.port_b.Q_flow = RealVariables21[52];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.G_HTFtoTube = RealVariables21[53];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.G_TubetoPCM = RealVariables21[54];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.HTFtoTube.Q_flow = RealVariables21[55];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.HTFtoTube.dT = RealVariables21[56];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.HTFtoTube.port_a.T = RealVariables21[57];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.HTFtoTube.port_a.Q_flow = RealVariables21[58];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.HTFtoTube.port_b.T = RealVariables21[59];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.HTFtoTube.port_b.Q_flow = RealVariables21[60];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.HTFtoTube.G = RealVariables21[61];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubetoPCM.Q_flow = RealVariables21[62];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubetoPCM.dT = RealVariables21[63];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubetoPCM.port_a.T = RealVariables21[64];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubetoPCM.port_a.Q_flow = RealVariables21[65];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubetoPCM.port_b.T = RealVariables21[66];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubetoPCM.port_b.Q_flow = RealVariables21[67];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubetoPCM.G = RealVariables21[68];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.T = RealVariables21[69];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.T_der = RealVariables21[70];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.Q_flow = RealVariables21[71];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.port.T = RealVariables21[72];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.port.Q_flow = RealVariables21[73];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.der_T = RealVariables21[74];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.C = RealVariables21[75];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.port_a.T = RealVariables21[76];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.port_a.Q_flow = RealVariables21[77];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.port_b.T = RealVariables21[78];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.port_b.Q_flow = RealVariables21[79];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.G_HTFtoTube = RealVariables21[80];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.G_TubetoPCM = RealVariables21[81];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.HTFtoTube.Q_flow = RealVariables21[82];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.HTFtoTube.dT = RealVariables21[83];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.HTFtoTube.port_a.T = RealVariables21[84];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.HTFtoTube.port_a.Q_flow = RealVariables21[85];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.HTFtoTube.port_b.T = RealVariables21[86];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.HTFtoTube.port_b.Q_flow = RealVariables21[87];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.HTFtoTube.G = RealVariables21[88];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubetoPCM.Q_flow = RealVariables21[89];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubetoPCM.dT = RealVariables21[90];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubetoPCM.port_a.T = RealVariables21[91];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubetoPCM.port_a.Q_flow = RealVariables21[92];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubetoPCM.port_b.T = RealVariables21[93];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubetoPCM.port_b.Q_flow = RealVariables21[94];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubetoPCM.G = RealVariables21[95];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.T = RealVariables21[96];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.T_der = RealVariables21[97];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.Q_flow = RealVariables21[98];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.port.T = RealVariables21[99];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.port.Q_flow = RealVariables21[100];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.der_T = RealVariables22[1];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.C = RealVariables22[2];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.port_a.T = RealVariables22[3];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.port_a.Q_flow = RealVariables22[4];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.port_b.T = RealVariables22[5];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.port_b.Q_flow = RealVariables22[6];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.G_HTFtoTube = RealVariables22[7];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.G_TubetoPCM = RealVariables22[8];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.HTFtoTube.Q_flow = RealVariables22[9];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.HTFtoTube.dT = RealVariables22[10];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.HTFtoTube.port_a.T = RealVariables22[11];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.HTFtoTube.port_a.Q_flow = RealVariables22[12];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.HTFtoTube.port_b.T = RealVariables22[13];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.HTFtoTube.port_b.Q_flow = RealVariables22[14];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.HTFtoTube.G = RealVariables22[15];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubetoPCM.Q_flow = RealVariables22[16];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubetoPCM.dT = RealVariables22[17];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubetoPCM.port_a.T = RealVariables22[18];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubetoPCM.port_a.Q_flow = RealVariables22[19];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubetoPCM.port_b.T = RealVariables22[20];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubetoPCM.port_b.Q_flow = RealVariables22[21];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubetoPCM.G = RealVariables22[22];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.T = RealVariables22[23];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.T_der = RealVariables22[24];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.Q_flow = RealVariables22[25];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.port.T = RealVariables22[26];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.port.Q_flow = RealVariables22[27];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.der_T = RealVariables22[28];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.C = RealVariables22[29];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.port_a.T = RealVariables22[30];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.port_a.Q_flow = RealVariables22[31];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.port_b.T = RealVariables22[32];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.port_b.Q_flow = RealVariables22[33];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.G_HTFtoTube = RealVariables22[34];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.G_TubetoPCM = RealVariables22[35];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.HTFtoTube.Q_flow = RealVariables22[36];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.HTFtoTube.dT = RealVariables22[37];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.HTFtoTube.port_a.T = RealVariables22[38];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.HTFtoTube.port_a.Q_flow = RealVariables22[39];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.HTFtoTube.port_b.T = RealVariables22[40];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.HTFtoTube.port_b.Q_flow = RealVariables22[41];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.HTFtoTube.G = RealVariables22[42];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubetoPCM.Q_flow = RealVariables22[43];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubetoPCM.dT = RealVariables22[44];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubetoPCM.port_a.T = RealVariables22[45];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubetoPCM.port_a.Q_flow = RealVariables22[46];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubetoPCM.port_b.T = RealVariables22[47];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubetoPCM.port_b.Q_flow = RealVariables22[48];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubetoPCM.G = RealVariables22[49];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.T = RealVariables22[50];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.T_der = RealVariables22[51];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.Q_flow = RealVariables22[52];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.port.T = RealVariables22[53];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.port.Q_flow = RealVariables22[54];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.der_T = RealVariables22[55];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.C = RealVariables22[56];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.port_a.T = RealVariables22[57];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.port_a.Q_flow = RealVariables22[58];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.port_b.T = RealVariables22[59];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.port_b.Q_flow = RealVariables22[60];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.G_HTFtoTube = RealVariables22[61];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.G_TubetoPCM = RealVariables22[62];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.HTFtoTube.Q_flow = RealVariables22[63];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.HTFtoTube.dT = RealVariables22[64];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.HTFtoTube.port_a.T = RealVariables22[65];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.HTFtoTube.port_a.Q_flow = RealVariables22[66];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.HTFtoTube.port_b.T = RealVariables22[67];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.HTFtoTube.port_b.Q_flow = RealVariables22[68];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.HTFtoTube.G = RealVariables22[69];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubetoPCM.Q_flow = RealVariables22[70];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubetoPCM.dT = RealVariables22[71];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubetoPCM.port_a.T = RealVariables22[72];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubetoPCM.port_a.Q_flow = RealVariables22[73];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubetoPCM.port_b.T = RealVariables22[74];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubetoPCM.port_b.Q_flow = RealVariables22[75];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubetoPCM.G = RealVariables22[76];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.T = RealVariables22[77];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.T_der = RealVariables22[78];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.Q_flow = RealVariables22[79];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.port.T = RealVariables22[80];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.port.Q_flow = RealVariables22[81];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.der_T = RealVariables22[82];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.C = RealVariables22[83];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.port_a.T = RealVariables22[84];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.port_a.Q_flow = RealVariables22[85];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.port_b.T = RealVariables22[86];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.port_b.Q_flow = RealVariables22[87];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.G_HTFtoTube = RealVariables22[88];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.G_TubetoPCM = RealVariables22[89];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.HTFtoTube.Q_flow = RealVariables22[90];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.HTFtoTube.dT = RealVariables22[91];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.HTFtoTube.port_a.T = RealVariables22[92];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.HTFtoTube.port_a.Q_flow = RealVariables22[93];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.HTFtoTube.port_b.T = RealVariables22[94];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.HTFtoTube.port_b.Q_flow = RealVariables22[95];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.HTFtoTube.G = RealVariables22[96];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubetoPCM.Q_flow = RealVariables22[97];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubetoPCM.dT = RealVariables22[98];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubetoPCM.port_a.T = RealVariables22[99];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubetoPCM.port_a.Q_flow = RealVariables22[100];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubetoPCM.port_b.T = RealVariables23[1];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubetoPCM.port_b.Q_flow = RealVariables23[2];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubetoPCM.G = RealVariables23[3];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.T = RealVariables23[4];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.T_der = RealVariables23[5];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.Q_flow = RealVariables23[6];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.port.T = RealVariables23[7];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.port.Q_flow = RealVariables23[8];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.der_T = RealVariables23[9];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.C = RealVariables23[10];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.port_a.T = RealVariables23[11];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.port_a.Q_flow = RealVariables23[12];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.port_b.T = RealVariables23[13];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.port_b.Q_flow = RealVariables23[14];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.G_HTFtoTube = RealVariables23[15];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.G_TubetoPCM = RealVariables23[16];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.HTFtoTube.Q_flow = RealVariables23[17];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.HTFtoTube.dT = RealVariables23[18];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.HTFtoTube.port_a.T = RealVariables23[19];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.HTFtoTube.port_a.Q_flow = RealVariables23[20];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.HTFtoTube.port_b.T = RealVariables23[21];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.HTFtoTube.port_b.Q_flow = RealVariables23[22];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.HTFtoTube.G = RealVariables23[23];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubetoPCM.Q_flow = RealVariables23[24];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubetoPCM.dT = RealVariables23[25];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubetoPCM.port_a.T = RealVariables23[26];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubetoPCM.port_a.Q_flow = RealVariables23[27];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubetoPCM.port_b.T = RealVariables23[28];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubetoPCM.port_b.Q_flow = RealVariables23[29];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubetoPCM.G = RealVariables23[30];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.T = RealVariables23[31];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.T_der = RealVariables23[32];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.Q_flow = RealVariables23[33];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.port.T = RealVariables23[34];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.port.Q_flow = RealVariables23[35];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.der_T = RealVariables23[36];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.C = RealVariables23[37];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.port_a.T = RealVariables23[38];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.port_a.Q_flow = RealVariables23[39];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.port_b.T = RealVariables23[40];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.port_b.Q_flow = RealVariables23[41];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.G_HTFtoTube = RealVariables23[42];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.G_TubetoPCM = RealVariables23[43];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.HTFtoTube.Q_flow = RealVariables23[44];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.HTFtoTube.dT = RealVariables23[45];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.HTFtoTube.port_a.T = RealVariables23[46];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.HTFtoTube.port_a.Q_flow = RealVariables23[47];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.HTFtoTube.port_b.T = RealVariables23[48];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.HTFtoTube.port_b.Q_flow = RealVariables23[49];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.HTFtoTube.G = RealVariables23[50];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubetoPCM.Q_flow = RealVariables23[51];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubetoPCM.dT = RealVariables23[52];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubetoPCM.port_a.T = RealVariables23[53];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubetoPCM.port_a.Q_flow = RealVariables23[54];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubetoPCM.port_b.T = RealVariables23[55];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubetoPCM.port_b.Q_flow = RealVariables23[56];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubetoPCM.G = RealVariables23[57];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.T = RealVariables23[58];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.T_der = RealVariables23[59];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.Q_flow = RealVariables23[60];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.port.T = RealVariables23[61];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.port.Q_flow = RealVariables23[62];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.der_T = RealVariables23[63];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.C = RealVariables23[64];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.port_a.T = RealVariables23[65];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.port_a.Q_flow = RealVariables23[66];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.port_b.T = RealVariables23[67];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.port_b.Q_flow = RealVariables23[68];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.G_HTFtoTube = RealVariables23[69];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.G_TubetoPCM = RealVariables23[70];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.HTFtoTube.Q_flow = RealVariables23[71];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.HTFtoTube.dT = RealVariables23[72];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.HTFtoTube.port_a.T = RealVariables23[73];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.HTFtoTube.port_a.Q_flow = RealVariables23[74];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.HTFtoTube.port_b.T = RealVariables23[75];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.HTFtoTube.port_b.Q_flow = RealVariables23[76];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.HTFtoTube.G = RealVariables23[77];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubetoPCM.Q_flow = RealVariables23[78];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubetoPCM.dT = RealVariables23[79];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubetoPCM.port_a.T = RealVariables23[80];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubetoPCM.port_a.Q_flow = RealVariables23[81];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubetoPCM.port_b.T = RealVariables23[82];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubetoPCM.port_b.Q_flow = RealVariables23[83];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubetoPCM.G = RealVariables23[84];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.T = RealVariables23[85];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.T_der = RealVariables23[86];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.Q_flow = RealVariables23[87];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.port.T = RealVariables23[88];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.port.Q_flow = RealVariables23[89];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.der_T = RealVariables23[90];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.C = RealVariables23[91];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.port_a.T = RealVariables23[92];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.port_a.Q_flow = RealVariables23[93];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.port_b.T = RealVariables23[94];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.port_b.Q_flow = RealVariables23[95];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.G_HTFtoTube = RealVariables23[96];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.G_TubetoPCM = RealVariables23[97];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.HTFtoTube.Q_flow = RealVariables23[98];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.HTFtoTube.dT = RealVariables23[99];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.HTFtoTube.port_a.T = RealVariables23[100];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.HTFtoTube.port_a.Q_flow = RealVariables24[1];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.HTFtoTube.port_b.T = RealVariables24[2];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.HTFtoTube.port_b.Q_flow = RealVariables24[3];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.HTFtoTube.G = RealVariables24[4];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubetoPCM.Q_flow = RealVariables24[5];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubetoPCM.dT = RealVariables24[6];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubetoPCM.port_a.T = RealVariables24[7];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubetoPCM.port_a.Q_flow = RealVariables24[8];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubetoPCM.port_b.T = RealVariables24[9];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubetoPCM.port_b.Q_flow = RealVariables24[10];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubetoPCM.G = RealVariables24[11];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.T = RealVariables24[12];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.T_der = RealVariables24[13];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.Q_flow = RealVariables24[14];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.port.T = RealVariables24[15];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.port.Q_flow = RealVariables24[16];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.der_T = RealVariables24[17];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.C = RealVariables24[18];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.port_a.T = RealVariables24[19];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.port_a.Q_flow = RealVariables24[20];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.port_b.T = RealVariables24[21];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.port_b.Q_flow = RealVariables24[22];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.G_HTFtoTube = RealVariables24[23];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.G_TubetoPCM = RealVariables24[24];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.HTFtoTube.Q_flow = RealVariables24[25];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.HTFtoTube.dT = RealVariables24[26];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.HTFtoTube.port_a.T = RealVariables24[27];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.HTFtoTube.port_a.Q_flow = RealVariables24[28];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.HTFtoTube.port_b.T = RealVariables24[29];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.HTFtoTube.port_b.Q_flow = RealVariables24[30];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.HTFtoTube.G = RealVariables24[31];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubetoPCM.Q_flow = RealVariables24[32];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubetoPCM.dT = RealVariables24[33];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubetoPCM.port_a.T = RealVariables24[34];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubetoPCM.port_a.Q_flow = RealVariables24[35];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubetoPCM.port_b.T = RealVariables24[36];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubetoPCM.port_b.Q_flow = RealVariables24[37];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubetoPCM.G = RealVariables24[38];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.T = RealVariables24[39];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.T_der = RealVariables24[40];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.Q_flow = RealVariables24[41];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.port.T = RealVariables24[42];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.port.Q_flow = RealVariables24[43];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.der_T = RealVariables24[44];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.C = RealVariables24[45];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.port_a.T = RealVariables24[46];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.port_a.Q_flow = RealVariables24[47];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.port_b.T = RealVariables24[48];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.port_b.Q_flow = RealVariables24[49];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.G_HTFtoTube = RealVariables24[50];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.G_TubetoPCM = RealVariables24[51];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.HTFtoTube.Q_flow = RealVariables24[52];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.HTFtoTube.dT = RealVariables24[53];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.HTFtoTube.port_a.T = RealVariables24[54];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.HTFtoTube.port_a.Q_flow = RealVariables24[55];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.HTFtoTube.port_b.T = RealVariables24[56];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.HTFtoTube.port_b.Q_flow = RealVariables24[57];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.HTFtoTube.G = RealVariables24[58];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubetoPCM.Q_flow = RealVariables24[59];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubetoPCM.dT = RealVariables24[60];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubetoPCM.port_a.T = RealVariables24[61];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubetoPCM.port_a.Q_flow = RealVariables24[62];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubetoPCM.port_b.T = RealVariables24[63];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubetoPCM.port_b.Q_flow = RealVariables24[64];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubetoPCM.G = RealVariables24[65];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.T = RealVariables24[66];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.T_der = RealVariables24[67];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.Q_flow = RealVariables24[68];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.port.T = RealVariables24[69];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.port.Q_flow = RealVariables24[70];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.der_T = RealVariables24[71];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.C = RealVariables24[72];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.port_a.T = RealVariables24[73];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.port_a.Q_flow = RealVariables24[74];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.port_b.T = RealVariables24[75];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.port_b.Q_flow = RealVariables24[76];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.G_HTFtoTube = RealVariables24[77];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.G_TubetoPCM = RealVariables24[78];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.HTFtoTube.Q_flow = RealVariables24[79];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.HTFtoTube.dT = RealVariables24[80];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.HTFtoTube.port_a.T = RealVariables24[81];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.HTFtoTube.port_a.Q_flow = RealVariables24[82];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.HTFtoTube.port_b.T = RealVariables24[83];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.HTFtoTube.port_b.Q_flow = RealVariables24[84];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.HTFtoTube.G = RealVariables24[85];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubetoPCM.Q_flow = RealVariables24[86];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubetoPCM.dT = RealVariables24[87];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubetoPCM.port_a.T = RealVariables24[88];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubetoPCM.port_a.Q_flow = RealVariables24[89];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubetoPCM.port_b.T = RealVariables24[90];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubetoPCM.port_b.Q_flow = RealVariables24[91];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubetoPCM.G = RealVariables24[92];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.T = RealVariables24[93];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.T_der = RealVariables24[94];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.Q_flow = RealVariables24[95];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.port.T = RealVariables24[96];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.port.Q_flow = RealVariables24[97];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.der_T = RealVariables24[98];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.C = RealVariables24[99];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.port_a.T = RealVariables24[100];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.port_a.Q_flow = RealVariables25[1];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.port_b.T = RealVariables25[2];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.port_b.Q_flow = RealVariables25[3];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.G_HTFtoTube = RealVariables25[4];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.G_TubetoPCM = RealVariables25[5];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.HTFtoTube.Q_flow = RealVariables25[6];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.HTFtoTube.dT = RealVariables25[7];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.HTFtoTube.port_a.T = RealVariables25[8];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.HTFtoTube.port_a.Q_flow = RealVariables25[9];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.HTFtoTube.port_b.T = RealVariables25[10];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.HTFtoTube.port_b.Q_flow = RealVariables25[11];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.HTFtoTube.G = RealVariables25[12];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubetoPCM.Q_flow = RealVariables25[13];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubetoPCM.dT = RealVariables25[14];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubetoPCM.port_a.T = RealVariables25[15];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubetoPCM.port_a.Q_flow = RealVariables25[16];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubetoPCM.port_b.T = RealVariables25[17];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubetoPCM.port_b.Q_flow = RealVariables25[18];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubetoPCM.G = RealVariables25[19];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.T = RealVariables25[20];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.T_der = RealVariables25[21];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.Q_flow = RealVariables25[22];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.port.T = RealVariables25[23];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.port.Q_flow = RealVariables25[24];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.der_T = RealVariables25[25];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.C = RealVariables25[26];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.port_a.T = RealVariables25[27];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.port_a.Q_flow = RealVariables25[28];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.port_b.T = RealVariables25[29];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.port_b.Q_flow = RealVariables25[30];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.G_HTFtoTube = RealVariables25[31];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.G_TubetoPCM = RealVariables25[32];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.HTFtoTube.Q_flow = RealVariables25[33];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.HTFtoTube.dT = RealVariables25[34];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.HTFtoTube.port_a.T = RealVariables25[35];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.HTFtoTube.port_a.Q_flow = RealVariables25[36];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.HTFtoTube.port_b.T = RealVariables25[37];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.HTFtoTube.port_b.Q_flow = RealVariables25[38];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.HTFtoTube.G = RealVariables25[39];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubetoPCM.Q_flow = RealVariables25[40];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubetoPCM.dT = RealVariables25[41];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubetoPCM.port_a.T = RealVariables25[42];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubetoPCM.port_a.Q_flow = RealVariables25[43];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubetoPCM.port_b.T = RealVariables25[44];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubetoPCM.port_b.Q_flow = RealVariables25[45];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubetoPCM.G = RealVariables25[46];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.T = RealVariables25[47];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.T_der = RealVariables25[48];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.Q_flow = RealVariables25[49];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.port.T = RealVariables25[50];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.port.Q_flow = RealVariables25[51];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.der_T = RealVariables25[52];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.C = RealVariables25[53];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.port_a.T = RealVariables25[54];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.port_a.Q_flow = RealVariables25[55];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.port_b.T = RealVariables25[56];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.port_b.Q_flow = RealVariables25[57];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.G_HTFtoTube = RealVariables25[58];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.G_TubetoPCM = RealVariables25[59];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.HTFtoTube.Q_flow = RealVariables25[60];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.HTFtoTube.dT = RealVariables25[61];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.HTFtoTube.port_a.T = RealVariables25[62];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.HTFtoTube.port_a.Q_flow = RealVariables25[63];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.HTFtoTube.port_b.T = RealVariables25[64];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.HTFtoTube.port_b.Q_flow = RealVariables25[65];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.HTFtoTube.G = RealVariables25[66];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubetoPCM.Q_flow = RealVariables25[67];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubetoPCM.dT = RealVariables25[68];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubetoPCM.port_a.T = RealVariables25[69];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubetoPCM.port_a.Q_flow = RealVariables25[70];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubetoPCM.port_b.T = RealVariables25[71];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubetoPCM.port_b.Q_flow = RealVariables25[72];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubetoPCM.G = RealVariables25[73];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.T = RealVariables25[74];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.T_der = RealVariables25[75];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.Q_flow = RealVariables25[76];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.port.T = RealVariables25[77];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.port.Q_flow = RealVariables25[78];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.der_T = RealVariables25[79];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.C = RealVariables25[80];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.port_a.T = RealVariables25[81];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.port_a.Q_flow = RealVariables25[82];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.port_b.T = RealVariables25[83];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.port_b.Q_flow = RealVariables25[84];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.G_HTFtoTube = RealVariables25[85];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.G_TubetoPCM = RealVariables25[86];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.HTFtoTube.Q_flow = RealVariables25[87];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.HTFtoTube.dT = RealVariables25[88];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.HTFtoTube.port_a.T = RealVariables25[89];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.HTFtoTube.port_a.Q_flow = RealVariables25[90];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.HTFtoTube.port_b.T = RealVariables25[91];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.HTFtoTube.port_b.Q_flow = RealVariables25[92];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.HTFtoTube.G = RealVariables25[93];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubetoPCM.Q_flow = RealVariables25[94];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubetoPCM.dT = RealVariables25[95];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubetoPCM.port_a.T = RealVariables25[96];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubetoPCM.port_a.Q_flow = RealVariables25[97];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubetoPCM.port_b.T = RealVariables25[98];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubetoPCM.port_b.Q_flow = RealVariables25[99];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubetoPCM.G = RealVariables25[100];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.T = RealVariables26[1];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.T_der = RealVariables26[2];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.Q_flow = RealVariables26[3];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.port.T = RealVariables26[4];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.port.Q_flow = RealVariables26[5];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.der_T = RealVariables26[6];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.C = RealVariables26[7];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.port_a.T = RealVariables26[8];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.port_a.Q_flow = RealVariables26[9];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.port_b.T = RealVariables26[10];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.port_b.Q_flow = RealVariables26[11];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.G_HTFtoTube = RealVariables26[12];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.G_TubetoPCM = RealVariables26[13];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.HTFtoTube.Q_flow = RealVariables26[14];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.HTFtoTube.dT = RealVariables26[15];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.HTFtoTube.port_a.T = RealVariables26[16];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.HTFtoTube.port_a.Q_flow = RealVariables26[17];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.HTFtoTube.port_b.T = RealVariables26[18];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.HTFtoTube.port_b.Q_flow = RealVariables26[19];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.HTFtoTube.G = RealVariables26[20];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubetoPCM.Q_flow = RealVariables26[21];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubetoPCM.dT = RealVariables26[22];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubetoPCM.port_a.T = RealVariables26[23];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubetoPCM.port_a.Q_flow = RealVariables26[24];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubetoPCM.port_b.T = RealVariables26[25];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubetoPCM.port_b.Q_flow = RealVariables26[26];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubetoPCM.G = RealVariables26[27];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.T = RealVariables26[28];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.T_der = RealVariables26[29];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.Q_flow = RealVariables26[30];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.port.T = RealVariables26[31];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.port.Q_flow = RealVariables26[32];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.der_T = RealVariables26[33];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.C = RealVariables26[34];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.port_a.T = RealVariables26[35];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.port_a.Q_flow = RealVariables26[36];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.port_b.T = RealVariables26[37];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.port_b.Q_flow = RealVariables26[38];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.G_HTFtoTube = RealVariables26[39];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.G_TubetoPCM = RealVariables26[40];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.HTFtoTube.Q_flow = RealVariables26[41];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.HTFtoTube.dT = RealVariables26[42];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.HTFtoTube.port_a.T = RealVariables26[43];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.HTFtoTube.port_a.Q_flow = RealVariables26[44];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.HTFtoTube.port_b.T = RealVariables26[45];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.HTFtoTube.port_b.Q_flow = RealVariables26[46];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.HTFtoTube.G = RealVariables26[47];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubetoPCM.Q_flow = RealVariables26[48];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubetoPCM.dT = RealVariables26[49];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubetoPCM.port_a.T = RealVariables26[50];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubetoPCM.port_a.Q_flow = RealVariables26[51];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubetoPCM.port_b.T = RealVariables26[52];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubetoPCM.port_b.Q_flow = RealVariables26[53];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubetoPCM.G = RealVariables26[54];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.T = RealVariables26[55];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.T_der = RealVariables26[56];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.Q_flow = RealVariables26[57];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.port.T = RealVariables26[58];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.port.Q_flow = RealVariables26[59];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.der_T = RealVariables26[60];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.C = RealVariables26[61];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.port_a.T = RealVariables26[62];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.port_a.Q_flow = RealVariables26[63];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.port_b.T = RealVariables26[64];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.port_b.Q_flow = RealVariables26[65];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.G_HTFtoTube = RealVariables26[66];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.G_TubetoPCM = RealVariables26[67];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.HTFtoTube.Q_flow = RealVariables26[68];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.HTFtoTube.dT = RealVariables26[69];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.HTFtoTube.port_a.T = RealVariables26[70];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.HTFtoTube.port_a.Q_flow = RealVariables26[71];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.HTFtoTube.port_b.T = RealVariables26[72];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.HTFtoTube.port_b.Q_flow = RealVariables26[73];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.HTFtoTube.G = RealVariables26[74];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubetoPCM.Q_flow = RealVariables26[75];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubetoPCM.dT = RealVariables26[76];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubetoPCM.port_a.T = RealVariables26[77];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubetoPCM.port_a.Q_flow = RealVariables26[78];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubetoPCM.port_b.T = RealVariables26[79];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubetoPCM.port_b.Q_flow = RealVariables26[80];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubetoPCM.G = RealVariables26[81];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.T = RealVariables26[82];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.T_der = RealVariables26[83];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.Q_flow = RealVariables26[84];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.port.T = RealVariables26[85];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.port.Q_flow = RealVariables26[86];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.der_T = RealVariables26[87];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.C = RealVariables26[88];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.port_a.T = RealVariables26[89];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.port_a.Q_flow = RealVariables26[90];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.port_b.T = RealVariables26[91];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.port_b.Q_flow = RealVariables26[92];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.G_HTFtoTube = RealVariables26[93];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.G_TubetoPCM = RealVariables26[94];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.HTFtoTube.Q_flow = RealVariables26[95];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.HTFtoTube.dT = RealVariables26[96];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.HTFtoTube.port_a.T = RealVariables26[97];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.HTFtoTube.port_a.Q_flow = RealVariables26[98];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.HTFtoTube.port_b.T = RealVariables26[99];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.HTFtoTube.port_b.Q_flow = RealVariables26[100];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.HTFtoTube.G = RealVariables27[1];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubetoPCM.Q_flow = RealVariables27[2];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubetoPCM.dT = RealVariables27[3];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubetoPCM.port_a.T = RealVariables27[4];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubetoPCM.port_a.Q_flow = RealVariables27[5];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubetoPCM.port_b.T = RealVariables27[6];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubetoPCM.port_b.Q_flow = RealVariables27[7];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubetoPCM.G = RealVariables27[8];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.T = RealVariables27[9];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.T_der = RealVariables27[10];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.Q_flow = RealVariables27[11];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.port.T = RealVariables27[12];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.port.Q_flow = RealVariables27[13];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.der_T = RealVariables27[14];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.C = RealVariables27[15];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.port_a.T = RealVariables27[16];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.port_a.Q_flow = RealVariables27[17];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.port_b.T = RealVariables27[18];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.port_b.Q_flow = RealVariables27[19];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.G_HTFtoTube = RealVariables27[20];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.G_TubetoPCM = RealVariables27[21];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.HTFtoTube.Q_flow = RealVariables27[22];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.HTFtoTube.dT = RealVariables27[23];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.HTFtoTube.port_a.T = RealVariables27[24];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.HTFtoTube.port_a.Q_flow = RealVariables27[25];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.HTFtoTube.port_b.T = RealVariables27[26];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.HTFtoTube.port_b.Q_flow = RealVariables27[27];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.HTFtoTube.G = RealVariables27[28];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubetoPCM.Q_flow = RealVariables27[29];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubetoPCM.dT = RealVariables27[30];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubetoPCM.port_a.T = RealVariables27[31];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubetoPCM.port_a.Q_flow = RealVariables27[32];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubetoPCM.port_b.T = RealVariables27[33];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubetoPCM.port_b.Q_flow = RealVariables27[34];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubetoPCM.G = RealVariables27[35];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.T = RealVariables27[36];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.T_der = RealVariables27[37];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.Q_flow = RealVariables27[38];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.port.T = RealVariables27[39];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.port.Q_flow = RealVariables27[40];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.der_T = RealVariables27[41];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.C = RealVariables27[42];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.port_a.T = RealVariables27[43];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.port_a.Q_flow = RealVariables27[44];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.port_b.T = RealVariables27[45];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.port_b.Q_flow = RealVariables27[46];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.G_HTFtoTube = RealVariables27[47];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.G_TubetoPCM = RealVariables27[48];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.HTFtoTube.Q_flow = RealVariables27[49];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.HTFtoTube.dT = RealVariables27[50];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.HTFtoTube.port_a.T = RealVariables27[51];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.HTFtoTube.port_a.Q_flow = RealVariables27[52];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.HTFtoTube.port_b.T = RealVariables27[53];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.HTFtoTube.port_b.Q_flow = RealVariables27[54];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.HTFtoTube.G = RealVariables27[55];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubetoPCM.Q_flow = RealVariables27[56];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubetoPCM.dT = RealVariables27[57];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubetoPCM.port_a.T = RealVariables27[58];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubetoPCM.port_a.Q_flow = RealVariables27[59];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubetoPCM.port_b.T = RealVariables27[60];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubetoPCM.port_b.Q_flow = RealVariables27[61];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubetoPCM.G = RealVariables27[62];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.T = RealVariables27[63];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.T_der = RealVariables27[64];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.Q_flow = RealVariables27[65];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.port.T = RealVariables27[66];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.port.Q_flow = RealVariables27[67];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.der_T = RealVariables27[68];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.C = RealVariables27[69];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.port_a.T = RealVariables27[70];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.port_a.Q_flow = RealVariables27[71];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.port_b.T = RealVariables27[72];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.port_b.Q_flow = RealVariables27[73];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.G_HTFtoTube = RealVariables27[74];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.G_TubetoPCM = RealVariables27[75];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.HTFtoTube.Q_flow = RealVariables27[76];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.HTFtoTube.dT = RealVariables27[77];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.HTFtoTube.port_a.T = RealVariables27[78];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.HTFtoTube.port_a.Q_flow = RealVariables27[79];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.HTFtoTube.port_b.T = RealVariables27[80];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.HTFtoTube.port_b.Q_flow = RealVariables27[81];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.HTFtoTube.G = RealVariables27[82];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubetoPCM.Q_flow = RealVariables27[83];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubetoPCM.dT = RealVariables27[84];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubetoPCM.port_a.T = RealVariables27[85];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubetoPCM.port_a.Q_flow = RealVariables27[86];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubetoPCM.port_b.T = RealVariables27[87];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubetoPCM.port_b.Q_flow = RealVariables27[88];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubetoPCM.G = RealVariables27[89];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.T = RealVariables27[90];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.T_der = RealVariables27[91];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.Q_flow = RealVariables27[92];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.port.T = RealVariables27[93];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.port.Q_flow = RealVariables27[94];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.der_T = RealVariables27[95];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.C = RealVariables27[96];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.port_a.T = RealVariables27[97];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.port_a.Q_flow = RealVariables27[98];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.port_b.T = RealVariables27[99];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.port_b.Q_flow = RealVariables27[100];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.G_HTFtoTube = RealVariables28[1];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.G_TubetoPCM = RealVariables28[2];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.HTFtoTube.Q_flow = RealVariables28[3];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.HTFtoTube.dT = RealVariables28[4];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.HTFtoTube.port_a.T = RealVariables28[5];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.HTFtoTube.port_a.Q_flow = RealVariables28[6];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.HTFtoTube.port_b.T = RealVariables28[7];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.HTFtoTube.port_b.Q_flow = RealVariables28[8];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.HTFtoTube.G = RealVariables28[9];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubetoPCM.Q_flow = RealVariables28[10];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubetoPCM.dT = RealVariables28[11];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubetoPCM.port_a.T = RealVariables28[12];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubetoPCM.port_a.Q_flow = RealVariables28[13];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubetoPCM.port_b.T = RealVariables28[14];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubetoPCM.port_b.Q_flow = RealVariables28[15];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubetoPCM.G = RealVariables28[16];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.T = RealVariables28[17];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.T_der = RealVariables28[18];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.Q_flow = RealVariables28[19];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.port.T = RealVariables28[20];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.port.Q_flow = RealVariables28[21];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.der_T = RealVariables28[22];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.C = RealVariables28[23];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.port_a.T = RealVariables28[24];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.port_a.Q_flow = RealVariables28[25];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.port_b.T = RealVariables28[26];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.port_b.Q_flow = RealVariables28[27];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.G_HTFtoTube = RealVariables28[28];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.G_TubetoPCM = RealVariables28[29];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.HTFtoTube.Q_flow = RealVariables28[30];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.HTFtoTube.dT = RealVariables28[31];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.HTFtoTube.port_a.T = RealVariables28[32];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.HTFtoTube.port_a.Q_flow = RealVariables28[33];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.HTFtoTube.port_b.T = RealVariables28[34];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.HTFtoTube.port_b.Q_flow = RealVariables28[35];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.HTFtoTube.G = RealVariables28[36];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubetoPCM.Q_flow = RealVariables28[37];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubetoPCM.dT = RealVariables28[38];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubetoPCM.port_a.T = RealVariables28[39];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubetoPCM.port_a.Q_flow = RealVariables28[40];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubetoPCM.port_b.T = RealVariables28[41];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubetoPCM.port_b.Q_flow = RealVariables28[42];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubetoPCM.G = RealVariables28[43];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.T = RealVariables28[44];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.T_der = RealVariables28[45];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.Q_flow = RealVariables28[46];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.port.T = RealVariables28[47];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.port.Q_flow = RealVariables28[48];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.der_T = RealVariables28[49];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.C = RealVariables28[50];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.port_a.T = RealVariables28[51];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.port_a.Q_flow = RealVariables28[52];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.port_b.T = RealVariables28[53];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.port_b.Q_flow = RealVariables28[54];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.G_HTFtoTube = RealVariables28[55];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.G_TubetoPCM = RealVariables28[56];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.HTFtoTube.Q_flow = RealVariables28[57];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.HTFtoTube.dT = RealVariables28[58];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.HTFtoTube.port_a.T = RealVariables28[59];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.HTFtoTube.port_a.Q_flow = RealVariables28[60];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.HTFtoTube.port_b.T = RealVariables28[61];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.HTFtoTube.port_b.Q_flow = RealVariables28[62];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.HTFtoTube.G = RealVariables28[63];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubetoPCM.Q_flow = RealVariables28[64];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubetoPCM.dT = RealVariables28[65];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubetoPCM.port_a.T = RealVariables28[66];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubetoPCM.port_a.Q_flow = RealVariables28[67];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubetoPCM.port_b.T = RealVariables28[68];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubetoPCM.port_b.Q_flow = RealVariables28[69];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubetoPCM.G = RealVariables28[70];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.T = RealVariables28[71];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.T_der = RealVariables28[72];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.Q_flow = RealVariables28[73];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.port.T = RealVariables28[74];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.port.Q_flow = RealVariables28[75];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.der_T = RealVariables28[76];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.C = RealVariables28[77];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.port_a.T = RealVariables28[78];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.port_a.Q_flow = RealVariables28[79];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.port_b.T = RealVariables28[80];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.port_b.Q_flow = RealVariables28[81];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.G_HTFtoTube = RealVariables28[82];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.G_TubetoPCM = RealVariables28[83];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.HTFtoTube.Q_flow = RealVariables28[84];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.HTFtoTube.dT = RealVariables28[85];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.HTFtoTube.port_a.T = RealVariables28[86];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.HTFtoTube.port_a.Q_flow = RealVariables28[87];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.HTFtoTube.port_b.T = RealVariables28[88];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.HTFtoTube.port_b.Q_flow = RealVariables28[89];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.HTFtoTube.G = RealVariables28[90];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubetoPCM.Q_flow = RealVariables28[91];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubetoPCM.dT = RealVariables28[92];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubetoPCM.port_a.T = RealVariables28[93];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubetoPCM.port_a.Q_flow = RealVariables28[94];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubetoPCM.port_b.T = RealVariables28[95];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubetoPCM.port_b.Q_flow = RealVariables28[96];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubetoPCM.G = RealVariables28[97];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.T = RealVariables28[98];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.T_der = RealVariables28[99];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.Q_flow = RealVariables28[100];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.port.T = RealVariables29[1];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.port.Q_flow = RealVariables29[2];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.der_T = RealVariables29[3];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.C = RealVariables29[4];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.port_a.T = RealVariables29[5];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.port_a.Q_flow = RealVariables29[6];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.port_b.T = RealVariables29[7];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.port_b.Q_flow = RealVariables29[8];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.G_HTFtoTube = RealVariables29[9];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.G_TubetoPCM = RealVariables29[10];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.HTFtoTube.Q_flow = RealVariables29[11];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.HTFtoTube.dT = RealVariables29[12];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.HTFtoTube.port_a.T = RealVariables29[13];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.HTFtoTube.port_a.Q_flow = RealVariables29[14];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.HTFtoTube.port_b.T = RealVariables29[15];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.HTFtoTube.port_b.Q_flow = RealVariables29[16];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.HTFtoTube.G = RealVariables29[17];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubetoPCM.Q_flow = RealVariables29[18];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubetoPCM.dT = RealVariables29[19];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubetoPCM.port_a.T = RealVariables29[20];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubetoPCM.port_a.Q_flow = RealVariables29[21];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubetoPCM.port_b.T = RealVariables29[22];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubetoPCM.port_b.Q_flow = RealVariables29[23];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubetoPCM.G = RealVariables29[24];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.T = RealVariables29[25];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.T_der = RealVariables29[26];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.Q_flow = RealVariables29[27];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.port.T = RealVariables29[28];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.port.Q_flow = RealVariables29[29];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.der_T = RealVariables29[30];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.C = RealVariables29[31];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.port_a.T = RealVariables29[32];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.port_a.Q_flow = RealVariables29[33];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.port_b.T = RealVariables29[34];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.port_b.Q_flow = RealVariables29[35];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.G_HTFtoTube = RealVariables29[36];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.G_TubetoPCM = RealVariables29[37];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.HTFtoTube.Q_flow = RealVariables29[38];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.HTFtoTube.dT = RealVariables29[39];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.HTFtoTube.port_a.T = RealVariables29[40];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.HTFtoTube.port_a.Q_flow = RealVariables29[41];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.HTFtoTube.port_b.T = RealVariables29[42];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.HTFtoTube.port_b.Q_flow = RealVariables29[43];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.HTFtoTube.G = RealVariables29[44];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubetoPCM.Q_flow = RealVariables29[45];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubetoPCM.dT = RealVariables29[46];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubetoPCM.port_a.T = RealVariables29[47];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubetoPCM.port_a.Q_flow = RealVariables29[48];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubetoPCM.port_b.T = RealVariables29[49];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubetoPCM.port_b.Q_flow = RealVariables29[50];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubetoPCM.G = RealVariables29[51];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.T = RealVariables29[52];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.T_der = RealVariables29[53];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.Q_flow = RealVariables29[54];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.port.T = RealVariables29[55];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.port.Q_flow = RealVariables29[56];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.der_T = RealVariables29[57];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.C = RealVariables29[58];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.port_a.T = RealVariables29[59];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.port_a.Q_flow = RealVariables29[60];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.port_b.T = RealVariables29[61];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.port_b.Q_flow = RealVariables29[62];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.G_HTFtoTube = RealVariables29[63];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.G_TubetoPCM = RealVariables29[64];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.HTFtoTube.Q_flow = RealVariables29[65];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.HTFtoTube.dT = RealVariables29[66];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.HTFtoTube.port_a.T = RealVariables29[67];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.HTFtoTube.port_a.Q_flow = RealVariables29[68];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.HTFtoTube.port_b.T = RealVariables29[69];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.HTFtoTube.port_b.Q_flow = RealVariables29[70];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.HTFtoTube.G = RealVariables29[71];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubetoPCM.Q_flow = RealVariables29[72];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubetoPCM.dT = RealVariables29[73];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubetoPCM.port_a.T = RealVariables29[74];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubetoPCM.port_a.Q_flow = RealVariables29[75];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubetoPCM.port_b.T = RealVariables29[76];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubetoPCM.port_b.Q_flow = RealVariables29[77];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubetoPCM.G = RealVariables29[78];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.T = RealVariables29[79];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.T_der = RealVariables29[80];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.Q_flow = RealVariables29[81];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.port.T = RealVariables29[82];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.port.Q_flow = RealVariables29[83];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.der_T = RealVariables29[84];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.C = RealVariables29[85];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.port_a.T = RealVariables29[86];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.port_a.Q_flow = RealVariables29[87];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.port_b.T = RealVariables29[88];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.port_b.Q_flow = RealVariables29[89];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.G_HTFtoTube = RealVariables29[90];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.G_TubetoPCM = RealVariables29[91];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.HTFtoTube.Q_flow = RealVariables29[92];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.HTFtoTube.dT = RealVariables29[93];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.HTFtoTube.port_a.T = RealVariables29[94];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.HTFtoTube.port_a.Q_flow = RealVariables29[95];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.HTFtoTube.port_b.T = RealVariables29[96];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.HTFtoTube.port_b.Q_flow = RealVariables29[97];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.HTFtoTube.G = RealVariables29[98];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubetoPCM.Q_flow = RealVariables29[99];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubetoPCM.dT = RealVariables29[100];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubetoPCM.port_a.T = RealVariables30[1];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubetoPCM.port_a.Q_flow = RealVariables30[2];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubetoPCM.port_b.T = RealVariables30[3];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubetoPCM.port_b.Q_flow = RealVariables30[4];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubetoPCM.G = RealVariables30[5];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.T = RealVariables30[6];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.T_der = RealVariables30[7];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.Q_flow = RealVariables30[8];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.port.T = RealVariables30[9];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.port.Q_flow = RealVariables30[10];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.der_T = RealVariables30[11];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.C = RealVariables30[12];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.port_a.T = RealVariables30[13];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.port_a.Q_flow = RealVariables30[14];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.port_b.T = RealVariables30[15];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.port_b.Q_flow = RealVariables30[16];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.G_HTFtoTube = RealVariables30[17];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.G_TubetoPCM = RealVariables30[18];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.HTFtoTube.Q_flow = RealVariables30[19];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.HTFtoTube.dT = RealVariables30[20];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.HTFtoTube.port_a.T = RealVariables30[21];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.HTFtoTube.port_a.Q_flow = RealVariables30[22];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.HTFtoTube.port_b.T = RealVariables30[23];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.HTFtoTube.port_b.Q_flow = RealVariables30[24];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.HTFtoTube.G = RealVariables30[25];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubetoPCM.Q_flow = RealVariables30[26];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubetoPCM.dT = RealVariables30[27];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubetoPCM.port_a.T = RealVariables30[28];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubetoPCM.port_a.Q_flow = RealVariables30[29];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubetoPCM.port_b.T = RealVariables30[30];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubetoPCM.port_b.Q_flow = RealVariables30[31];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubetoPCM.G = RealVariables30[32];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.T = RealVariables30[33];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.T_der = RealVariables30[34];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.Q_flow = RealVariables30[35];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.port.T = RealVariables30[36];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.port.Q_flow = RealVariables30[37];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.der_T = RealVariables30[38];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.C = RealVariables30[39];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.port_a.T = RealVariables30[40];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.port_a.Q_flow = RealVariables30[41];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.port_b.T = RealVariables30[42];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.port_b.Q_flow = RealVariables30[43];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.G_HTFtoTube = RealVariables30[44];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.G_TubetoPCM = RealVariables30[45];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.HTFtoTube.Q_flow = RealVariables30[46];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.HTFtoTube.dT = RealVariables30[47];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.HTFtoTube.port_a.T = RealVariables30[48];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.HTFtoTube.port_a.Q_flow = RealVariables30[49];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.HTFtoTube.port_b.T = RealVariables30[50];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.HTFtoTube.port_b.Q_flow = RealVariables30[51];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.HTFtoTube.G = RealVariables30[52];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubetoPCM.Q_flow = RealVariables30[53];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubetoPCM.dT = RealVariables30[54];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubetoPCM.port_a.T = RealVariables30[55];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubetoPCM.port_a.Q_flow = RealVariables30[56];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubetoPCM.port_b.T = RealVariables30[57];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubetoPCM.port_b.Q_flow = RealVariables30[58];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubetoPCM.G = RealVariables30[59];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.T = RealVariables30[60];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.T_der = RealVariables30[61];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.Q_flow = RealVariables30[62];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.port.T = RealVariables30[63];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.port.Q_flow = RealVariables30[64];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.der_T = RealVariables30[65];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.C = RealVariables30[66];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.port_a.T = RealVariables30[67];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.port_a.Q_flow = RealVariables30[68];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.port_b.T = RealVariables30[69];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.port_b.Q_flow = RealVariables30[70];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.G_HTFtoTube = RealVariables30[71];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.G_TubetoPCM = RealVariables30[72];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.HTFtoTube.Q_flow = RealVariables30[73];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.HTFtoTube.dT = RealVariables30[74];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.HTFtoTube.port_a.T = RealVariables30[75];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.HTFtoTube.port_a.Q_flow = RealVariables30[76];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.HTFtoTube.port_b.T = RealVariables30[77];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.HTFtoTube.port_b.Q_flow = RealVariables30[78];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.HTFtoTube.G = RealVariables30[79];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubetoPCM.Q_flow = RealVariables30[80];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubetoPCM.dT = RealVariables30[81];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubetoPCM.port_a.T = RealVariables30[82];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubetoPCM.port_a.Q_flow = RealVariables30[83];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubetoPCM.port_b.T = RealVariables30[84];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubetoPCM.port_b.Q_flow = RealVariables30[85];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubetoPCM.G = RealVariables30[86];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.T = RealVariables30[87];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.T_der = RealVariables30[88];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.Q_flow = RealVariables30[89];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.port.T = RealVariables30[90];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.port.Q_flow = RealVariables30[91];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.der_T = RealVariables30[92];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.C = RealVariables30[93];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.port_a.T = RealVariables30[94];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.port_a.Q_flow = RealVariables30[95];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.port_b.T = RealVariables30[96];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.port_b.Q_flow = RealVariables30[97];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.G_HTFtoTube = RealVariables30[98];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.G_TubetoPCM = RealVariables30[99];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.HTFtoTube.Q_flow = RealVariables30[100];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.HTFtoTube.dT = RealVariables31[1];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.HTFtoTube.port_a.T = RealVariables31[2];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.HTFtoTube.port_a.Q_flow = RealVariables31[3];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.HTFtoTube.port_b.T = RealVariables31[4];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.HTFtoTube.port_b.Q_flow = RealVariables31[5];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.HTFtoTube.G = RealVariables31[6];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubetoPCM.Q_flow = RealVariables31[7];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubetoPCM.dT = RealVariables31[8];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubetoPCM.port_a.T = RealVariables31[9];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubetoPCM.port_a.Q_flow = RealVariables31[10];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubetoPCM.port_b.T = RealVariables31[11];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubetoPCM.port_b.Q_flow = RealVariables31[12];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubetoPCM.G = RealVariables31[13];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.T = RealVariables31[14];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.T_der = RealVariables31[15];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.Q_flow = RealVariables31[16];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.port.T = RealVariables31[17];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.port.Q_flow = RealVariables31[18];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.der_T = RealVariables31[19];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.C = RealVariables31[20];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.port_a.T = RealVariables31[21];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.port_a.Q_flow = RealVariables31[22];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.port_b.T = RealVariables31[23];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.port_b.Q_flow = RealVariables31[24];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.G_HTFtoTube = RealVariables31[25];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.G_TubetoPCM = RealVariables31[26];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.HTFtoTube.Q_flow = RealVariables31[27];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.HTFtoTube.dT = RealVariables31[28];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.HTFtoTube.port_a.T = RealVariables31[29];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.HTFtoTube.port_a.Q_flow = RealVariables31[30];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.HTFtoTube.port_b.T = RealVariables31[31];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.HTFtoTube.port_b.Q_flow = RealVariables31[32];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.HTFtoTube.G = RealVariables31[33];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubetoPCM.Q_flow = RealVariables31[34];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubetoPCM.dT = RealVariables31[35];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubetoPCM.port_a.T = RealVariables31[36];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubetoPCM.port_a.Q_flow = RealVariables31[37];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubetoPCM.port_b.T = RealVariables31[38];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubetoPCM.port_b.Q_flow = RealVariables31[39];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubetoPCM.G = RealVariables31[40];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.T = RealVariables31[41];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.T_der = RealVariables31[42];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.Q_flow = RealVariables31[43];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.port.T = RealVariables31[44];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.port.Q_flow = RealVariables31[45];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.der_T = RealVariables31[46];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.C = RealVariables31[47];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.port_a.T = RealVariables31[48];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.port_a.Q_flow = RealVariables31[49];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.port_b.T = RealVariables31[50];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.port_b.Q_flow = RealVariables31[51];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.G_HTFtoTube = RealVariables31[52];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.G_TubetoPCM = RealVariables31[53];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.HTFtoTube.Q_flow = RealVariables31[54];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.HTFtoTube.dT = RealVariables31[55];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.HTFtoTube.port_a.T = RealVariables31[56];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.HTFtoTube.port_a.Q_flow = RealVariables31[57];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.HTFtoTube.port_b.T = RealVariables31[58];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.HTFtoTube.port_b.Q_flow = RealVariables31[59];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.HTFtoTube.G = RealVariables31[60];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubetoPCM.Q_flow = RealVariables31[61];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubetoPCM.dT = RealVariables31[62];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubetoPCM.port_a.T = RealVariables31[63];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubetoPCM.port_a.Q_flow = RealVariables31[64];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubetoPCM.port_b.T = RealVariables31[65];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubetoPCM.port_b.Q_flow = RealVariables31[66];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubetoPCM.G = RealVariables31[67];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.T = RealVariables31[68];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.T_der = RealVariables31[69];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.Q_flow = RealVariables31[70];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.port.T = RealVariables31[71];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.port.Q_flow = RealVariables31[72];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.der_T = RealVariables31[73];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.C = RealVariables31[74];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.port_a.T = RealVariables31[75];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.port_a.Q_flow = RealVariables31[76];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.port_b.T = RealVariables31[77];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.port_b.Q_flow = RealVariables31[78];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.G_HTFtoTube = RealVariables31[79];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.G_TubetoPCM = RealVariables31[80];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.HTFtoTube.Q_flow = RealVariables31[81];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.HTFtoTube.dT = RealVariables31[82];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.HTFtoTube.port_a.T = RealVariables31[83];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.HTFtoTube.port_a.Q_flow = RealVariables31[84];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.HTFtoTube.port_b.T = RealVariables31[85];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.HTFtoTube.port_b.Q_flow = RealVariables31[86];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.HTFtoTube.G = RealVariables31[87];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubetoPCM.Q_flow = RealVariables31[88];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubetoPCM.dT = RealVariables31[89];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubetoPCM.port_a.T = RealVariables31[90];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubetoPCM.port_a.Q_flow = RealVariables31[91];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubetoPCM.port_b.T = RealVariables31[92];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubetoPCM.port_b.Q_flow = RealVariables31[93];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubetoPCM.G = RealVariables31[94];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.T = RealVariables31[95];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.T_der = RealVariables31[96];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.Q_flow = RealVariables31[97];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.port.T = RealVariables31[98];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.port.Q_flow = RealVariables31[99];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.der_T = RealVariables31[100];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.C = RealVariables32[1];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.port_a.T = RealVariables32[2];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.port_a.Q_flow = RealVariables32[3];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.port_b.T = RealVariables32[4];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.port_b.Q_flow = RealVariables32[5];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.G_HTFtoTube = RealVariables32[6];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.G_TubetoPCM = RealVariables32[7];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.HTFtoTube.Q_flow = RealVariables32[8];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.HTFtoTube.dT = RealVariables32[9];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.HTFtoTube.port_a.T = RealVariables32[10];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.HTFtoTube.port_a.Q_flow = RealVariables32[11];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.HTFtoTube.port_b.T = RealVariables32[12];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.HTFtoTube.port_b.Q_flow = RealVariables32[13];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.HTFtoTube.G = RealVariables32[14];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubetoPCM.Q_flow = RealVariables32[15];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubetoPCM.dT = RealVariables32[16];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubetoPCM.port_a.T = RealVariables32[17];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubetoPCM.port_a.Q_flow = RealVariables32[18];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubetoPCM.port_b.T = RealVariables32[19];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubetoPCM.port_b.Q_flow = RealVariables32[20];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubetoPCM.G = RealVariables32[21];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.T = RealVariables32[22];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.T_der = RealVariables32[23];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.Q_flow = RealVariables32[24];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.port.T = RealVariables32[25];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.port.Q_flow = RealVariables32[26];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.der_T = RealVariables32[27];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.C = RealVariables32[28];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.port_a.T = RealVariables32[29];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.port_a.Q_flow = RealVariables32[30];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.port_b.T = RealVariables32[31];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.port_b.Q_flow = RealVariables32[32];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.G_HTFtoTube = RealVariables32[33];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.G_TubetoPCM = RealVariables32[34];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.HTFtoTube.Q_flow = RealVariables32[35];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.HTFtoTube.dT = RealVariables32[36];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.HTFtoTube.port_a.T = RealVariables32[37];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.HTFtoTube.port_a.Q_flow = RealVariables32[38];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.HTFtoTube.port_b.T = RealVariables32[39];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.HTFtoTube.port_b.Q_flow = RealVariables32[40];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.HTFtoTube.G = RealVariables32[41];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubetoPCM.Q_flow = RealVariables32[42];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubetoPCM.dT = RealVariables32[43];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubetoPCM.port_a.T = RealVariables32[44];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubetoPCM.port_a.Q_flow = RealVariables32[45];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubetoPCM.port_b.T = RealVariables32[46];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubetoPCM.port_b.Q_flow = RealVariables32[47];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubetoPCM.G = RealVariables32[48];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.T = RealVariables32[49];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.T_der = RealVariables32[50];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.Q_flow = RealVariables32[51];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.port.T = RealVariables32[52];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.port.Q_flow = RealVariables32[53];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.der_T = RealVariables32[54];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.C = RealVariables32[55];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.port_a.T = RealVariables32[56];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.port_a.Q_flow = RealVariables32[57];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.port_b.T = RealVariables32[58];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.port_b.Q_flow = RealVariables32[59];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.G_HTFtoTube = RealVariables32[60];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.G_TubetoPCM = RealVariables32[61];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.HTFtoTube.Q_flow = RealVariables32[62];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.HTFtoTube.dT = RealVariables32[63];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.HTFtoTube.port_a.T = RealVariables32[64];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.HTFtoTube.port_a.Q_flow = RealVariables32[65];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.HTFtoTube.port_b.T = RealVariables32[66];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.HTFtoTube.port_b.Q_flow = RealVariables32[67];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.HTFtoTube.G = RealVariables32[68];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubetoPCM.Q_flow = RealVariables32[69];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubetoPCM.dT = RealVariables32[70];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubetoPCM.port_a.T = RealVariables32[71];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubetoPCM.port_a.Q_flow = RealVariables32[72];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubetoPCM.port_b.T = RealVariables32[73];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubetoPCM.port_b.Q_flow = RealVariables32[74];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubetoPCM.G = RealVariables32[75];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.T = RealVariables32[76];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.T_der = RealVariables32[77];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.Q_flow = RealVariables32[78];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.port.T = RealVariables32[79];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.port.Q_flow = RealVariables32[80];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.der_T = RealVariables32[81];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.C = RealVariables32[82];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.port_a.T = RealVariables32[83];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.port_a.Q_flow = RealVariables32[84];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.port_b.T = RealVariables32[85];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.port_b.Q_flow = RealVariables32[86];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.G_HTFtoTube = RealVariables32[87];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.G_TubetoPCM = RealVariables32[88];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.HTFtoTube.Q_flow = RealVariables32[89];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.HTFtoTube.dT = RealVariables32[90];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.HTFtoTube.port_a.T = RealVariables32[91];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.HTFtoTube.port_a.Q_flow = RealVariables32[92];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.HTFtoTube.port_b.T = RealVariables32[93];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.HTFtoTube.port_b.Q_flow = RealVariables32[94];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.HTFtoTube.G = RealVariables32[95];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubetoPCM.Q_flow = RealVariables32[96];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubetoPCM.dT = RealVariables32[97];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubetoPCM.port_a.T = RealVariables32[98];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubetoPCM.port_a.Q_flow = RealVariables32[99];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubetoPCM.port_b.T = RealVariables32[100];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubetoPCM.port_b.Q_flow = RealVariables33[1];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubetoPCM.G = RealVariables33[2];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.T = RealVariables33[3];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.T_der = RealVariables33[4];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.Q_flow = RealVariables33[5];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.port.T = RealVariables33[6];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.port.Q_flow = RealVariables33[7];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.der_T = RealVariables33[8];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.C = RealVariables33[9];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.port_a.T = RealVariables33[10];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.port_a.Q_flow = RealVariables33[11];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.port_b.T = RealVariables33[12];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.port_b.Q_flow = RealVariables33[13];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.G_HTFtoTube = RealVariables33[14];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.G_TubetoPCM = RealVariables33[15];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.HTFtoTube.Q_flow = RealVariables33[16];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.HTFtoTube.dT = RealVariables33[17];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.HTFtoTube.port_a.T = RealVariables33[18];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.HTFtoTube.port_a.Q_flow = RealVariables33[19];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.HTFtoTube.port_b.T = RealVariables33[20];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.HTFtoTube.port_b.Q_flow = RealVariables33[21];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.HTFtoTube.G = RealVariables33[22];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubetoPCM.Q_flow = RealVariables33[23];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubetoPCM.dT = RealVariables33[24];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubetoPCM.port_a.T = RealVariables33[25];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubetoPCM.port_a.Q_flow = RealVariables33[26];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubetoPCM.port_b.T = RealVariables33[27];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubetoPCM.port_b.Q_flow = RealVariables33[28];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubetoPCM.G = RealVariables33[29];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.T = RealVariables33[30];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.T_der = RealVariables33[31];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.Q_flow = RealVariables33[32];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.port.T = RealVariables33[33];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.port.Q_flow = RealVariables33[34];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.der_T = RealVariables33[35];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.C = RealVariables33[36];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.port_a.T = RealVariables33[37];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.port_a.Q_flow = RealVariables33[38];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.port_b.T = RealVariables33[39];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.port_b.Q_flow = RealVariables33[40];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.G_HTFtoTube = RealVariables33[41];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.G_TubetoPCM = RealVariables33[42];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.HTFtoTube.Q_flow = RealVariables33[43];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.HTFtoTube.dT = RealVariables33[44];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.HTFtoTube.port_a.T = RealVariables33[45];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.HTFtoTube.port_a.Q_flow = RealVariables33[46];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.HTFtoTube.port_b.T = RealVariables33[47];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.HTFtoTube.port_b.Q_flow = RealVariables33[48];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.HTFtoTube.G = RealVariables33[49];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubetoPCM.Q_flow = RealVariables33[50];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubetoPCM.dT = RealVariables33[51];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubetoPCM.port_a.T = RealVariables33[52];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubetoPCM.port_a.Q_flow = RealVariables33[53];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubetoPCM.port_b.T = RealVariables33[54];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubetoPCM.port_b.Q_flow = RealVariables33[55];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubetoPCM.G = RealVariables33[56];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.T = RealVariables33[57];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.T_der = RealVariables33[58];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.Q_flow = RealVariables33[59];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.port.T = RealVariables33[60];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.port.Q_flow = RealVariables33[61];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.der_T = RealVariables33[62];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.C = RealVariables33[63];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.port_a.T = RealVariables33[64];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.port_a.Q_flow = RealVariables33[65];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.port_b.T = RealVariables33[66];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.port_b.Q_flow = RealVariables33[67];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.G_HTFtoTube = RealVariables33[68];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.G_TubetoPCM = RealVariables33[69];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.HTFtoTube.Q_flow = RealVariables33[70];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.HTFtoTube.dT = RealVariables33[71];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.HTFtoTube.port_a.T = RealVariables33[72];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.HTFtoTube.port_a.Q_flow = RealVariables33[73];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.HTFtoTube.port_b.T = RealVariables33[74];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.HTFtoTube.port_b.Q_flow = RealVariables33[75];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.HTFtoTube.G = RealVariables33[76];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubetoPCM.Q_flow = RealVariables33[77];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubetoPCM.dT = RealVariables33[78];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubetoPCM.port_a.T = RealVariables33[79];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubetoPCM.port_a.Q_flow = RealVariables33[80];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubetoPCM.port_b.T = RealVariables33[81];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubetoPCM.port_b.Q_flow = RealVariables33[82];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubetoPCM.G = RealVariables33[83];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.T = RealVariables33[84];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.T_der = RealVariables33[85];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.Q_flow = RealVariables33[86];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.port.T = RealVariables33[87];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.port.Q_flow = RealVariables33[88];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.der_T = RealVariables33[89];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.C = RealVariables33[90];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.port_a.T = RealVariables33[91];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.port_a.Q_flow = RealVariables33[92];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.port_b.T = RealVariables33[93];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.port_b.Q_flow = RealVariables33[94];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.G_HTFtoTube = RealVariables33[95];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.G_TubetoPCM = RealVariables33[96];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.HTFtoTube.Q_flow = RealVariables33[97];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.HTFtoTube.dT = RealVariables33[98];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.HTFtoTube.port_a.T = RealVariables33[99];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.HTFtoTube.port_a.Q_flow = RealVariables33[100];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.HTFtoTube.port_b.T = RealVariables34[1];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.HTFtoTube.port_b.Q_flow = RealVariables34[2];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.HTFtoTube.G = RealVariables34[3];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubetoPCM.Q_flow = RealVariables34[4];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubetoPCM.dT = RealVariables34[5];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubetoPCM.port_a.T = RealVariables34[6];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubetoPCM.port_a.Q_flow = RealVariables34[7];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubetoPCM.port_b.T = RealVariables34[8];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubetoPCM.port_b.Q_flow = RealVariables34[9];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubetoPCM.G = RealVariables34[10];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.T = RealVariables34[11];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.T_der = RealVariables34[12];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.Q_flow = RealVariables34[13];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.port.T = RealVariables34[14];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.port.Q_flow = RealVariables34[15];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.der_T = RealVariables34[16];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.C = RealVariables34[17];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.port_a.T = RealVariables34[18];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.port_a.Q_flow = RealVariables34[19];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.port_b.T = RealVariables34[20];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.port_b.Q_flow = RealVariables34[21];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.G_HTFtoTube = RealVariables34[22];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.G_TubetoPCM = RealVariables34[23];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.HTFtoTube.Q_flow = RealVariables34[24];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.HTFtoTube.dT = RealVariables34[25];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.HTFtoTube.port_a.T = RealVariables34[26];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.HTFtoTube.port_a.Q_flow = RealVariables34[27];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.HTFtoTube.port_b.T = RealVariables34[28];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.HTFtoTube.port_b.Q_flow = RealVariables34[29];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.HTFtoTube.G = RealVariables34[30];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubetoPCM.Q_flow = RealVariables34[31];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubetoPCM.dT = RealVariables34[32];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubetoPCM.port_a.T = RealVariables34[33];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubetoPCM.port_a.Q_flow = RealVariables34[34];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubetoPCM.port_b.T = RealVariables34[35];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubetoPCM.port_b.Q_flow = RealVariables34[36];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubetoPCM.G = RealVariables34[37];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.T = RealVariables34[38];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.T_der = RealVariables34[39];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.Q_flow = RealVariables34[40];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.port.T = RealVariables34[41];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.port.Q_flow = RealVariables34[42];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.der_T = RealVariables34[43];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.C = RealVariables34[44];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.port_a.T = RealVariables34[45];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.port_a.Q_flow = RealVariables34[46];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.port_b.T = RealVariables34[47];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.port_b.Q_flow = RealVariables34[48];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.G_HTFtoTube = RealVariables34[49];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.G_TubetoPCM = RealVariables34[50];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.HTFtoTube.Q_flow = RealVariables34[51];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.HTFtoTube.dT = RealVariables34[52];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.HTFtoTube.port_a.T = RealVariables34[53];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.HTFtoTube.port_a.Q_flow = RealVariables34[54];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.HTFtoTube.port_b.T = RealVariables34[55];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.HTFtoTube.port_b.Q_flow = RealVariables34[56];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.HTFtoTube.G = RealVariables34[57];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubetoPCM.Q_flow = RealVariables34[58];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubetoPCM.dT = RealVariables34[59];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubetoPCM.port_a.T = RealVariables34[60];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubetoPCM.port_a.Q_flow = RealVariables34[61];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubetoPCM.port_b.T = RealVariables34[62];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubetoPCM.port_b.Q_flow = RealVariables34[63];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubetoPCM.G = RealVariables34[64];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.T = RealVariables34[65];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.T_der = RealVariables34[66];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.Q_flow = RealVariables34[67];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.port.T = RealVariables34[68];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.port.Q_flow = RealVariables34[69];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.der_T = RealVariables34[70];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.C = RealVariables34[71];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.port_a.T = RealVariables34[72];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.port_a.Q_flow = RealVariables34[73];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.port_b.T = RealVariables34[74];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.port_b.Q_flow = RealVariables34[75];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.G_HTFtoTube = RealVariables34[76];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.G_TubetoPCM = RealVariables34[77];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.HTFtoTube.Q_flow = RealVariables34[78];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.HTFtoTube.dT = RealVariables34[79];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.HTFtoTube.port_a.T = RealVariables34[80];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.HTFtoTube.port_a.Q_flow = RealVariables34[81];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.HTFtoTube.port_b.T = RealVariables34[82];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.HTFtoTube.port_b.Q_flow = RealVariables34[83];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.HTFtoTube.G = RealVariables34[84];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubetoPCM.Q_flow = RealVariables34[85];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubetoPCM.dT = RealVariables34[86];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubetoPCM.port_a.T = RealVariables34[87];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubetoPCM.port_a.Q_flow = RealVariables34[88];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubetoPCM.port_b.T = RealVariables34[89];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubetoPCM.port_b.Q_flow = RealVariables34[90];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubetoPCM.G = RealVariables34[91];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.T = RealVariables34[92];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.T_der = RealVariables34[93];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.Q_flow = RealVariables34[94];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.port.T = RealVariables34[95];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.port.Q_flow = RealVariables34[96];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.der_T = RealVariables34[97];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.C = RealVariables34[98];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.port_a.T = RealVariables34[99];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.port_a.Q_flow = RealVariables34[100];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.port_b.T = RealVariables35[1];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.port_b.Q_flow = RealVariables35[2];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.G_HTFtoTube = RealVariables35[3];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.G_TubetoPCM = RealVariables35[4];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.HTFtoTube.Q_flow = RealVariables35[5];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.HTFtoTube.dT = RealVariables35[6];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.HTFtoTube.port_a.T = RealVariables35[7];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.HTFtoTube.port_a.Q_flow = RealVariables35[8];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.HTFtoTube.port_b.T = RealVariables35[9];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.HTFtoTube.port_b.Q_flow = RealVariables35[10];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.HTFtoTube.G = RealVariables35[11];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubetoPCM.Q_flow = RealVariables35[12];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubetoPCM.dT = RealVariables35[13];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubetoPCM.port_a.T = RealVariables35[14];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubetoPCM.port_a.Q_flow = RealVariables35[15];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubetoPCM.port_b.T = RealVariables35[16];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubetoPCM.port_b.Q_flow = RealVariables35[17];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubetoPCM.G = RealVariables35[18];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.T = RealVariables35[19];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.T_der = RealVariables35[20];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.Q_flow = RealVariables35[21];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.port.T = RealVariables35[22];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.port.Q_flow = RealVariables35[23];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.der_T = RealVariables35[24];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.C = RealVariables35[25];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.port_a.T = RealVariables35[26];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.port_a.Q_flow = RealVariables35[27];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.port_b.T = RealVariables35[28];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.port_b.Q_flow = RealVariables35[29];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.G_HTFtoTube = RealVariables35[30];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.G_TubetoPCM = RealVariables35[31];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.HTFtoTube.Q_flow = RealVariables35[32];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.HTFtoTube.dT = RealVariables35[33];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.HTFtoTube.port_a.T = RealVariables35[34];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.HTFtoTube.port_a.Q_flow = RealVariables35[35];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.HTFtoTube.port_b.T = RealVariables35[36];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.HTFtoTube.port_b.Q_flow = RealVariables35[37];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.HTFtoTube.G = RealVariables35[38];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubetoPCM.Q_flow = RealVariables35[39];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubetoPCM.dT = RealVariables35[40];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubetoPCM.port_a.T = RealVariables35[41];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubetoPCM.port_a.Q_flow = RealVariables35[42];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubetoPCM.port_b.T = RealVariables35[43];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubetoPCM.port_b.Q_flow = RealVariables35[44];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubetoPCM.G = RealVariables35[45];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.T = RealVariables35[46];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.T_der = RealVariables35[47];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.Q_flow = RealVariables35[48];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.port.T = RealVariables35[49];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.port.Q_flow = RealVariables35[50];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.der_T = RealVariables35[51];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.C = RealVariables35[52];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.port_a.T = RealVariables35[53];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.port_a.Q_flow = RealVariables35[54];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.port_b.T = RealVariables35[55];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.port_b.Q_flow = RealVariables35[56];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.G_HTFtoTube = RealVariables35[57];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.G_TubetoPCM = RealVariables35[58];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.HTFtoTube.Q_flow = RealVariables35[59];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.HTFtoTube.dT = RealVariables35[60];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.HTFtoTube.port_a.T = RealVariables35[61];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.HTFtoTube.port_a.Q_flow = RealVariables35[62];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.HTFtoTube.port_b.T = RealVariables35[63];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.HTFtoTube.port_b.Q_flow = RealVariables35[64];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.HTFtoTube.G = RealVariables35[65];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubetoPCM.Q_flow = RealVariables35[66];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubetoPCM.dT = RealVariables35[67];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubetoPCM.port_a.T = RealVariables35[68];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubetoPCM.port_a.Q_flow = RealVariables35[69];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubetoPCM.port_b.T = RealVariables35[70];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubetoPCM.port_b.Q_flow = RealVariables35[71];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubetoPCM.G = RealVariables35[72];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.T = RealVariables35[73];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.T_der = RealVariables35[74];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.Q_flow = RealVariables35[75];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.port.T = RealVariables35[76];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.port.Q_flow = RealVariables35[77];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.der_T = RealVariables35[78];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.C = RealVariables35[79];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.port_a.T = RealVariables35[80];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.port_a.Q_flow = RealVariables35[81];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.port_b.T = RealVariables35[82];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.port_b.Q_flow = RealVariables35[83];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.G_HTFtoTube = RealVariables35[84];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.G_TubetoPCM = RealVariables35[85];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.HTFtoTube.Q_flow = RealVariables35[86];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.HTFtoTube.dT = RealVariables35[87];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.HTFtoTube.port_a.T = RealVariables35[88];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.HTFtoTube.port_a.Q_flow = RealVariables35[89];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.HTFtoTube.port_b.T = RealVariables35[90];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.HTFtoTube.port_b.Q_flow = RealVariables35[91];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.HTFtoTube.G = RealVariables35[92];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubetoPCM.Q_flow = RealVariables35[93];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubetoPCM.dT = RealVariables35[94];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubetoPCM.port_a.T = RealVariables35[95];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubetoPCM.port_a.Q_flow = RealVariables35[96];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubetoPCM.port_b.T = RealVariables35[97];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubetoPCM.port_b.Q_flow = RealVariables35[98];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubetoPCM.G = RealVariables35[99];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.T = RealVariables35[100];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.T_der = RealVariables36[1];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.Q_flow = RealVariables36[2];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.port.T = RealVariables36[3];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.port.Q_flow = RealVariables36[4];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.der_T = RealVariables36[5];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.C = RealVariables36[6];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.port_a.T = RealVariables36[7];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.port_a.Q_flow = RealVariables36[8];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.port_b.T = RealVariables36[9];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.port_b.Q_flow = RealVariables36[10];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.G_HTFtoTube = RealVariables36[11];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.G_TubetoPCM = RealVariables36[12];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.HTFtoTube.Q_flow = RealVariables36[13];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.HTFtoTube.dT = RealVariables36[14];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.HTFtoTube.port_a.T = RealVariables36[15];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.HTFtoTube.port_a.Q_flow = RealVariables36[16];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.HTFtoTube.port_b.T = RealVariables36[17];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.HTFtoTube.port_b.Q_flow = RealVariables36[18];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.HTFtoTube.G = RealVariables36[19];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubetoPCM.Q_flow = RealVariables36[20];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubetoPCM.dT = RealVariables36[21];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubetoPCM.port_a.T = RealVariables36[22];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubetoPCM.port_a.Q_flow = RealVariables36[23];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubetoPCM.port_b.T = RealVariables36[24];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubetoPCM.port_b.Q_flow = RealVariables36[25];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubetoPCM.G = RealVariables36[26];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.T = RealVariables36[27];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.T_der = RealVariables36[28];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.Q_flow = RealVariables36[29];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.port.T = RealVariables36[30];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.port.Q_flow = RealVariables36[31];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.der_T = RealVariables36[32];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.C = RealVariables36[33];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.port_a.T = RealVariables36[34];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.port_a.Q_flow = RealVariables36[35];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.port_b.T = RealVariables36[36];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.port_b.Q_flow = RealVariables36[37];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.G_HTFtoTube = RealVariables36[38];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.G_TubetoPCM = RealVariables36[39];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.HTFtoTube.Q_flow = RealVariables36[40];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.HTFtoTube.dT = RealVariables36[41];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.HTFtoTube.port_a.T = RealVariables36[42];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.HTFtoTube.port_a.Q_flow = RealVariables36[43];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.HTFtoTube.port_b.T = RealVariables36[44];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.HTFtoTube.port_b.Q_flow = RealVariables36[45];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.HTFtoTube.G = RealVariables36[46];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubetoPCM.Q_flow = RealVariables36[47];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubetoPCM.dT = RealVariables36[48];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubetoPCM.port_a.T = RealVariables36[49];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubetoPCM.port_a.Q_flow = RealVariables36[50];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubetoPCM.port_b.T = RealVariables36[51];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubetoPCM.port_b.Q_flow = RealVariables36[52];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubetoPCM.G = RealVariables36[53];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.T = RealVariables36[54];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.T_der = RealVariables36[55];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.Q_flow = RealVariables36[56];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.port.T = RealVariables36[57];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.port.Q_flow = RealVariables36[58];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.der_T = RealVariables36[59];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.C = RealVariables36[60];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.port_a.T = RealVariables36[61];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.port_a.Q_flow = RealVariables36[62];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.port_b.T = RealVariables36[63];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.port_b.Q_flow = RealVariables36[64];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.G_HTFtoTube = RealVariables36[65];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.G_TubetoPCM = RealVariables36[66];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.HTFtoTube.Q_flow = RealVariables36[67];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.HTFtoTube.dT = RealVariables36[68];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.HTFtoTube.port_a.T = RealVariables36[69];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.HTFtoTube.port_a.Q_flow = RealVariables36[70];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.HTFtoTube.port_b.T = RealVariables36[71];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.HTFtoTube.port_b.Q_flow = RealVariables36[72];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.HTFtoTube.G = RealVariables36[73];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubetoPCM.Q_flow = RealVariables36[74];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubetoPCM.dT = RealVariables36[75];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubetoPCM.port_a.T = RealVariables36[76];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubetoPCM.port_a.Q_flow = RealVariables36[77];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubetoPCM.port_b.T = RealVariables36[78];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubetoPCM.port_b.Q_flow = RealVariables36[79];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubetoPCM.G = RealVariables36[80];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.T = RealVariables36[81];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.T_der = RealVariables36[82];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.Q_flow = RealVariables36[83];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.port.T = RealVariables36[84];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.port.Q_flow = RealVariables36[85];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.der_T = RealVariables36[86];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.C = RealVariables36[87];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.port_a.T = RealVariables36[88];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.port_a.Q_flow = RealVariables36[89];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.port_b.T = RealVariables36[90];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.port_b.Q_flow = RealVariables36[91];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.G_HTFtoTube = RealVariables36[92];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.G_TubetoPCM = RealVariables36[93];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.HTFtoTube.Q_flow = RealVariables36[94];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.HTFtoTube.dT = RealVariables36[95];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.HTFtoTube.port_a.T = RealVariables36[96];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.HTFtoTube.port_a.Q_flow = RealVariables36[97];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.HTFtoTube.port_b.T = RealVariables36[98];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.HTFtoTube.port_b.Q_flow = RealVariables36[99];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.HTFtoTube.G = RealVariables36[100];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubetoPCM.Q_flow = RealVariables37[1];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubetoPCM.dT = RealVariables37[2];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubetoPCM.port_a.T = RealVariables37[3];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubetoPCM.port_a.Q_flow = RealVariables37[4];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubetoPCM.port_b.T = RealVariables37[5];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubetoPCM.port_b.Q_flow = RealVariables37[6];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubetoPCM.G = RealVariables37[7];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.T = RealVariables37[8];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.T_der = RealVariables37[9];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.Q_flow = RealVariables37[10];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.port.T = RealVariables37[11];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.port.Q_flow = RealVariables37[12];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.der_T = RealVariables37[13];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.C = RealVariables37[14];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.port_a.T = RealVariables37[15];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.port_a.Q_flow = RealVariables37[16];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.port_b.T = RealVariables37[17];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.port_b.Q_flow = RealVariables37[18];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.G_HTFtoTube = RealVariables37[19];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.G_TubetoPCM = RealVariables37[20];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.HTFtoTube.Q_flow = RealVariables37[21];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.HTFtoTube.dT = RealVariables37[22];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.HTFtoTube.port_a.T = RealVariables37[23];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.HTFtoTube.port_a.Q_flow = RealVariables37[24];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.HTFtoTube.port_b.T = RealVariables37[25];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.HTFtoTube.port_b.Q_flow = RealVariables37[26];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.HTFtoTube.G = RealVariables37[27];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubetoPCM.Q_flow = RealVariables37[28];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubetoPCM.dT = RealVariables37[29];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubetoPCM.port_a.T = RealVariables37[30];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubetoPCM.port_a.Q_flow = RealVariables37[31];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubetoPCM.port_b.T = RealVariables37[32];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubetoPCM.port_b.Q_flow = RealVariables37[33];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubetoPCM.G = RealVariables37[34];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.T = RealVariables37[35];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.T_der = RealVariables37[36];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.Q_flow = RealVariables37[37];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.port.T = RealVariables37[38];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.port.Q_flow = RealVariables37[39];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.der_T = RealVariables37[40];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.C = RealVariables37[41];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.port_a.T = RealVariables37[42];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.port_a.Q_flow = RealVariables37[43];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.port_b.T = RealVariables37[44];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.port_b.Q_flow = RealVariables37[45];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.G_HTFtoTube = RealVariables37[46];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.G_TubetoPCM = RealVariables37[47];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.HTFtoTube.Q_flow = RealVariables37[48];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.HTFtoTube.dT = RealVariables37[49];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.HTFtoTube.port_a.T = RealVariables37[50];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.HTFtoTube.port_a.Q_flow = RealVariables37[51];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.HTFtoTube.port_b.T = RealVariables37[52];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.HTFtoTube.port_b.Q_flow = RealVariables37[53];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.HTFtoTube.G = RealVariables37[54];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubetoPCM.Q_flow = RealVariables37[55];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubetoPCM.dT = RealVariables37[56];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubetoPCM.port_a.T = RealVariables37[57];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubetoPCM.port_a.Q_flow = RealVariables37[58];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubetoPCM.port_b.T = RealVariables37[59];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubetoPCM.port_b.Q_flow = RealVariables37[60];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubetoPCM.G = RealVariables37[61];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.T = RealVariables37[62];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.T_der = RealVariables37[63];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.Q_flow = RealVariables37[64];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.port.T = RealVariables37[65];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.port.Q_flow = RealVariables37[66];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.der_T = RealVariables37[67];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.C = RealVariables37[68];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.port_a.T = RealVariables37[69];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.port_a.Q_flow = RealVariables37[70];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.port_b.T = RealVariables37[71];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.port_b.Q_flow = RealVariables37[72];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.G_HTFtoTube = RealVariables37[73];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.G_TubetoPCM = RealVariables37[74];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.HTFtoTube.Q_flow = RealVariables37[75];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.HTFtoTube.dT = RealVariables37[76];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.HTFtoTube.port_a.T = RealVariables37[77];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.HTFtoTube.port_a.Q_flow = RealVariables37[78];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.HTFtoTube.port_b.T = RealVariables37[79];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.HTFtoTube.port_b.Q_flow = RealVariables37[80];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.HTFtoTube.G = RealVariables37[81];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubetoPCM.Q_flow = RealVariables37[82];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubetoPCM.dT = RealVariables37[83];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubetoPCM.port_a.T = RealVariables37[84];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubetoPCM.port_a.Q_flow = RealVariables37[85];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubetoPCM.port_b.T = RealVariables37[86];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubetoPCM.port_b.Q_flow = RealVariables37[87];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubetoPCM.G = RealVariables37[88];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.T = RealVariables37[89];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.T_der = RealVariables37[90];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.Q_flow = RealVariables37[91];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.port.T = RealVariables37[92];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.port.Q_flow = RealVariables37[93];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.der_T = RealVariables37[94];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.C = RealVariables37[95];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.port_a.T = RealVariables37[96];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.port_a.Q_flow = RealVariables37[97];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.port_b.T = RealVariables37[98];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.port_b.Q_flow = RealVariables37[99];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.G_HTFtoTube = RealVariables37[100];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.G_TubetoPCM = RealVariables38[1];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.HTFtoTube.Q_flow = RealVariables38[2];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.HTFtoTube.dT = RealVariables38[3];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.HTFtoTube.port_a.T = RealVariables38[4];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.HTFtoTube.port_a.Q_flow = RealVariables38[5];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.HTFtoTube.port_b.T = RealVariables38[6];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.HTFtoTube.port_b.Q_flow = RealVariables38[7];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.HTFtoTube.G = RealVariables38[8];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubetoPCM.Q_flow = RealVariables38[9];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubetoPCM.dT = RealVariables38[10];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubetoPCM.port_a.T = RealVariables38[11];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubetoPCM.port_a.Q_flow = RealVariables38[12];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubetoPCM.port_b.T = RealVariables38[13];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubetoPCM.port_b.Q_flow = RealVariables38[14];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubetoPCM.G = RealVariables38[15];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.T = RealVariables38[16];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.T_der = RealVariables38[17];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.Q_flow = RealVariables38[18];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.port.T = RealVariables38[19];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.port.Q_flow = RealVariables38[20];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.der_T = RealVariables38[21];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.C = RealVariables38[22];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.port_a.T = RealVariables38[23];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.port_a.Q_flow = RealVariables38[24];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.port_b.T = RealVariables38[25];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.port_b.Q_flow = RealVariables38[26];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.G_HTFtoTube = RealVariables38[27];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.G_TubetoPCM = RealVariables38[28];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.HTFtoTube.Q_flow = RealVariables38[29];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.HTFtoTube.dT = RealVariables38[30];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.HTFtoTube.port_a.T = RealVariables38[31];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.HTFtoTube.port_a.Q_flow = RealVariables38[32];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.HTFtoTube.port_b.T = RealVariables38[33];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.HTFtoTube.port_b.Q_flow = RealVariables38[34];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.HTFtoTube.G = RealVariables38[35];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubetoPCM.Q_flow = RealVariables38[36];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubetoPCM.dT = RealVariables38[37];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubetoPCM.port_a.T = RealVariables38[38];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubetoPCM.port_a.Q_flow = RealVariables38[39];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubetoPCM.port_b.T = RealVariables38[40];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubetoPCM.port_b.Q_flow = RealVariables38[41];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubetoPCM.G = RealVariables38[42];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.T = RealVariables38[43];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.T_der = RealVariables38[44];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.Q_flow = RealVariables38[45];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.port.T = RealVariables38[46];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.port.Q_flow = RealVariables38[47];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.der_T = RealVariables38[48];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.C = RealVariables38[49];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.port_a.T = RealVariables38[50];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.port_a.Q_flow = RealVariables38[51];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.port_b.T = RealVariables38[52];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.port_b.Q_flow = RealVariables38[53];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.G_HTFtoTube = RealVariables38[54];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.G_TubetoPCM = RealVariables38[55];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.HTFtoTube.Q_flow = RealVariables38[56];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.HTFtoTube.dT = RealVariables38[57];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.HTFtoTube.port_a.T = RealVariables38[58];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.HTFtoTube.port_a.Q_flow = RealVariables38[59];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.HTFtoTube.port_b.T = RealVariables38[60];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.HTFtoTube.port_b.Q_flow = RealVariables38[61];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.HTFtoTube.G = RealVariables38[62];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubetoPCM.Q_flow = RealVariables38[63];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubetoPCM.dT = RealVariables38[64];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubetoPCM.port_a.T = RealVariables38[65];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubetoPCM.port_a.Q_flow = RealVariables38[66];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubetoPCM.port_b.T = RealVariables38[67];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubetoPCM.port_b.Q_flow = RealVariables38[68];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubetoPCM.G = RealVariables38[69];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.T = RealVariables38[70];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.T_der = RealVariables38[71];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.Q_flow = RealVariables38[72];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.port.T = RealVariables38[73];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.port.Q_flow = RealVariables38[74];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.der_T = RealVariables38[75];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.C = RealVariables38[76];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.port_a.T = RealVariables38[77];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.port_a.Q_flow = RealVariables38[78];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.port_b.T = RealVariables38[79];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.port_b.Q_flow = RealVariables38[80];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.G_HTFtoTube = RealVariables38[81];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.G_TubetoPCM = RealVariables38[82];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.HTFtoTube.Q_flow = RealVariables38[83];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.HTFtoTube.dT = RealVariables38[84];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.HTFtoTube.port_a.T = RealVariables38[85];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.HTFtoTube.port_a.Q_flow = RealVariables38[86];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.HTFtoTube.port_b.T = RealVariables38[87];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.HTFtoTube.port_b.Q_flow = RealVariables38[88];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.HTFtoTube.G = RealVariables38[89];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubetoPCM.Q_flow = RealVariables38[90];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubetoPCM.dT = RealVariables38[91];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubetoPCM.port_a.T = RealVariables38[92];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubetoPCM.port_a.Q_flow = RealVariables38[93];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubetoPCM.port_b.T = RealVariables38[94];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubetoPCM.port_b.Q_flow = RealVariables38[95];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubetoPCM.G = RealVariables38[96];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.T = RealVariables38[97];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.T_der = RealVariables38[98];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.Q_flow = RealVariables38[99];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.port.T = RealVariables38[100];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.port.Q_flow = RealVariables39[1];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.der_T = RealVariables39[2];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.C = RealVariables39[3];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.port_a.T = RealVariables39[4];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.port_a.Q_flow = RealVariables39[5];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.port_b.T = RealVariables39[6];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.port_b.Q_flow = RealVariables39[7];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.G_HTFtoTube = RealVariables39[8];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.G_TubetoPCM = RealVariables39[9];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.HTFtoTube.Q_flow = RealVariables39[10];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.HTFtoTube.dT = RealVariables39[11];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.HTFtoTube.port_a.T = RealVariables39[12];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.HTFtoTube.port_a.Q_flow = RealVariables39[13];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.HTFtoTube.port_b.T = RealVariables39[14];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.HTFtoTube.port_b.Q_flow = RealVariables39[15];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.HTFtoTube.G = RealVariables39[16];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubetoPCM.Q_flow = RealVariables39[17];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubetoPCM.dT = RealVariables39[18];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubetoPCM.port_a.T = RealVariables39[19];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubetoPCM.port_a.Q_flow = RealVariables39[20];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubetoPCM.port_b.T = RealVariables39[21];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubetoPCM.port_b.Q_flow = RealVariables39[22];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubetoPCM.G = RealVariables39[23];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.T = RealVariables39[24];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.T_der = RealVariables39[25];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.Q_flow = RealVariables39[26];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.port.T = RealVariables39[27];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.port.Q_flow = RealVariables39[28];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.der_T = RealVariables39[29];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.C = RealVariables39[30];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.port_a.T = RealVariables39[31];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.port_a.Q_flow = RealVariables39[32];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.port_b.T = RealVariables39[33];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.port_b.Q_flow = RealVariables39[34];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.G_HTFtoTube = RealVariables39[35];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.G_TubetoPCM = RealVariables39[36];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.HTFtoTube.Q_flow = RealVariables39[37];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.HTFtoTube.dT = RealVariables39[38];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.HTFtoTube.port_a.T = RealVariables39[39];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.HTFtoTube.port_a.Q_flow = RealVariables39[40];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.HTFtoTube.port_b.T = RealVariables39[41];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.HTFtoTube.port_b.Q_flow = RealVariables39[42];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.HTFtoTube.G = RealVariables39[43];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubetoPCM.Q_flow = RealVariables39[44];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubetoPCM.dT = RealVariables39[45];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubetoPCM.port_a.T = RealVariables39[46];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubetoPCM.port_a.Q_flow = RealVariables39[47];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubetoPCM.port_b.T = RealVariables39[48];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubetoPCM.port_b.Q_flow = RealVariables39[49];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubetoPCM.G = RealVariables39[50];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.T = RealVariables39[51];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.T_der = RealVariables39[52];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.Q_flow = RealVariables39[53];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.port.T = RealVariables39[54];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.port.Q_flow = RealVariables39[55];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.der_T = RealVariables39[56];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.C = RealVariables39[57];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.port_a.T = RealVariables39[58];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.port_a.Q_flow = RealVariables39[59];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.port_b.T = RealVariables39[60];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.port_b.Q_flow = RealVariables39[61];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.G_HTFtoTube = RealVariables39[62];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.G_TubetoPCM = RealVariables39[63];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.HTFtoTube.Q_flow = RealVariables39[64];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.HTFtoTube.dT = RealVariables39[65];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.HTFtoTube.port_a.T = RealVariables39[66];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.HTFtoTube.port_a.Q_flow = RealVariables39[67];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.HTFtoTube.port_b.T = RealVariables39[68];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.HTFtoTube.port_b.Q_flow = RealVariables39[69];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.HTFtoTube.G = RealVariables39[70];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubetoPCM.Q_flow = RealVariables39[71];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubetoPCM.dT = RealVariables39[72];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubetoPCM.port_a.T = RealVariables39[73];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubetoPCM.port_a.Q_flow = RealVariables39[74];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubetoPCM.port_b.T = RealVariables39[75];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubetoPCM.port_b.Q_flow = RealVariables39[76];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubetoPCM.G = RealVariables39[77];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.T = RealVariables39[78];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.T_der = RealVariables39[79];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.Q_flow = RealVariables39[80];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.port.T = RealVariables39[81];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.port.Q_flow = RealVariables39[82];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.der_T = RealVariables39[83];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.C = RealVariables39[84];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.port_a.T = RealVariables39[85];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.port_a.Q_flow = RealVariables39[86];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.port_b.T = RealVariables39[87];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.port_b.Q_flow = RealVariables39[88];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.G_HTFtoTube = RealVariables39[89];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.G_TubetoPCM = RealVariables39[90];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.HTFtoTube.Q_flow = RealVariables39[91];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.HTFtoTube.dT = RealVariables39[92];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.HTFtoTube.port_a.T = RealVariables39[93];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.HTFtoTube.port_a.Q_flow = RealVariables39[94];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.HTFtoTube.port_b.T = RealVariables39[95];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.HTFtoTube.port_b.Q_flow = RealVariables39[96];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.HTFtoTube.G = RealVariables39[97];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubetoPCM.Q_flow = RealVariables39[98];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubetoPCM.dT = RealVariables39[99];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubetoPCM.port_a.T = RealVariables39[100];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubetoPCM.port_a.Q_flow = RealVariables40[1];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubetoPCM.port_b.T = RealVariables40[2];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubetoPCM.port_b.Q_flow = RealVariables40[3];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubetoPCM.G = RealVariables40[4];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.T = RealVariables40[5];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.T_der = RealVariables40[6];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.Q_flow = RealVariables40[7];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.port.T = RealVariables40[8];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.port.Q_flow = RealVariables40[9];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.der_T = RealVariables40[10];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.C = RealVariables40[11];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.port_a.T = RealVariables40[12];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.port_a.Q_flow = RealVariables40[13];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.port_b.T = RealVariables40[14];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.port_b.Q_flow = RealVariables40[15];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.G_HTFtoTube = RealVariables40[16];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.G_TubetoPCM = RealVariables40[17];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.HTFtoTube.Q_flow = RealVariables40[18];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.HTFtoTube.dT = RealVariables40[19];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.HTFtoTube.port_a.T = RealVariables40[20];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.HTFtoTube.port_a.Q_flow = RealVariables40[21];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.HTFtoTube.port_b.T = RealVariables40[22];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.HTFtoTube.port_b.Q_flow = RealVariables40[23];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.HTFtoTube.G = RealVariables40[24];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubetoPCM.Q_flow = RealVariables40[25];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubetoPCM.dT = RealVariables40[26];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubetoPCM.port_a.T = RealVariables40[27];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubetoPCM.port_a.Q_flow = RealVariables40[28];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubetoPCM.port_b.T = RealVariables40[29];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubetoPCM.port_b.Q_flow = RealVariables40[30];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubetoPCM.G = RealVariables40[31];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.T = RealVariables40[32];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.T_der = RealVariables40[33];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.Q_flow = RealVariables40[34];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.port.T = RealVariables40[35];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.port.Q_flow = RealVariables40[36];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.der_T = RealVariables40[37];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.C = RealVariables40[38];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.port_a.T = RealVariables40[39];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.port_a.Q_flow = RealVariables40[40];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.port_b.T = RealVariables40[41];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.port_b.Q_flow = RealVariables40[42];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.G_HTFtoTube = RealVariables40[43];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.G_TubetoPCM = RealVariables40[44];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.HTFtoTube.Q_flow = RealVariables40[45];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.HTFtoTube.dT = RealVariables40[46];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.HTFtoTube.port_a.T = RealVariables40[47];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.HTFtoTube.port_a.Q_flow = RealVariables40[48];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.HTFtoTube.port_b.T = RealVariables40[49];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.HTFtoTube.port_b.Q_flow = RealVariables40[50];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.HTFtoTube.G = RealVariables40[51];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubetoPCM.Q_flow = RealVariables40[52];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubetoPCM.dT = RealVariables40[53];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubetoPCM.port_a.T = RealVariables40[54];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubetoPCM.port_a.Q_flow = RealVariables40[55];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubetoPCM.port_b.T = RealVariables40[56];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubetoPCM.port_b.Q_flow = RealVariables40[57];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubetoPCM.G = RealVariables40[58];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.T = RealVariables40[59];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.T_der = RealVariables40[60];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.Q_flow = RealVariables40[61];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.port.T = RealVariables40[62];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.port.Q_flow = RealVariables40[63];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.der_T = RealVariables40[64];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.C = RealVariables40[65];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.port_a.T = RealVariables40[66];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.port_a.Q_flow = RealVariables40[67];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.port_b.T = RealVariables40[68];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.port_b.Q_flow = RealVariables40[69];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.G_HTFtoTube = RealVariables40[70];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.G_TubetoPCM = RealVariables40[71];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.HTFtoTube.Q_flow = RealVariables40[72];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.HTFtoTube.dT = RealVariables40[73];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.HTFtoTube.port_a.T = RealVariables40[74];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.HTFtoTube.port_a.Q_flow = RealVariables40[75];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.HTFtoTube.port_b.T = RealVariables40[76];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.HTFtoTube.port_b.Q_flow = RealVariables40[77];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.HTFtoTube.G = RealVariables40[78];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubetoPCM.Q_flow = RealVariables40[79];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubetoPCM.dT = RealVariables40[80];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubetoPCM.port_a.T = RealVariables40[81];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubetoPCM.port_a.Q_flow = RealVariables40[82];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubetoPCM.port_b.T = RealVariables40[83];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubetoPCM.port_b.Q_flow = RealVariables40[84];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubetoPCM.G = RealVariables40[85];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.T = RealVariables40[86];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.T_der = RealVariables40[87];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.Q_flow = RealVariables40[88];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.port.T = RealVariables40[89];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.port.Q_flow = RealVariables40[90];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.der_T = RealVariables40[91];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.C = RealVariables40[92];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.port_a.T = RealVariables40[93];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.port_a.Q_flow = RealVariables40[94];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.port_b.T = RealVariables40[95];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.port_b.Q_flow = RealVariables40[96];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.G_HTFtoTube = RealVariables40[97];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.G_TubetoPCM = RealVariables40[98];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.HTFtoTube.Q_flow = RealVariables40[99];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.HTFtoTube.dT = RealVariables40[100];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.HTFtoTube.port_a.T = RealVariables41[1];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.HTFtoTube.port_a.Q_flow = RealVariables41[2];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.HTFtoTube.port_b.T = RealVariables41[3];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.HTFtoTube.port_b.Q_flow = RealVariables41[4];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.HTFtoTube.G = RealVariables41[5];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubetoPCM.Q_flow = RealVariables41[6];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubetoPCM.dT = RealVariables41[7];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubetoPCM.port_a.T = RealVariables41[8];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubetoPCM.port_a.Q_flow = RealVariables41[9];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubetoPCM.port_b.T = RealVariables41[10];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubetoPCM.port_b.Q_flow = RealVariables41[11];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubetoPCM.G = RealVariables41[12];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.T = RealVariables41[13];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.T_der = RealVariables41[14];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.Q_flow = RealVariables41[15];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.port.T = RealVariables41[16];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.port.Q_flow = RealVariables41[17];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.der_T = RealVariables41[18];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.C = RealVariables41[19];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.port_a.T = RealVariables41[20];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.port_a.Q_flow = RealVariables41[21];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.port_b.T = RealVariables41[22];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.port_b.Q_flow = RealVariables41[23];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.G_HTFtoTube = RealVariables41[24];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.G_TubetoPCM = RealVariables41[25];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.HTFtoTube.Q_flow = RealVariables41[26];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.HTFtoTube.dT = RealVariables41[27];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.HTFtoTube.port_a.T = RealVariables41[28];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.HTFtoTube.port_a.Q_flow = RealVariables41[29];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.HTFtoTube.port_b.T = RealVariables41[30];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.HTFtoTube.port_b.Q_flow = RealVariables41[31];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.HTFtoTube.G = RealVariables41[32];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubetoPCM.Q_flow = RealVariables41[33];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubetoPCM.dT = RealVariables41[34];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubetoPCM.port_a.T = RealVariables41[35];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubetoPCM.port_a.Q_flow = RealVariables41[36];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubetoPCM.port_b.T = RealVariables41[37];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubetoPCM.port_b.Q_flow = RealVariables41[38];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubetoPCM.G = RealVariables41[39];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.T = RealVariables41[40];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.T_der = RealVariables41[41];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.Q_flow = RealVariables41[42];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.port.T = RealVariables41[43];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.port.Q_flow = RealVariables41[44];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.der_T = RealVariables41[45];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.C = RealVariables41[46];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.port_a.T = RealVariables41[47];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.port_a.Q_flow = RealVariables41[48];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.port_b.T = RealVariables41[49];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.port_b.Q_flow = RealVariables41[50];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.G_HTFtoTube = RealVariables41[51];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.G_TubetoPCM = RealVariables41[52];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.HTFtoTube.Q_flow = RealVariables41[53];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.HTFtoTube.dT = RealVariables41[54];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.HTFtoTube.port_a.T = RealVariables41[55];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.HTFtoTube.port_a.Q_flow = RealVariables41[56];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.HTFtoTube.port_b.T = RealVariables41[57];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.HTFtoTube.port_b.Q_flow = RealVariables41[58];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.HTFtoTube.G = RealVariables41[59];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubetoPCM.Q_flow = RealVariables41[60];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubetoPCM.dT = RealVariables41[61];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubetoPCM.port_a.T = RealVariables41[62];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubetoPCM.port_a.Q_flow = RealVariables41[63];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubetoPCM.port_b.T = RealVariables41[64];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubetoPCM.port_b.Q_flow = RealVariables41[65];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubetoPCM.G = RealVariables41[66];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.T = RealVariables41[67];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.T_der = RealVariables41[68];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.Q_flow = RealVariables41[69];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.port.T = RealVariables41[70];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.port.Q_flow = RealVariables41[71];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.der_T = RealVariables41[72];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.C = RealVariables41[73];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.port_a.T = RealVariables41[74];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.port_a.Q_flow = RealVariables41[75];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.port_b.T = RealVariables41[76];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.port_b.Q_flow = RealVariables41[77];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.G_HTFtoTube = RealVariables41[78];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.G_TubetoPCM = RealVariables41[79];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.HTFtoTube.Q_flow = RealVariables41[80];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.HTFtoTube.dT = RealVariables41[81];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.HTFtoTube.port_a.T = RealVariables41[82];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.HTFtoTube.port_a.Q_flow = RealVariables41[83];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.HTFtoTube.port_b.T = RealVariables41[84];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.HTFtoTube.port_b.Q_flow = RealVariables41[85];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.HTFtoTube.G = RealVariables41[86];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubetoPCM.Q_flow = RealVariables41[87];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubetoPCM.dT = RealVariables41[88];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubetoPCM.port_a.T = RealVariables41[89];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubetoPCM.port_a.Q_flow = RealVariables41[90];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubetoPCM.port_b.T = RealVariables41[91];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubetoPCM.port_b.Q_flow = RealVariables41[92];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubetoPCM.G = RealVariables41[93];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.T = RealVariables41[94];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.T_der = RealVariables41[95];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.Q_flow = RealVariables41[96];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.port.T = RealVariables41[97];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.port.Q_flow = RealVariables41[98];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.der_T = RealVariables41[99];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.C = RealVariables41[100];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.port_a.T = RealVariables42[1];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.port_a.Q_flow = RealVariables42[2];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.port_b.T = RealVariables42[3];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.port_b.Q_flow = RealVariables42[4];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.G_HTFtoTube = RealVariables42[5];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.G_TubetoPCM = RealVariables42[6];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.HTFtoTube.Q_flow = RealVariables42[7];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.HTFtoTube.dT = RealVariables42[8];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.HTFtoTube.port_a.T = RealVariables42[9];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.HTFtoTube.port_a.Q_flow = RealVariables42[10];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.HTFtoTube.port_b.T = RealVariables42[11];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.HTFtoTube.port_b.Q_flow = RealVariables42[12];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.HTFtoTube.G = RealVariables42[13];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubetoPCM.Q_flow = RealVariables42[14];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubetoPCM.dT = RealVariables42[15];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubetoPCM.port_a.T = RealVariables42[16];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubetoPCM.port_a.Q_flow = RealVariables42[17];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubetoPCM.port_b.T = RealVariables42[18];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubetoPCM.port_b.Q_flow = RealVariables42[19];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubetoPCM.G = RealVariables42[20];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.T = RealVariables42[21];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.T_der = RealVariables42[22];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.Q_flow = RealVariables42[23];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.port.T = RealVariables42[24];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.port.Q_flow = RealVariables42[25];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.der_T = RealVariables42[26];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.C = RealVariables42[27];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.port_a.T = RealVariables42[28];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.port_a.Q_flow = RealVariables42[29];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.port_b.T = RealVariables42[30];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.port_b.Q_flow = RealVariables42[31];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.G_HTFtoTube = RealVariables42[32];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.G_TubetoPCM = RealVariables42[33];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.HTFtoTube.Q_flow = RealVariables42[34];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.HTFtoTube.dT = RealVariables42[35];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.HTFtoTube.port_a.T = RealVariables42[36];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.HTFtoTube.port_a.Q_flow = RealVariables42[37];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.HTFtoTube.port_b.T = RealVariables42[38];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.HTFtoTube.port_b.Q_flow = RealVariables42[39];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.HTFtoTube.G = RealVariables42[40];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubetoPCM.Q_flow = RealVariables42[41];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubetoPCM.dT = RealVariables42[42];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubetoPCM.port_a.T = RealVariables42[43];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubetoPCM.port_a.Q_flow = RealVariables42[44];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubetoPCM.port_b.T = RealVariables42[45];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubetoPCM.port_b.Q_flow = RealVariables42[46];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubetoPCM.G = RealVariables42[47];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.T = RealVariables42[48];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.T_der = RealVariables42[49];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.Q_flow = RealVariables42[50];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.port.T = RealVariables42[51];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.port.Q_flow = RealVariables42[52];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.der_T = RealVariables42[53];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.C = RealVariables42[54];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.port_a.T = RealVariables42[55];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.port_a.Q_flow = RealVariables42[56];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.port_b.T = RealVariables42[57];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.port_b.Q_flow = RealVariables42[58];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.G_HTFtoTube = RealVariables42[59];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.G_TubetoPCM = RealVariables42[60];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.HTFtoTube.Q_flow = RealVariables42[61];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.HTFtoTube.dT = RealVariables42[62];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.HTFtoTube.port_a.T = RealVariables42[63];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.HTFtoTube.port_a.Q_flow = RealVariables42[64];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.HTFtoTube.port_b.T = RealVariables42[65];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.HTFtoTube.port_b.Q_flow = RealVariables42[66];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.HTFtoTube.G = RealVariables42[67];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubetoPCM.Q_flow = RealVariables42[68];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubetoPCM.dT = RealVariables42[69];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubetoPCM.port_a.T = RealVariables42[70];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubetoPCM.port_a.Q_flow = RealVariables42[71];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubetoPCM.port_b.T = RealVariables42[72];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubetoPCM.port_b.Q_flow = RealVariables42[73];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubetoPCM.G = RealVariables42[74];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.T = RealVariables42[75];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.T_der = RealVariables42[76];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.Q_flow = RealVariables42[77];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.port.T = RealVariables42[78];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.port.Q_flow = RealVariables42[79];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.der_T = RealVariables42[80];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.C = RealVariables42[81];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.port_a.T = RealVariables42[82];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.port_a.Q_flow = RealVariables42[83];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.port_b.T = RealVariables42[84];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.port_b.Q_flow = RealVariables42[85];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.G_HTFtoTube = RealVariables42[86];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.G_TubetoPCM = RealVariables42[87];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.HTFtoTube.Q_flow = RealVariables42[88];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.HTFtoTube.dT = RealVariables42[89];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.HTFtoTube.port_a.T = RealVariables42[90];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.HTFtoTube.port_a.Q_flow = RealVariables42[91];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.HTFtoTube.port_b.T = RealVariables42[92];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.HTFtoTube.port_b.Q_flow = RealVariables42[93];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.HTFtoTube.G = RealVariables42[94];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubetoPCM.Q_flow = RealVariables42[95];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubetoPCM.dT = RealVariables42[96];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubetoPCM.port_a.T = RealVariables42[97];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubetoPCM.port_a.Q_flow = RealVariables42[98];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubetoPCM.port_b.T = RealVariables42[99];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubetoPCM.port_b.Q_flow = RealVariables42[100];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubetoPCM.G = RealVariables43[1];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.T = RealVariables43[2];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.T_der = RealVariables43[3];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.Q_flow = RealVariables43[4];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.port.T = RealVariables43[5];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.port.Q_flow = RealVariables43[6];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.der_T = RealVariables43[7];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.C = RealVariables43[8];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.port_a.T = RealVariables43[9];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.port_a.Q_flow = RealVariables43[10];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.port_b.T = RealVariables43[11];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.port_b.Q_flow = RealVariables43[12];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.G_HTFtoTube = RealVariables43[13];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.G_TubetoPCM = RealVariables43[14];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.HTFtoTube.Q_flow = RealVariables43[15];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.HTFtoTube.dT = RealVariables43[16];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.HTFtoTube.port_a.T = RealVariables43[17];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.HTFtoTube.port_a.Q_flow = RealVariables43[18];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.HTFtoTube.port_b.T = RealVariables43[19];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.HTFtoTube.port_b.Q_flow = RealVariables43[20];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.HTFtoTube.G = RealVariables43[21];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubetoPCM.Q_flow = RealVariables43[22];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubetoPCM.dT = RealVariables43[23];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubetoPCM.port_a.T = RealVariables43[24];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubetoPCM.port_a.Q_flow = RealVariables43[25];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubetoPCM.port_b.T = RealVariables43[26];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubetoPCM.port_b.Q_flow = RealVariables43[27];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubetoPCM.G = RealVariables43[28];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.T = RealVariables43[29];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.T_der = RealVariables43[30];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.Q_flow = RealVariables43[31];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.port.T = RealVariables43[32];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.port.Q_flow = RealVariables43[33];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.der_T = RealVariables43[34];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.C = RealVariables43[35];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.port_a.T = RealVariables43[36];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.port_a.Q_flow = RealVariables43[37];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.port_b.T = RealVariables43[38];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.port_b.Q_flow = RealVariables43[39];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.G_HTFtoTube = RealVariables43[40];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.G_TubetoPCM = RealVariables43[41];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.HTFtoTube.Q_flow = RealVariables43[42];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.HTFtoTube.dT = RealVariables43[43];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.HTFtoTube.port_a.T = RealVariables43[44];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.HTFtoTube.port_a.Q_flow = RealVariables43[45];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.HTFtoTube.port_b.T = RealVariables43[46];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.HTFtoTube.port_b.Q_flow = RealVariables43[47];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.HTFtoTube.G = RealVariables43[48];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubetoPCM.Q_flow = RealVariables43[49];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubetoPCM.dT = RealVariables43[50];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubetoPCM.port_a.T = RealVariables43[51];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubetoPCM.port_a.Q_flow = RealVariables43[52];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubetoPCM.port_b.T = RealVariables43[53];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubetoPCM.port_b.Q_flow = RealVariables43[54];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubetoPCM.G = RealVariables43[55];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.T = RealVariables43[56];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.T_der = RealVariables43[57];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.Q_flow = RealVariables43[58];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.port.T = RealVariables43[59];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.port.Q_flow = RealVariables43[60];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.der_T = RealVariables43[61];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.C = RealVariables43[62];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.port_a.T = RealVariables43[63];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.port_a.Q_flow = RealVariables43[64];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.port_b.T = RealVariables43[65];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.port_b.Q_flow = RealVariables43[66];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.G_HTFtoTube = RealVariables43[67];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.G_TubetoPCM = RealVariables43[68];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.HTFtoTube.Q_flow = RealVariables43[69];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.HTFtoTube.dT = RealVariables43[70];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.HTFtoTube.port_a.T = RealVariables43[71];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.HTFtoTube.port_a.Q_flow = RealVariables43[72];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.HTFtoTube.port_b.T = RealVariables43[73];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.HTFtoTube.port_b.Q_flow = RealVariables43[74];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.HTFtoTube.G = RealVariables43[75];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubetoPCM.Q_flow = RealVariables43[76];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubetoPCM.dT = RealVariables43[77];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubetoPCM.port_a.T = RealVariables43[78];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubetoPCM.port_a.Q_flow = RealVariables43[79];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubetoPCM.port_b.T = RealVariables43[80];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubetoPCM.port_b.Q_flow = RealVariables43[81];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubetoPCM.G = RealVariables43[82];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.T = RealVariables43[83];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.T_der = RealVariables43[84];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.Q_flow = RealVariables43[85];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.port.T = RealVariables43[86];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.port.Q_flow = RealVariables43[87];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.der_T = RealVariables43[88];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.C = RealVariables43[89];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.port_a.T = RealVariables43[90];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.port_a.Q_flow = RealVariables43[91];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.port_b.T = RealVariables43[92];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.port_b.Q_flow = RealVariables43[93];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.G_HTFtoTube = RealVariables43[94];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.G_TubetoPCM = RealVariables43[95];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.HTFtoTube.Q_flow = RealVariables43[96];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.HTFtoTube.dT = RealVariables43[97];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.HTFtoTube.port_a.T = RealVariables43[98];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.HTFtoTube.port_a.Q_flow = RealVariables43[99];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.HTFtoTube.port_b.T = RealVariables43[100];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.HTFtoTube.port_b.Q_flow = RealVariables44[1];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.HTFtoTube.G = RealVariables44[2];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubetoPCM.Q_flow = RealVariables44[3];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubetoPCM.dT = RealVariables44[4];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubetoPCM.port_a.T = RealVariables44[5];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubetoPCM.port_a.Q_flow = RealVariables44[6];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubetoPCM.port_b.T = RealVariables44[7];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubetoPCM.port_b.Q_flow = RealVariables44[8];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubetoPCM.G = RealVariables44[9];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.T = RealVariables44[10];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.T_der = RealVariables44[11];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.Q_flow = RealVariables44[12];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.port.T = RealVariables44[13];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.port.Q_flow = RealVariables44[14];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.der_T = RealVariables44[15];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.C = RealVariables44[16];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.port_a.T = RealVariables44[17];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.port_a.Q_flow = RealVariables44[18];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.port_b.T = RealVariables44[19];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.port_b.Q_flow = RealVariables44[20];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.G_HTFtoTube = RealVariables44[21];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.G_TubetoPCM = RealVariables44[22];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.HTFtoTube.Q_flow = RealVariables44[23];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.HTFtoTube.dT = RealVariables44[24];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.HTFtoTube.port_a.T = RealVariables44[25];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.HTFtoTube.port_a.Q_flow = RealVariables44[26];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.HTFtoTube.port_b.T = RealVariables44[27];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.HTFtoTube.port_b.Q_flow = RealVariables44[28];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.HTFtoTube.G = RealVariables44[29];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubetoPCM.Q_flow = RealVariables44[30];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubetoPCM.dT = RealVariables44[31];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubetoPCM.port_a.T = RealVariables44[32];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubetoPCM.port_a.Q_flow = RealVariables44[33];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubetoPCM.port_b.T = RealVariables44[34];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubetoPCM.port_b.Q_flow = RealVariables44[35];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubetoPCM.G = RealVariables44[36];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.T = RealVariables44[37];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.T_der = RealVariables44[38];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.Q_flow = RealVariables44[39];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.port.T = RealVariables44[40];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.port.Q_flow = RealVariables44[41];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.der_T = RealVariables44[42];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.C = RealVariables44[43];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.port_a.T = RealVariables44[44];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.port_a.Q_flow = RealVariables44[45];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.port_b.T = RealVariables44[46];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.port_b.Q_flow = RealVariables44[47];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.G_HTFtoTube = RealVariables44[48];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.G_TubetoPCM = RealVariables44[49];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.HTFtoTube.Q_flow = RealVariables44[50];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.HTFtoTube.dT = RealVariables44[51];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.HTFtoTube.port_a.T = RealVariables44[52];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.HTFtoTube.port_a.Q_flow = RealVariables44[53];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.HTFtoTube.port_b.T = RealVariables44[54];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.HTFtoTube.port_b.Q_flow = RealVariables44[55];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.HTFtoTube.G = RealVariables44[56];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubetoPCM.Q_flow = RealVariables44[57];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubetoPCM.dT = RealVariables44[58];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubetoPCM.port_a.T = RealVariables44[59];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubetoPCM.port_a.Q_flow = RealVariables44[60];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubetoPCM.port_b.T = RealVariables44[61];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubetoPCM.port_b.Q_flow = RealVariables44[62];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubetoPCM.G = RealVariables44[63];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.T = RealVariables44[64];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.T_der = RealVariables44[65];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.Q_flow = RealVariables44[66];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.port.T = RealVariables44[67];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.port.Q_flow = RealVariables44[68];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.der_T = RealVariables44[69];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.C = RealVariables44[70];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.port_a.T = RealVariables44[71];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.port_a.Q_flow = RealVariables44[72];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.port_b.T = RealVariables44[73];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.port_b.Q_flow = RealVariables44[74];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.G_HTFtoTube = RealVariables44[75];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.G_TubetoPCM = RealVariables44[76];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.HTFtoTube.Q_flow = RealVariables44[77];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.HTFtoTube.dT = RealVariables44[78];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.HTFtoTube.port_a.T = RealVariables44[79];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.HTFtoTube.port_a.Q_flow = RealVariables44[80];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.HTFtoTube.port_b.T = RealVariables44[81];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.HTFtoTube.port_b.Q_flow = RealVariables44[82];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.HTFtoTube.G = RealVariables44[83];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubetoPCM.Q_flow = RealVariables44[84];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubetoPCM.dT = RealVariables44[85];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubetoPCM.port_a.T = RealVariables44[86];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubetoPCM.port_a.Q_flow = RealVariables44[87];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubetoPCM.port_b.T = RealVariables44[88];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubetoPCM.port_b.Q_flow = RealVariables44[89];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubetoPCM.G = RealVariables44[90];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.T = RealVariables44[91];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.T_der = RealVariables44[92];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.Q_flow = RealVariables44[93];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.port.T = RealVariables44[94];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.port.Q_flow = RealVariables44[95];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.der_T = RealVariables44[96];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.C = RealVariables44[97];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.port_a.T = RealVariables44[98];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.port_a.Q_flow = RealVariables44[99];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.port_b.T = RealVariables44[100];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.port_b.Q_flow = RealVariables45[1];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.G_HTFtoTube = RealVariables45[2];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.G_TubetoPCM = RealVariables45[3];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.HTFtoTube.Q_flow = RealVariables45[4];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.HTFtoTube.dT = RealVariables45[5];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.HTFtoTube.port_a.T = RealVariables45[6];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.HTFtoTube.port_a.Q_flow = RealVariables45[7];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.HTFtoTube.port_b.T = RealVariables45[8];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.HTFtoTube.port_b.Q_flow = RealVariables45[9];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.HTFtoTube.G = RealVariables45[10];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubetoPCM.Q_flow = RealVariables45[11];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubetoPCM.dT = RealVariables45[12];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubetoPCM.port_a.T = RealVariables45[13];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubetoPCM.port_a.Q_flow = RealVariables45[14];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubetoPCM.port_b.T = RealVariables45[15];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubetoPCM.port_b.Q_flow = RealVariables45[16];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubetoPCM.G = RealVariables45[17];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.T = RealVariables45[18];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.T_der = RealVariables45[19];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.Q_flow = RealVariables45[20];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.port.T = RealVariables45[21];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.port.Q_flow = RealVariables45[22];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.der_T = RealVariables45[23];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.C = RealVariables45[24];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.port_a.T = RealVariables45[25];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.port_a.Q_flow = RealVariables45[26];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.port_b.T = RealVariables45[27];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.port_b.Q_flow = RealVariables45[28];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.G_HTFtoTube = RealVariables45[29];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.G_TubetoPCM = RealVariables45[30];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.HTFtoTube.Q_flow = RealVariables45[31];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.HTFtoTube.dT = RealVariables45[32];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.HTFtoTube.port_a.T = RealVariables45[33];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.HTFtoTube.port_a.Q_flow = RealVariables45[34];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.HTFtoTube.port_b.T = RealVariables45[35];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.HTFtoTube.port_b.Q_flow = RealVariables45[36];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.HTFtoTube.G = RealVariables45[37];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubetoPCM.Q_flow = RealVariables45[38];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubetoPCM.dT = RealVariables45[39];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubetoPCM.port_a.T = RealVariables45[40];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubetoPCM.port_a.Q_flow = RealVariables45[41];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubetoPCM.port_b.T = RealVariables45[42];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubetoPCM.port_b.Q_flow = RealVariables45[43];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubetoPCM.G = RealVariables45[44];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.T = RealVariables45[45];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.T_der = RealVariables45[46];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.Q_flow = RealVariables45[47];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.port.T = RealVariables45[48];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.port.Q_flow = RealVariables45[49];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.der_T = RealVariables45[50];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.C = RealVariables45[51];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.port_a.T = RealVariables45[52];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.port_a.Q_flow = RealVariables45[53];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.port_b.T = RealVariables45[54];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.port_b.Q_flow = RealVariables45[55];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.G_HTFtoTube = RealVariables45[56];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.G_TubetoPCM = RealVariables45[57];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.HTFtoTube.Q_flow = RealVariables45[58];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.HTFtoTube.dT = RealVariables45[59];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.HTFtoTube.port_a.T = RealVariables45[60];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.HTFtoTube.port_a.Q_flow = RealVariables45[61];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.HTFtoTube.port_b.T = RealVariables45[62];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.HTFtoTube.port_b.Q_flow = RealVariables45[63];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.HTFtoTube.G = RealVariables45[64];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubetoPCM.Q_flow = RealVariables45[65];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubetoPCM.dT = RealVariables45[66];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubetoPCM.port_a.T = RealVariables45[67];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubetoPCM.port_a.Q_flow = RealVariables45[68];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubetoPCM.port_b.T = RealVariables45[69];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubetoPCM.port_b.Q_flow = RealVariables45[70];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubetoPCM.G = RealVariables45[71];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.T = RealVariables45[72];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.T_der = RealVariables45[73];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.Q_flow = RealVariables45[74];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.port.T = RealVariables45[75];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.port.Q_flow = RealVariables45[76];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.der_T = RealVariables45[77];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.C = RealVariables45[78];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.port_a.T = RealVariables45[79];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.port_a.Q_flow = RealVariables45[80];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.port_b.T = RealVariables45[81];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.port_b.Q_flow = RealVariables45[82];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.G_HTFtoTube = RealVariables45[83];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.G_TubetoPCM = RealVariables45[84];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.HTFtoTube.Q_flow = RealVariables45[85];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.HTFtoTube.dT = RealVariables45[86];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.HTFtoTube.port_a.T = RealVariables45[87];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.HTFtoTube.port_a.Q_flow = RealVariables45[88];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.HTFtoTube.port_b.T = RealVariables45[89];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.HTFtoTube.port_b.Q_flow = RealVariables45[90];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.HTFtoTube.G = RealVariables45[91];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubetoPCM.Q_flow = RealVariables45[92];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubetoPCM.dT = RealVariables45[93];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubetoPCM.port_a.T = RealVariables45[94];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubetoPCM.port_a.Q_flow = RealVariables45[95];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubetoPCM.port_b.T = RealVariables45[96];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubetoPCM.port_b.Q_flow = RealVariables45[97];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubetoPCM.G = RealVariables45[98];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.T = RealVariables45[99];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.T_der = RealVariables45[100];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.Q_flow = RealVariables46[1];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.port.T = RealVariables46[2];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.port.Q_flow = RealVariables46[3];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.der_T = RealVariables46[4];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.C = RealVariables46[5];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.port_a.T = RealVariables46[6];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.port_a.Q_flow = RealVariables46[7];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.port_b.T = RealVariables46[8];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.port_b.Q_flow = RealVariables46[9];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.G_HTFtoTube = RealVariables46[10];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.G_TubetoPCM = RealVariables46[11];
  iceStorageInternalMelt.pipe.port_a.m_flow = RealVariables46[12];
  iceStorageInternalMelt.pipe.port_a.p = RealVariables46[13];
  iceStorageInternalMelt.pipe.port_a.h_outflow = RealVariables46[14];
  iceStorageInternalMelt.pipe.port_b.m_flow = RealVariables46[15];
  iceStorageInternalMelt.pipe.port_b.p = RealVariables46[16];
  iceStorageInternalMelt.pipe.port_b.h_outflow = RealVariables46[17];
  iceStorageInternalMelt.pipe.'Us[1]' = RealVariables46[18];
  iceStorageInternalMelt.pipe.'Us[1]_der' = RealVariables46[19];
  iceStorageInternalMelt.pipe.'Us[2]' = RealVariables46[20];
  iceStorageInternalMelt.pipe.'Us[2]_der' = RealVariables46[21];
  iceStorageInternalMelt.pipe.'Us[3]' = RealVariables46[22];
  iceStorageInternalMelt.pipe.'Us[3]_der' = RealVariables46[23];
  iceStorageInternalMelt.pipe.'Us[4]' = RealVariables46[24];
  iceStorageInternalMelt.pipe.'Us[4]_der' = RealVariables46[25];
  iceStorageInternalMelt.pipe.'Us[5]' = RealVariables46[26];
  iceStorageInternalMelt.pipe.'Us[5]_der' = RealVariables46[27];
  iceStorageInternalMelt.pipe.'Us[6]' = RealVariables46[28];
  iceStorageInternalMelt.pipe.'Us[6]_der' = RealVariables46[29];
  iceStorageInternalMelt.pipe.'Us[7]' = RealVariables46[30];
  iceStorageInternalMelt.pipe.'Us[7]_der' = RealVariables46[31];
  iceStorageInternalMelt.pipe.'Us[8]' = RealVariables46[32];
  iceStorageInternalMelt.pipe.'Us[8]_der' = RealVariables46[33];
  iceStorageInternalMelt.pipe.'Us[9]' = RealVariables46[34];
  iceStorageInternalMelt.pipe.'Us[9]_der' = RealVariables46[35];
  iceStorageInternalMelt.pipe.'Us[10]' = RealVariables46[36];
  iceStorageInternalMelt.pipe.'Us[10]_der' = RealVariables46[37];
  iceStorageInternalMelt.pipe.'ms[1]' = RealVariables46[38];
  iceStorageInternalMelt.pipe.'ms[1]_der' = RealVariables46[39];
  iceStorageInternalMelt.pipe.'ms[2]' = RealVariables46[40];
  iceStorageInternalMelt.pipe.'ms[2]_der' = RealVariables46[41];
  iceStorageInternalMelt.pipe.'ms[3]' = RealVariables46[42];
  iceStorageInternalMelt.pipe.'ms[3]_der' = RealVariables46[43];
  iceStorageInternalMelt.pipe.'ms[4]' = RealVariables46[44];
  iceStorageInternalMelt.pipe.'ms[4]_der' = RealVariables46[45];
  iceStorageInternalMelt.pipe.'ms[5]' = RealVariables46[46];
  iceStorageInternalMelt.pipe.'ms[5]_der' = RealVariables46[47];
  iceStorageInternalMelt.pipe.'ms[6]' = RealVariables46[48];
  iceStorageInternalMelt.pipe.'ms[6]_der' = RealVariables46[49];
  iceStorageInternalMelt.pipe.'ms[7]' = RealVariables46[50];
  iceStorageInternalMelt.pipe.'ms[7]_der' = RealVariables46[51];
  iceStorageInternalMelt.pipe.'ms[8]' = RealVariables46[52];
  iceStorageInternalMelt.pipe.'ms[8]_der' = RealVariables46[53];
  iceStorageInternalMelt.pipe.'ms[9]' = RealVariables46[54];
  iceStorageInternalMelt.pipe.'ms[9]_der' = RealVariables46[55];
  iceStorageInternalMelt.pipe.'ms[10]' = RealVariables46[56];
  iceStorageInternalMelt.pipe.'ms[10]_der' = RealVariables46[57];
  iceStorageInternalMelt.pipe.'mb_flows[1]' = RealVariables46[58];
  iceStorageInternalMelt.pipe.'mb_flows[2]' = RealVariables46[59];
  iceStorageInternalMelt.pipe.'mb_flows[3]' = RealVariables46[60];
  iceStorageInternalMelt.pipe.'mb_flows[4]' = RealVariables46[61];
  iceStorageInternalMelt.pipe.'mb_flows[5]' = RealVariables46[62];
  iceStorageInternalMelt.pipe.'mb_flows[6]' = RealVariables46[63];
  iceStorageInternalMelt.pipe.'mb_flows[7]' = RealVariables46[64];
  iceStorageInternalMelt.pipe.'mb_flows[8]' = RealVariables46[65];
  iceStorageInternalMelt.pipe.'mb_flows[9]' = RealVariables46[66];
  iceStorageInternalMelt.pipe.'mb_flows[10]' = RealVariables46[67];
  iceStorageInternalMelt.pipe.'Hb_flows[1]' = RealVariables46[68];
  iceStorageInternalMelt.pipe.'Hb_flows[2]' = RealVariables46[69];
  iceStorageInternalMelt.pipe.'Hb_flows[3]' = RealVariables46[70];
  iceStorageInternalMelt.pipe.'Hb_flows[4]' = RealVariables46[71];
  iceStorageInternalMelt.pipe.'Hb_flows[5]' = RealVariables46[72];
  iceStorageInternalMelt.pipe.'Hb_flows[6]' = RealVariables46[73];
  iceStorageInternalMelt.pipe.'Hb_flows[7]' = RealVariables46[74];
  iceStorageInternalMelt.pipe.'Hb_flows[8]' = RealVariables46[75];
  iceStorageInternalMelt.pipe.'Hb_flows[9]' = RealVariables46[76];
  iceStorageInternalMelt.pipe.'Hb_flows[10]' = RealVariables46[77];
  iceStorageInternalMelt.pipe.'Qb_flows[1]' = RealVariables46[78];
  iceStorageInternalMelt.pipe.'Qb_flows[2]' = RealVariables46[79];
  iceStorageInternalMelt.pipe.'Qb_flows[3]' = RealVariables46[80];
  iceStorageInternalMelt.pipe.'Qb_flows[4]' = RealVariables46[81];
  iceStorageInternalMelt.pipe.'Qb_flows[5]' = RealVariables46[82];
  iceStorageInternalMelt.pipe.'Qb_flows[6]' = RealVariables46[83];
  iceStorageInternalMelt.pipe.'Qb_flows[7]' = RealVariables46[84];
  iceStorageInternalMelt.pipe.'Qb_flows[8]' = RealVariables46[85];
  iceStorageInternalMelt.pipe.'Qb_flows[9]' = RealVariables46[86];
  iceStorageInternalMelt.pipe.'Qb_flows[10]' = RealVariables46[87];
  iceStorageInternalMelt.pipe.'Wb_flows[1]' = RealVariables46[88];
  iceStorageInternalMelt.pipe.'Wb_flows[2]' = RealVariables46[89];
  iceStorageInternalMelt.pipe.'Wb_flows[3]' = RealVariables46[90];
  iceStorageInternalMelt.pipe.'Wb_flows[4]' = RealVariables46[91];
  iceStorageInternalMelt.pipe.'Wb_flows[5]' = RealVariables46[92];
  iceStorageInternalMelt.pipe.'Wb_flows[6]' = RealVariables46[93];
  iceStorageInternalMelt.pipe.'Wb_flows[7]' = RealVariables46[94];
  iceStorageInternalMelt.pipe.'Wb_flows[8]' = RealVariables46[95];
  iceStorageInternalMelt.pipe.'Wb_flows[9]' = RealVariables46[96];
  iceStorageInternalMelt.pipe.'Wb_flows[10]' = RealVariables46[97];
  iceStorageInternalMelt.pipe.state_a.p = RealVariables46[98];
  iceStorageInternalMelt.pipe.state_a.T = RealVariables46[99];
  iceStorageInternalMelt.pipe.state_b.p = RealVariables46[100];
  iceStorageInternalMelt.pipe.state_b.T = RealVariables47[1];
  iceStorageInternalMelt.pipe.'statesFM[1]'.p = RealVariables47[2];
  iceStorageInternalMelt.pipe.'statesFM[1]'.T = RealVariables47[3];
  iceStorageInternalMelt.pipe.'statesFM[2]'.p = RealVariables47[4];
  iceStorageInternalMelt.pipe.'statesFM[2]'.T = RealVariables47[5];
  iceStorageInternalMelt.pipe.'statesFM[3]'.p = RealVariables47[6];
  iceStorageInternalMelt.pipe.'statesFM[3]'.T = RealVariables47[7];
  iceStorageInternalMelt.pipe.'statesFM[4]'.p = RealVariables47[8];
  iceStorageInternalMelt.pipe.'statesFM[4]'.T = RealVariables47[9];
  iceStorageInternalMelt.pipe.'statesFM[5]'.p = RealVariables47[10];
  iceStorageInternalMelt.pipe.'statesFM[5]'.T = RealVariables47[11];
  iceStorageInternalMelt.pipe.'statesFM[6]'.p = RealVariables47[12];
  iceStorageInternalMelt.pipe.'statesFM[6]'.T = RealVariables47[13];
  iceStorageInternalMelt.pipe.'statesFM[7]'.p = RealVariables47[14];
  iceStorageInternalMelt.pipe.'statesFM[7]'.T = RealVariables47[15];
  iceStorageInternalMelt.pipe.'statesFM[8]'.p = RealVariables47[16];
  iceStorageInternalMelt.pipe.'statesFM[8]'.T = RealVariables47[17];
  iceStorageInternalMelt.pipe.'statesFM[9]'.p = RealVariables47[18];
  iceStorageInternalMelt.pipe.'statesFM[9]'.T = RealVariables47[19];
  iceStorageInternalMelt.pipe.'statesFM[10]'.p = RealVariables47[20];
  iceStorageInternalMelt.pipe.'statesFM[10]'.T = RealVariables47[21];
  iceStorageInternalMelt.pipe.flowModel.'states[1]'.p = RealVariables47[22];
  iceStorageInternalMelt.pipe.flowModel.'states[1]'.T = RealVariables47[23];
  iceStorageInternalMelt.pipe.flowModel.'states[2]'.p = RealVariables47[24];
  iceStorageInternalMelt.pipe.flowModel.'states[2]'.T = RealVariables47[25];
  iceStorageInternalMelt.pipe.flowModel.'states[3]'.p = RealVariables47[26];
  iceStorageInternalMelt.pipe.flowModel.'states[3]'.T = RealVariables47[27];
  iceStorageInternalMelt.pipe.flowModel.'states[4]'.p = RealVariables47[28];
  iceStorageInternalMelt.pipe.flowModel.'states[4]'.T = RealVariables47[29];
  iceStorageInternalMelt.pipe.flowModel.'states[5]'.p = RealVariables47[30];
  iceStorageInternalMelt.pipe.flowModel.'states[5]'.T = RealVariables47[31];
  iceStorageInternalMelt.pipe.flowModel.'states[6]'.p = RealVariables47[32];
  iceStorageInternalMelt.pipe.flowModel.'states[6]'.T = RealVariables47[33];
  iceStorageInternalMelt.pipe.flowModel.'states[7]'.p = RealVariables47[34];
  iceStorageInternalMelt.pipe.flowModel.'states[7]'.T = RealVariables47[35];
  iceStorageInternalMelt.pipe.flowModel.'states[8]'.p = RealVariables47[36];
  iceStorageInternalMelt.pipe.flowModel.'states[8]'.T = RealVariables47[37];
  iceStorageInternalMelt.pipe.flowModel.'states[9]'.p = RealVariables47[38];
  iceStorageInternalMelt.pipe.flowModel.'states[9]'.T = RealVariables47[39];
  iceStorageInternalMelt.pipe.flowModel.'states[10]'.p = RealVariables47[40];
  iceStorageInternalMelt.pipe.flowModel.'states[10]'.T = RealVariables47[41];
  iceStorageInternalMelt.pipe.flowModel.'vs[1]' = RealVariables47[42];
  iceStorageInternalMelt.pipe.flowModel.'vs[2]' = RealVariables47[43];
  iceStorageInternalMelt.pipe.flowModel.'vs[3]' = RealVariables47[44];
  iceStorageInternalMelt.pipe.flowModel.'vs[4]' = RealVariables47[45];
  iceStorageInternalMelt.pipe.flowModel.'vs[5]' = RealVariables47[46];
  iceStorageInternalMelt.pipe.flowModel.'vs[6]' = RealVariables47[47];
  iceStorageInternalMelt.pipe.flowModel.'vs[7]' = RealVariables47[48];
  iceStorageInternalMelt.pipe.flowModel.'vs[8]' = RealVariables47[49];
  iceStorageInternalMelt.pipe.flowModel.'vs[9]' = RealVariables47[50];
  iceStorageInternalMelt.pipe.flowModel.'vs[10]' = RealVariables47[51];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[1]' = RealVariables47[52];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[2]' = RealVariables47[53];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[3]' = RealVariables47[54];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[4]' = RealVariables47[55];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[5]' = RealVariables47[56];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[6]' = RealVariables47[57];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[7]' = RealVariables47[58];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[8]' = RealVariables47[59];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[9]' = RealVariables47[60];
  iceStorageInternalMelt.pipe.flowModel.'crossAreas[10]' = RealVariables47[61];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[1]' = RealVariables47[62];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[2]' = RealVariables47[63];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[3]' = RealVariables47[64];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[4]' = RealVariables47[65];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[5]' = RealVariables47[66];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[6]' = RealVariables47[67];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[7]' = RealVariables47[68];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[8]' = RealVariables47[69];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[9]' = RealVariables47[70];
  iceStorageInternalMelt.pipe.flowModel.'dimensions[10]' = RealVariables47[71];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[1]' = RealVariables47[72];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[2]' = RealVariables47[73];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[3]' = RealVariables47[74];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[4]' = RealVariables47[75];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[5]' = RealVariables47[76];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[6]' = RealVariables47[77];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[7]' = RealVariables47[78];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[8]' = RealVariables47[79];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[9]' = RealVariables47[80];
  iceStorageInternalMelt.pipe.flowModel.'roughnesses[10]' = RealVariables47[81];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[1]' = RealVariables47[82];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[2]' = RealVariables47[83];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[3]' = RealVariables47[84];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[4]' = RealVariables47[85];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[5]' = RealVariables47[86];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[6]' = RealVariables47[87];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[7]' = RealVariables47[88];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[8]' = RealVariables47[89];
  iceStorageInternalMelt.pipe.flowModel.'m_flows[9]' = RealVariables47[90];
  iceStorageInternalMelt.pipe.flowModel.'Is[1]' = RealVariables47[91];
  iceStorageInternalMelt.pipe.flowModel.'Is[2]' = RealVariables47[92];
  iceStorageInternalMelt.pipe.flowModel.'Is[3]' = RealVariables47[93];
  iceStorageInternalMelt.pipe.flowModel.'Is[4]' = RealVariables47[94];
  iceStorageInternalMelt.pipe.flowModel.'Is[5]' = RealVariables47[95];
  iceStorageInternalMelt.pipe.flowModel.'Is[6]' = RealVariables47[96];
  iceStorageInternalMelt.pipe.flowModel.'Is[7]' = RealVariables47[97];
  iceStorageInternalMelt.pipe.flowModel.'Is[8]' = RealVariables47[98];
  iceStorageInternalMelt.pipe.flowModel.'Is[9]' = RealVariables47[99];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[1]' = RealVariables47[100];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[2]' = RealVariables48[1];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[3]' = RealVariables48[2];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[4]' = RealVariables48[3];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[5]' = RealVariables48[4];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[6]' = RealVariables48[5];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[7]' = RealVariables48[6];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[8]' = RealVariables48[7];
  iceStorageInternalMelt.pipe.flowModel.'Fs_p[9]' = RealVariables48[8];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[1]' = RealVariables48[9];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[2]' = RealVariables48[10];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[3]' = RealVariables48[11];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[4]' = RealVariables48[12];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[5]' = RealVariables48[13];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[6]' = RealVariables48[14];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[7]' = RealVariables48[15];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[8]' = RealVariables48[16];
  iceStorageInternalMelt.pipe.flowModel.'Fs_fg[9]' = RealVariables48[17];
  iceStorageInternalMelt.pipe.flowModel.'rhos[1]' = RealVariables48[18];
  iceStorageInternalMelt.pipe.flowModel.'rhos[2]' = RealVariables48[19];
  iceStorageInternalMelt.pipe.flowModel.'rhos[3]' = RealVariables48[20];
  iceStorageInternalMelt.pipe.flowModel.'rhos[4]' = RealVariables48[21];
  iceStorageInternalMelt.pipe.flowModel.'rhos[5]' = RealVariables48[22];
  iceStorageInternalMelt.pipe.flowModel.'rhos[6]' = RealVariables48[23];
  iceStorageInternalMelt.pipe.flowModel.'rhos[7]' = RealVariables48[24];
  iceStorageInternalMelt.pipe.flowModel.'rhos[8]' = RealVariables48[25];
  iceStorageInternalMelt.pipe.flowModel.'rhos[9]' = RealVariables48[26];
  iceStorageInternalMelt.pipe.flowModel.'rhos[10]' = RealVariables48[27];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[1]' = RealVariables48[28];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[2]' = RealVariables48[29];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[3]' = RealVariables48[30];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[4]' = RealVariables48[31];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[5]' = RealVariables48[32];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[6]' = RealVariables48[33];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[7]' = RealVariables48[34];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[8]' = RealVariables48[35];
  iceStorageInternalMelt.pipe.flowModel.'rhos_act[9]' = RealVariables48[36];
  iceStorageInternalMelt.pipe.flowModel.'mus[1]' = RealVariables48[37];
  iceStorageInternalMelt.pipe.flowModel.'mus[2]' = RealVariables48[38];
  iceStorageInternalMelt.pipe.flowModel.'mus[3]' = RealVariables48[39];
  iceStorageInternalMelt.pipe.flowModel.'mus[4]' = RealVariables48[40];
  iceStorageInternalMelt.pipe.flowModel.'mus[5]' = RealVariables48[41];
  iceStorageInternalMelt.pipe.flowModel.'mus[6]' = RealVariables48[42];
  iceStorageInternalMelt.pipe.flowModel.'mus[7]' = RealVariables48[43];
  iceStorageInternalMelt.pipe.flowModel.'mus[8]' = RealVariables48[44];
  iceStorageInternalMelt.pipe.flowModel.'mus[9]' = RealVariables48[45];
  iceStorageInternalMelt.pipe.flowModel.'mus[10]' = RealVariables48[46];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[1]' = RealVariables48[47];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[2]' = RealVariables48[48];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[3]' = RealVariables48[49];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[4]' = RealVariables48[50];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[5]' = RealVariables48[51];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[6]' = RealVariables48[52];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[7]' = RealVariables48[53];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[8]' = RealVariables48[54];
  iceStorageInternalMelt.pipe.flowModel.'mus_act[9]' = RealVariables48[55];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[1]' = RealVariables48[56];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[2]' = RealVariables48[57];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[3]' = RealVariables48[58];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[4]' = RealVariables48[59];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[5]' = RealVariables48[60];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[6]' = RealVariables48[61];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[7]' = RealVariables48[62];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[8]' = RealVariables48[63];
  iceStorageInternalMelt.pipe.flowModel.'dps_fg[9]' = RealVariables48[64];
  iceStorageInternalMelt.pipe.'m_flows[1]' = RealVariables48[65];
  iceStorageInternalMelt.pipe.'m_flows[2]' = RealVariables48[66];
  iceStorageInternalMelt.pipe.'m_flows[3]' = RealVariables48[67];
  iceStorageInternalMelt.pipe.'m_flows[4]' = RealVariables48[68];
  iceStorageInternalMelt.pipe.'m_flows[5]' = RealVariables48[69];
  iceStorageInternalMelt.pipe.'m_flows[6]' = RealVariables48[70];
  iceStorageInternalMelt.pipe.'m_flows[7]' = RealVariables48[71];
  iceStorageInternalMelt.pipe.'m_flows[8]' = RealVariables48[72];
  iceStorageInternalMelt.pipe.'m_flows[9]' = RealVariables48[73];
  iceStorageInternalMelt.pipe.'m_flows[10]' = RealVariables48[74];
  iceStorageInternalMelt.pipe.'m_flows[11]' = RealVariables48[75];
  iceStorageInternalMelt.pipe.'H_flows[1]' = RealVariables48[76];
  iceStorageInternalMelt.pipe.'H_flows[2]' = RealVariables48[77];
  iceStorageInternalMelt.pipe.'H_flows[3]' = RealVariables48[78];
  iceStorageInternalMelt.pipe.'H_flows[4]' = RealVariables48[79];
  iceStorageInternalMelt.pipe.'H_flows[5]' = RealVariables48[80];
  iceStorageInternalMelt.pipe.'H_flows[6]' = RealVariables48[81];
  iceStorageInternalMelt.pipe.'H_flows[7]' = RealVariables48[82];
  iceStorageInternalMelt.pipe.'H_flows[8]' = RealVariables48[83];
  iceStorageInternalMelt.pipe.'H_flows[9]' = RealVariables48[84];
  iceStorageInternalMelt.pipe.'H_flows[10]' = RealVariables48[85];
  iceStorageInternalMelt.pipe.'H_flows[11]' = RealVariables48[86];
  iceStorageInternalMelt.pipe.'vs[1]' = RealVariables48[87];
  iceStorageInternalMelt.pipe.'vs[2]' = RealVariables48[88];
  iceStorageInternalMelt.pipe.'vs[3]' = RealVariables48[89];
  iceStorageInternalMelt.pipe.'vs[4]' = RealVariables48[90];
  iceStorageInternalMelt.pipe.'vs[5]' = RealVariables48[91];
  iceStorageInternalMelt.pipe.'vs[6]' = RealVariables48[92];
  iceStorageInternalMelt.pipe.'vs[7]' = RealVariables48[93];
  iceStorageInternalMelt.pipe.'vs[8]' = RealVariables48[94];
  iceStorageInternalMelt.pipe.'vs[9]' = RealVariables48[95];
  iceStorageInternalMelt.pipe.'vs[10]' = RealVariables48[96];
  iceStorageInternalMelt.pipe.'heatPorts[1]'.T = RealVariables48[97];
  iceStorageInternalMelt.pipe.'heatPorts[1]'.Q_flow = RealVariables48[98];
  iceStorageInternalMelt.pipe.'heatPorts[2]'.T = RealVariables48[99];
  iceStorageInternalMelt.pipe.'heatPorts[2]'.Q_flow = RealVariables48[100];
  iceStorageInternalMelt.pipe.'heatPorts[3]'.T = RealVariables49[1];
  iceStorageInternalMelt.pipe.'heatPorts[3]'.Q_flow = RealVariables49[2];
  iceStorageInternalMelt.pipe.'heatPorts[4]'.T = RealVariables49[3];
  iceStorageInternalMelt.pipe.'heatPorts[4]'.Q_flow = RealVariables49[4];
  iceStorageInternalMelt.pipe.'heatPorts[5]'.T = RealVariables49[5];
  iceStorageInternalMelt.pipe.'heatPorts[5]'.Q_flow = RealVariables49[6];
  iceStorageInternalMelt.pipe.'heatPorts[6]'.T = RealVariables49[7];
  iceStorageInternalMelt.pipe.'heatPorts[6]'.Q_flow = RealVariables49[8];
  iceStorageInternalMelt.pipe.'heatPorts[7]'.T = RealVariables49[9];
  iceStorageInternalMelt.pipe.'heatPorts[7]'.Q_flow = RealVariables49[10];
  iceStorageInternalMelt.pipe.'heatPorts[8]'.T = RealVariables49[11];
  iceStorageInternalMelt.pipe.'heatPorts[8]'.Q_flow = RealVariables49[12];
  iceStorageInternalMelt.pipe.'heatPorts[9]'.T = RealVariables49[13];
  iceStorageInternalMelt.pipe.'heatPorts[9]'.Q_flow = RealVariables49[14];
  iceStorageInternalMelt.pipe.'heatPorts[10]'.T = RealVariables49[15];
  iceStorageInternalMelt.pipe.'heatPorts[10]'.Q_flow = RealVariables49[16];
  iceStorageInternalMelt.pipe.heatTransfer.'states[1]'.p = RealVariables49[17];
  iceStorageInternalMelt.pipe.heatTransfer.'states[1]'.T = RealVariables49[18];
  iceStorageInternalMelt.pipe.heatTransfer.'states[2]'.p = RealVariables49[19];
  iceStorageInternalMelt.pipe.heatTransfer.'states[2]'.T = RealVariables49[20];
  iceStorageInternalMelt.pipe.heatTransfer.'states[3]'.p = RealVariables49[21];
  iceStorageInternalMelt.pipe.heatTransfer.'states[3]'.T = RealVariables49[22];
  iceStorageInternalMelt.pipe.heatTransfer.'states[4]'.p = RealVariables49[23];
  iceStorageInternalMelt.pipe.heatTransfer.'states[4]'.T = RealVariables49[24];
  iceStorageInternalMelt.pipe.heatTransfer.'states[5]'.p = RealVariables49[25];
  iceStorageInternalMelt.pipe.heatTransfer.'states[5]'.T = RealVariables49[26];
  iceStorageInternalMelt.pipe.heatTransfer.'states[6]'.p = RealVariables49[27];
  iceStorageInternalMelt.pipe.heatTransfer.'states[6]'.T = RealVariables49[28];
  iceStorageInternalMelt.pipe.heatTransfer.'states[7]'.p = RealVariables49[29];
  iceStorageInternalMelt.pipe.heatTransfer.'states[7]'.T = RealVariables49[30];
  iceStorageInternalMelt.pipe.heatTransfer.'states[8]'.p = RealVariables49[31];
  iceStorageInternalMelt.pipe.heatTransfer.'states[8]'.T = RealVariables49[32];
  iceStorageInternalMelt.pipe.heatTransfer.'states[9]'.p = RealVariables49[33];
  iceStorageInternalMelt.pipe.heatTransfer.'states[9]'.T = RealVariables49[34];
  iceStorageInternalMelt.pipe.heatTransfer.'states[10]'.p = RealVariables49[35];
  iceStorageInternalMelt.pipe.heatTransfer.'states[10]'.T = RealVariables49[36];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[1]' = RealVariables49[37];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[2]' = RealVariables49[38];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[3]' = RealVariables49[39];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[4]' = RealVariables49[40];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[5]' = RealVariables49[41];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[6]' = RealVariables49[42];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[7]' = RealVariables49[43];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[8]' = RealVariables49[44];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[9]' = RealVariables49[45];
  iceStorageInternalMelt.pipe.heatTransfer.'surfaceAreas[10]' = RealVariables49[46];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[1]' = RealVariables49[47];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[2]' = RealVariables49[48];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[3]' = RealVariables49[49];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[4]' = RealVariables49[50];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[5]' = RealVariables49[51];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[6]' = RealVariables49[52];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[7]' = RealVariables49[53];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[8]' = RealVariables49[54];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[9]' = RealVariables49[55];
  iceStorageInternalMelt.pipe.heatTransfer.'Q_flows[10]' = RealVariables49[56];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[1]'.T = RealVariables49[57];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[1]'.Q_flow = RealVariables49[58];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[2]'.T = RealVariables49[59];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[2]'.Q_flow = RealVariables49[60];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[3]'.T = RealVariables49[61];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[3]'.Q_flow = RealVariables49[62];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[4]'.T = RealVariables49[63];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[4]'.Q_flow = RealVariables49[64];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[5]'.T = RealVariables49[65];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[5]'.Q_flow = RealVariables49[66];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[6]'.T = RealVariables49[67];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[6]'.Q_flow = RealVariables49[68];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[7]'.T = RealVariables49[69];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[7]'.Q_flow = RealVariables49[70];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[8]'.T = RealVariables49[71];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[8]'.Q_flow = RealVariables49[72];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[9]'.T = RealVariables49[73];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[9]'.Q_flow = RealVariables49[74];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[10]'.T = RealVariables49[75];
  iceStorageInternalMelt.pipe.heatTransfer.'heatPorts[10]'.Q_flow = RealVariables49[76];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[1]' = RealVariables49[77];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[2]' = RealVariables49[78];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[3]' = RealVariables49[79];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[4]' = RealVariables49[80];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[5]' = RealVariables49[81];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[6]' = RealVariables49[82];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[7]' = RealVariables49[83];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[8]' = RealVariables49[84];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[9]' = RealVariables49[85];
  iceStorageInternalMelt.pipe.heatTransfer.'Ts[10]' = RealVariables49[86];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[1]' = RealVariables49[87];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[2]' = RealVariables49[88];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[3]' = RealVariables49[89];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[4]' = RealVariables49[90];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[5]' = RealVariables49[91];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[6]' = RealVariables49[92];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[7]' = RealVariables49[93];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[8]' = RealVariables49[94];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[9]' = RealVariables49[95];
  iceStorageInternalMelt.pipe.heatTransfer.'vs[10]' = RealVariables49[96];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[1]' = RealVariables49[97];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[2]' = RealVariables49[98];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[3]' = RealVariables49[99];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[4]' = RealVariables49[100];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[5]' = RealVariables50[1];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[6]' = RealVariables50[2];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[7]' = RealVariables50[3];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[8]' = RealVariables50[4];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[9]' = RealVariables50[5];
  iceStorageInternalMelt.pipe.heatTransfer.'dimensions[10]' = RealVariables50[6];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[1]' = RealVariables50[7];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[2]' = RealVariables50[8];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[3]' = RealVariables50[9];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[4]' = RealVariables50[10];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[5]' = RealVariables50[11];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[6]' = RealVariables50[12];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[7]' = RealVariables50[13];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[8]' = RealVariables50[14];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[9]' = RealVariables50[15];
  iceStorageInternalMelt.pipe.heatTransfer.'roughnesses[10]' = RealVariables50[16];
  iceStorageInternalMelt.pipe.'mediums[1]'.p = RealVariables50[17];
  iceStorageInternalMelt.pipe.'mediums[1]'.p_der = RealVariables50[18];
  iceStorageInternalMelt.pipe.'mediums[1]'.h = RealVariables50[19];
  iceStorageInternalMelt.pipe.'mediums[1]'.d = RealVariables50[20];
  iceStorageInternalMelt.pipe.'mediums[1]'.d_der = RealVariables50[21];
  iceStorageInternalMelt.pipe.'mediums[1]'.T = RealVariables50[22];
  iceStorageInternalMelt.pipe.'mediums[1]'.T_der = RealVariables50[23];
  iceStorageInternalMelt.pipe.'mediums[1]'.u = RealVariables50[24];
  iceStorageInternalMelt.pipe.'mediums[1]'.u_der = RealVariables50[25];
  iceStorageInternalMelt.pipe.'mediums[1]'.state.p = RealVariables50[26];
  iceStorageInternalMelt.pipe.'mediums[1]'.state.T = RealVariables50[27];
  iceStorageInternalMelt.pipe.'mediums[1]'.T_degC = RealVariables50[28];
  iceStorageInternalMelt.pipe.'mediums[1]'.p_bar = RealVariables50[29];
  iceStorageInternalMelt.pipe.'mediums[2]'.p = RealVariables50[30];
  iceStorageInternalMelt.pipe.'mediums[2]'.p_der = RealVariables50[31];
  iceStorageInternalMelt.pipe.'mediums[2]'.h = RealVariables50[32];
  iceStorageInternalMelt.pipe.'mediums[2]'.h_der = RealVariables50[33];
  iceStorageInternalMelt.pipe.'mediums[2]'.d = RealVariables50[34];
  iceStorageInternalMelt.pipe.'mediums[2]'.d_der = RealVariables50[35];
  iceStorageInternalMelt.pipe.'mediums[2]'.T = RealVariables50[36];
  iceStorageInternalMelt.pipe.'mediums[2]'.T_der = RealVariables50[37];
  iceStorageInternalMelt.pipe.'mediums[2]'.u = RealVariables50[38];
  iceStorageInternalMelt.pipe.'mediums[2]'.u_der = RealVariables50[39];
  iceStorageInternalMelt.pipe.'mediums[2]'.state.p = RealVariables50[40];
  iceStorageInternalMelt.pipe.'mediums[2]'.state.T = RealVariables50[41];
  iceStorageInternalMelt.pipe.'mediums[2]'.T_degC = RealVariables50[42];
  iceStorageInternalMelt.pipe.'mediums[2]'.p_bar = RealVariables50[43];
  iceStorageInternalMelt.pipe.'mediums[3]'.p = RealVariables50[44];
  iceStorageInternalMelt.pipe.'mediums[3]'.p_der = RealVariables50[45];
  iceStorageInternalMelt.pipe.'mediums[3]'.h = RealVariables50[46];
  iceStorageInternalMelt.pipe.'mediums[3]'.h_der = RealVariables50[47];
  iceStorageInternalMelt.pipe.'mediums[3]'.d = RealVariables50[48];
  iceStorageInternalMelt.pipe.'mediums[3]'.d_der = RealVariables50[49];
  iceStorageInternalMelt.pipe.'mediums[3]'.T = RealVariables50[50];
  iceStorageInternalMelt.pipe.'mediums[3]'.T_der = RealVariables50[51];
  iceStorageInternalMelt.pipe.'mediums[3]'.u = RealVariables50[52];
  iceStorageInternalMelt.pipe.'mediums[3]'.u_der = RealVariables50[53];
  iceStorageInternalMelt.pipe.'mediums[3]'.state.p = RealVariables50[54];
  iceStorageInternalMelt.pipe.'mediums[3]'.state.T = RealVariables50[55];
  iceStorageInternalMelt.pipe.'mediums[3]'.T_degC = RealVariables50[56];
  iceStorageInternalMelt.pipe.'mediums[3]'.p_bar = RealVariables50[57];
  iceStorageInternalMelt.pipe.'mediums[4]'.p = RealVariables50[58];
  iceStorageInternalMelt.pipe.'mediums[4]'.p_der = RealVariables50[59];
  iceStorageInternalMelt.pipe.'mediums[4]'.h = RealVariables50[60];
  iceStorageInternalMelt.pipe.'mediums[4]'.h_der = RealVariables50[61];
  iceStorageInternalMelt.pipe.'mediums[4]'.d = RealVariables50[62];
  iceStorageInternalMelt.pipe.'mediums[4]'.d_der = RealVariables50[63];
  iceStorageInternalMelt.pipe.'mediums[4]'.T = RealVariables50[64];
  iceStorageInternalMelt.pipe.'mediums[4]'.T_der = RealVariables50[65];
  iceStorageInternalMelt.pipe.'mediums[4]'.u = RealVariables50[66];
  iceStorageInternalMelt.pipe.'mediums[4]'.u_der = RealVariables50[67];
  iceStorageInternalMelt.pipe.'mediums[4]'.state.p = RealVariables50[68];
  iceStorageInternalMelt.pipe.'mediums[4]'.state.T = RealVariables50[69];
  iceStorageInternalMelt.pipe.'mediums[4]'.T_degC = RealVariables50[70];
  iceStorageInternalMelt.pipe.'mediums[4]'.p_bar = RealVariables50[71];
  iceStorageInternalMelt.pipe.'mediums[5]'.p = RealVariables50[72];
  iceStorageInternalMelt.pipe.'mediums[5]'.p_der = RealVariables50[73];
  iceStorageInternalMelt.pipe.'mediums[5]'.h = RealVariables50[74];
  iceStorageInternalMelt.pipe.'mediums[5]'.h_der = RealVariables50[75];
  iceStorageInternalMelt.pipe.'mediums[5]'.d = RealVariables50[76];
  iceStorageInternalMelt.pipe.'mediums[5]'.d_der = RealVariables50[77];
  iceStorageInternalMelt.pipe.'mediums[5]'.T = RealVariables50[78];
  iceStorageInternalMelt.pipe.'mediums[5]'.T_der = RealVariables50[79];
  iceStorageInternalMelt.pipe.'mediums[5]'.u = RealVariables50[80];
  iceStorageInternalMelt.pipe.'mediums[5]'.u_der = RealVariables50[81];
  iceStorageInternalMelt.pipe.'mediums[5]'.state.p = RealVariables50[82];
  iceStorageInternalMelt.pipe.'mediums[5]'.state.T = RealVariables50[83];
  iceStorageInternalMelt.pipe.'mediums[5]'.T_degC = RealVariables50[84];
  iceStorageInternalMelt.pipe.'mediums[5]'.p_bar = RealVariables50[85];
  iceStorageInternalMelt.pipe.'mediums[6]'.p = RealVariables50[86];
  iceStorageInternalMelt.pipe.'mediums[6]'.p_der = RealVariables50[87];
  iceStorageInternalMelt.pipe.'mediums[6]'.h = RealVariables50[88];
  iceStorageInternalMelt.pipe.'mediums[6]'.h_der = RealVariables50[89];
  iceStorageInternalMelt.pipe.'mediums[6]'.d = RealVariables50[90];
  iceStorageInternalMelt.pipe.'mediums[6]'.d_der = RealVariables50[91];
  iceStorageInternalMelt.pipe.'mediums[6]'.T = RealVariables50[92];
  iceStorageInternalMelt.pipe.'mediums[6]'.T_der = RealVariables50[93];
  iceStorageInternalMelt.pipe.'mediums[6]'.u = RealVariables50[94];
  iceStorageInternalMelt.pipe.'mediums[6]'.u_der = RealVariables50[95];
  iceStorageInternalMelt.pipe.'mediums[6]'.state.p = RealVariables50[96];
  iceStorageInternalMelt.pipe.'mediums[6]'.state.T = RealVariables50[97];
  iceStorageInternalMelt.pipe.'mediums[6]'.T_degC = RealVariables50[98];
  iceStorageInternalMelt.pipe.'mediums[6]'.p_bar = RealVariables50[99];
  iceStorageInternalMelt.pipe.'mediums[7]'.p = RealVariables50[100];
  iceStorageInternalMelt.pipe.'mediums[7]'.p_der = RealVariables51[1];
  iceStorageInternalMelt.pipe.'mediums[7]'.h = RealVariables51[2];
  iceStorageInternalMelt.pipe.'mediums[7]'.h_der = RealVariables51[3];
  iceStorageInternalMelt.pipe.'mediums[7]'.d = RealVariables51[4];
  iceStorageInternalMelt.pipe.'mediums[7]'.d_der = RealVariables51[5];
  iceStorageInternalMelt.pipe.'mediums[7]'.T = RealVariables51[6];
  iceStorageInternalMelt.pipe.'mediums[7]'.T_der = RealVariables51[7];
  iceStorageInternalMelt.pipe.'mediums[7]'.u = RealVariables51[8];
  iceStorageInternalMelt.pipe.'mediums[7]'.u_der = RealVariables51[9];
  iceStorageInternalMelt.pipe.'mediums[7]'.state.p = RealVariables51[10];
  iceStorageInternalMelt.pipe.'mediums[7]'.state.T = RealVariables51[11];
  iceStorageInternalMelt.pipe.'mediums[7]'.T_degC = RealVariables51[12];
  iceStorageInternalMelt.pipe.'mediums[7]'.p_bar = RealVariables51[13];
  iceStorageInternalMelt.pipe.'mediums[8]'.p = RealVariables51[14];
  iceStorageInternalMelt.pipe.'mediums[8]'.p_der = RealVariables51[15];
  iceStorageInternalMelt.pipe.'mediums[8]'.h = RealVariables51[16];
  iceStorageInternalMelt.pipe.'mediums[8]'.h_der = RealVariables51[17];
  iceStorageInternalMelt.pipe.'mediums[8]'.d = RealVariables51[18];
  iceStorageInternalMelt.pipe.'mediums[8]'.d_der = RealVariables51[19];
  iceStorageInternalMelt.pipe.'mediums[8]'.T = RealVariables51[20];
  iceStorageInternalMelt.pipe.'mediums[8]'.T_der = RealVariables51[21];
  iceStorageInternalMelt.pipe.'mediums[8]'.u = RealVariables51[22];
  iceStorageInternalMelt.pipe.'mediums[8]'.u_der = RealVariables51[23];
  iceStorageInternalMelt.pipe.'mediums[8]'.state.p = RealVariables51[24];
  iceStorageInternalMelt.pipe.'mediums[8]'.state.T = RealVariables51[25];
  iceStorageInternalMelt.pipe.'mediums[8]'.T_degC = RealVariables51[26];
  iceStorageInternalMelt.pipe.'mediums[8]'.p_bar = RealVariables51[27];
  iceStorageInternalMelt.pipe.'mediums[9]'.p = RealVariables51[28];
  iceStorageInternalMelt.pipe.'mediums[9]'.p_der = RealVariables51[29];
  iceStorageInternalMelt.pipe.'mediums[9]'.h = RealVariables51[30];
  iceStorageInternalMelt.pipe.'mediums[9]'.h_der = RealVariables51[31];
  iceStorageInternalMelt.pipe.'mediums[9]'.d = RealVariables51[32];
  iceStorageInternalMelt.pipe.'mediums[9]'.d_der = RealVariables51[33];
  iceStorageInternalMelt.pipe.'mediums[9]'.T = RealVariables51[34];
  iceStorageInternalMelt.pipe.'mediums[9]'.T_der = RealVariables51[35];
  iceStorageInternalMelt.pipe.'mediums[9]'.u = RealVariables51[36];
  iceStorageInternalMelt.pipe.'mediums[9]'.u_der = RealVariables51[37];
  iceStorageInternalMelt.pipe.'mediums[9]'.state.p = RealVariables51[38];
  iceStorageInternalMelt.pipe.'mediums[9]'.state.T = RealVariables51[39];
  iceStorageInternalMelt.pipe.'mediums[9]'.T_degC = RealVariables51[40];
  iceStorageInternalMelt.pipe.'mediums[9]'.p_bar = RealVariables51[41];
  iceStorageInternalMelt.pipe.'mediums[10]'.p = RealVariables51[42];
  iceStorageInternalMelt.pipe.'mediums[10]'.p_der = RealVariables51[43];
  iceStorageInternalMelt.pipe.'mediums[10]'.h = RealVariables51[44];
  iceStorageInternalMelt.pipe.'mediums[10]'.d = RealVariables51[45];
  iceStorageInternalMelt.pipe.'mediums[10]'.d_der = RealVariables51[46];
  iceStorageInternalMelt.pipe.'mediums[10]'.T = RealVariables51[47];
  iceStorageInternalMelt.pipe.'mediums[10]'.T_der = RealVariables51[48];
  iceStorageInternalMelt.pipe.'mediums[10]'.u = RealVariables51[49];
  iceStorageInternalMelt.pipe.'mediums[10]'.u_der = RealVariables51[50];
  iceStorageInternalMelt.pipe.'mediums[10]'.state.p = RealVariables51[51];
  iceStorageInternalMelt.pipe.'mediums[10]'.state.T = RealVariables51[52];
  iceStorageInternalMelt.pipe.'mediums[10]'.T_degC = RealVariables51[53];
  iceStorageInternalMelt.pipe.'mediums[10]'.p_bar = RealVariables51[54];
  iceStorageInternalMelt.port_b_Tambient.T = RealVariables51[55];
  iceStorageInternalMelt.port_b_Tambient.Q_flow = RealVariables51[56];
  iceStorageInternalMelt.volumeFlowRate.port_a.m_flow = RealVariables51[57];
  iceStorageInternalMelt.volumeFlowRate.port_a.p = RealVariables51[58];
  iceStorageInternalMelt.volumeFlowRate.port_a.h_outflow = RealVariables51[59];
  iceStorageInternalMelt.volumeFlowRate.port_b.m_flow = RealVariables51[60];
  iceStorageInternalMelt.volumeFlowRate.port_b.p = RealVariables51[61];
  iceStorageInternalMelt.volumeFlowRate.port_b.h_outflow = RealVariables51[62];
  iceStorageInternalMelt.volumeFlowRate.m_flow = RealVariables51[63];
  iceStorageInternalMelt.volumeFlowRate.dp = RealVariables51[64];
  iceStorageInternalMelt.volumeFlowRate.V_flow = RealVariables51[65];
  iceStorageInternalMelt.volumeFlowRate.port_a_T = RealVariables51[66];
  iceStorageInternalMelt.volumeFlowRate.port_b_T = RealVariables51[67];
  iceStorageInternalMelt.'tubeToPCM[1]'.y = RealVariables51[68];
  iceStorageInternalMelt.'tubeToPCM[2]'.y = RealVariables51[69];
  iceStorageInternalMelt.'tubeToPCM[3]'.y = RealVariables51[70];
  iceStorageInternalMelt.'tubeToPCM[4]'.y = RealVariables51[71];
  iceStorageInternalMelt.'tubeToPCM[5]'.y = RealVariables51[72];
  iceStorageInternalMelt.'tubeToPCM[6]'.y = RealVariables51[73];
  iceStorageInternalMelt.'tubeToPCM[7]'.y = RealVariables51[74];
  iceStorageInternalMelt.'tubeToPCM[8]'.y = RealVariables51[75];
  iceStorageInternalMelt.'tubeToPCM[9]'.y = RealVariables51[76];
  iceStorageInternalMelt.'tubeToPCM[10]'.y = RealVariables51[77];
  iceStorageInternalMelt.'HTFtoTube[1]'.y = RealVariables51[78];
  iceStorageInternalMelt.'HTFtoTube[2]'.y = RealVariables51[79];
  iceStorageInternalMelt.'HTFtoTube[3]'.y = RealVariables51[80];
  iceStorageInternalMelt.'HTFtoTube[4]'.y = RealVariables51[81];
  iceStorageInternalMelt.'HTFtoTube[5]'.y = RealVariables51[82];
  iceStorageInternalMelt.'HTFtoTube[6]'.y = RealVariables51[83];
  iceStorageInternalMelt.'HTFtoTube[7]'.y = RealVariables51[84];
  iceStorageInternalMelt.'HTFtoTube[8]'.y = RealVariables51[85];
  iceStorageInternalMelt.'HTFtoTube[9]'.y = RealVariables51[86];
  iceStorageInternalMelt.'HTFtoTube[10]'.y = RealVariables51[87];
  iceStorageInternalMelt.port_b_Tfloor.T = RealVariables51[88];
  iceStorageInternalMelt.port_b_Tfloor.Q_flow = RealVariables51[89];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.T = RealVariables51[90];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.T_der = RealVariables51[91];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.Q_flow = RealVariables51[92];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.port.T = RealVariables51[93];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.port.Q_flow = RealVariables51[94];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.der_T = RealVariables51[95];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.C = RealVariables51[96];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.T = RealVariables51[97];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.T_der = RealVariables51[98];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.Q_flow = RealVariables51[99];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.port.T = RealVariables51[100];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.port.Q_flow = RealVariables52[1];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.der_T = RealVariables52[2];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.C = RealVariables52[3];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.T = RealVariables52[4];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.T_der = RealVariables52[5];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.Q_flow = RealVariables52[6];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.port.T = RealVariables52[7];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.port.Q_flow = RealVariables52[8];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.der_T = RealVariables52[9];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.C = RealVariables52[10];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.T = RealVariables52[11];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.T_der = RealVariables52[12];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.Q_flow = RealVariables52[13];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.port.T = RealVariables52[14];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.port.Q_flow = RealVariables52[15];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.der_T = RealVariables52[16];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.C = RealVariables52[17];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.Q_flow = RealVariables52[18];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.dT = RealVariables52[19];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.port_a.T = RealVariables52[20];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.port_a.Q_flow = RealVariables52[21];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.port_b.T = RealVariables52[22];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.port_b.Q_flow = RealVariables52[23];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.T = RealVariables52[24];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.G = RealVariables52[25];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.k = RealVariables52[26];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.Q_flow = RealVariables52[27];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.dT = RealVariables52[28];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.port_a.T = RealVariables52[29];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.port_a.Q_flow = RealVariables52[30];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.port_b.T = RealVariables52[31];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.port_b.Q_flow = RealVariables52[32];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.T = RealVariables52[33];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.G = RealVariables52[34];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.k = RealVariables52[35];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.Q_flow = RealVariables52[36];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.dT = RealVariables52[37];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.port_a.T = RealVariables52[38];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.port_a.Q_flow = RealVariables52[39];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.port_b.T = RealVariables52[40];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.port_b.Q_flow = RealVariables52[41];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.T = RealVariables52[42];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.G = RealVariables52[43];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.k = RealVariables52[44];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.Q_flow = RealVariables52[45];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.dT = RealVariables52[46];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.port_a.T = RealVariables52[47];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.port_a.Q_flow = RealVariables52[48];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.port_b.T = RealVariables52[49];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.port_b.Q_flow = RealVariables52[50];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.T = RealVariables52[51];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.G = RealVariables52[52];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.k = RealVariables52[53];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.Q_flow = RealVariables52[54];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.dT = RealVariables52[55];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.port_a.T = RealVariables52[56];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.port_a.Q_flow = RealVariables52[57];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.port_b.T = RealVariables52[58];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.port_b.Q_flow = RealVariables52[59];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.T = RealVariables52[60];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.G = RealVariables52[61];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.k = RealVariables52[62];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.Q_flow = RealVariables52[63];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.dT = RealVariables52[64];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.port_a.T = RealVariables52[65];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.port_a.Q_flow = RealVariables52[66];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.port_b.T = RealVariables52[67];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.port_b.Q_flow = RealVariables52[68];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.T = RealVariables52[69];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.G = RealVariables52[70];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.k = RealVariables52[71];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.Q_flow = RealVariables52[72];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.dT = RealVariables52[73];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.port_a.T = RealVariables52[74];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.port_a.Q_flow = RealVariables52[75];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.port_b.T = RealVariables52[76];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.port_b.Q_flow = RealVariables52[77];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.T = RealVariables52[78];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.G = RealVariables52[79];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.k = RealVariables52[80];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.Q_flow = RealVariables52[81];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.dT = RealVariables52[82];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.port_a.T = RealVariables52[83];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.port_a.Q_flow = RealVariables52[84];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.port_b.T = RealVariables52[85];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.port_b.Q_flow = RealVariables52[86];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.T = RealVariables52[87];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.G = RealVariables52[88];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.k = RealVariables52[89];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 1]'.T = RealVariables52[90];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 1]'.Q_flow = RealVariables52[91];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 2]'.T = RealVariables52[92];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 2]'.Q_flow = RealVariables52[93];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 3]'.T = RealVariables52[94];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 3]'.Q_flow = RealVariables52[95];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 4]'.T = RealVariables52[96];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 4]'.Q_flow = RealVariables52[97];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 5]'.T = RealVariables52[98];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 5]'.Q_flow = RealVariables52[99];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 6]'.T = RealVariables52[100];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 6]'.Q_flow = RealVariables53[1];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 7]'.T = RealVariables53[2];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 7]'.Q_flow = RealVariables53[3];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 8]'.T = RealVariables53[4];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 8]'.Q_flow = RealVariables53[5];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 9]'.T = RealVariables53[6];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 9]'.Q_flow = RealVariables53[7];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 10]'.T = RealVariables53[8];
  iceStorageInternalMelt.storageWall.'T_PCM[1, 10]'.Q_flow = RealVariables53[9];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 1]'.T = RealVariables53[10];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 1]'.Q_flow = RealVariables53[11];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 2]'.T = RealVariables53[12];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 2]'.Q_flow = RealVariables53[13];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 3]'.T = RealVariables53[14];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 3]'.Q_flow = RealVariables53[15];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 4]'.T = RealVariables53[16];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 4]'.Q_flow = RealVariables53[17];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 5]'.T = RealVariables53[18];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 5]'.Q_flow = RealVariables53[19];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 6]'.T = RealVariables53[20];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 6]'.Q_flow = RealVariables53[21];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 7]'.T = RealVariables53[22];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 7]'.Q_flow = RealVariables53[23];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 8]'.T = RealVariables53[24];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 8]'.Q_flow = RealVariables53[25];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 9]'.T = RealVariables53[26];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 9]'.Q_flow = RealVariables53[27];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 10]'.T = RealVariables53[28];
  iceStorageInternalMelt.storageWall.'T_PCM[2, 10]'.Q_flow = RealVariables53[29];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 1]'.T = RealVariables53[30];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 1]'.Q_flow = RealVariables53[31];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 2]'.T = RealVariables53[32];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 2]'.Q_flow = RealVariables53[33];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 3]'.T = RealVariables53[34];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 3]'.Q_flow = RealVariables53[35];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 4]'.T = RealVariables53[36];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 4]'.Q_flow = RealVariables53[37];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 5]'.T = RealVariables53[38];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 5]'.Q_flow = RealVariables53[39];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 6]'.T = RealVariables53[40];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 6]'.Q_flow = RealVariables53[41];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 7]'.T = RealVariables53[42];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 7]'.Q_flow = RealVariables53[43];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 8]'.T = RealVariables53[44];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 8]'.Q_flow = RealVariables53[45];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 9]'.T = RealVariables53[46];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 9]'.Q_flow = RealVariables53[47];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 10]'.T = RealVariables53[48];
  iceStorageInternalMelt.storageWall.'T_PCM[3, 10]'.Q_flow = RealVariables53[49];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 1]'.T = RealVariables53[50];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 1]'.Q_flow = RealVariables53[51];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 2]'.T = RealVariables53[52];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 2]'.Q_flow = RealVariables53[53];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 3]'.T = RealVariables53[54];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 3]'.Q_flow = RealVariables53[55];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 4]'.T = RealVariables53[56];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 4]'.Q_flow = RealVariables53[57];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 5]'.T = RealVariables53[58];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 5]'.Q_flow = RealVariables53[59];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 6]'.T = RealVariables53[60];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 6]'.Q_flow = RealVariables53[61];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 7]'.T = RealVariables53[62];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 7]'.Q_flow = RealVariables53[63];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 8]'.T = RealVariables53[64];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 8]'.Q_flow = RealVariables53[65];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 9]'.T = RealVariables53[66];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 9]'.Q_flow = RealVariables53[67];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 10]'.T = RealVariables53[68];
  iceStorageInternalMelt.storageWall.'T_PCM[4, 10]'.Q_flow = RealVariables53[69];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 1]'.T = RealVariables53[70];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 1]'.Q_flow = RealVariables53[71];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 2]'.T = RealVariables53[72];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 2]'.Q_flow = RealVariables53[73];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 3]'.T = RealVariables53[74];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 3]'.Q_flow = RealVariables53[75];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 4]'.T = RealVariables53[76];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 4]'.Q_flow = RealVariables53[77];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 5]'.T = RealVariables53[78];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 5]'.Q_flow = RealVariables53[79];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 6]'.T = RealVariables53[80];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 6]'.Q_flow = RealVariables53[81];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 7]'.T = RealVariables53[82];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 7]'.Q_flow = RealVariables53[83];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 8]'.T = RealVariables53[84];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 8]'.Q_flow = RealVariables53[85];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 9]'.T = RealVariables53[86];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 9]'.Q_flow = RealVariables53[87];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 10]'.T = RealVariables53[88];
  iceStorageInternalMelt.storageWall.'T_PCM[5, 10]'.Q_flow = RealVariables53[89];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 1]'.T = RealVariables53[90];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 1]'.Q_flow = RealVariables53[91];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 2]'.T = RealVariables53[92];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 2]'.Q_flow = RealVariables53[93];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 3]'.T = RealVariables53[94];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 3]'.Q_flow = RealVariables53[95];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 4]'.T = RealVariables53[96];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 4]'.Q_flow = RealVariables53[97];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 5]'.T = RealVariables53[98];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 5]'.Q_flow = RealVariables53[99];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 6]'.T = RealVariables53[100];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 6]'.Q_flow = RealVariables54[1];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 7]'.T = RealVariables54[2];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 7]'.Q_flow = RealVariables54[3];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 8]'.T = RealVariables54[4];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 8]'.Q_flow = RealVariables54[5];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 9]'.T = RealVariables54[6];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 9]'.Q_flow = RealVariables54[7];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 10]'.T = RealVariables54[8];
  iceStorageInternalMelt.storageWall.'T_PCM[6, 10]'.Q_flow = RealVariables54[9];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 1]'.T = RealVariables54[10];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 1]'.Q_flow = RealVariables54[11];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 2]'.T = RealVariables54[12];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 2]'.Q_flow = RealVariables54[13];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 3]'.T = RealVariables54[14];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 3]'.Q_flow = RealVariables54[15];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 4]'.T = RealVariables54[16];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 4]'.Q_flow = RealVariables54[17];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 5]'.T = RealVariables54[18];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 5]'.Q_flow = RealVariables54[19];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 6]'.T = RealVariables54[20];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 6]'.Q_flow = RealVariables54[21];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 7]'.T = RealVariables54[22];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 7]'.Q_flow = RealVariables54[23];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 8]'.T = RealVariables54[24];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 8]'.Q_flow = RealVariables54[25];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 9]'.T = RealVariables54[26];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 9]'.Q_flow = RealVariables54[27];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 10]'.T = RealVariables54[28];
  iceStorageInternalMelt.storageWall.'T_PCM[7, 10]'.Q_flow = RealVariables54[29];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 1]'.T = RealVariables54[30];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 1]'.Q_flow = RealVariables54[31];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 2]'.T = RealVariables54[32];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 2]'.Q_flow = RealVariables54[33];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 3]'.T = RealVariables54[34];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 3]'.Q_flow = RealVariables54[35];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 4]'.T = RealVariables54[36];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 4]'.Q_flow = RealVariables54[37];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 5]'.T = RealVariables54[38];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 5]'.Q_flow = RealVariables54[39];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 6]'.T = RealVariables54[40];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 6]'.Q_flow = RealVariables54[41];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 7]'.T = RealVariables54[42];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 7]'.Q_flow = RealVariables54[43];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 8]'.T = RealVariables54[44];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 8]'.Q_flow = RealVariables54[45];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 9]'.T = RealVariables54[46];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 9]'.Q_flow = RealVariables54[47];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 10]'.T = RealVariables54[48];
  iceStorageInternalMelt.storageWall.'T_PCM[8, 10]'.Q_flow = RealVariables54[49];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 1]'.T = RealVariables54[50];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 1]'.Q_flow = RealVariables54[51];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 2]'.T = RealVariables54[52];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 2]'.Q_flow = RealVariables54[53];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 3]'.T = RealVariables54[54];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 3]'.Q_flow = RealVariables54[55];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 4]'.T = RealVariables54[56];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 4]'.Q_flow = RealVariables54[57];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 5]'.T = RealVariables54[58];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 5]'.Q_flow = RealVariables54[59];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 6]'.T = RealVariables54[60];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 6]'.Q_flow = RealVariables54[61];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 7]'.T = RealVariables54[62];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 7]'.Q_flow = RealVariables54[63];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 8]'.T = RealVariables54[64];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 8]'.Q_flow = RealVariables54[65];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 9]'.T = RealVariables54[66];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 9]'.Q_flow = RealVariables54[67];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 10]'.T = RealVariables54[68];
  iceStorageInternalMelt.storageWall.'T_PCM[9, 10]'.Q_flow = RealVariables54[69];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 1]'.T = RealVariables54[70];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 1]'.Q_flow = RealVariables54[71];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 2]'.T = RealVariables54[72];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 2]'.Q_flow = RealVariables54[73];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 3]'.T = RealVariables54[74];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 3]'.Q_flow = RealVariables54[75];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 4]'.T = RealVariables54[76];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 4]'.Q_flow = RealVariables54[77];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 5]'.T = RealVariables54[78];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 5]'.Q_flow = RealVariables54[79];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 6]'.T = RealVariables54[80];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 6]'.Q_flow = RealVariables54[81];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 7]'.T = RealVariables54[82];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 7]'.Q_flow = RealVariables54[83];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 8]'.T = RealVariables54[84];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 8]'.Q_flow = RealVariables54[85];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 9]'.T = RealVariables54[86];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 9]'.Q_flow = RealVariables54[87];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 10]'.T = RealVariables54[88];
  iceStorageInternalMelt.storageWall.'T_PCM[10, 10]'.Q_flow = RealVariables54[89];
  iceStorageInternalMelt.storageWall.port_a_ambient.T = RealVariables54[90];
  iceStorageInternalMelt.storageWall.port_a_ambient.Q_flow = RealVariables54[91];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.T = RealVariables54[92];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.T_der = RealVariables54[93];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.Q_flow = RealVariables54[94];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.port.T = RealVariables54[95];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.port.Q_flow = RealVariables54[96];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.der_T = RealVariables54[97];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.C = RealVariables54[98];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.T = RealVariables54[99];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.T_der = RealVariables54[100];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.Q_flow = RealVariables55[1];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.port.T = RealVariables55[2];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.port.Q_flow = RealVariables55[3];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.der_T = RealVariables55[4];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.C = RealVariables55[5];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.Q_flow = RealVariables55[6];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.dT = RealVariables55[7];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.port_a.T = RealVariables55[8];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.port_a.Q_flow = RealVariables55[9];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.port_b.T = RealVariables55[10];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.port_b.Q_flow = RealVariables55[11];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.T = RealVariables55[12];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.G = RealVariables55[13];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.k = RealVariables55[14];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.Q_flow = RealVariables55[15];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.dT = RealVariables55[16];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.port_a.T = RealVariables55[17];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.port_a.Q_flow = RealVariables55[18];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.port_b.T = RealVariables55[19];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.port_b.Q_flow = RealVariables55[20];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.T = RealVariables55[21];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.G = RealVariables55[22];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.k = RealVariables55[23];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.Q_flow = RealVariables55[24];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.dT = RealVariables55[25];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.port_a.T = RealVariables55[26];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.port_a.Q_flow = RealVariables55[27];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.port_b.T = RealVariables55[28];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.port_b.Q_flow = RealVariables55[29];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.T = RealVariables55[30];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.G = RealVariables55[31];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.k = RealVariables55[32];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.Q_flow = RealVariables55[33];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.dT = RealVariables55[34];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.port_a.T = RealVariables55[35];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.port_a.Q_flow = RealVariables55[36];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.port_b.T = RealVariables55[37];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.port_b.Q_flow = RealVariables55[38];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.T = RealVariables55[39];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.G = RealVariables55[40];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.k = RealVariables55[41];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 1]'.T = RealVariables55[42];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 1]'.Q_flow = RealVariables55[43];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 2]'.T = RealVariables55[44];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 2]'.Q_flow = RealVariables55[45];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 3]'.T = RealVariables55[46];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 3]'.Q_flow = RealVariables55[47];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 4]'.T = RealVariables55[48];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 4]'.Q_flow = RealVariables55[49];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 5]'.T = RealVariables55[50];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 5]'.Q_flow = RealVariables55[51];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 6]'.T = RealVariables55[52];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 6]'.Q_flow = RealVariables55[53];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 7]'.T = RealVariables55[54];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 7]'.Q_flow = RealVariables55[55];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 8]'.T = RealVariables55[56];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 8]'.Q_flow = RealVariables55[57];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 9]'.T = RealVariables55[58];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 9]'.Q_flow = RealVariables55[59];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 10]'.T = RealVariables55[60];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[1, 10]'.Q_flow = RealVariables55[61];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 1]'.T = RealVariables55[62];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 1]'.Q_flow = RealVariables55[63];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 2]'.T = RealVariables55[64];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 2]'.Q_flow = RealVariables55[65];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 3]'.T = RealVariables55[66];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 3]'.Q_flow = RealVariables55[67];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 4]'.T = RealVariables55[68];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 4]'.Q_flow = RealVariables55[69];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 5]'.T = RealVariables55[70];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 5]'.Q_flow = RealVariables55[71];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 6]'.T = RealVariables55[72];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 6]'.Q_flow = RealVariables55[73];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 7]'.T = RealVariables55[74];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 7]'.Q_flow = RealVariables55[75];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 8]'.T = RealVariables55[76];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 8]'.Q_flow = RealVariables55[77];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 9]'.T = RealVariables55[78];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 9]'.Q_flow = RealVariables55[79];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 10]'.T = RealVariables55[80];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[2, 10]'.Q_flow = RealVariables55[81];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 1]'.T = RealVariables55[82];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 1]'.Q_flow = RealVariables55[83];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 2]'.T = RealVariables55[84];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 2]'.Q_flow = RealVariables55[85];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 3]'.T = RealVariables55[86];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 3]'.Q_flow = RealVariables55[87];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 4]'.T = RealVariables55[88];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 4]'.Q_flow = RealVariables55[89];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 5]'.T = RealVariables55[90];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 5]'.Q_flow = RealVariables55[91];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 6]'.T = RealVariables55[92];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 6]'.Q_flow = RealVariables55[93];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 7]'.T = RealVariables55[94];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 7]'.Q_flow = RealVariables55[95];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 8]'.T = RealVariables55[96];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 8]'.Q_flow = RealVariables55[97];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 9]'.T = RealVariables55[98];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 9]'.Q_flow = RealVariables55[99];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 10]'.T = RealVariables55[100];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[3, 10]'.Q_flow = RealVariables56[1];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 1]'.T = RealVariables56[2];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 1]'.Q_flow = RealVariables56[3];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 2]'.T = RealVariables56[4];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 2]'.Q_flow = RealVariables56[5];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 3]'.T = RealVariables56[6];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 3]'.Q_flow = RealVariables56[7];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 4]'.T = RealVariables56[8];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 4]'.Q_flow = RealVariables56[9];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 5]'.T = RealVariables56[10];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 5]'.Q_flow = RealVariables56[11];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 6]'.T = RealVariables56[12];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 6]'.Q_flow = RealVariables56[13];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 7]'.T = RealVariables56[14];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 7]'.Q_flow = RealVariables56[15];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 8]'.T = RealVariables56[16];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 8]'.Q_flow = RealVariables56[17];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 9]'.T = RealVariables56[18];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 9]'.Q_flow = RealVariables56[19];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 10]'.T = RealVariables56[20];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[4, 10]'.Q_flow = RealVariables56[21];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 1]'.T = RealVariables56[22];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 1]'.Q_flow = RealVariables56[23];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 2]'.T = RealVariables56[24];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 2]'.Q_flow = RealVariables56[25];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 3]'.T = RealVariables56[26];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 3]'.Q_flow = RealVariables56[27];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 4]'.T = RealVariables56[28];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 4]'.Q_flow = RealVariables56[29];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 5]'.T = RealVariables56[30];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 5]'.Q_flow = RealVariables56[31];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 6]'.T = RealVariables56[32];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 6]'.Q_flow = RealVariables56[33];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 7]'.T = RealVariables56[34];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 7]'.Q_flow = RealVariables56[35];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 8]'.T = RealVariables56[36];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 8]'.Q_flow = RealVariables56[37];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 9]'.T = RealVariables56[38];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 9]'.Q_flow = RealVariables56[39];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 10]'.T = RealVariables56[40];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[5, 10]'.Q_flow = RealVariables56[41];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 1]'.T = RealVariables56[42];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 1]'.Q_flow = RealVariables56[43];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 2]'.T = RealVariables56[44];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 2]'.Q_flow = RealVariables56[45];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 3]'.T = RealVariables56[46];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 3]'.Q_flow = RealVariables56[47];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 4]'.T = RealVariables56[48];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 4]'.Q_flow = RealVariables56[49];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 5]'.T = RealVariables56[50];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 5]'.Q_flow = RealVariables56[51];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 6]'.T = RealVariables56[52];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 6]'.Q_flow = RealVariables56[53];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 7]'.T = RealVariables56[54];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 7]'.Q_flow = RealVariables56[55];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 8]'.T = RealVariables56[56];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 8]'.Q_flow = RealVariables56[57];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 9]'.T = RealVariables56[58];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 9]'.Q_flow = RealVariables56[59];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 10]'.T = RealVariables56[60];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[6, 10]'.Q_flow = RealVariables56[61];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 1]'.T = RealVariables56[62];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 1]'.Q_flow = RealVariables56[63];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 2]'.T = RealVariables56[64];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 2]'.Q_flow = RealVariables56[65];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 3]'.T = RealVariables56[66];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 3]'.Q_flow = RealVariables56[67];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 4]'.T = RealVariables56[68];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 4]'.Q_flow = RealVariables56[69];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 5]'.T = RealVariables56[70];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 5]'.Q_flow = RealVariables56[71];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 6]'.T = RealVariables56[72];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 6]'.Q_flow = RealVariables56[73];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 7]'.T = RealVariables56[74];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 7]'.Q_flow = RealVariables56[75];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 8]'.T = RealVariables56[76];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 8]'.Q_flow = RealVariables56[77];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 9]'.T = RealVariables56[78];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 9]'.Q_flow = RealVariables56[79];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 10]'.T = RealVariables56[80];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[7, 10]'.Q_flow = RealVariables56[81];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 1]'.T = RealVariables56[82];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 1]'.Q_flow = RealVariables56[83];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 2]'.T = RealVariables56[84];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 2]'.Q_flow = RealVariables56[85];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 3]'.T = RealVariables56[86];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 3]'.Q_flow = RealVariables56[87];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 4]'.T = RealVariables56[88];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 4]'.Q_flow = RealVariables56[89];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 5]'.T = RealVariables56[90];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 5]'.Q_flow = RealVariables56[91];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 6]'.T = RealVariables56[92];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 6]'.Q_flow = RealVariables56[93];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 7]'.T = RealVariables56[94];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 7]'.Q_flow = RealVariables56[95];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 8]'.T = RealVariables56[96];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 8]'.Q_flow = RealVariables56[97];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 9]'.T = RealVariables56[98];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 9]'.Q_flow = RealVariables56[99];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 10]'.T = RealVariables56[100];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[8, 10]'.Q_flow = RealVariables57[1];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 1]'.T = RealVariables57[2];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 1]'.Q_flow = RealVariables57[3];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 2]'.T = RealVariables57[4];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 2]'.Q_flow = RealVariables57[5];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 3]'.T = RealVariables57[6];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 3]'.Q_flow = RealVariables57[7];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 4]'.T = RealVariables57[8];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 4]'.Q_flow = RealVariables57[9];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 5]'.T = RealVariables57[10];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 5]'.Q_flow = RealVariables57[11];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 6]'.T = RealVariables57[12];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 6]'.Q_flow = RealVariables57[13];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 7]'.T = RealVariables57[14];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 7]'.Q_flow = RealVariables57[15];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 8]'.T = RealVariables57[16];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 8]'.Q_flow = RealVariables57[17];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 9]'.T = RealVariables57[18];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 9]'.Q_flow = RealVariables57[19];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 10]'.T = RealVariables57[20];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[9, 10]'.Q_flow = RealVariables57[21];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 1]'.T = RealVariables57[22];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 1]'.Q_flow = RealVariables57[23];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 2]'.T = RealVariables57[24];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 2]'.Q_flow = RealVariables57[25];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 3]'.T = RealVariables57[26];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 3]'.Q_flow = RealVariables57[27];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 4]'.T = RealVariables57[28];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 4]'.Q_flow = RealVariables57[29];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 5]'.T = RealVariables57[30];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 5]'.Q_flow = RealVariables57[31];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 6]'.T = RealVariables57[32];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 6]'.Q_flow = RealVariables57[33];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 7]'.T = RealVariables57[34];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 7]'.Q_flow = RealVariables57[35];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 8]'.T = RealVariables57[36];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 8]'.Q_flow = RealVariables57[37];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 9]'.T = RealVariables57[38];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 9]'.Q_flow = RealVariables57[39];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 10]'.T = RealVariables57[40];
  iceStorageInternalMelt.storageWall.midTemperature.'port_a[10, 10]'.Q_flow = RealVariables57[41];
  iceStorageInternalMelt.storageWall.midTemperature.port_b.T = RealVariables57[42];
  iceStorageInternalMelt.storageWall.midTemperature.port_b.Q_flow = RealVariables57[43];
  iceStorageInternalMelt.storageWall.port_a_floor.T = RealVariables57[44];
  iceStorageInternalMelt.storageWall.port_a_floor.Q_flow = RealVariables57[45];
  iceStorageInternalMelt.PCM_T = RealVariables57[46];
  iceStorageInternalMelt.x_liquid_Total = RealVariables57[47];
  iceStorageInternalMelt.'A_PCMs_out[1]' = RealVariables57[48];
  iceStorageInternalMelt.'A_PCMs_out[2]' = RealVariables57[49];
  iceStorageInternalMelt.'A_PCMs_out[3]' = RealVariables57[50];
  iceStorageInternalMelt.'A_PCMs_out[4]' = RealVariables57[51];
  iceStorageInternalMelt.'A_PCMs_out[5]' = RealVariables57[52];
  iceStorageInternalMelt.'A_PCMs_out[6]' = RealVariables57[53];
  iceStorageInternalMelt.'A_PCMs_out[7]' = RealVariables57[54];
  iceStorageInternalMelt.'A_PCMs_out[8]' = RealVariables57[55];
  iceStorageInternalMelt.'A_PCMs_out[9]' = RealVariables57[56];
  iceStorageInternalMelt.'A_PCMs_out[10]' = RealVariables57[57];
  iceStorageInternalMelt.A_PCMs_total = RealVariables57[58];
  iceStorageInternalMelt.'A_PCMl_out[1]' = RealVariables57[59];
  iceStorageInternalMelt.'A_PCMl_out[2]' = RealVariables57[60];
  iceStorageInternalMelt.'A_PCMl_out[3]' = RealVariables57[61];
  iceStorageInternalMelt.'A_PCMl_out[4]' = RealVariables57[62];
  iceStorageInternalMelt.'A_PCMl_out[5]' = RealVariables57[63];
  iceStorageInternalMelt.'A_PCMl_out[6]' = RealVariables57[64];
  iceStorageInternalMelt.'A_PCMl_out[7]' = RealVariables57[65];
  iceStorageInternalMelt.'A_PCMl_out[8]' = RealVariables57[66];
  iceStorageInternalMelt.'A_PCMl_out[9]' = RealVariables57[67];
  iceStorageInternalMelt.'A_PCMl_out[10]' = RealVariables57[68];
  iceStorageInternalMelt.A_PCMl_total = RealVariables57[69];
  iceStorageInternalMelt.T_HTFo = RealVariables57[70];
  iceStorageInternalMelt.T_HTFi = RealVariables57[71];
  iceStorageInternalMelt.'f[1]' = RealVariables57[72];
  iceStorageInternalMelt.'f[2]' = RealVariables57[73];
  iceStorageInternalMelt.'f[3]' = RealVariables57[74];
  iceStorageInternalMelt.'f[4]' = RealVariables57[75];
  iceStorageInternalMelt.'f[5]' = RealVariables57[76];
  iceStorageInternalMelt.'f[6]' = RealVariables57[77];
  iceStorageInternalMelt.'f[7]' = RealVariables57[78];
  iceStorageInternalMelt.'f[8]' = RealVariables57[79];
  iceStorageInternalMelt.'f[9]' = RealVariables57[80];
  iceStorageInternalMelt.'f[10]' = RealVariables57[81];
  iceStorageInternalMelt.'AR[1]' = RealVariables57[82];
  iceStorageInternalMelt.'AR[2]' = RealVariables57[83];
  iceStorageInternalMelt.'AR[3]' = RealVariables57[84];
  iceStorageInternalMelt.'AR[4]' = RealVariables57[85];
  iceStorageInternalMelt.'AR[5]' = RealVariables57[86];
  iceStorageInternalMelt.'AR[6]' = RealVariables57[87];
  iceStorageInternalMelt.'AR[7]' = RealVariables57[88];
  iceStorageInternalMelt.'AR[8]' = RealVariables57[89];
  iceStorageInternalMelt.'AR[9]' = RealVariables57[90];
  iceStorageInternalMelt.'AR[10]' = RealVariables57[91];
  outlet_HTF.medium.p = RealVariables57[92];
  outlet_HTF.medium.h = RealVariables57[93];
  outlet_HTF.medium.T = RealVariables57[94];
  outlet_HTF.medium.state.p = RealVariables57[95];
  outlet_HTF.medium.state.T = RealVariables57[96];
  outlet_HTF.'ports[1]'.m_flow = RealVariables57[97];
  outlet_HTF.'ports[1]'.p = RealVariables57[98];
  inlet_HTF.medium.p = RealVariables57[99];
  inlet_HTF.medium.h = RealVariables57[100];
  inlet_HTF.medium.d = RealVariables58[1];
  inlet_HTF.medium.T = RealVariables58[2];
  inlet_HTF.medium.u = RealVariables58[3];
  inlet_HTF.medium.state.p = RealVariables58[4];
  inlet_HTF.medium.state.T = RealVariables58[5];
  inlet_HTF.medium.T_degC = RealVariables58[6];
  inlet_HTF.medium.p_bar = RealVariables58[7];
  inlet_HTF.'ports[1]'.m_flow = RealVariables58[8];
  inlet_HTF.'ports[1]'.p = RealVariables58[9];
  inlet_HTF.'ports[1]'.h_outflow = RealVariables58[10];
  inlet_HTF.m_flow_in = RealVariables58[11];
  inlet_HTF.T_in = RealVariables58[12];
  m_inlet_HTF_T.port.p = RealVariables58[13];
  m_inlet_HTF_T.T = RealVariables58[14];
  m_outlet_HTF_T.port.p = RealVariables58[15];
  m_outlet_HTF_T.T = RealVariables58[16];
  floorTemperature.port.T = RealVariables58[17];
  floorTemperature.port.Q_flow = RealVariables58[18];
  floorTemperature.T = RealVariables58[19];
  'system'.T_start = RealDependentParameters1[1];
  'system'.m_flow_nominal = RealDependentParameters1[2];
  iceStorageInternalMelt.D_tube_in = RealDependentParameters1[3];
  iceStorageInternalMelt.p_PCM = RealDependentParameters1[4];
  iceStorageInternalMelt.m_PCM_tube = RealDependentParameters1[5];
  iceStorageInternalMelt.D_tube_out = RealDependentParameters1[6];
  iceStorageInternalMelt.a = RealDependentParameters1[7];
  iceStorageInternalMelt.b = RealDependentParameters1[8];
  iceStorageInternalMelt.vol = RealDependentParameters1[9];
  iceStorageInternalMelt.h = RealDependentParameters1[10];
  iceStorageInternalMelt.w = RealDependentParameters1[11];
  iceStorageInternalMelt.e = RealDependentParameters1[12];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.p_PCM = RealDependentParameters1[13];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.m_PCM = RealDependentParameters1[14];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.D_tube_out = RealDependentParameters1[15];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.D_smax = RealDependentParameters1[16];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.D_lmax = RealDependentParameters1[17];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.p_PCM = RealDependentParameters1[18];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.m_PCM = RealDependentParameters1[19];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.D_tube_out = RealDependentParameters1[20];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.D_smax = RealDependentParameters1[21];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.D_lmax = RealDependentParameters1[22];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.p_PCM = RealDependentParameters1[23];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.m_PCM = RealDependentParameters1[24];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.D_tube_out = RealDependentParameters1[25];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.D_smax = RealDependentParameters1[26];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.D_lmax = RealDependentParameters1[27];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.p_PCM = RealDependentParameters1[28];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.m_PCM = RealDependentParameters1[29];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.D_tube_out = RealDependentParameters1[30];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.D_smax = RealDependentParameters1[31];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.D_lmax = RealDependentParameters1[32];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.p_PCM = RealDependentParameters1[33];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.m_PCM = RealDependentParameters1[34];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.D_tube_out = RealDependentParameters1[35];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.D_smax = RealDependentParameters1[36];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.D_lmax = RealDependentParameters1[37];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.p_PCM = RealDependentParameters1[38];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.m_PCM = RealDependentParameters1[39];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.D_tube_out = RealDependentParameters1[40];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.D_smax = RealDependentParameters1[41];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.D_lmax = RealDependentParameters1[42];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.p_PCM = RealDependentParameters1[43];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.m_PCM = RealDependentParameters1[44];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.D_tube_out = RealDependentParameters1[45];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.D_smax = RealDependentParameters1[46];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.D_lmax = RealDependentParameters1[47];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.p_PCM = RealDependentParameters1[48];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.m_PCM = RealDependentParameters1[49];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.D_tube_out = RealDependentParameters1[50];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.D_smax = RealDependentParameters1[51];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.D_lmax = RealDependentParameters1[52];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.p_PCM = RealDependentParameters1[53];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.m_PCM = RealDependentParameters1[54];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.D_tube_out = RealDependentParameters1[55];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.D_smax = RealDependentParameters1[56];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.D_lmax = RealDependentParameters1[57];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.p_PCM = RealDependentParameters1[58];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.m_PCM = RealDependentParameters1[59];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.D_tube_out = RealDependentParameters1[60];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.D_smax = RealDependentParameters1[61];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.D_lmax = RealDependentParameters1[62];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.p_PCM = RealDependentParameters1[63];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.m_PCM = RealDependentParameters1[64];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.D_tube_out = RealDependentParameters1[65];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.D_smax = RealDependentParameters1[66];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.D_lmax = RealDependentParameters1[67];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.p_PCM = RealDependentParameters1[68];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.m_PCM = RealDependentParameters1[69];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.D_tube_out = RealDependentParameters1[70];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.D_smax = RealDependentParameters1[71];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.D_lmax = RealDependentParameters1[72];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.p_PCM = RealDependentParameters1[73];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.m_PCM = RealDependentParameters1[74];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.D_tube_out = RealDependentParameters1[75];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.D_smax = RealDependentParameters1[76];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.D_lmax = RealDependentParameters1[77];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.p_PCM = RealDependentParameters1[78];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.m_PCM = RealDependentParameters1[79];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.D_tube_out = RealDependentParameters1[80];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.D_smax = RealDependentParameters1[81];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.D_lmax = RealDependentParameters1[82];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.p_PCM = RealDependentParameters1[83];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.m_PCM = RealDependentParameters1[84];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.D_tube_out = RealDependentParameters1[85];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.D_smax = RealDependentParameters1[86];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.D_lmax = RealDependentParameters1[87];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.p_PCM = RealDependentParameters1[88];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.m_PCM = RealDependentParameters1[89];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.D_tube_out = RealDependentParameters1[90];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.D_smax = RealDependentParameters1[91];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.D_lmax = RealDependentParameters1[92];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.p_PCM = RealDependentParameters1[93];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.m_PCM = RealDependentParameters1[94];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.D_tube_out = RealDependentParameters1[95];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.D_smax = RealDependentParameters1[96];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.D_lmax = RealDependentParameters1[97];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.p_PCM = RealDependentParameters1[98];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.m_PCM = RealDependentParameters1[99];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.D_tube_out = RealDependentParameters1[100];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.D_smax = RealDependentParameters2[1];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.D_lmax = RealDependentParameters2[2];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.p_PCM = RealDependentParameters2[3];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.m_PCM = RealDependentParameters2[4];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.D_tube_out = RealDependentParameters2[5];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.D_smax = RealDependentParameters2[6];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.D_lmax = RealDependentParameters2[7];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.p_PCM = RealDependentParameters2[8];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.m_PCM = RealDependentParameters2[9];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.D_tube_out = RealDependentParameters2[10];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.D_smax = RealDependentParameters2[11];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.D_lmax = RealDependentParameters2[12];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.p_PCM = RealDependentParameters2[13];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.m_PCM = RealDependentParameters2[14];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.D_tube_out = RealDependentParameters2[15];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.D_smax = RealDependentParameters2[16];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.D_lmax = RealDependentParameters2[17];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.p_PCM = RealDependentParameters2[18];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.m_PCM = RealDependentParameters2[19];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.D_tube_out = RealDependentParameters2[20];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.D_smax = RealDependentParameters2[21];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.D_lmax = RealDependentParameters2[22];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.p_PCM = RealDependentParameters2[23];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.m_PCM = RealDependentParameters2[24];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.D_tube_out = RealDependentParameters2[25];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.D_smax = RealDependentParameters2[26];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.D_lmax = RealDependentParameters2[27];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.p_PCM = RealDependentParameters2[28];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.m_PCM = RealDependentParameters2[29];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.D_tube_out = RealDependentParameters2[30];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.D_smax = RealDependentParameters2[31];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.D_lmax = RealDependentParameters2[32];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.p_PCM = RealDependentParameters2[33];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.m_PCM = RealDependentParameters2[34];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.D_tube_out = RealDependentParameters2[35];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.D_smax = RealDependentParameters2[36];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.D_lmax = RealDependentParameters2[37];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.p_PCM = RealDependentParameters2[38];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.m_PCM = RealDependentParameters2[39];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.D_tube_out = RealDependentParameters2[40];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.D_smax = RealDependentParameters2[41];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.D_lmax = RealDependentParameters2[42];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.p_PCM = RealDependentParameters2[43];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.m_PCM = RealDependentParameters2[44];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.D_tube_out = RealDependentParameters2[45];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.D_smax = RealDependentParameters2[46];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.D_lmax = RealDependentParameters2[47];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.p_PCM = RealDependentParameters2[48];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.m_PCM = RealDependentParameters2[49];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.D_tube_out = RealDependentParameters2[50];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.D_smax = RealDependentParameters2[51];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.D_lmax = RealDependentParameters2[52];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.p_PCM = RealDependentParameters2[53];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.m_PCM = RealDependentParameters2[54];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.D_tube_out = RealDependentParameters2[55];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.D_smax = RealDependentParameters2[56];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.D_lmax = RealDependentParameters2[57];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.p_PCM = RealDependentParameters2[58];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.m_PCM = RealDependentParameters2[59];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.D_tube_out = RealDependentParameters2[60];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.D_smax = RealDependentParameters2[61];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.D_lmax = RealDependentParameters2[62];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.p_PCM = RealDependentParameters2[63];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.m_PCM = RealDependentParameters2[64];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.D_tube_out = RealDependentParameters2[65];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.D_smax = RealDependentParameters2[66];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.D_lmax = RealDependentParameters2[67];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.p_PCM = RealDependentParameters2[68];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.m_PCM = RealDependentParameters2[69];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.D_tube_out = RealDependentParameters2[70];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.D_smax = RealDependentParameters2[71];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.D_lmax = RealDependentParameters2[72];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.p_PCM = RealDependentParameters2[73];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.m_PCM = RealDependentParameters2[74];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.D_tube_out = RealDependentParameters2[75];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.D_smax = RealDependentParameters2[76];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.D_lmax = RealDependentParameters2[77];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.p_PCM = RealDependentParameters2[78];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.m_PCM = RealDependentParameters2[79];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.D_tube_out = RealDependentParameters2[80];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.D_smax = RealDependentParameters2[81];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.D_lmax = RealDependentParameters2[82];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.p_PCM = RealDependentParameters2[83];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.m_PCM = RealDependentParameters2[84];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.D_tube_out = RealDependentParameters2[85];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.D_smax = RealDependentParameters2[86];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.D_lmax = RealDependentParameters2[87];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.p_PCM = RealDependentParameters2[88];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.m_PCM = RealDependentParameters2[89];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.D_tube_out = RealDependentParameters2[90];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.D_smax = RealDependentParameters2[91];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.D_lmax = RealDependentParameters2[92];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.p_PCM = RealDependentParameters2[93];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.m_PCM = RealDependentParameters2[94];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.D_tube_out = RealDependentParameters2[95];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.D_smax = RealDependentParameters2[96];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.D_lmax = RealDependentParameters2[97];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.p_PCM = RealDependentParameters2[98];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.m_PCM = RealDependentParameters2[99];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.D_tube_out = RealDependentParameters2[100];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.D_smax = RealDependentParameters3[1];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.D_lmax = RealDependentParameters3[2];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.p_PCM = RealDependentParameters3[3];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.m_PCM = RealDependentParameters3[4];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.D_tube_out = RealDependentParameters3[5];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.D_smax = RealDependentParameters3[6];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.D_lmax = RealDependentParameters3[7];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.p_PCM = RealDependentParameters3[8];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.m_PCM = RealDependentParameters3[9];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.D_tube_out = RealDependentParameters3[10];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.D_smax = RealDependentParameters3[11];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.D_lmax = RealDependentParameters3[12];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.p_PCM = RealDependentParameters3[13];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.m_PCM = RealDependentParameters3[14];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.D_tube_out = RealDependentParameters3[15];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.D_smax = RealDependentParameters3[16];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.D_lmax = RealDependentParameters3[17];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.p_PCM = RealDependentParameters3[18];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.m_PCM = RealDependentParameters3[19];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.D_tube_out = RealDependentParameters3[20];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.D_smax = RealDependentParameters3[21];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.D_lmax = RealDependentParameters3[22];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.p_PCM = RealDependentParameters3[23];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.m_PCM = RealDependentParameters3[24];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.D_tube_out = RealDependentParameters3[25];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.D_smax = RealDependentParameters3[26];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.D_lmax = RealDependentParameters3[27];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.p_PCM = RealDependentParameters3[28];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.m_PCM = RealDependentParameters3[29];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.D_tube_out = RealDependentParameters3[30];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.D_smax = RealDependentParameters3[31];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.D_lmax = RealDependentParameters3[32];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.p_PCM = RealDependentParameters3[33];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.m_PCM = RealDependentParameters3[34];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.D_tube_out = RealDependentParameters3[35];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.D_smax = RealDependentParameters3[36];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.D_lmax = RealDependentParameters3[37];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.p_PCM = RealDependentParameters3[38];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.m_PCM = RealDependentParameters3[39];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.D_tube_out = RealDependentParameters3[40];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.D_smax = RealDependentParameters3[41];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.D_lmax = RealDependentParameters3[42];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.p_PCM = RealDependentParameters3[43];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.m_PCM = RealDependentParameters3[44];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.D_tube_out = RealDependentParameters3[45];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.D_smax = RealDependentParameters3[46];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.D_lmax = RealDependentParameters3[47];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.p_PCM = RealDependentParameters3[48];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.m_PCM = RealDependentParameters3[49];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.D_tube_out = RealDependentParameters3[50];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.D_smax = RealDependentParameters3[51];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.D_lmax = RealDependentParameters3[52];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.p_PCM = RealDependentParameters3[53];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.m_PCM = RealDependentParameters3[54];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.D_tube_out = RealDependentParameters3[55];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.D_smax = RealDependentParameters3[56];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.D_lmax = RealDependentParameters3[57];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.p_PCM = RealDependentParameters3[58];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.m_PCM = RealDependentParameters3[59];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.D_tube_out = RealDependentParameters3[60];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.D_smax = RealDependentParameters3[61];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.D_lmax = RealDependentParameters3[62];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.p_PCM = RealDependentParameters3[63];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.m_PCM = RealDependentParameters3[64];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.D_tube_out = RealDependentParameters3[65];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.D_smax = RealDependentParameters3[66];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.D_lmax = RealDependentParameters3[67];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.p_PCM = RealDependentParameters3[68];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.m_PCM = RealDependentParameters3[69];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.D_tube_out = RealDependentParameters3[70];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.D_smax = RealDependentParameters3[71];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.D_lmax = RealDependentParameters3[72];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.p_PCM = RealDependentParameters3[73];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.m_PCM = RealDependentParameters3[74];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.D_tube_out = RealDependentParameters3[75];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.D_smax = RealDependentParameters3[76];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.D_lmax = RealDependentParameters3[77];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.p_PCM = RealDependentParameters3[78];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.m_PCM = RealDependentParameters3[79];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.D_tube_out = RealDependentParameters3[80];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.D_smax = RealDependentParameters3[81];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.D_lmax = RealDependentParameters3[82];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.p_PCM = RealDependentParameters3[83];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.m_PCM = RealDependentParameters3[84];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.D_tube_out = RealDependentParameters3[85];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.D_smax = RealDependentParameters3[86];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.D_lmax = RealDependentParameters3[87];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.p_PCM = RealDependentParameters3[88];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.m_PCM = RealDependentParameters3[89];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.D_tube_out = RealDependentParameters3[90];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.D_smax = RealDependentParameters3[91];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.D_lmax = RealDependentParameters3[92];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.p_PCM = RealDependentParameters3[93];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.m_PCM = RealDependentParameters3[94];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.D_tube_out = RealDependentParameters3[95];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.D_smax = RealDependentParameters3[96];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.D_lmax = RealDependentParameters3[97];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.p_PCM = RealDependentParameters3[98];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.m_PCM = RealDependentParameters3[99];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.D_tube_out = RealDependentParameters3[100];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.D_smax = RealDependentParameters4[1];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.D_lmax = RealDependentParameters4[2];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.p_PCM = RealDependentParameters4[3];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.m_PCM = RealDependentParameters4[4];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.D_tube_out = RealDependentParameters4[5];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.D_smax = RealDependentParameters4[6];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.D_lmax = RealDependentParameters4[7];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.p_PCM = RealDependentParameters4[8];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.m_PCM = RealDependentParameters4[9];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.D_tube_out = RealDependentParameters4[10];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.D_smax = RealDependentParameters4[11];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.D_lmax = RealDependentParameters4[12];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.p_PCM = RealDependentParameters4[13];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.m_PCM = RealDependentParameters4[14];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.D_tube_out = RealDependentParameters4[15];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.D_smax = RealDependentParameters4[16];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.D_lmax = RealDependentParameters4[17];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.p_PCM = RealDependentParameters4[18];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.m_PCM = RealDependentParameters4[19];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.D_tube_out = RealDependentParameters4[20];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.D_smax = RealDependentParameters4[21];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.D_lmax = RealDependentParameters4[22];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.p_PCM = RealDependentParameters4[23];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.m_PCM = RealDependentParameters4[24];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.D_tube_out = RealDependentParameters4[25];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.D_smax = RealDependentParameters4[26];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.D_lmax = RealDependentParameters4[27];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.p_PCM = RealDependentParameters4[28];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.m_PCM = RealDependentParameters4[29];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.D_tube_out = RealDependentParameters4[30];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.D_smax = RealDependentParameters4[31];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.D_lmax = RealDependentParameters4[32];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.p_PCM = RealDependentParameters4[33];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.m_PCM = RealDependentParameters4[34];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.D_tube_out = RealDependentParameters4[35];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.D_smax = RealDependentParameters4[36];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.D_lmax = RealDependentParameters4[37];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.p_PCM = RealDependentParameters4[38];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.m_PCM = RealDependentParameters4[39];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.D_tube_out = RealDependentParameters4[40];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.D_smax = RealDependentParameters4[41];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.D_lmax = RealDependentParameters4[42];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.p_PCM = RealDependentParameters4[43];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.m_PCM = RealDependentParameters4[44];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.D_tube_out = RealDependentParameters4[45];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.D_smax = RealDependentParameters4[46];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.D_lmax = RealDependentParameters4[47];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.p_PCM = RealDependentParameters4[48];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.m_PCM = RealDependentParameters4[49];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.D_tube_out = RealDependentParameters4[50];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.D_smax = RealDependentParameters4[51];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.D_lmax = RealDependentParameters4[52];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.p_PCM = RealDependentParameters4[53];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.m_PCM = RealDependentParameters4[54];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.D_tube_out = RealDependentParameters4[55];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.D_smax = RealDependentParameters4[56];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.D_lmax = RealDependentParameters4[57];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.p_PCM = RealDependentParameters4[58];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.m_PCM = RealDependentParameters4[59];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.D_tube_out = RealDependentParameters4[60];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.D_smax = RealDependentParameters4[61];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.D_lmax = RealDependentParameters4[62];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.p_PCM = RealDependentParameters4[63];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.m_PCM = RealDependentParameters4[64];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.D_tube_out = RealDependentParameters4[65];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.D_smax = RealDependentParameters4[66];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.D_lmax = RealDependentParameters4[67];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.p_PCM = RealDependentParameters4[68];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.m_PCM = RealDependentParameters4[69];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.D_tube_out = RealDependentParameters4[70];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.D_smax = RealDependentParameters4[71];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.D_lmax = RealDependentParameters4[72];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.p_PCM = RealDependentParameters4[73];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.m_PCM = RealDependentParameters4[74];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.D_tube_out = RealDependentParameters4[75];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.D_smax = RealDependentParameters4[76];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.D_lmax = RealDependentParameters4[77];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.p_PCM = RealDependentParameters4[78];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.m_PCM = RealDependentParameters4[79];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.D_tube_out = RealDependentParameters4[80];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.D_smax = RealDependentParameters4[81];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.D_lmax = RealDependentParameters4[82];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.p_PCM = RealDependentParameters4[83];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.m_PCM = RealDependentParameters4[84];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.D_tube_out = RealDependentParameters4[85];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.D_smax = RealDependentParameters4[86];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.D_lmax = RealDependentParameters4[87];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.p_PCM = RealDependentParameters4[88];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.m_PCM = RealDependentParameters4[89];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.D_tube_out = RealDependentParameters4[90];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.D_smax = RealDependentParameters4[91];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.D_lmax = RealDependentParameters4[92];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.p_PCM = RealDependentParameters4[93];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.m_PCM = RealDependentParameters4[94];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.D_tube_out = RealDependentParameters4[95];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.D_smax = RealDependentParameters4[96];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.D_lmax = RealDependentParameters4[97];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.p_PCM = RealDependentParameters4[98];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.m_PCM = RealDependentParameters4[99];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.D_tube_out = RealDependentParameters4[100];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.D_smax = RealDependentParameters5[1];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.D_lmax = RealDependentParameters5[2];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.p_PCM = RealDependentParameters5[3];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.m_PCM = RealDependentParameters5[4];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.D_tube_out = RealDependentParameters5[5];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.D_smax = RealDependentParameters5[6];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.D_lmax = RealDependentParameters5[7];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.p_PCM = RealDependentParameters5[8];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.m_PCM = RealDependentParameters5[9];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.D_tube_out = RealDependentParameters5[10];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.D_smax = RealDependentParameters5[11];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.D_lmax = RealDependentParameters5[12];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.p_PCM = RealDependentParameters5[13];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.m_PCM = RealDependentParameters5[14];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.D_tube_out = RealDependentParameters5[15];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.D_smax = RealDependentParameters5[16];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.D_lmax = RealDependentParameters5[17];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.p_PCM = RealDependentParameters5[18];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.m_PCM = RealDependentParameters5[19];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.D_tube_out = RealDependentParameters5[20];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.D_smax = RealDependentParameters5[21];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.D_lmax = RealDependentParameters5[22];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.p_PCM = RealDependentParameters5[23];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.m_PCM = RealDependentParameters5[24];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.D_tube_out = RealDependentParameters5[25];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.D_smax = RealDependentParameters5[26];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.D_lmax = RealDependentParameters5[27];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.p_PCM = RealDependentParameters5[28];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.m_PCM = RealDependentParameters5[29];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.D_tube_out = RealDependentParameters5[30];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.D_smax = RealDependentParameters5[31];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.D_lmax = RealDependentParameters5[32];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.p_PCM = RealDependentParameters5[33];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.m_PCM = RealDependentParameters5[34];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.D_tube_out = RealDependentParameters5[35];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.D_smax = RealDependentParameters5[36];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.D_lmax = RealDependentParameters5[37];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.p_PCM = RealDependentParameters5[38];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.m_PCM = RealDependentParameters5[39];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.D_tube_out = RealDependentParameters5[40];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.D_smax = RealDependentParameters5[41];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.D_lmax = RealDependentParameters5[42];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.p_PCM = RealDependentParameters5[43];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.m_PCM = RealDependentParameters5[44];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.D_tube_out = RealDependentParameters5[45];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.D_smax = RealDependentParameters5[46];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.D_lmax = RealDependentParameters5[47];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.p_PCM = RealDependentParameters5[48];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.m_PCM = RealDependentParameters5[49];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.D_tube_out = RealDependentParameters5[50];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.D_smax = RealDependentParameters5[51];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.D_lmax = RealDependentParameters5[52];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.p_PCM = RealDependentParameters5[53];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.m_PCM = RealDependentParameters5[54];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.D_tube_out = RealDependentParameters5[55];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.D_smax = RealDependentParameters5[56];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.D_lmax = RealDependentParameters5[57];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.p_PCM = RealDependentParameters5[58];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.m_PCM = RealDependentParameters5[59];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.D_tube_out = RealDependentParameters5[60];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.D_smax = RealDependentParameters5[61];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.D_lmax = RealDependentParameters5[62];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.p_PCM = RealDependentParameters5[63];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.m_PCM = RealDependentParameters5[64];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.D_tube_out = RealDependentParameters5[65];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.D_smax = RealDependentParameters5[66];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.D_lmax = RealDependentParameters5[67];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.p_PCM = RealDependentParameters5[68];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.m_PCM = RealDependentParameters5[69];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.D_tube_out = RealDependentParameters5[70];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.D_smax = RealDependentParameters5[71];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.D_lmax = RealDependentParameters5[72];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.p_PCM = RealDependentParameters5[73];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.m_PCM = RealDependentParameters5[74];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.D_tube_out = RealDependentParameters5[75];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.D_smax = RealDependentParameters5[76];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.D_lmax = RealDependentParameters5[77];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.p_PCM = RealDependentParameters5[78];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.m_PCM = RealDependentParameters5[79];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.D_tube_out = RealDependentParameters5[80];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.D_smax = RealDependentParameters5[81];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.D_lmax = RealDependentParameters5[82];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.p_PCM = RealDependentParameters5[83];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.m_PCM = RealDependentParameters5[84];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.D_tube_out = RealDependentParameters5[85];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.D_smax = RealDependentParameters5[86];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.D_lmax = RealDependentParameters5[87];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.p_PCM = RealDependentParameters5[88];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.m_PCM = RealDependentParameters5[89];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.D_tube_out = RealDependentParameters5[90];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.D_smax = RealDependentParameters5[91];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.D_lmax = RealDependentParameters5[92];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.p_PCM = RealDependentParameters5[93];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.m_PCM = RealDependentParameters5[94];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.D_tube_out = RealDependentParameters5[95];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.D_smax = RealDependentParameters5[96];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.D_lmax = RealDependentParameters5[97];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.p_PCM = RealDependentParameters5[98];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.m_PCM = RealDependentParameters5[99];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.D_tube_out = RealDependentParameters5[100];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.D_smax = RealDependentParameters6[1];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.D_lmax = RealDependentParameters6[2];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.p_PCM = RealDependentParameters6[3];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.m_PCM = RealDependentParameters6[4];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.D_tube_out = RealDependentParameters6[5];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.D_smax = RealDependentParameters6[6];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.D_lmax = RealDependentParameters6[7];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.p_PCM = RealDependentParameters6[8];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.m_PCM = RealDependentParameters6[9];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.D_tube_out = RealDependentParameters6[10];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.D_smax = RealDependentParameters6[11];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.D_lmax = RealDependentParameters6[12];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.vol = RealDependentParameters6[13];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.V = RealDependentParameters6[14];
  iceStorageInternalMelt.'HTFtoPCM[1, 1]'.TubeInertia.m = RealDependentParameters6[15];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.vol = RealDependentParameters6[16];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.V = RealDependentParameters6[17];
  iceStorageInternalMelt.'HTFtoPCM[1, 2]'.TubeInertia.m = RealDependentParameters6[18];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.vol = RealDependentParameters6[19];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.V = RealDependentParameters6[20];
  iceStorageInternalMelt.'HTFtoPCM[1, 3]'.TubeInertia.m = RealDependentParameters6[21];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.vol = RealDependentParameters6[22];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.V = RealDependentParameters6[23];
  iceStorageInternalMelt.'HTFtoPCM[1, 4]'.TubeInertia.m = RealDependentParameters6[24];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.vol = RealDependentParameters6[25];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.V = RealDependentParameters6[26];
  iceStorageInternalMelt.'HTFtoPCM[1, 5]'.TubeInertia.m = RealDependentParameters6[27];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.vol = RealDependentParameters6[28];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.V = RealDependentParameters6[29];
  iceStorageInternalMelt.'HTFtoPCM[1, 6]'.TubeInertia.m = RealDependentParameters6[30];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.vol = RealDependentParameters6[31];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.V = RealDependentParameters6[32];
  iceStorageInternalMelt.'HTFtoPCM[1, 7]'.TubeInertia.m = RealDependentParameters6[33];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.vol = RealDependentParameters6[34];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.V = RealDependentParameters6[35];
  iceStorageInternalMelt.'HTFtoPCM[1, 8]'.TubeInertia.m = RealDependentParameters6[36];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.vol = RealDependentParameters6[37];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.V = RealDependentParameters6[38];
  iceStorageInternalMelt.'HTFtoPCM[1, 9]'.TubeInertia.m = RealDependentParameters6[39];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.vol = RealDependentParameters6[40];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.V = RealDependentParameters6[41];
  iceStorageInternalMelt.'HTFtoPCM[1, 10]'.TubeInertia.m = RealDependentParameters6[42];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.vol = RealDependentParameters6[43];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.V = RealDependentParameters6[44];
  iceStorageInternalMelt.'HTFtoPCM[2, 1]'.TubeInertia.m = RealDependentParameters6[45];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.vol = RealDependentParameters6[46];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.V = RealDependentParameters6[47];
  iceStorageInternalMelt.'HTFtoPCM[2, 2]'.TubeInertia.m = RealDependentParameters6[48];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.vol = RealDependentParameters6[49];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.V = RealDependentParameters6[50];
  iceStorageInternalMelt.'HTFtoPCM[2, 3]'.TubeInertia.m = RealDependentParameters6[51];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.vol = RealDependentParameters6[52];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.V = RealDependentParameters6[53];
  iceStorageInternalMelt.'HTFtoPCM[2, 4]'.TubeInertia.m = RealDependentParameters6[54];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.vol = RealDependentParameters6[55];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.V = RealDependentParameters6[56];
  iceStorageInternalMelt.'HTFtoPCM[2, 5]'.TubeInertia.m = RealDependentParameters6[57];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.vol = RealDependentParameters6[58];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.V = RealDependentParameters6[59];
  iceStorageInternalMelt.'HTFtoPCM[2, 6]'.TubeInertia.m = RealDependentParameters6[60];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.vol = RealDependentParameters6[61];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.V = RealDependentParameters6[62];
  iceStorageInternalMelt.'HTFtoPCM[2, 7]'.TubeInertia.m = RealDependentParameters6[63];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.vol = RealDependentParameters6[64];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.V = RealDependentParameters6[65];
  iceStorageInternalMelt.'HTFtoPCM[2, 8]'.TubeInertia.m = RealDependentParameters6[66];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.vol = RealDependentParameters6[67];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.V = RealDependentParameters6[68];
  iceStorageInternalMelt.'HTFtoPCM[2, 9]'.TubeInertia.m = RealDependentParameters6[69];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.vol = RealDependentParameters6[70];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.V = RealDependentParameters6[71];
  iceStorageInternalMelt.'HTFtoPCM[2, 10]'.TubeInertia.m = RealDependentParameters6[72];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.vol = RealDependentParameters6[73];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.V = RealDependentParameters6[74];
  iceStorageInternalMelt.'HTFtoPCM[3, 1]'.TubeInertia.m = RealDependentParameters6[75];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.vol = RealDependentParameters6[76];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.V = RealDependentParameters6[77];
  iceStorageInternalMelt.'HTFtoPCM[3, 2]'.TubeInertia.m = RealDependentParameters6[78];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.vol = RealDependentParameters6[79];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.V = RealDependentParameters6[80];
  iceStorageInternalMelt.'HTFtoPCM[3, 3]'.TubeInertia.m = RealDependentParameters6[81];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.vol = RealDependentParameters6[82];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.V = RealDependentParameters6[83];
  iceStorageInternalMelt.'HTFtoPCM[3, 4]'.TubeInertia.m = RealDependentParameters6[84];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.vol = RealDependentParameters6[85];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.V = RealDependentParameters6[86];
  iceStorageInternalMelt.'HTFtoPCM[3, 5]'.TubeInertia.m = RealDependentParameters6[87];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.vol = RealDependentParameters6[88];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.V = RealDependentParameters6[89];
  iceStorageInternalMelt.'HTFtoPCM[3, 6]'.TubeInertia.m = RealDependentParameters6[90];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.vol = RealDependentParameters6[91];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.V = RealDependentParameters6[92];
  iceStorageInternalMelt.'HTFtoPCM[3, 7]'.TubeInertia.m = RealDependentParameters6[93];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.vol = RealDependentParameters6[94];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.V = RealDependentParameters6[95];
  iceStorageInternalMelt.'HTFtoPCM[3, 8]'.TubeInertia.m = RealDependentParameters6[96];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.vol = RealDependentParameters6[97];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.V = RealDependentParameters6[98];
  iceStorageInternalMelt.'HTFtoPCM[3, 9]'.TubeInertia.m = RealDependentParameters6[99];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.vol = RealDependentParameters6[100];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.V = RealDependentParameters7[1];
  iceStorageInternalMelt.'HTFtoPCM[3, 10]'.TubeInertia.m = RealDependentParameters7[2];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.vol = RealDependentParameters7[3];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.V = RealDependentParameters7[4];
  iceStorageInternalMelt.'HTFtoPCM[4, 1]'.TubeInertia.m = RealDependentParameters7[5];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.vol = RealDependentParameters7[6];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.V = RealDependentParameters7[7];
  iceStorageInternalMelt.'HTFtoPCM[4, 2]'.TubeInertia.m = RealDependentParameters7[8];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.vol = RealDependentParameters7[9];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.V = RealDependentParameters7[10];
  iceStorageInternalMelt.'HTFtoPCM[4, 3]'.TubeInertia.m = RealDependentParameters7[11];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.vol = RealDependentParameters7[12];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.V = RealDependentParameters7[13];
  iceStorageInternalMelt.'HTFtoPCM[4, 4]'.TubeInertia.m = RealDependentParameters7[14];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.vol = RealDependentParameters7[15];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.V = RealDependentParameters7[16];
  iceStorageInternalMelt.'HTFtoPCM[4, 5]'.TubeInertia.m = RealDependentParameters7[17];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.vol = RealDependentParameters7[18];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.V = RealDependentParameters7[19];
  iceStorageInternalMelt.'HTFtoPCM[4, 6]'.TubeInertia.m = RealDependentParameters7[20];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.vol = RealDependentParameters7[21];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.V = RealDependentParameters7[22];
  iceStorageInternalMelt.'HTFtoPCM[4, 7]'.TubeInertia.m = RealDependentParameters7[23];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.vol = RealDependentParameters7[24];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.V = RealDependentParameters7[25];
  iceStorageInternalMelt.'HTFtoPCM[4, 8]'.TubeInertia.m = RealDependentParameters7[26];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.vol = RealDependentParameters7[27];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.V = RealDependentParameters7[28];
  iceStorageInternalMelt.'HTFtoPCM[4, 9]'.TubeInertia.m = RealDependentParameters7[29];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.vol = RealDependentParameters7[30];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.V = RealDependentParameters7[31];
  iceStorageInternalMelt.'HTFtoPCM[4, 10]'.TubeInertia.m = RealDependentParameters7[32];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.vol = RealDependentParameters7[33];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.V = RealDependentParameters7[34];
  iceStorageInternalMelt.'HTFtoPCM[5, 1]'.TubeInertia.m = RealDependentParameters7[35];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.vol = RealDependentParameters7[36];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.V = RealDependentParameters7[37];
  iceStorageInternalMelt.'HTFtoPCM[5, 2]'.TubeInertia.m = RealDependentParameters7[38];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.vol = RealDependentParameters7[39];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.V = RealDependentParameters7[40];
  iceStorageInternalMelt.'HTFtoPCM[5, 3]'.TubeInertia.m = RealDependentParameters7[41];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.vol = RealDependentParameters7[42];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.V = RealDependentParameters7[43];
  iceStorageInternalMelt.'HTFtoPCM[5, 4]'.TubeInertia.m = RealDependentParameters7[44];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.vol = RealDependentParameters7[45];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.V = RealDependentParameters7[46];
  iceStorageInternalMelt.'HTFtoPCM[5, 5]'.TubeInertia.m = RealDependentParameters7[47];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.vol = RealDependentParameters7[48];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.V = RealDependentParameters7[49];
  iceStorageInternalMelt.'HTFtoPCM[5, 6]'.TubeInertia.m = RealDependentParameters7[50];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.vol = RealDependentParameters7[51];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.V = RealDependentParameters7[52];
  iceStorageInternalMelt.'HTFtoPCM[5, 7]'.TubeInertia.m = RealDependentParameters7[53];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.vol = RealDependentParameters7[54];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.V = RealDependentParameters7[55];
  iceStorageInternalMelt.'HTFtoPCM[5, 8]'.TubeInertia.m = RealDependentParameters7[56];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.vol = RealDependentParameters7[57];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.V = RealDependentParameters7[58];
  iceStorageInternalMelt.'HTFtoPCM[5, 9]'.TubeInertia.m = RealDependentParameters7[59];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.vol = RealDependentParameters7[60];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.V = RealDependentParameters7[61];
  iceStorageInternalMelt.'HTFtoPCM[5, 10]'.TubeInertia.m = RealDependentParameters7[62];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.vol = RealDependentParameters7[63];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.V = RealDependentParameters7[64];
  iceStorageInternalMelt.'HTFtoPCM[6, 1]'.TubeInertia.m = RealDependentParameters7[65];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.vol = RealDependentParameters7[66];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.V = RealDependentParameters7[67];
  iceStorageInternalMelt.'HTFtoPCM[6, 2]'.TubeInertia.m = RealDependentParameters7[68];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.vol = RealDependentParameters7[69];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.V = RealDependentParameters7[70];
  iceStorageInternalMelt.'HTFtoPCM[6, 3]'.TubeInertia.m = RealDependentParameters7[71];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.vol = RealDependentParameters7[72];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.V = RealDependentParameters7[73];
  iceStorageInternalMelt.'HTFtoPCM[6, 4]'.TubeInertia.m = RealDependentParameters7[74];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.vol = RealDependentParameters7[75];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.V = RealDependentParameters7[76];
  iceStorageInternalMelt.'HTFtoPCM[6, 5]'.TubeInertia.m = RealDependentParameters7[77];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.vol = RealDependentParameters7[78];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.V = RealDependentParameters7[79];
  iceStorageInternalMelt.'HTFtoPCM[6, 6]'.TubeInertia.m = RealDependentParameters7[80];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.vol = RealDependentParameters7[81];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.V = RealDependentParameters7[82];
  iceStorageInternalMelt.'HTFtoPCM[6, 7]'.TubeInertia.m = RealDependentParameters7[83];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.vol = RealDependentParameters7[84];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.V = RealDependentParameters7[85];
  iceStorageInternalMelt.'HTFtoPCM[6, 8]'.TubeInertia.m = RealDependentParameters7[86];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.vol = RealDependentParameters7[87];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.V = RealDependentParameters7[88];
  iceStorageInternalMelt.'HTFtoPCM[6, 9]'.TubeInertia.m = RealDependentParameters7[89];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.vol = RealDependentParameters7[90];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.V = RealDependentParameters7[91];
  iceStorageInternalMelt.'HTFtoPCM[6, 10]'.TubeInertia.m = RealDependentParameters7[92];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.vol = RealDependentParameters7[93];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.V = RealDependentParameters7[94];
  iceStorageInternalMelt.'HTFtoPCM[7, 1]'.TubeInertia.m = RealDependentParameters7[95];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.vol = RealDependentParameters7[96];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.V = RealDependentParameters7[97];
  iceStorageInternalMelt.'HTFtoPCM[7, 2]'.TubeInertia.m = RealDependentParameters7[98];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.vol = RealDependentParameters7[99];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.V = RealDependentParameters7[100];
  iceStorageInternalMelt.'HTFtoPCM[7, 3]'.TubeInertia.m = RealDependentParameters8[1];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.vol = RealDependentParameters8[2];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.V = RealDependentParameters8[3];
  iceStorageInternalMelt.'HTFtoPCM[7, 4]'.TubeInertia.m = RealDependentParameters8[4];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.vol = RealDependentParameters8[5];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.V = RealDependentParameters8[6];
  iceStorageInternalMelt.'HTFtoPCM[7, 5]'.TubeInertia.m = RealDependentParameters8[7];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.vol = RealDependentParameters8[8];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.V = RealDependentParameters8[9];
  iceStorageInternalMelt.'HTFtoPCM[7, 6]'.TubeInertia.m = RealDependentParameters8[10];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.vol = RealDependentParameters8[11];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.V = RealDependentParameters8[12];
  iceStorageInternalMelt.'HTFtoPCM[7, 7]'.TubeInertia.m = RealDependentParameters8[13];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.vol = RealDependentParameters8[14];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.V = RealDependentParameters8[15];
  iceStorageInternalMelt.'HTFtoPCM[7, 8]'.TubeInertia.m = RealDependentParameters8[16];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.vol = RealDependentParameters8[17];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.V = RealDependentParameters8[18];
  iceStorageInternalMelt.'HTFtoPCM[7, 9]'.TubeInertia.m = RealDependentParameters8[19];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.vol = RealDependentParameters8[20];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.V = RealDependentParameters8[21];
  iceStorageInternalMelt.'HTFtoPCM[7, 10]'.TubeInertia.m = RealDependentParameters8[22];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.vol = RealDependentParameters8[23];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.V = RealDependentParameters8[24];
  iceStorageInternalMelt.'HTFtoPCM[8, 1]'.TubeInertia.m = RealDependentParameters8[25];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.vol = RealDependentParameters8[26];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.V = RealDependentParameters8[27];
  iceStorageInternalMelt.'HTFtoPCM[8, 2]'.TubeInertia.m = RealDependentParameters8[28];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.vol = RealDependentParameters8[29];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.V = RealDependentParameters8[30];
  iceStorageInternalMelt.'HTFtoPCM[8, 3]'.TubeInertia.m = RealDependentParameters8[31];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.vol = RealDependentParameters8[32];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.V = RealDependentParameters8[33];
  iceStorageInternalMelt.'HTFtoPCM[8, 4]'.TubeInertia.m = RealDependentParameters8[34];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.vol = RealDependentParameters8[35];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.V = RealDependentParameters8[36];
  iceStorageInternalMelt.'HTFtoPCM[8, 5]'.TubeInertia.m = RealDependentParameters8[37];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.vol = RealDependentParameters8[38];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.V = RealDependentParameters8[39];
  iceStorageInternalMelt.'HTFtoPCM[8, 6]'.TubeInertia.m = RealDependentParameters8[40];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.vol = RealDependentParameters8[41];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.V = RealDependentParameters8[42];
  iceStorageInternalMelt.'HTFtoPCM[8, 7]'.TubeInertia.m = RealDependentParameters8[43];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.vol = RealDependentParameters8[44];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.V = RealDependentParameters8[45];
  iceStorageInternalMelt.'HTFtoPCM[8, 8]'.TubeInertia.m = RealDependentParameters8[46];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.vol = RealDependentParameters8[47];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.V = RealDependentParameters8[48];
  iceStorageInternalMelt.'HTFtoPCM[8, 9]'.TubeInertia.m = RealDependentParameters8[49];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.vol = RealDependentParameters8[50];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.V = RealDependentParameters8[51];
  iceStorageInternalMelt.'HTFtoPCM[8, 10]'.TubeInertia.m = RealDependentParameters8[52];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.vol = RealDependentParameters8[53];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.V = RealDependentParameters8[54];
  iceStorageInternalMelt.'HTFtoPCM[9, 1]'.TubeInertia.m = RealDependentParameters8[55];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.vol = RealDependentParameters8[56];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.V = RealDependentParameters8[57];
  iceStorageInternalMelt.'HTFtoPCM[9, 2]'.TubeInertia.m = RealDependentParameters8[58];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.vol = RealDependentParameters8[59];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.V = RealDependentParameters8[60];
  iceStorageInternalMelt.'HTFtoPCM[9, 3]'.TubeInertia.m = RealDependentParameters8[61];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.vol = RealDependentParameters8[62];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.V = RealDependentParameters8[63];
  iceStorageInternalMelt.'HTFtoPCM[9, 4]'.TubeInertia.m = RealDependentParameters8[64];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.vol = RealDependentParameters8[65];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.V = RealDependentParameters8[66];
  iceStorageInternalMelt.'HTFtoPCM[9, 5]'.TubeInertia.m = RealDependentParameters8[67];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.vol = RealDependentParameters8[68];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.V = RealDependentParameters8[69];
  iceStorageInternalMelt.'HTFtoPCM[9, 6]'.TubeInertia.m = RealDependentParameters8[70];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.vol = RealDependentParameters8[71];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.V = RealDependentParameters8[72];
  iceStorageInternalMelt.'HTFtoPCM[9, 7]'.TubeInertia.m = RealDependentParameters8[73];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.vol = RealDependentParameters8[74];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.V = RealDependentParameters8[75];
  iceStorageInternalMelt.'HTFtoPCM[9, 8]'.TubeInertia.m = RealDependentParameters8[76];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.vol = RealDependentParameters8[77];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.V = RealDependentParameters8[78];
  iceStorageInternalMelt.'HTFtoPCM[9, 9]'.TubeInertia.m = RealDependentParameters8[79];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.vol = RealDependentParameters8[80];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.V = RealDependentParameters8[81];
  iceStorageInternalMelt.'HTFtoPCM[9, 10]'.TubeInertia.m = RealDependentParameters8[82];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.vol = RealDependentParameters8[83];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.V = RealDependentParameters8[84];
  iceStorageInternalMelt.'HTFtoPCM[10, 1]'.TubeInertia.m = RealDependentParameters8[85];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.vol = RealDependentParameters8[86];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.V = RealDependentParameters8[87];
  iceStorageInternalMelt.'HTFtoPCM[10, 2]'.TubeInertia.m = RealDependentParameters8[88];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.vol = RealDependentParameters8[89];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.V = RealDependentParameters8[90];
  iceStorageInternalMelt.'HTFtoPCM[10, 3]'.TubeInertia.m = RealDependentParameters8[91];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.vol = RealDependentParameters8[92];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.V = RealDependentParameters8[93];
  iceStorageInternalMelt.'HTFtoPCM[10, 4]'.TubeInertia.m = RealDependentParameters8[94];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.vol = RealDependentParameters8[95];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.V = RealDependentParameters8[96];
  iceStorageInternalMelt.'HTFtoPCM[10, 5]'.TubeInertia.m = RealDependentParameters8[97];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.vol = RealDependentParameters8[98];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.V = RealDependentParameters8[99];
  iceStorageInternalMelt.'HTFtoPCM[10, 6]'.TubeInertia.m = RealDependentParameters8[100];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.vol = RealDependentParameters9[1];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.V = RealDependentParameters9[2];
  iceStorageInternalMelt.'HTFtoPCM[10, 7]'.TubeInertia.m = RealDependentParameters9[3];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.vol = RealDependentParameters9[4];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.V = RealDependentParameters9[5];
  iceStorageInternalMelt.'HTFtoPCM[10, 8]'.TubeInertia.m = RealDependentParameters9[6];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.vol = RealDependentParameters9[7];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.V = RealDependentParameters9[8];
  iceStorageInternalMelt.'HTFtoPCM[10, 9]'.TubeInertia.m = RealDependentParameters9[9];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.vol = RealDependentParameters9[10];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.V = RealDependentParameters9[11];
  iceStorageInternalMelt.'HTFtoPCM[10, 10]'.TubeInertia.m = RealDependentParameters9[12];
  iceStorageInternalMelt.pipe.diameter = RealDependentParameters9[13];
  iceStorageInternalMelt.pipe.crossArea = RealDependentParameters9[14];
  iceStorageInternalMelt.pipe.perimeter = RealDependentParameters9[15];
  iceStorageInternalMelt.pipe.V = RealDependentParameters9[16];
  iceStorageInternalMelt.pipe.'fluidVolumes[1]' = RealDependentParameters9[17];
  iceStorageInternalMelt.pipe.'fluidVolumes[2]' = RealDependentParameters9[18];
  iceStorageInternalMelt.pipe.'fluidVolumes[3]' = RealDependentParameters9[19];
  iceStorageInternalMelt.pipe.'fluidVolumes[4]' = RealDependentParameters9[20];
  iceStorageInternalMelt.pipe.'fluidVolumes[5]' = RealDependentParameters9[21];
  iceStorageInternalMelt.pipe.'fluidVolumes[6]' = RealDependentParameters9[22];
  iceStorageInternalMelt.pipe.'fluidVolumes[7]' = RealDependentParameters9[23];
  iceStorageInternalMelt.pipe.'fluidVolumes[8]' = RealDependentParameters9[24];
  iceStorageInternalMelt.pipe.'fluidVolumes[9]' = RealDependentParameters9[25];
  iceStorageInternalMelt.pipe.'fluidVolumes[10]' = RealDependentParameters9[26];
  iceStorageInternalMelt.pipe.h_start = RealDependentParameters9[27];
  iceStorageInternalMelt.pipe.'crossAreas[1]' = RealDependentParameters9[28];
  iceStorageInternalMelt.pipe.'crossAreas[2]' = RealDependentParameters9[29];
  iceStorageInternalMelt.pipe.'crossAreas[3]' = RealDependentParameters9[30];
  iceStorageInternalMelt.pipe.'crossAreas[4]' = RealDependentParameters9[31];
  iceStorageInternalMelt.pipe.'crossAreas[5]' = RealDependentParameters9[32];
  iceStorageInternalMelt.pipe.'crossAreas[6]' = RealDependentParameters9[33];
  iceStorageInternalMelt.pipe.'crossAreas[7]' = RealDependentParameters9[34];
  iceStorageInternalMelt.pipe.'crossAreas[8]' = RealDependentParameters9[35];
  iceStorageInternalMelt.pipe.'crossAreas[9]' = RealDependentParameters9[36];
  iceStorageInternalMelt.pipe.'crossAreas[10]' = RealDependentParameters9[37];
  iceStorageInternalMelt.pipe.'dimensions[1]' = RealDependentParameters9[38];
  iceStorageInternalMelt.pipe.'dimensions[2]' = RealDependentParameters9[39];
  iceStorageInternalMelt.pipe.'dimensions[3]' = RealDependentParameters9[40];
  iceStorageInternalMelt.pipe.'dimensions[4]' = RealDependentParameters9[41];
  iceStorageInternalMelt.pipe.'dimensions[5]' = RealDependentParameters9[42];
  iceStorageInternalMelt.pipe.'dimensions[6]' = RealDependentParameters9[43];
  iceStorageInternalMelt.pipe.'dimensions[7]' = RealDependentParameters9[44];
  iceStorageInternalMelt.pipe.'dimensions[8]' = RealDependentParameters9[45];
  iceStorageInternalMelt.pipe.'dimensions[9]' = RealDependentParameters9[46];
  iceStorageInternalMelt.pipe.'dimensions[10]' = RealDependentParameters9[47];
  iceStorageInternalMelt.pipe.'roughnesses[1]' = RealDependentParameters9[48];
  iceStorageInternalMelt.pipe.'roughnesses[2]' = RealDependentParameters9[49];
  iceStorageInternalMelt.pipe.'roughnesses[3]' = RealDependentParameters9[50];
  iceStorageInternalMelt.pipe.'roughnesses[4]' = RealDependentParameters9[51];
  iceStorageInternalMelt.pipe.'roughnesses[5]' = RealDependentParameters9[52];
  iceStorageInternalMelt.pipe.'roughnesses[6]' = RealDependentParameters9[53];
  iceStorageInternalMelt.pipe.'roughnesses[7]' = RealDependentParameters9[54];
  iceStorageInternalMelt.pipe.'roughnesses[8]' = RealDependentParameters9[55];
  iceStorageInternalMelt.pipe.'roughnesses[9]' = RealDependentParameters9[56];
  iceStorageInternalMelt.pipe.'roughnesses[10]' = RealDependentParameters9[57];
  iceStorageInternalMelt.pipe.flowModel.g = RealDependentParameters9[58];
  iceStorageInternalMelt.pipe.flowModel.dp_nominal = RealDependentParameters9[59];
  iceStorageInternalMelt.pipe.flowModel.m_flow_nominal = RealDependentParameters9[60];
  iceStorageInternalMelt.pipe.flowModel.m_flow_small = RealDependentParameters9[61];
  iceStorageInternalMelt.pipe.heatTransfer.T_ambient = RealDependentParameters9[62];
  iceStorageInternalMelt.volumeFlowRate.m_flow_small = RealDependentParameters9[63];
  iceStorageInternalMelt.volumeFlowRate.a = RealDependentParameters9[64];
  iceStorageInternalMelt.volumeFlowRate.b = RealDependentParameters9[65];
  iceStorageInternalMelt.storageWall.T_Wall_start = RealDependentParameters9[66];
  iceStorageInternalMelt.storageWall.h = RealDependentParameters9[67];
  iceStorageInternalMelt.storageWall.w = RealDependentParameters9[68];
  iceStorageInternalMelt.storageWall.e = RealDependentParameters9[69];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.V = RealDependentParameters9[70];
  iceStorageInternalMelt.storageWall.'sideInertia[1]'.m = RealDependentParameters9[71];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.V = RealDependentParameters9[72];
  iceStorageInternalMelt.storageWall.'sideInertia[2]'.m = RealDependentParameters9[73];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.V = RealDependentParameters9[74];
  iceStorageInternalMelt.storageWall.'topInertia[1]'.m = RealDependentParameters9[75];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.V = RealDependentParameters9[76];
  iceStorageInternalMelt.storageWall.'topInertia[2]'.m = RealDependentParameters9[77];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.L = RealDependentParameters9[78];
  iceStorageInternalMelt.storageWall.'sideCond2[1]'.A = RealDependentParameters9[79];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.L = RealDependentParameters9[80];
  iceStorageInternalMelt.storageWall.'sideCond2[2]'.A = RealDependentParameters9[81];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.L = RealDependentParameters9[82];
  iceStorageInternalMelt.storageWall.'sideCond1[1]'.A = RealDependentParameters9[83];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.L = RealDependentParameters9[84];
  iceStorageInternalMelt.storageWall.'sideCond1[2]'.A = RealDependentParameters9[85];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.L = RealDependentParameters9[86];
  iceStorageInternalMelt.storageWall.'topCond1[1]'.A = RealDependentParameters9[87];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.L = RealDependentParameters9[88];
  iceStorageInternalMelt.storageWall.'topCond1[2]'.A = RealDependentParameters9[89];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.L = RealDependentParameters9[90];
  iceStorageInternalMelt.storageWall.'topCond2[1]'.A = RealDependentParameters9[91];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.L = RealDependentParameters9[92];
  iceStorageInternalMelt.storageWall.'topCond2[2]'.A = RealDependentParameters9[93];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.V = RealDependentParameters9[94];
  iceStorageInternalMelt.storageWall.'frontInertia[1]'.m = RealDependentParameters9[95];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.V = RealDependentParameters9[96];
  iceStorageInternalMelt.storageWall.'frontInertia[2]'.m = RealDependentParameters9[97];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.L = RealDependentParameters9[98];
  iceStorageInternalMelt.storageWall.'frontCond1[1]'.A = RealDependentParameters9[99];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.L = RealDependentParameters9[100];
  iceStorageInternalMelt.storageWall.'frontCond1[2]'.A = RealDependentParameters10[1];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.L = RealDependentParameters10[2];
  iceStorageInternalMelt.storageWall.'frontCond2[1]'.A = RealDependentParameters10[3];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.L = RealDependentParameters10[4];
  iceStorageInternalMelt.storageWall.'frontCond2[2]'.A = RealDependentParameters10[5];
  iceStorageInternalMelt.D_tube_mid = RealDependentParameters10[6];
  iceStorageInternalMelt.m_PCM = RealDependentParameters10[7];
  iceStorageInternalMelt.k_PCMs = RealDependentParameters10[8];
  iceStorageInternalMelt.h_PCMl = RealDependentParameters10[9];
  iceStorageInternalMelt.k_PCMl = RealDependentParameters10[10];
  iceStorageInternalMelt.h_HTF = RealDependentParameters10[11];
  outlet_HTF.medium.d = RealDependentParameters10[12];
  outlet_HTF.medium.u = RealDependentParameters10[13];
  outlet_HTF.medium.T_degC = RealDependentParameters10[14];
  outlet_HTF.medium.p_bar = RealDependentParameters10[15];
  outlet_HTF.'ports[1]'.h_outflow = RealDependentParameters10[16];
  outlet_HTF.d = RealDependentParameters10[17];
  outlet_HTF.h = RealDependentParameters10[18];
  m_inlet_HTF_T.port.h_outflow = RealDependentParameters10[19];
  m_outlet_HTF_T.port.h_outflow = RealDependentParameters10[20];
  iceStorageInternalMelt.Charging = BooleanVariables1[1];
  iceStorageInternalMelt.Charged = BooleanVariables1[2];
  iceStorageInternalMelt.'ice_WaterRing[1, 1]'.Charging = BooleanVariables1[3];
  iceStorageInternalMelt.'ice_WaterRing[1, 2]'.Charging = BooleanVariables1[4];
  iceStorageInternalMelt.'ice_WaterRing[1, 3]'.Charging = BooleanVariables1[5];
  iceStorageInternalMelt.'ice_WaterRing[1, 4]'.Charging = BooleanVariables1[6];
  iceStorageInternalMelt.'ice_WaterRing[1, 5]'.Charging = BooleanVariables1[7];
  iceStorageInternalMelt.'ice_WaterRing[1, 6]'.Charging = BooleanVariables1[8];
  iceStorageInternalMelt.'ice_WaterRing[1, 7]'.Charging = BooleanVariables1[9];
  iceStorageInternalMelt.'ice_WaterRing[1, 8]'.Charging = BooleanVariables1[10];
  iceStorageInternalMelt.'ice_WaterRing[1, 9]'.Charging = BooleanVariables1[11];
  iceStorageInternalMelt.'ice_WaterRing[1, 10]'.Charging = BooleanVariables1[12];
  iceStorageInternalMelt.'ice_WaterRing[2, 1]'.Charging = BooleanVariables1[13];
  iceStorageInternalMelt.'ice_WaterRing[2, 2]'.Charging = BooleanVariables1[14];
  iceStorageInternalMelt.'ice_WaterRing[2, 3]'.Charging = BooleanVariables1[15];
  iceStorageInternalMelt.'ice_WaterRing[2, 4]'.Charging = BooleanVariables1[16];
  iceStorageInternalMelt.'ice_WaterRing[2, 5]'.Charging = BooleanVariables1[17];
  iceStorageInternalMelt.'ice_WaterRing[2, 6]'.Charging = BooleanVariables1[18];
  iceStorageInternalMelt.'ice_WaterRing[2, 7]'.Charging = BooleanVariables1[19];
  iceStorageInternalMelt.'ice_WaterRing[2, 8]'.Charging = BooleanVariables1[20];
  iceStorageInternalMelt.'ice_WaterRing[2, 9]'.Charging = BooleanVariables1[21];
  iceStorageInternalMelt.'ice_WaterRing[2, 10]'.Charging = BooleanVariables1[22];
  iceStorageInternalMelt.'ice_WaterRing[3, 1]'.Charging = BooleanVariables1[23];
  iceStorageInternalMelt.'ice_WaterRing[3, 2]'.Charging = BooleanVariables1[24];
  iceStorageInternalMelt.'ice_WaterRing[3, 3]'.Charging = BooleanVariables1[25];
  iceStorageInternalMelt.'ice_WaterRing[3, 4]'.Charging = BooleanVariables1[26];
  iceStorageInternalMelt.'ice_WaterRing[3, 5]'.Charging = BooleanVariables1[27];
  iceStorageInternalMelt.'ice_WaterRing[3, 6]'.Charging = BooleanVariables1[28];
  iceStorageInternalMelt.'ice_WaterRing[3, 7]'.Charging = BooleanVariables1[29];
  iceStorageInternalMelt.'ice_WaterRing[3, 8]'.Charging = BooleanVariables1[30];
  iceStorageInternalMelt.'ice_WaterRing[3, 9]'.Charging = BooleanVariables1[31];
  iceStorageInternalMelt.'ice_WaterRing[3, 10]'.Charging = BooleanVariables1[32];
  iceStorageInternalMelt.'ice_WaterRing[4, 1]'.Charging = BooleanVariables1[33];
  iceStorageInternalMelt.'ice_WaterRing[4, 2]'.Charging = BooleanVariables1[34];
  iceStorageInternalMelt.'ice_WaterRing[4, 3]'.Charging = BooleanVariables1[35];
  iceStorageInternalMelt.'ice_WaterRing[4, 4]'.Charging = BooleanVariables1[36];
  iceStorageInternalMelt.'ice_WaterRing[4, 5]'.Charging = BooleanVariables1[37];
  iceStorageInternalMelt.'ice_WaterRing[4, 6]'.Charging = BooleanVariables1[38];
  iceStorageInternalMelt.'ice_WaterRing[4, 7]'.Charging = BooleanVariables1[39];
  iceStorageInternalMelt.'ice_WaterRing[4, 8]'.Charging = BooleanVariables1[40];
  iceStorageInternalMelt.'ice_WaterRing[4, 9]'.Charging = BooleanVariables1[41];
  iceStorageInternalMelt.'ice_WaterRing[4, 10]'.Charging = BooleanVariables1[42];
  iceStorageInternalMelt.'ice_WaterRing[5, 1]'.Charging = BooleanVariables1[43];
  iceStorageInternalMelt.'ice_WaterRing[5, 2]'.Charging = BooleanVariables1[44];
  iceStorageInternalMelt.'ice_WaterRing[5, 3]'.Charging = BooleanVariables1[45];
  iceStorageInternalMelt.'ice_WaterRing[5, 4]'.Charging = BooleanVariables1[46];
  iceStorageInternalMelt.'ice_WaterRing[5, 5]'.Charging = BooleanVariables1[47];
  iceStorageInternalMelt.'ice_WaterRing[5, 6]'.Charging = BooleanVariables1[48];
  iceStorageInternalMelt.'ice_WaterRing[5, 7]'.Charging = BooleanVariables1[49];
  iceStorageInternalMelt.'ice_WaterRing[5, 8]'.Charging = BooleanVariables1[50];
  iceStorageInternalMelt.'ice_WaterRing[5, 9]'.Charging = BooleanVariables1[51];
  iceStorageInternalMelt.'ice_WaterRing[5, 10]'.Charging = BooleanVariables1[52];
  iceStorageInternalMelt.'ice_WaterRing[6, 1]'.Charging = BooleanVariables1[53];
  iceStorageInternalMelt.'ice_WaterRing[6, 2]'.Charging = BooleanVariables1[54];
  iceStorageInternalMelt.'ice_WaterRing[6, 3]'.Charging = BooleanVariables1[55];
  iceStorageInternalMelt.'ice_WaterRing[6, 4]'.Charging = BooleanVariables1[56];
  iceStorageInternalMelt.'ice_WaterRing[6, 5]'.Charging = BooleanVariables1[57];
  iceStorageInternalMelt.'ice_WaterRing[6, 6]'.Charging = BooleanVariables1[58];
  iceStorageInternalMelt.'ice_WaterRing[6, 7]'.Charging = BooleanVariables1[59];
  iceStorageInternalMelt.'ice_WaterRing[6, 8]'.Charging = BooleanVariables1[60];
  iceStorageInternalMelt.'ice_WaterRing[6, 9]'.Charging = BooleanVariables1[61];
  iceStorageInternalMelt.'ice_WaterRing[6, 10]'.Charging = BooleanVariables1[62];
  iceStorageInternalMelt.'ice_WaterRing[7, 1]'.Charging = BooleanVariables1[63];
  iceStorageInternalMelt.'ice_WaterRing[7, 2]'.Charging = BooleanVariables1[64];
  iceStorageInternalMelt.'ice_WaterRing[7, 3]'.Charging = BooleanVariables1[65];
  iceStorageInternalMelt.'ice_WaterRing[7, 4]'.Charging = BooleanVariables1[66];
  iceStorageInternalMelt.'ice_WaterRing[7, 5]'.Charging = BooleanVariables1[67];
  iceStorageInternalMelt.'ice_WaterRing[7, 6]'.Charging = BooleanVariables1[68];
  iceStorageInternalMelt.'ice_WaterRing[7, 7]'.Charging = BooleanVariables1[69];
  iceStorageInternalMelt.'ice_WaterRing[7, 8]'.Charging = BooleanVariables1[70];
  iceStorageInternalMelt.'ice_WaterRing[7, 9]'.Charging = BooleanVariables1[71];
  iceStorageInternalMelt.'ice_WaterRing[7, 10]'.Charging = BooleanVariables1[72];
  iceStorageInternalMelt.'ice_WaterRing[8, 1]'.Charging = BooleanVariables1[73];
  iceStorageInternalMelt.'ice_WaterRing[8, 2]'.Charging = BooleanVariables1[74];
  iceStorageInternalMelt.'ice_WaterRing[8, 3]'.Charging = BooleanVariables1[75];
  iceStorageInternalMelt.'ice_WaterRing[8, 4]'.Charging = BooleanVariables1[76];
  iceStorageInternalMelt.'ice_WaterRing[8, 5]'.Charging = BooleanVariables1[77];
  iceStorageInternalMelt.'ice_WaterRing[8, 6]'.Charging = BooleanVariables1[78];
  iceStorageInternalMelt.'ice_WaterRing[8, 7]'.Charging = BooleanVariables1[79];
  iceStorageInternalMelt.'ice_WaterRing[8, 8]'.Charging = BooleanVariables1[80];
  iceStorageInternalMelt.'ice_WaterRing[8, 9]'.Charging = BooleanVariables1[81];
  iceStorageInternalMelt.'ice_WaterRing[8, 10]'.Charging = BooleanVariables1[82];
  iceStorageInternalMelt.'ice_WaterRing[9, 1]'.Charging = BooleanVariables1[83];
  iceStorageInternalMelt.'ice_WaterRing[9, 2]'.Charging = BooleanVariables1[84];
  iceStorageInternalMelt.'ice_WaterRing[9, 3]'.Charging = BooleanVariables1[85];
  iceStorageInternalMelt.'ice_WaterRing[9, 4]'.Charging = BooleanVariables1[86];
  iceStorageInternalMelt.'ice_WaterRing[9, 5]'.Charging = BooleanVariables1[87];
  iceStorageInternalMelt.'ice_WaterRing[9, 6]'.Charging = BooleanVariables1[88];
  iceStorageInternalMelt.'ice_WaterRing[9, 7]'.Charging = BooleanVariables1[89];
  iceStorageInternalMelt.'ice_WaterRing[9, 8]'.Charging = BooleanVariables1[90];
  iceStorageInternalMelt.'ice_WaterRing[9, 9]'.Charging = BooleanVariables1[91];
  iceStorageInternalMelt.'ice_WaterRing[9, 10]'.Charging = BooleanVariables1[92];
  iceStorageInternalMelt.'ice_WaterRing[10, 1]'.Charging = BooleanVariables1[93];
  iceStorageInternalMelt.'ice_WaterRing[10, 2]'.Charging = BooleanVariables1[94];
  iceStorageInternalMelt.'ice_WaterRing[10, 3]'.Charging = BooleanVariables1[95];
  iceStorageInternalMelt.'ice_WaterRing[10, 4]'.Charging = BooleanVariables1[96];
  iceStorageInternalMelt.'ice_WaterRing[10, 5]'.Charging = BooleanVariables1[97];
  iceStorageInternalMelt.'ice_WaterRing[10, 6]'.Charging = BooleanVariables1[98];
  iceStorageInternalMelt.'ice_WaterRing[10, 7]'.Charging = BooleanVariables1[99];
  iceStorageInternalMelt.'ice_WaterRing[10, 8]'.Charging = BooleanVariables1[100];
  iceStorageInternalMelt.'ice_WaterRing[10, 9]'.Charging = BooleanVariables2[1];
  iceStorageInternalMelt.'ice_WaterRing[10, 10]'.Charging = BooleanVariables2[2];
  annotation (__Dymola_FMUImportVersion="Dymola 2017 FD01", experiment(StartTime=0.0, StopTime=60000.0, Tolerance=0.0001),
    Icon(graphics={
      Rectangle(
        extent={{-100,100},{100,-100}},
        lineColor={95,95,95},
        fillColor={255,255,255},
        fillPattern=FillPattern.Solid,
        lineThickness=0.5),
      Text(
        extent={{-70,20},{70,-20}},
        lineColor={0,0,255},
        textString="%name"),
      Text(
        extent={{-70,-72},{70,-94}},
        lineColor={95,95,95},
        textString="FMI 1.0 CS Import")}),
Documentation(info="<html>
<h4>ModelDescription Attributes</h4>
<ul>
<li>fmiVersion = 1.0</li>
<li>modelName = Modelica_IK4_TEKNIKER.DCOL.Generation.LatentStorages.FMI.IceStorage_Dym</li>
<li>generationTool = Dymola Version 2017 FD01 (64-bit), 2016-10-11 (requires license to execute)</li>
<li>generationDateAndTime = 2017-06-02T09:59:59Z</li>
</ul>
<p><br><b>Co-Simulation Attributes</b></p>
<ul>
<li>canHandleVariableCommunicationStepSize = true</li>
<li>canHandleEvents = true</li>
<li>canRejectSteps = false</li>
<li>canInterpolateInputs = true</li>
<li>maxOutputDerivativeOrder = 1</li>
<li>canRunAsynchronuously = false</li>
<li>canSignalEvents = false</li>
<li>canBeInstantiatedOnlyOncePerProcess = false</li>
<li>canNotUseMemoryManagementFunctions = false</li>
</ul>
</html>",
      revisions="<html>
<p>2016-05-16 <a href=\"mailto: eduardo.ubieta@tekniker.es\">Eduardo Ubieta</a></a> (IK4-TEKNIKER): First implementation</p>
<p><b>Copyright &copy; <a href=\"http://www.tekniker.es/en\">IK4-TEKNIKER</a></b></p>
</html>"));
end IceStorage_FMU;
